@@ -22,7 +22,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <dcopserver.h>
 #include <dcopsignals.h>
 
-template class QList<DCOPSignalConnection>;
+template class QPtrList<DCOPSignalConnection>;
 
 DCOPSignals::DCOPSignals()
 {
@@ -32,7 +32,7 @@ DCOPSignals::DCOPSignals()
 /**
  * Client "conn" emits the signal "fun" with "data" as arguments.
  *
- * If "excludeSelf" is true, signal is never send to "conn" itself.
+ * If "excludeSelf" is true, signal is never sent to "conn" itself.
  */
 void
 DCOPSignals::emitSignal( DCOPConnection *conn, const QCString &_fun, const QByteArray &data, bool excludeSelf)
