@@ -26,11 +26,13 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 class DCOPClient;
 class DCOPStubPrivate;
 
+#include <stdlib.h>
+
 #include <qstring.h>
 
 /**
 * Abstract base class for dcop stubs as created by the
-* dcopidl2cpp compiler
+* dcopidl2cpp compiler.
 *
 */
 
@@ -39,39 +41,48 @@ class DCOPStub
 public:
     /**
        Creates a DCOPStub for application @p app and object @p obj
+       @param app the application id
+       @param obj the object id
      */
     DCOPStub( const QCString& app, const QCString& obj );
 
     /** 
       Creates a DCOPStub for application @p app and object @p obj
        that operates on the DCOPClient @p client
+       @param client the DCOPClient
+       @param app the application id
+       @param obj the object id
      */
     DCOPStub( DCOPClient* client, const QCString& app, const QCString& obj );
     virtual ~DCOPStub();
 
     /**
        Return the application id.
+       @return the application id
      */
     QCString app() const;
     /**
        Return the object  id.
+       @return the object id
      */
     QCString obj() const;
 
     enum Status{ CallSucceeded, CallFailed };
     /**
      * Return the status of the last call, either @p CallSucceeded or
-     * @p CallFailed
+     * @p CallFailed.
      *
-     *See @ref ok();
+     * @return the status of the last call
+     * @see ok();
      */
     Status status() const;
 
 
     /**
-     *Return whether no error occured
+     * Return whether no error occured,
      *
-     * See @ref status();
+     * @return true if the last call was successful, false otherwise
+     * @see status();
      */
     bool ok()  const;
 
@@ -79,6 +90,8 @@ protected:
 
     /**
        Sets the status to status. Possible values are 'CallSucceeded' and 'CallFailed'
+       @param _status the new status
+       @see status()
      */
     void setStatus( Status _status );
 
@@ -91,9 +104,25 @@ protected:
     /** 
       The dcopClient this stub operates on. Either the specific one
        specified in the constructor or DCOPClient::mainClient.
+       @return the stub's DCOPClient
     */
     DCOPClient* dcopClient();
 
+    /**
+     * @internal
+     * Never use. Used only for default ctors of inherited stubs,
+     * because of the way ctors of virtual base classes work.
+     * Otherwise dcopidl2cpp would have to call ctors of all, even
+     * indirect, bases.
+     * @since 3.1
+     */
+    enum never_use_t { never_use };
+    /**
+     * @internal
+     * @since 3.1
+     */
+    DCOPStub( never_use_t ) { abort(); }
+    
 private:
     QCString m_app;
     QCString m_obj;
