@@ -6,14 +6,14 @@
    the KDE addressbook
 
    $ Author: Mirko Boehm $
-   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Copyright: (C) 1996-2001, Mirko Boehm $
    $ Contact: mirko@kde.org
          http://www.kde.org $
    $ License: GPL with the following explicit clarification:
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: kabapi.cc,v 1.23 2000/11/16 03:04:21 mirko Exp $	 
+   $Id: kabapi.cc,v 1.27 2001/08/31 07:35:04 mueller Exp $
 */
 
 #include "kabapi.h"
@@ -27,7 +27,7 @@
 
 #ifdef KAB_KDEBUG_AREA
 #undef KAB_KDEBUG_AREA
-#endif 
+#endif
 
 #define KAB_KDEBUG_AREA 800
 
@@ -39,11 +39,18 @@ KabAPI::KabAPI(QWidget* parent, const char* name)
     listbox(new KListBox(this)),
     selection(-1)
 {
-  CHECK_PTR(listbox);
+  Q_CHECK_PTR(listbox);
   setMainWidget(listbox);
   showButtonApply(false);
   enableButtonSeparator(true);
   connect(listbox, SIGNAL(highlighted(int)), SLOT(entrySelected(int)));
+  connect(listbox, SIGNAL(doubleClicked ( QListBoxItem * )),SLOT(slotDoubleClicked ( QListBoxItem * )));
+}
+
+
+void KabAPI::slotDoubleClicked ( QListBoxItem * )
+{
+    accept();
 }
 
 int KabAPI::exec()
@@ -75,11 +82,11 @@ int KabAPI::exec()
 	  return -1;
 	}
     }
-}  
-    
+}
+
 AddressBook::ErrorCode KabAPI::init()
 {
-  // ############################################################################  
+  // ############################################################################
   book=new AddressBook(0, "KABAPI::book", true);  //change parent from "this" to "0" //dsweet
   if(book->getState()==AddressBook::NoError)
     {
@@ -89,7 +96,7 @@ AddressBook::ErrorCode KabAPI::init()
     } else {
       return AddressBook::InternError;
     }
-  // ############################################################################  
+  // ############################################################################
 }
 
 AddressBook::ErrorCode KabAPI::getEntry(AddressBook::Entry& entry, KabKey& key)
@@ -115,13 +122,13 @@ AddressBook::ErrorCode KabAPI::getEntry(AddressBook::Entry& entry, KabKey& key)
     } else {
       return AddressBook::InternError;
     }
-  // ############################################################################  
+  // ############################################################################
 }
 
 AddressBook::ErrorCode KabAPI::add(const AddressBook::Entry& entry, KabKey& key,
 				   bool update)
 {
-  // ############################################################################  
+  // ############################################################################
   if(book->add(entry, key, update)!=AddressBook::NoError)
     {
       KMessageBox::sorry(this, i18n("Your new entry could not be added."));
@@ -129,48 +136,48 @@ AddressBook::ErrorCode KabAPI::add(const AddressBook::Entry& entry, KabKey& key,
     } else {
       return AddressBook::NoError;
     }
-  // ############################################################################  
+  // ############################################################################
 }
 
 AddressBook::ErrorCode KabAPI::remove(const KabKey& key)
 {
-  CHECK_PTR(book);
-  // ############################################################################  
+  Q_CHECK_PTR(book);
+  // ############################################################################
   if(book->AddressBook::remove(key)==AddressBook::NoError)
     {
       return AddressBook::NoError;
     } else {
       return AddressBook::NoEntry;
     }
-  // ############################################################################  
+  // ############################################################################
 }
 
-AddressBook::ErrorCode KabAPI::getEntryByName(const QString&, 
+AddressBook::ErrorCode KabAPI::getEntryByName(const QString&,
 					 list<AddressBook::Entry>&, const int)
 {
-  // ############################################################################  
+  // ############################################################################
   return AddressBook::NotImplemented;
-  // ############################################################################  
+  // ############################################################################
 }
 
 AddressBook::ErrorCode KabAPI::getEntryByName(const AddressBook::Entry&,
 					 list<AddressBook::Entry>&, const int)
 {
-  // ############################################################################  
+  // ############################################################################
   return AddressBook::NotImplemented;
-  // ############################################################################  
+  // ############################################################################
 }
 
 AddressBook::ErrorCode KabAPI::getEntries(list<AddressBook::Entry>& entries)
 {
   kdDebug(KAB_KDEBUG_AREA) << "KabAPI::getEntries: called." << endl;
-  // ############################################################################  
+  // ############################################################################
   if(book->noOfEntries()==0)
     { // ----- database is valid, but empty:
       kdDebug(KAB_KDEBUG_AREA) << "KabAPI::getEntries: no entries." << endl;
       return AddressBook::NoEntry;
     }
-  if(!book->getEntries(entries))
+  if(book->getEntries(entries)!=AddressBook::NoError)
     {
       kdDebug(KAB_KDEBUG_AREA) << "KabAPI::getEntries: intern error." << endl;
       return AddressBook::InternError;
@@ -178,7 +185,7 @@ AddressBook::ErrorCode KabAPI::getEntries(list<AddressBook::Entry>& entries)
       kdDebug(KAB_KDEBUG_AREA) << "KabAPI::getEntries: done." << endl;
       return AddressBook::NoError;
     }
-  // ############################################################################  
+  // ############################################################################
 }
 
 AddressBook* KabAPI::addressbook()
