@@ -3,14 +3,14 @@
    the KDE addressbook
 
    $ Author: Mirko Boehm $
-   $ Copyright: (C) 1996-2000, Mirko Boehm $
+   $ Copyright: (C) 1996-2001, Mirko Boehm $
    $ Contact: mirko@kde.org
          http://www.kde.org $
    $ License: GPL with the following explicit clarification:
          This code may be linked against any version of the Qt toolkit
          from Troll Tech, Norway. $
 
-   $Id: qconfigDB.cc,v 1.24 2000/11/24 21:54:40 faure Exp $	 
+   $Id: qconfigDB.cc,v 1.27 2001/11/03 00:23:56 matz Exp $	 
 */
 
 #include "qconfigDB.h"
@@ -190,6 +190,16 @@ bool KeyValueMap::invariant()
   return true;
 }
 
+StringStringMap::iterator KeyValueMap::begin()
+{
+  return data->begin();
+}
+
+StringStringMap::iterator KeyValueMap::end()
+{
+  return data->end();
+}
+
 unsigned int
 KeyValueMap::size() const
 {
@@ -279,7 +289,7 @@ KeyValueMap::save(const QString& filename, bool force)
     {
       QTextStream stream(&file);
       stream.setEncoding(QTextStream::Latin1); // no conversion
-      stream << "# saved by KeyValueMap object ($Revision: 1.24 $)" << endl;
+      stream << "# saved by KeyValueMap object ($Revision: 1.27 $)" << endl;
       for(pos=data->begin(); pos!=data->end(); ++pos)
 	{ // values do not get coded here
 	  stream << (*pos).first << '=' << (*pos).second << endl;
@@ -692,7 +702,7 @@ KeyValueMap::insert(const QCString& key, const QString& value, bool force)
 }
 
 bool
-KeyValueMap::get(const QCString& key, QString& value)
+KeyValueMap::get(const QCString& key, QString& value) const
 {
   register bool GUARD; GUARD=false;
   // ###########################################################################
