@@ -54,9 +54,17 @@ void DistributionList::insertEntry( const Addressee &a, const QString &email )
 
   QValueList<Entry>::Iterator it;
   for( it = mEntries.begin(); it != mEntries.end(); ++it ) {
-    if ( (*it).addressee.uid() == a.uid() && (*it).email == email ) {
-      *it = e;
-      return;
+    if ( (*it).addressee.uid() == a.uid() ) {
+      /**
+        We have to check if both email addresses contains no data,
+        a simple 'email1 == email2' wont work here
+       */
+      if ( ( (*it).email.isNull() && email.isEmpty() ) ||
+           ( (*it).email.isEmpty() && email.isNull() ) ||
+           ( (*it).email == email ) ) {
+        *it = e;
+        return;
+      }
     }
   }
   mEntries.append( e );
@@ -102,6 +110,10 @@ DistributionListManager::DistributionListManager( AddressBook *ab ) :
 {
 }
 
+DistributionListManager::~DistributionListManager()
+{
+}
+
 DistributionList *DistributionListManager::list( const QString &name )
 {
   DistributionList *list;
@@ -153,7 +165,7 @@ bool DistributionListManager::load()
 
   QMap<QString,QString> entryMap = cfg.entryMap( mAddressBook->identifier() );
   if ( entryMap.isEmpty() ) {
-    kdDebug() << "No distlists for '" << mAddressBook->identifier() << "'" << endl;
+    kdDebug(5700) << "No distlists for '" << mAddressBook->identifier() << "'" << endl;
     return false;
   }
 
@@ -164,7 +176,7 @@ bool DistributionListManager::load()
     QString name = it.key();
     QStringList value = cfg.readListEntry( name );
 
-    kdDebug() << "DLM::load(): " << name << ": " << value.join(",") << endl;
+    kdDebug(5700) << "DLM::load(): " << name << ": " << value.join(",") << endl;
 
     DistributionList *list = new DistributionList( this, name );
 
@@ -173,7 +185,7 @@ bool DistributionListManager::load()
       QString id = *it2++;
       QString email = *it2;
 
-      kdDebug() << "----- Entry " << id << endl; 
+      kdDebug(5700) << "----- Entry " << id << endl; 
       
       Addressee a = mAddressBook->findByUid( id );
       if ( !a.isEmpty() ) {
@@ -190,7 +202,7 @@ bool DistributionListManager::load()
 
 bool DistributionListManager::save()
 {
-  kdDebug() << "DistListManager::save()" << endl;
+  kdDebug(5700) << "DistListManager::save()" << endl;
 
   KSimpleConfig cfg( locateLocal( "data", "kabc/distlists" ) );
 
@@ -199,7 +211,7 @@ bool DistributionListManager::save()
   
   DistributionList *list;
   for( list = mLists.first(); list; list = mLists.next() ) {
-    kdDebug() << "  Saving '" << list->name() << "'" << endl;
+    kdDebug(5700) << "  Saving '" << list->name() << "'" << endl;
     QStringList value;
     DistributionList::Entry::List entries = list->entries();
     DistributionList::Entry::List::ConstIterator it;
@@ -214,3 +226,32 @@ bool DistributionListManager::save()
   
   return true;
 }
+
+DistributionListWatcher* DistributionListWatcher::mSelf = 0;
+
+DistributionListWatcher::DistributionListWatcher()
+ : QObject( 0, "DistributionListWatcher" )
+{
+  mDirWatch = new KDirWatch;
+  mDirWatch->addFile( locateLocal( "data", "kabc/distlists" ) );
+  
+  connect( mDirWatch, SIGNAL( dirty( const QString& ) ), SIGNAL( changed() ) );
+  mDirWatch->startScan();
+}
+
+DistributionListWatcher::~DistributionListWatcher()
+{
+  delete mDirWatch;
+  mDirWatch = 0;
+}
+
+DistributionListWatcher *DistributionListWatcher::self()
+{
+  if ( !mSelf )
+    mSelf = new DistributionListWatcher();
+
+  return mSelf;
+}
+
+#include "distributionlist.moc"
+
