@@ -35,10 +35,16 @@ class UTCValue : public Value
 {
 	
 #include "UTCValue-generated.h"
+
+  UTCValue *clone();
 	
-	bool isPositive();
-	unsigned int hour();
-	unsigned int minute();
+  void setPositive( int p ) { positive_ = p; assembled_ = false; }
+  void setHour( int h ) { hour_ = h; assembled_ = false; }
+  void setMinute( int m ) { minute_ = m; assembled_ = false; }
+
+	bool positive() { parse(); return positive_; }
+	unsigned int hour() { parse(); return hour_; }
+	unsigned int minute() { parse(); return minute_; }
 	
 	private:
 		
