@@ -19,12 +19,10 @@
 #ifndef _KATE_HIGHLIGHTDOWNLOAD_H_
 #define _KATE_HIGHLIGHTDOWNLOAD_H_
 
-#include "kateglobal.h"
-
 #include <kdialogbase.h>
 #include <kio/jobclasses.h>
 
-#define HLDOWNLOADPATH "http://www.kde.org/kate/hl/update.xml"
+#define HLDOWNLOADPATH "http://www.kde.org/apps/kate/hl/update.xml"
 
 class HlDownloadDialog: public KDialogBase
 {
