@@ -19,7 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kateiconborder.cpp,v 1.47 2002/09/30 16:08:49 rodda Exp $
+// $Id: kateiconborder.cpp,v 1.47.2.1 2003/08/27 17:01:04 mcamen Exp $
 
 #include "kateiconborder.h"
 #include "kateiconborder.moc"
@@ -207,7 +207,7 @@ void KateIconBorder::updateFont()
 
 int KateIconBorder::lineNumberWidth() const
 {
-  return ((int)log10(m_view->doc()->numLines()) + 1) * m_maxCharWidth + 4;
+  return ((int)log10((double)(m_view->doc()->numLines())) + 1) * m_maxCharWidth + 4;
 }
 
 void KateIconBorder::paintEvent(QPaintEvent* e)
