@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kateviewdialog.cpp,v 1.73 2002/10/11 14:30:30 rodda Exp $
+// $Id: kateviewdialog.cpp,v 1.73.2.1 2003/02/09 14:09:58 rnolden Exp $
 
 #include "kateviewdialog.h"
 #include "kateviewdialog.moc"
@@ -58,7 +58,7 @@
 
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
-#include <qcollection.h>
+#include <qptrcollection.h>
 #include <qdialog.h>
 #include <qgrid.h>
 #include <qgroupbox.h>
