@@ -127,50 +127,6 @@ void usleep(unsigned int usec) {
 }
 #endif
 
-#endif
-
-#if !defined(HAVE_GETDOMAINNAME)
-
-#include <sys/utsname.h>
-#include <netdb.h>
-#include <strings.h>
-#include <errno.h>
-#include <stdio.h>
-
-int getdomainname(char *name, size_t len)
-{
-        struct utsname uts;
-        struct hostent *hent;
-        int rv = -1;
-
-        if (name == 0L)
-          errno = EINVAL;
-        else
-        {
-                name[0] = '\0';
-                if (uname(&uts) >= 0)
-                {
-                        if ((hent = gethostbyname(uts.nodename)) != 0L)
-                        {
-                                char *p = strchr(hent->h_name, '.');
-                                if (p != 0L)
-                                {
-                                        ++p;
-                                        if (strlen(p) > len-1)
-                                          errno = EINVAL;
-                                        else
-                                        {
-                                                strcpy(name, p);
-                                                rv = 0;
-                                        }
-                                }
-                        }
-                }
-        }
-        return rv;
-}
-
-
 #endif
 
 #ifndef HAVE_RANDOM
