@@ -23,16 +23,17 @@
 #include "kaccelbase.h"
 
 #include <qkeycode.h>
+#include <qlabel.h>
 #include <qpopupmenu.h>
 
 #include <kconfig.h>
 #include <kckey.h>
 #include <kdebug.h>
 #include <kglobal.h>
-#include <kglobalsettings.h>
 #include <kkeynative.h>
 #include <kkeyserver_x11.h>
 #include <klocale.h>
+#include <kshortcutmenu.h>
 
 //---------------------------------------------------------------------
 // class KAccelBase::ActionInfo
@@ -177,8 +178,8 @@ bool KAccelBase::setActionSlot( const QString& sAction, const QObject* pObjSlot,
 
 /*
 KAccelBase
-	Execute Command=Meta+Enter;Alt+F2
-	KAccelAction = "Execute Command"
+	Run Command=Meta+Enter;Alt+F2
+	KAccelAction = "Run Command"
 		1) KAccelKeySeries = "Meta+Enter"
 			1a) Meta+Enter
 			1b) Meta+Keypad_Enter
@@ -219,7 +220,7 @@ connect new key sequences
 	}
 	Sort by: iVariation, iSequence, iSeries, iAction
 
-	1) KAccelAction = "Execute Command"
+	1) KAccelAction = "Run Command"
 		1) KAccelKeySeries = "Meta+Enter"
 			1a) Meta+Enter
 			1b) Meta+Keypad_Enter
@@ -329,14 +330,16 @@ bool KAccelBase::updateConnections()
 			bNonUnique = true;
 		// If this key is requested by more than one action,
 		else if( i < rgKeys.size() - 1 && key == rgKeys[i+1].key ) {
-			kdDebug(125) << "key = " << key.key().toStringInternal()
-				<< " action1 = " << info.pAction->name()
-				<< " action2 = " << m_rgActions.actionPtr( rgKeys[i+1].iAction )->name() << endl;
 			// If multiple actions requesting this key
 			//  have the same priority as the first one,
 			if( info.iVariation == rgKeys[i+1].iVari && info.iSeq == rgKeys[i+1].iSeq )
 				bNonUnique = true;
 
+			kdDebug(125) << "key conflict = " << key.key().toStringInternal()
+				<< " action1 = " << info.pAction->name()
+				<< " action2 = " << m_rgActions.actionPtr( rgKeys[i+1].iAction )->name() 
+				<< " non-unique = " << bNonUnique << endl;
+			
 			// Skip over the other records with this same key.
 			while( i < rgKeys.size() - 1 && key == rgKeys[i+1].key )
 				i++;
@@ -406,7 +409,7 @@ bool KAccelBase::updateConnections()
 }
 
 // Construct a list of keys to be connected, sorted highest priority first.
-void KAccelBase::createKeyList( QValueVector<X>& rgKeys )
+void KAccelBase::createKeyList( QValueVector<struct X>& rgKeys )
 {
 	//kdDebug(125) << "KAccelBase::createKeyList()" << endl;
 	if( !m_bEnabled )
@@ -478,7 +481,8 @@ bool KAccelBase::insertConnection( KAccelAction* pAction )
 					// TODO: make this more efficient where possible.
 					if( m_mapKeyToAction[key].pAction != pAction
 					    && m_mapKeyToAction[key].pAction != 0 ) {
-						kdDebug(125) << "Key conflict: call updateConnections()" << endl;
+						kdDebug(125) << "Key conflict: call updateConnections():" 
+							<< " key = " << key.key().toStringInternal() << endl;
 						return updateConnections();
 					}
 				}
@@ -563,13 +567,16 @@ void KAccelBase::writeSettings( KConfigBase* pConfig ) const
 
 QPopupMenu* KAccelBase::createPopupMenu( QWidget* pParent, const KKeySequence& seq )
 {
-	QPopupMenu* pMenu = new QPopupMenu( pParent, "KAccelBase-QPopupMenu" );
-	pMenu->setFont( KGlobalSettings::menuFont() );
-
+	KShortcutMenu* pMenu = new KShortcutMenu( pParent, &actions(), seq );
+	
 	bool bActionInserted = false;
 	bool bInsertSeparator = false;
 	for( uint i = 0; i < actionCount(); i++ ) {
 		const KAccelAction* pAction = actions().actionPtr( i );
+
+		if( !pAction->isEnabled() )
+			continue;
+
 		// If an action has already been inserted into the menu
 		//  and we have a label instead of an action here,
 		//  then indicate that we should insert a separator before the next menu entry.
@@ -584,26 +591,15 @@ QPopupMenu* KAccelBase::createPopupMenu( QWidget* pParent, const KKeySequence& s
 					bInsertSeparator = false;
 				}
 
-				QString sLabel = pAction->label();
-				if( seq.count() < seqAction.count() ) {
-					sLabel += "\t&";
-					for( uint iKey = seq.count(); iKey < seqAction.count(); iKey++ ) {
-						sLabel += seqAction.key(iKey).toString();
-						if( iKey < seqAction.count() - 1 )
-							sLabel += '+';
-					}
-				}
+				pMenu->insertAction( i, seqAction );
 
-				pMenu->insertItem( sLabel, i );
+				//kdDebug(125) << "sLabel = " << sLabel << ", seq = " << (QString)seqMenu.qt() << ", i = " << i << endl;
+				//kdDebug(125) << "pMenu->accel(" << i << ") = " << (QString)pMenu->accel(i) << endl;
 				bActionInserted = true;
 				break;
 			}
 		}
 	}
-
+	pMenu->updateShortcuts();
 	return pMenu;
 }
-
-void KAccelBase::virtual_hook( int, void* )
-{ /*BASE::virtual_hook( id, data );*/ }
-
