@@ -18,7 +18,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: kapplication.h,v 1.278 2002/10/27 12:22:23 hausmann Exp $
+// $Id: kapplication.h,v 1.278.2.1 2003/03/03 14:39:42 lunakl Exp $
 
 #ifndef _KAPP_H
 #define _KAPP_H
@@ -86,7 +86,7 @@ class KApplicationPrivate;
 * 
 * @short Controls and provides information to all KDE applications.
 * @author Matthias Kalle Dalheimer <kalle@kde.org>
-* @version $Id: kapplication.h,v 1.278 2002/10/27 12:22:23 hausmann Exp $
+* @version $Id: kapplication.h,v 1.278.2.1 2003/03/03 14:39:42 lunakl Exp $
 */
 class KApplication : public QApplication, public KInstance
 {
@@ -318,6 +318,17 @@ public:
      * @internal
      */
   void saveState( QSessionManager& sm );
+  
+  /**
+   * Returns true if the application is currently saving its session
+   * data (most probably before KDE logout). This is intended for use
+   * mainly in KMainWindow::queryClose() and KMainWindow::queryExit().
+   *
+   * @see KMainWindow::queryClose
+   * @see KMainWindow::queryExit
+   * @since 3.1.1
+   */
+  bool sessionSaving() const;
 
   /**
    * Returns a pointer to a @ref DCOPClient for the application.
