@@ -1,6 +1,6 @@
 /* This file is part of the KDE libraries
     Copyright (C) 1999 Lars Knoll (knoll@kde.org)
-    $Id: kcharsets.cpp,v 1.134.2.2 2003/02/21 13:07:02 mutz Exp $
+    $Id: kcharsets.cpp,v 1.134.2.3 2003/06/29 21:42:59 deller Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -568,7 +568,7 @@ QTextCodec *KCharsets::codecForName(const QString &n, bool &ok) const
     QString dir;
     {
     KConfigGroupSaver cfgsav( KGlobal::config(), "i18n" );
-    dir = KGlobal::config()->readEntry("i18ndir", QString::fromLatin1("/usr/share/i18n/charmaps"));
+    dir = KGlobal::config()->readPathEntry("i18ndir", QString::fromLatin1("/usr/share/i18n/charmaps"));
     dir += "/";
     }
 
