@@ -1,6 +1,6 @@
 /* This file is part of the KDE libraries
     Copyright (C) 1999 Lars Knoll (knoll@kde.org)
-    $Id: kcharsets.h,v 1.53 2002/09/28 11:14:45 tjansen Exp $
+    $Id: kcharsets.h,v 1.53.2.1 2003/02/09 13:55:28 rnolden Exp $
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -23,7 +23,7 @@
 #include <qstring.h>
 #include <qfont.h>
 #include <qstringlist.h>
-#include <qlist.h>
+#include <qptrlist.h>
 
 class KGlobal;
 class KCharsetsPrivate;
@@ -39,7 +39,7 @@ class QTextCodec;
  * in languages which use non iso-8859-1 charsets.
  *
  * @author Lars Knoll <knoll@kde.org>
- * @version $Id: kcharsets.h,v 1.53 2002/09/28 11:14:45 tjansen Exp $
+ * @version $Id: kcharsets.h,v 1.53.2.1 2003/02/09 13:55:28 rnolden Exp $
  */
 class KCharsets
 {
