@@ -1,5 +1,5 @@
 /* This file is part of the KDE libraries
-    Copyright (C) 1999,2000 Carsten Pfeiffer <pfeiffer@kde.org>
+    Copyright (C) 1999,2000,2001 Carsten Pfeiffer <pfeiffer@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -18,31 +18,53 @@
 */
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kdebug.h>
 #include <klocale.h>
 #include <knotifyclient.h>
+#include <kglobal.h>
 
 #include "kcompletion.h"
 #include "kcompletion_private.h"
 
 
+class KCompletionPrivate
+{
+public:
+    // not a member to avoid #including kcompletion_private.h from kcompletion.h
+    // list used for nextMatch() and previousMatch()
+    KCompletionMatchesWrapper matches;
+};
+
 KCompletion::KCompletion()
 {
+    d = new KCompletionPrivate;
+
     myCompletionMode = KGlobalSettings::completionMode();
     myTreeRoot = new KCompTreeNode;
     myBeep       = true;
     myIgnoreCase = false;
     myHasMultipleMatches = false;
     myRotationIndex = 0;
-    myOrder = Insertion;
+    setOrder( Insertion );
 }
 
 KCompletion::~KCompletion()
 {
+    delete d;
     delete myTreeRoot;
 }
 
+void KCompletion::setOrder( CompOrder order )
+{
+    myOrder = order;
+    d->matches.setSorting( order == Weighted );
+}
+
+void KCompletion::setIgnoreCase( bool ignoreCase )
+{
+    myIgnoreCase = ignoreCase;
+}
 
 void KCompletion::setItems( const QStringList& items )
 {
@@ -68,17 +90,17 @@ void KCompletion::insertItems( const QStringList& items )
 
 QStringList KCompletion::items() const
 {
-    QStringList list;
+    KCompletionMatchesWrapper list; // unsorted
     bool addWeight = (myOrder == Weighted);
     extractStringsFromNode( myTreeRoot, QString::null, &list, addWeight );
 
-    return list;
+    return list.list();
 }
 
 
 void KCompletion::addItem( const QString& item )
 {
-    myMatches.clear();
+    d->matches.clear();
     myRotationIndex = 0;
     myLastString = QString::null;
 
@@ -109,6 +131,7 @@ void KCompletion::addItem( const QString& item, uint weight )
     node = node->insert( 0x0, true );
     if ( weighted )
 	node->confirm( weight -1 );
+//     qDebug("*** added: %s (%i)", item.latin1(), node->weight());
 }
 
 void KCompletion::addWeightedItem( const QString& item )
@@ -139,7 +162,7 @@ void KCompletion::addWeightedItem( const QString& item )
 
 void KCompletion::removeItem( const QString& item )
 {
-    myMatches.clear();
+    d->matches.clear();
     myRotationIndex = 0;
     myLastString = QString::null;
 
@@ -149,7 +172,7 @@ void KCompletion::removeItem( const QString& item )
 
 void KCompletion::clear()
 {
-    myMatches.clear();
+    d->matches.clear();
     myRotationIndex = 0;
     myLastString = QString::null;
 
@@ -165,7 +188,7 @@ QString KCompletion::makeCompletion( const QString& string )
 
     //kdDebug(0) << "KCompletion: completing: " << string << endl;
 
-    myMatches.clear();
+    d->matches.clear();
     myRotationIndex = 0;
     myHasMultipleMatches = false;
     myLastMatch = myCurrentMatch;
@@ -174,30 +197,44 @@ QString KCompletion::makeCompletion( const QString& string )
     // complete-string twice
     if ( myCompletionMode == KGlobalSettings::CompletionShell &&
 	 string == myLastString ) {
-	// Don't use myMatches since calling postProcessMatches()
-	// on myMatches here would interfere with call to
+	// Don't use d->matches since calling postProcessMatches()
+	// on d->matches here would interfere with call to
 	// postProcessMatch() during rotation
-	QStringList l = findAllCompletions( string );
+	
+	findAllCompletions( string, &d->matches, myHasMultipleMatches );
+        QStringList l = d->matches.list();
 	postProcessMatches( &l );
 	emit matches( l );
+
+	if ( l.isEmpty() )
+	    doBeep( NoMatch );
+	
+	return QString::null;
     }
 
-    QString completion = findCompletion( string );
+    QString completion;
+    // in case-insensitive popup mode, we search all completions at once
+    if ( myCompletionMode == KGlobalSettings::CompletionPopup ||
+         myCompletionMode == KGlobalSettings::CompletionPopupAuto ) {
+        findAllCompletions( string, &d->matches, myHasMultipleMatches );
+        if ( !d->matches.isEmpty() )
+            completion = d->matches.first();
+    }
+    else
+        completion = findCompletion( string );
+
     if ( myHasMultipleMatches )
         emit multipleMatches();
 
     myLastString = string;
     myCurrentMatch = completion;
 
+    postProcessMatch( &completion );
+
     if ( !string.isEmpty() ) { // only emit match when string != ""
 	//kdDebug(0) << "KCompletion: Match: " << completion << endl;
-
-	postProcessMatch( &completion );
         emit match( completion );
     }
-    else
-        postProcessMatch( &completion );
-
 
     if ( completion.isNull() )
         doBeep( NoMatch );
@@ -206,6 +243,45 @@ QString KCompletion::makeCompletion( const QString& string )
 }
 
 
+QStringList KCompletion::substringCompletion( const QString& string ) const
+{
+    // get all items in the tree, eventually in sorted order
+    bool sorted = (myOrder == Weighted);
+    KCompletionMatchesWrapper allItems( sorted );
+    extractStringsFromNode( myTreeRoot, QString::null, &allItems, false );
+
+    QStringList list = allItems.list();
+    
+    // subStringMatches is invoked manually, via a shortcut, so we should
+    // beep here, if necessary.
+    if ( list.isEmpty() ) {
+        doBeep( NoMatch );
+        return list;
+    }
+
+    if ( string.isEmpty() ) { // shortcut
+        postProcessMatches( &list );
+        return list;
+    }
+
+    QStringList matches;
+    QStringList::ConstIterator it = list.begin();
+
+    for( ; it != list.end(); ++it ) {
+        QString item = *it;
+        if ( item.find( string, 0, false ) != -1 ) { // always case insensitive
+            postProcessMatch( &item );
+            matches.append( item );
+        }
+    }
+
+    if ( matches.isEmpty() )
+        doBeep( NoMatch );
+
+    return matches;
+}
+
+
 void KCompletion::setCompletionMode( KGlobalSettings::Completion mode )
 {
     myCompletionMode = mode;
@@ -214,22 +290,48 @@ void KCompletion::setCompletionMode( KGlobalSettings::Completion mode )
 
 QStringList KCompletion::allMatches()
 {
-	// Don't use myMatches since calling postProcessMatches()
-	// on myMatches here would interfere with call to
-	// postProcessMatch() during rotation
-	QStringList l = findAllCompletions( myLastString );
-	postProcessMatches( &l );
-	return l;
+    // Don't use d->matches since calling postProcessMatches()
+    // on d->matches here would interfere with call to
+    // postProcessMatch() during rotation
+    KCompletionMatchesWrapper matches( myOrder == Weighted );
+    bool dummy;
+    findAllCompletions( myLastString, &matches, dummy );
+    QStringList l = matches.list();
+    postProcessMatches( &l );
+    return l;
 }
 
-QStringList KCompletion::allMatches( const QString &text )
+KCompletionMatches KCompletion::allWeightedMatches()
 {
-	// Don't use myMatches since calling postProcessMatches()
-	// on myMatches here would interfere with call to
-	// postProcessMatch() during rotation
-	QStringList l = findAllCompletions( text );
-	postProcessMatches( &l );
-	return l;
+    // Don't use d->matches since calling postProcessMatches()
+    // on d->matches here would interfere with call to
+    // postProcessMatch() during rotation
+    KCompletionMatchesWrapper matches( myOrder == Weighted );
+    bool dummy;
+    findAllCompletions( myLastString, &matches, dummy );
+    KCompletionMatches ret( matches );
+    postProcessMatches( &ret );
+    return ret;
+}
+
+QStringList KCompletion::allMatches( const QString &string )
+{
+    KCompletionMatchesWrapper matches( myOrder == Weighted );
+    bool dummy;
+    findAllCompletions( string, &matches, dummy );
+    QStringList l = matches.list();
+    postProcessMatches( &l );
+    return l;
+}
+
+KCompletionMatches KCompletion::allWeightedMatches( const QString &string )
+{
+    KCompletionMatchesWrapper matches( myOrder == Weighted );
+    bool dummy;
+    findAllCompletions( string, &matches, dummy );
+    KCompletionMatches ret( matches );
+    postProcessMatches( &ret );
+    return ret;
 }
 
 /////////////////////////////////////////////////////
@@ -241,24 +343,26 @@ QString KCompletion::nextMatch()
     QString completion;
     myLastMatch = myCurrentMatch;
 
-    if ( myMatches.isEmpty() ) {
-	myMatches = findAllCompletions( myLastString );
-	completion = myMatches.first();
+    if ( d->matches.isEmpty() ) {
+	findAllCompletions( myLastString, &d->matches, myHasMultipleMatches );
+	completion = d->matches.first();
 	myCurrentMatch = completion;
+        myRotationIndex = 0;
 	postProcessMatch( &completion );
 	emit match( completion );
 	return completion;
     }
 
-    myLastMatch = myMatches[ myRotationIndex++ ];
+    QStringList matches = d->matches.list();
+    myLastMatch = matches[ myRotationIndex++ ];
 
-    if ( myRotationIndex == myMatches.count() -1 )
+    if ( myRotationIndex == matches.count() -1 )
 	doBeep( Rotation ); // indicate last matching item -> rotating
 
-    else if ( myRotationIndex == myMatches.count() )
+    else if ( myRotationIndex == matches.count() )
 	myRotationIndex = 0;
 
-    completion = myMatches[ myRotationIndex ];
+    completion = matches[ myRotationIndex ];
     myCurrentMatch = completion;
     postProcessMatch( &completion );
     emit match( completion );
@@ -272,25 +376,27 @@ QString KCompletion::previousMatch()
     QString completion;
     myLastMatch = myCurrentMatch;
 
-    if ( myMatches.isEmpty() ) {
-	myMatches = findAllCompletions( myLastString );
-	completion = myMatches.last();
+    if ( d->matches.isEmpty() ) {
+	findAllCompletions( myLastString, &d->matches, myHasMultipleMatches );
+	completion = d->matches.last();
 	myCurrentMatch = completion;
+        myRotationIndex = 0;
 	postProcessMatch( &completion );
 	emit match( completion );
 	return completion;
     }
 
-    myLastMatch = myMatches[ myRotationIndex ];
+    QStringList matches = d->matches.list();
+    myLastMatch = matches[ myRotationIndex ];
     if ( myRotationIndex == 1 )
 	doBeep( Rotation ); // indicate first item -> rotating
 
     else if ( myRotationIndex == 0 )
-	myRotationIndex = myMatches.count();
+	myRotationIndex = matches.count();
 
     myRotationIndex--;
 
-    completion = myMatches[ myRotationIndex ];
+    completion = matches[ myRotationIndex ];
     myCurrentMatch = completion;
     postProcessMatch( &completion );
     emit match( completion );
@@ -309,7 +415,7 @@ QString KCompletion::findCompletion( const QString& string )
     // start at the tree-root and try to find the search-string
     for( uint i = 0; i < string.length(); i++ ) {
         ch = string.at( i );
-	node = node->find( ch, myIgnoreCase );
+	node = node->find( ch );
 
 	if ( node )
 	    completion += ch;
@@ -376,14 +482,20 @@ QString KCompletion::findCompletion( const QString& string )
 }
 
 
-const QStringList& KCompletion::findAllCompletions( const QString& string )
+void KCompletion::findAllCompletions(const QString& string,
+                                     KCompletionMatchesWrapper *matches,
+                                     bool& hasMultipleMatches) const
 {
     //kdDebug(0) << "*** finding all completions for " << string << endl;
-    myMatches.clear();
-    myRotationIndex = 0;
 
     if ( string.isEmpty() )
-        return myMatches;
+        return;
+
+    if ( myIgnoreCase ) { // case insensitive completion
+        extractStringsFromNodeCI( myTreeRoot, QString::null, string, matches );
+        hasMultipleMatches = (matches->count() > 1);
+        return;
+    }
 
     QChar ch;
     QString completion;
@@ -392,12 +504,12 @@ const QStringList& KCompletion::findAllCompletions( const QString& string )
     // start at the tree-root and try to find the search-string
     for( uint i = 0; i < string.length(); i++ ) {
         ch = string.at( i );
-	node = node->find( ch, myIgnoreCase );
+	node = node->find( ch );
 
 	if ( node )
 	    completion += ch;
 	else
-	    return myMatches; // no completion -> return empty list
+	    return; // no completion -> return empty list
     }
 	
     // Now we have the last node of the to be completed string.
@@ -414,37 +526,34 @@ const QStringList& KCompletion::findAllCompletions( const QString& string )
 
     // there is just one single match)
     if ( node->childrenCount() == 0 )
-        myMatches.append( completion );
+        matches->append( node->weight(), completion );
 
     else {
         // node has more than one child
         // -> recursively find all remaining completions
-	myHasMultipleMatches = true;
-        extractStringsFromNode( node, completion, &myMatches );
+	hasMultipleMatches = true;
+        extractStringsFromNode( node, completion, matches );
     }
-
-    return myMatches;
 }
 
 
 void KCompletion::extractStringsFromNode( const KCompTreeNode *node,
 					  const QString& beginning,
-					  QStringList *matches,
+					  KCompletionMatchesWrapper *matches,
 					  bool addWeight ) const
 {
     if ( !node || !matches )
         return;
 
     // kDebug() << "Beginning: " << beginning << endl;
-    KCompTreeChildren::ConstIterator it;
     const KCompTreeChildren *list = node->children();
     QString string;
     QString w;
 
     // loop thru all children
-    for ( it = list->begin(); it != list->end(); ++it ) {
+    for ( KCompTreeNode *cur = list->begin(); cur ; cur = cur->next) {
         string = beginning;
-        node = *it;
+	node = cur;
 	if ( !node->isNull() )
 	    string += *node;
 
@@ -462,7 +571,7 @@ void KCompletion::extractStringsFromNode( const KCompTreeNode *node,
 		w.setNum( node->weight() );
 		string.append( w );
 	    }
-	    matches->append( string );
+	    matches->append( node->weight(), string );
 	}
 
 	// recursively find all other strings.
@@ -471,8 +580,42 @@ void KCompletion::extractStringsFromNode( const KCompTreeNode *node,
     }
 }
 
+void KCompletion::extractStringsFromNodeCI( const KCompTreeNode *node,
+                                            const QString& beginning,
+                                            const QString& restString,
+                                      KCompletionMatchesWrapper *matches ) const
+{
+    if ( restString.isEmpty() ) {
+        extractStringsFromNode( node, beginning, matches, false /*noweight*/ );
+        return;
+    }
 
-void KCompletion::doBeep( BeepMode mode )
+    QChar ch1 = restString.at(0);
+    QString newRest = restString.mid(1);
+    KCompTreeNode *child1, *child2;
+
+    child1 = node->find( ch1 ); // the correct match
+    if ( child1 )
+        extractStringsFromNodeCI( child1, beginning + *child1, newRest,
+                                  matches );
+
+    // append the case insensitive matches, if available
+    if ( ch1.isLetter() ) {
+        // find out if we have to lower or upper it. Is there a better way?
+        QChar ch2 = ch1.lower();
+        if ( ch1 == ch2 )
+            ch2 = ch1.upper();
+        if ( ch1 != ch2 ) {
+            child2 = node->find( ch2 );
+            if ( child2 )
+                extractStringsFromNodeCI( child2, beginning + *child2, newRest,
+                                          matches );
+        }
+    }
+}
+
+
+void KCompletion::doBeep( BeepMode mode ) const
 {
     if ( !myBeep )
 	return;
@@ -516,9 +659,12 @@ void KCompletion::doBeep( BeepMode mode )
 KCompTreeNode::~KCompTreeNode()
 {
     // delete all children
-    KCompTreeChildren::Iterator it;
-    for ( it = myChildren.begin(); it != myChildren.end(); ++it )
-        delete *it;
+    KCompTreeNode *cur = myChildren.begin();
+    while (cur) {
+        KCompTreeNode * next = cur->next;
+        delete myChildren.remove(cur);
+        cur = next;
+    }
 }
 
 
@@ -526,20 +672,25 @@ KCompTreeNode::~KCompTreeNode()
 // it will not be created. Returns the new/existing node.
 KCompTreeNode * KCompTreeNode::insert( const QChar& ch, bool sorted )
 {
-    KCompTreeNode *child = find( ch, false );
+    KCompTreeNode *child = find( ch );
     if ( !child ) {
         child = new KCompTreeNode( ch );
 
 	// FIXME, first (slow) sorted insertion implementation
 	if ( sorted ) {
-	    KCompTreeChildren::Iterator it = myChildren.begin();
-	    while ( it != myChildren.end() ) {
-	        if ( ch > *(*it) )
-		    ++it;
-		else
+	    KCompTreeNode * prev = 0;
+	    KCompTreeNode * cur = myChildren.begin();
+	    while ( cur ) {
+	        if ( ch > *cur ) {
+		    prev = cur;
+		    cur = cur->next;
+		} else
 		    break;
 	    }
-	    myChildren.insert( it, child );
+	    if (prev)
+	        myChildren.insert( prev, child );
+	    else
+	        myChildren.prepend(child);
 	}
 
 	else
@@ -560,20 +711,164 @@ void KCompTreeNode::remove( const QString& string )
     KCompTreeNode *child = 0L;
 
     if ( string.isEmpty() ) {
-        child = find( 0x0, false );
-	myChildren.remove( child );
-	return;
+        child = find( 0x0 );
+        delete myChildren.remove( child );
+        return;
     }
 
     QChar ch = string.at(0);
-    child = find( ch, false );
+    child = find( ch );
     if ( child ) {
         child->remove( string.right( string.length() -1 ) );
-	if ( child->myChildren.count() == 0 ) {
-	    delete child;
-	    myChildren.remove( child );
-	}
+        if ( child->myChildren.count() == 0 ) {
+            delete myChildren.remove( child );
+        }
     }
 }
 
+QStringList KCompletionMatchesWrapper::list() const {
+    if ( sortedList && dirty ) {
+        sortedList->sort();
+        dirty = false;
+
+        stringList.clear();
+
+        // high weight == sorted last -> reverse the sorting here
+        QValueListConstIterator<KSortableItem<QString> > it;
+        for ( it = sortedList->begin(); it != sortedList->end(); ++it )
+            stringList.prepend( (*it).value() );
+    }
+
+    return stringList;
+}
+
+KCompletionMatches::KCompletionMatches( bool sort_P )
+    : _sorting( sort_P )
+{
+}
+
+KCompletionMatches::KCompletionMatches( const KCompletionMatchesWrapper& matches )
+    : _sorting( matches.sorting())
+{
+    if( matches.sortedList != 0L )
+        KCompletionMatchesList::operator=( *matches.sortedList );
+    else {
+        QStringList l = matches.list();
+        for( QStringList::ConstIterator it = l.begin();
+             it != l.end();
+             ++it )
+            prepend( KSortableItem<QString, int>( 1, *it ) );
+    }
+}
+    
+KCompletionMatches::~KCompletionMatches()
+{
+}
+
+QStringList KCompletionMatches::list( bool sort_P ) const
+{
+    if( _sorting && sort_P )
+        const_cast< KCompletionMatches* >( this )->sort();
+    QStringList stringList;
+    // high weight == sorted last -> reverse the sorting here
+    for ( ConstIterator it = begin(); it != end(); ++it )
+        stringList.prepend( (*it).value() );
+    return stringList;
+}
+
+void KCompletionMatches::removeDuplicates()
+{
+    Iterator it1, it2;
+    for ( it1 = begin(); it1 != end(); ++it1 ) {
+        for ( (it2 = it1), ++it2; it2 != end();) {
+            if( (*it1).value() == (*it2).value()) {
+                // use the max height
+                (*it1).first = kMax( (*it1).index(), (*it2).index());
+                it2 = remove( it2 );
+                continue;
+            }
+            ++it2;
+        }
+    }
+}
+
+void KCompTreeNodeList::append(KCompTreeNode *item)
+{
+    m_count++;
+    if (!last) {
+	last = item;
+	last->next = 0;
+	first = item;
+	return;
+    }
+    last->next = item;
+    item->next = 0;
+    last = item;
+}
+
+void KCompTreeNodeList::prepend(KCompTreeNode *item)
+{
+    m_count++;
+    if (!last) {
+	last = item;
+	last->next = 0;
+	first = item;
+	return;
+    }
+    item->next = first;
+    first = item;
+}
+
+void KCompTreeNodeList::insert(KCompTreeNode *after, KCompTreeNode *item)
+{
+    if (!after) {
+	append(item);
+	return;
+    }
+
+    m_count++;
+
+    item->next = after->next;
+    after->next = item;
+
+    if (after == last)
+	last = item;
+}
+
+KCompTreeNode *KCompTreeNodeList::remove(KCompTreeNode *item)
+{
+    if (!first || !item)
+	return 0;
+    KCompTreeNode *cur = 0;
+
+    if (item == first)
+	first = first->next;
+    else {
+	cur = first;
+	while (cur && cur->next != item) cur = cur->next;
+	if (!cur)
+	    return 0;
+	cur->next = item->next;
+    }
+    if (item == last)
+	last = cur;
+    m_count--;
+    return item;
+}
+
+KCompTreeNode *KCompTreeNodeList::at(uint index) const
+{
+    KCompTreeNode *cur = first;
+    while (index-- && cur) cur = cur->next;
+    return cur;
+}
+
+KZoneAllocator KCompTreeNode::alloc(8192);
+
+void KCompletion::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
+
+void KCompletionBase::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
+
 #include "kcompletion.moc"
