@@ -21,7 +21,7 @@
 #define KCOMPLETION_H
 
 #include <qmap.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qobject.h>
 #include <qstring.h>
 #include <qstringlist.h>
@@ -125,7 +125,7 @@ class QPopupMenu;
  *
  * @short A generic class for completing QStrings
  * @author Carsten Pfeiffer <pfeiffer@kde.org>
- * @version $Id: kcompletion.h,v 1.65 2002/09/21 15:53:39 tjansen Exp $
+ * @version $Id: kcompletion.h,v 1.65.2.1 2003/02/09 13:55:28 rnolden Exp $
  */
 class KCompletion : public QObject
 {
