@@ -19,7 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kconfig.h,v 1.46 2002/03/03 21:20:25 lunakl Exp $
+// $Id: kconfig.h,v 1.51 2002/09/28 12:28:47 tjansen Exp $
 
 #ifndef _KCONFIG_H
 #define _KCONFIG_H
@@ -36,7 +36,7 @@ class KConfigPrivate;
 * This class implements KDE's default configuration system.
 *
 * @author Kalle Dalheimer <kalle@kde.org>, Preston Brown <pbrown@kde.org>
-* @version $Id: kconfig.h,v 1.46 2002/03/03 21:20:25 lunakl Exp $
+* @version $Id: kconfig.h,v 1.51 2002/09/28 12:28:47 tjansen Exp $
 * @see KGlobal::config(), KConfigBase, KSimpleConfig
 * @short KDE Configuration Management class
 */
@@ -52,7 +52,9 @@ public:
    *        system-wide file(s).  If it is not provided, only global
    *        KDE configuration data will be read (depending on the value of
    *        @p bUseKDEGlobals).
-   * @param bReadOnly Set the config object's read-only status.
+   * @param bReadOnly Set the config object's read-only status. Note that the
+   *        object will automatically become read-only if either the user does not have
+   *        write permission to @p fileName or if no file was specified.
    * @param bUseKDEGlobals Toggle reading the global KDE configuration file.
    * @param resType the place to look in (config, data, etc) See @ref KStandardDirs.
    */
@@ -84,6 +86,7 @@ public:
 
   /**
    * Returns a list of groups that are known.
+   * @return a list of of groups
    */
   virtual QStringList groupList() const;
 
@@ -109,6 +112,7 @@ public:
   /**
    * Set the file mode for newly created files.
    *
+   * @param mode the mode for new files as described in chmod(2)
    * @see man:chmod(2) for a description of @p mode
    */
   void setFileWriteMode(int mode);
@@ -116,15 +120,33 @@ public:
   /**
    * Forces all following write-operations being performed on kdeglobals,
    * independent of the bGlobal flag in writeEntry().
+   * @param force true to force writing in kdeglobals
    * @see #forceGlobal
    */
   void setForceGlobal( bool force ) { bForceGlobal = force; }
 
   /**
    * Returns true if all entries are being written into kdeglobals.
+   * @return true if all entries are being written into kdeglobals
    * @see #setForceGlobal
    */
   bool forceGlobal() const { return bForceGlobal; }
+
+  /**
+   * Checks whether the config file contains the update @p id
+   * as contained in @p updateFile. If not, it runs kconf_update
+   * to update the config file.
+   *
+   * If you install config update files with critical fixes
+   * you may wish to use this method to verify that a critical
+   * update has indeed been performed to catch the case where
+   * a user restores an old config file from backup that has
+   * not been updated yet.
+   * @param id the update to check
+   * @param updateFile the file containing the update
+   * @since 3.1
+   */
+  void checkUpdate(const QString &id, const QString &updateFile);
     
 protected:
 
@@ -132,7 +154,7 @@ protected:
    * Returns true if the specified group is known.
    *
    * @param group The group to search for.
-   * @returns @p true if the group exists.
+   * @returns true if the group exists.
    */
   virtual bool internalHasGroup(const QCString &group) const;
 
