@@ -20,7 +20,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kconfigbase.h,v 1.83 2002/09/08 14:55:41 tjansen Exp $
+// $Id: kconfigbase.h,v 1.83.2.1 2003/06/22 21:39:31 deller Exp $
 
 #ifndef _KCONFIGBASE_H
 #define _KCONFIGBASE_H
@@ -63,7 +63,7 @@ class KConfigGroup;
  * group name.
  *
  * @author Kalle Dalheimer <kalle@kde.org>, Preston Brown <pbrown@kde.org>
- * @version $Id: kconfigbase.h,v 1.83 2002/09/08 14:55:41 tjansen Exp $
+ * @version $Id: kconfigbase.h,v 1.83.2.1 2003/06/22 21:39:31 deller Exp $
  * @see  KGlobal#config()  KConfig  KSimpleConfig
  * @short KDE Configuration Management abstract base class
  */
@@ -303,6 +303,35 @@ public:
    */
   QString readPathEntry( const char *pKey, const QString & aDefault = QString::null ) const;
 
+  /**
+   * Reads a list of string paths.
+   *
+   * Read the value of an entry specified by @p pKey in the current group
+   * and interpret it as a list of paths. This means, dollar expansion is activated
+   * for this value, so that e.g. $HOME gets expanded.
+   *
+   * @param pKey The key to search for.
+   * @param sep  The list separator (default is ",").
+   * @return The list. Empty if the entry does not exist.
+   * @since 3.1.3
+   */
+  QStringList readPathListEntry( const QString& pKey, char sep = ',' ) const;
+
+  /**
+   * Reads a list of string paths.
+   *
+   * Read the value of an entry specified by @p pKey in the current group
+   * and interpret it as a list of paths. This means, dollar expansion is activated
+   * for this value, so that e.g. $HOME gets expanded.
+   *
+   * @param pKey The key to search for.
+   * @param sep  The list separator (default is ",").
+   * @return The list. Empty if the entry does not exist.
+   * @since 3.1.3
+   */
+  QStringList readPathListEntry( const char *pKey, char sep = ',' ) const;
+
+
   /**
    * Reads a numerical value.
    *
@@ -1405,6 +1434,55 @@ public:
                        bool bPersistent = true, bool bGlobal = false,
                        bool bNLS = false );
 
+  /**
+   * @ref writePathEntry() overridden to accept a list of paths (strings).
+   *
+   * It is checked whether the paths are located under $HOME. If so each of 
+   * the paths are written out with the user's home-directory replaced with
+   * $HOME. The paths should be read back with @ref readPathListEntry()
+   *
+   * @param pKey The key to write
+   * @param rValue The list to write
+   * @param bPersistent If @p bPersistent is false, the entry's dirty flag
+   *                    will not be set and thus the entry will not be
+   *                    written to disk at deletion time.
+   * @param bGlobal If @p bGlobal is true, the pair is not saved to the
+   *                application specific config file, but to the
+   *                global KDE config file.
+   * @param bNLS If @p bNLS is true, the locale tag is added to the key
+   *             when writing it back.
+   *
+   * @see  writePathEntry()
+   * @see  readPathListEntry()
+   * @since 3.1.3
+   */
+  void writePathEntry( const QString& pKey, const QStringList &rValue,
+		   char sep = ',', bool bPersistent = true, bool bGlobal = false, bool bNLS = false );
+  /**
+   * @ref writePathEntry() overridden to accept a list of paths (strings).
+   *
+   * It is checked whether the paths are located under $HOME. If so each of 
+   * the paths are written out with the user's home-directory replaced with
+   * $HOME. The paths should be read back with @ref readPathListEntry()
+   *
+   * @param pKey The key to write
+   * @param rValue The list to write
+   * @param bPersistent If @p bPersistent is false, the entry's dirty flag
+   *                    will not be set and thus the entry will not be
+   *                    written to disk at deletion time.
+   * @param bGlobal If @p bGlobal is true, the pair is not saved to the
+   *                application specific config file, but to the
+   *                global KDE config file.
+   * @param bNLS If @p bNLS is true, the locale tag is added to the key
+   *             when writing it back.
+   *
+   * @see  writePathEntry()
+   * @see  readPathListEntry()
+   * @since 3.1.3
+   */
+  void writePathEntry( const char *pKey, const QStringList &rValue,
+		   char sep = ',', bool bPersistent = true, bool bGlobal = false, bool bNLS = false );
+
 
   /**
    * Deletes the entry specified by @p pKey in the current group.
@@ -1754,7 +1832,7 @@ class KConfigGroupSaverPrivate;
   * in one block.
   *
   * @author Matthias Kalle Dalheimer <kalle@kde.org>
-  * @version $Id: kconfigbase.h,v 1.83 2002/09/08 14:55:41 tjansen Exp $
+  * @version $Id: kconfigbase.h,v 1.83.2.1 2003/06/22 21:39:31 deller Exp $
   * @see KConfigBase, KConfig, KSimpleConfig
   * @short Helper class for easier use of KConfig/KSimpleConfig groups
   */
