@@ -122,18 +122,31 @@ KCrash::defaultCrashHandler (int sig)
     crashRecursionCounter++; // 
   }
   
+        // Close dcop connections
+  DCOPClient::emergencyClose();
+  // Close all remaining file descriptors
+  struct rlimit rlp;
+  getrlimit(RLIMIT_NOFILE, &rlp);
+  for (int i = 0; i < (int)rlp.rlim_cur; i++)
+    close(i);
+
   if (crashRecursionCounter < 3)
   {
     if (appName) 
     {
-      fprintf(stderr, "KCrash: crashing.... crashRecursionCounter = %d\n", crashRecursionCounter);
+#ifndef NDEBUG
+      fprintf(stderr, "KCrash: crashing... crashRecursionCounter = %d\n", crashRecursionCounter);
       fprintf(stderr, "KCrash: Application Name = %s path = %s pid = %d\n", appName ? appName : "<unknown>" , appPath ? appPath : "<unknown>", getpid());
+#else
+      fprintf(stderr, "KCrash: Application '%s' crashing...\n", appName ? appName : "<unknown>");
+#endif
+
       pid_t pid = fork();
 
       if (pid <= 0) {
         // this code is leaking, but this should not hurt cause we will do a
         // exec() afterwards. exec() is supposed to clean up.
-        char * argv[16]; // don't forget to update this
+        char * argv[18]; // don't forget to update this
         int i = 0;
 
         // argument 0 has to be drkonqi
@@ -195,6 +208,11 @@ KCrash::defaultCrashHandler (int sig)
 	  }
         }
 
+	if ( kapp && !kapp->startupId().isNull()) {
+	    argv[i++] = qstrdup("--startupid");
+	    argv[i++] = qstrdup(kapp->startupId());
+	}
+
         // NULL terminated list
         argv[i++] = NULL;
 
@@ -210,14 +228,7 @@ KCrash::defaultCrashHandler (int sig)
       }
       else
       {
-        // Close dcop connections
-        DCOPClient::emergencyClose();
-        // Close all remaining file descriptors
-        struct rlimit rlp;
-        getrlimit(RLIMIT_NOFILE, &rlp);
-        for (int i = 0; i < (int)rlp.rlim_cur; i++)
-           close(i);
-           
+          
         alarm(0); // Seems we made it....
 
         // wait for child to exit
@@ -232,7 +243,7 @@ KCrash::defaultCrashHandler (int sig)
    
   if (crashRecursionCounter < 4)
   {
-     fprintf(stderr, "Unable to start dr. konqi\n");
+     fprintf(stderr, "Unable to start Dr. Konqi\n");
   }
   _exit(255);
 }
