@@ -19,7 +19,7 @@
   Boston, MA 02111-1307, USA.
 */
 
-// $Id: kdesktopfile.cpp,v 1.33.2.3 2003/06/29 21:42:59 deller Exp $
+// $Id: kdesktopfile.cpp,v 1.33.2.4 2003/08/27 13:53:04 waba Exp $
 
 #include <stdlib.h>
 #include <unistd.h>
@@ -216,7 +216,7 @@ bool KDesktopFile::tryExec() const
 
   if (!te.isEmpty()) {
     if (te[0] == '/') {
-      if (::access(QFile::encodeName(te), R_OK & X_OK))
+      if (::access(QFile::encodeName(te), R_OK | X_OK))
 	return false;
     } else {
       // !!! Sergey A. Sukiyazov <corwin@micom.don.ru> !!!
@@ -227,7 +227,7 @@ bool KDesktopFile::tryExec() const
       bool match = false;
       for (; it != dirs.end(); ++it) {
 	QString fName = *it + "/" + te;
-	if (::access(QFile::encodeName(fName), R_OK & X_OK) == 0)
+	if (::access(QFile::encodeName(fName), R_OK | X_OK) == 0)
 	{
 	  match = true;
 	  break;
