@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (C) 2000-2002 Thiago Macieira <thiagom@mail.com>
  *
- *  $Id: kextsock.cpp,v 1.44.2.5 2003/03/27 00:20:22 thiago Exp $
+ *  $Id: kextsock.cpp,v 1.44.2.8 2003/06/16 09:31:43 waba Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -107,8 +107,8 @@ public:
 
   QSocketNotifier *qsnIn, *qsnOut;
   int inMaxSize, outMaxSize;
-  bool emitRead, emitWrite;
-  bool addressReusable;
+  bool emitRead : 1, emitWrite : 1;
+  mutable bool addressReusable : 1, ipv6only : 1;
 
   KExtendedSocketLookup *dns, *dnsLocal;
 
@@ -117,7 +117,7 @@ public:
     host(QString::null), service(QString::null), localhost(QString::null), localservice(QString::null),
     resolution(0), bindres(0), current(0), local(0), peer(0),
     qsnIn(0), qsnOut(0), inMaxSize(-1), outMaxSize(-1), emitRead(false), emitWrite(false),
-    addressReusable(false), dns(0), dnsLocal(0)
+    addressReusable(false), ipv6only(false), dns(0), dnsLocal(0)
   {
     timeout.tv_sec = timeout.tv_usec = 0;
   }
@@ -778,6 +778,67 @@ bool KExtendedSocket::addressReusable()
   return on != 0;
 }
 
+/*
+ * Set the IPV6_V6ONLY flag
+ */
+bool KExtendedSocket::setIPv6Only(bool enable)
+{
+#ifdef IPV6_V6ONLY
+  cleanError();
+
+  d->ipv6only = enable;
+  if (sockfd == -1)
+    return true;		// can't set on a non-existing socket
+
+  int on = enable;
+
+  if (setsockopt(sockfd, IPPROTO_IPV6, IPV6_V6ONLY,
+		 (char *)&on, sizeof(on)) == -1)
+    {
+      setError(IO_UnspecifiedError, errno);
+      return false;
+    }
+  else
+    return true;
+
+#else
+  // we don't have the IPV6_V6ONLY constant in this system
+  d->ipv6only = enable;
+
+  setError(IO_UnspecifiedError, ENOSYS);
+  return false;			// can't set if we don't know about this flag
+#endif
+}
+
+/*
+ * retrieve the IPV6_V6ONLY flag
+ */
+bool KExtendedSocket::isIPv6Only()
+{
+#ifdef IPV6_V6ONLY
+  cleanError();
+
+  if (d->status < created || sockfd == -1)
+    return d->ipv6only;
+
+  int on;
+  socklen_t onsiz = sizeof(on);
+  if (getsockopt(sockfd, IPPROTO_IPV6, IPV6_V6ONLY,
+		 (char *)&on, &onsiz) == -1)
+    {
+      setError(IO_UnspecifiedError, errno);
+      return false;
+    }
+
+  return d->ipv6only = on;
+
+#else
+  // we don't have the constant
+  setError(IO_UnspecifiedError, ENOSYS);
+  return false;
+#endif
+}
+
 /*
  * Sets the buffer sizes in this socket
  * Also, we create or delete the socket notifiers
@@ -1084,6 +1145,8 @@ int KExtendedSocket::listen(int N)
 
       if (d->addressReusable)
 	setAddressReusable(sockfd, true);
+      setIPv6Only(d->ipv6only);
+      cleanError();
       if (KSocks::self()->bind(sockfd, p->ai_addr, p->ai_addrlen) == -1)
 	{
 	  kdDebug(170) << "Failed to bind: " << perror << endl;
@@ -1262,6 +1325,8 @@ int KExtendedSocket::connect()
 	    continue;		// cannot create this socket
 	  if (d->addressReusable)
 	    setAddressReusable(sockfd, true);
+	  setIPv6Only(d->ipv6only);
+	  cleanError();
 	  if (KSocks::self()->bind(sockfd, q->ai_addr, q->ai_addrlen) == -1)
 	    {
 	      kdDebug(170) << "Bind failed: " << perror << endl;
@@ -1279,13 +1344,17 @@ int KExtendedSocket::connect()
 	      setError(IO_ConnectError, errno);
 	      continue;
 	    }
+	  if (d->addressReusable)
+	    setAddressReusable(sockfd, true);
+	  setIPv6Only(d->ipv6only);
+	  cleanError();
 	}
 
 //      kdDebug(170) << "Socket " << sockfd << " created" << endl;
       d->status = created;
 
       // check if we have to do timeout
-      if (doingtimeout)
+      if (doingtimeout && KSocks::self()->hasWorkingAsyncConnect())
 	{
 	  fd_set rd, wr;
 
@@ -1913,15 +1982,15 @@ void KExtendedSocket::socketActivityRead()
 	      else if (len == 0)
 		{
 		  // EOF condition here
-		  emit closed(involuntary |
-			      (readBufferSize() ? availRead : 0) |
-			      (writeBufferSize() ? dirtyWrite : 0));
 		  ::close(sockfd);
 		  sockfd = -1;	// we're closed
 		  d->qsnIn->deleteLater();
 		  delete d->qsnOut;
 		  d->qsnIn = d->qsnOut = NULL;
 		  d->status = done;
+		  emit closed(involuntary |
+			      (readBufferSize() ? availRead : 0) |
+			      (writeBufferSize() ? dirtyWrite : 0));
 		  return;
 		}
 	      else
@@ -1971,13 +2040,13 @@ void KExtendedSocket::socketActivityWrite()
     {
       // done sending the missing data!
       d->status = done;
-      emit closed(delayed | (readBufferSize() ? availRead : 0));
 
       delete d->qsnOut;
       ::close(sockfd);
 
       d->qsnOut = NULL;
       sockfd = -1;
+      emit closed(delayed | (readBufferSize() ? availRead : 0));
     }
 }
 
@@ -2070,6 +2139,8 @@ void KExtendedSocket::connectionEvent()
 	    continue;		// cannot create this socket
 	  if (d->addressReusable)
 	    setAddressReusable(sockfd, true);
+	  setIPv6Only(d->ipv6only);
+	  cleanError();
 	  if (KSocks::self()->bind(sockfd, q->ai_addr, q->ai_addrlen) == -1)
 	    {
 	      ::close(sockfd);
@@ -2087,9 +2158,14 @@ void KExtendedSocket::connectionEvent()
 	      errcode = errno;
 	      continue;
 	    }
+	  if (d->addressReusable)
+	    setAddressReusable(sockfd, true);
+	  setIPv6Only(d->ipv6only);
+	  cleanError();
 	}
 
-      setBlockingMode(false);
+      if (KSocks::self()->hasWorkingAsyncConnect())
+        setBlockingMode(false);
       if (KSocks::self()->connect(sockfd, p->ai_addr, p->ai_addrlen) == -1)
 	{
 	  if (errno != EWOULDBLOCK && errno != EINPROGRESS)
