@@ -58,6 +58,9 @@ KAccelAction* KGlobalAccel::insert( const QString& sName, const QString& sDesc )
 bool KGlobalAccel::updateConnections()
 	{ return d->updateConnections(); }
 
+bool KGlobalAccel::remove( const QString& sAction )
+        { return d->remove( sAction ); }
+        
 const KShortcut& KGlobalAccel::shortcut( const QString& sAction ) const
 {
 	const KAccelAction* pAction = d->actions().actionPtr( sAction );
@@ -79,6 +82,12 @@ bool KGlobalAccel::readSettings( KConfigBase* pConfig )
 	{ d->readSettings( pConfig ); return true; }
 bool KGlobalAccel::writeSettings( KConfigBase* pConfig ) const
 	{ d->writeSettings( pConfig ); return true; }
+bool KGlobalAccel::writeSettings( KConfigBase* pConfig, bool bGlobal ) const
+{
+	d->setConfigGlobal( bGlobal ); 
+	d->writeSettings( pConfig ); 
+	return true; 
+}
 
 bool KGlobalAccel::useFourModifierKeys()
 	{ return KAccelAction::useFourModifierKeys(); }
