@@ -1,5 +1,5 @@
 /* vi: ts=8 sts=4 sw=4
- * $Id: kiconeffect.cpp,v 1.38.2.1 2002/05/08 10:14:18 pfeiffer Exp $
+ * $Id: kiconeffect.cpp,v 1.44 2002/11/21 19:18:51 pfeiffer Exp $
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -33,14 +33,23 @@
 #include "kiconeffect.h"
 
 extern bool qt_use_xrender;
+extern bool qt_has_xft;
+
+class KIconEffectPrivate
+{
+public:
+	QString mKey[6][3];
+};
 
 KIconEffect::KIconEffect()
 {
+    d = new KIconEffectPrivate;
     init();
 }
 
 KIconEffect::~KIconEffect()
 {
+    delete d;
 }
 
 void KIconEffect::init()
@@ -74,7 +83,8 @@ void KIconEffect::init()
 	// Default effects
 	mEffect[i][0] = NoEffect;
 	mEffect[i][1] =  ((i==0)||(i==4)) ? ToGamma : NoEffect;
-	mEffect[i][2] = NoEffect;
+	mEffect[i][2] = ToGray; 
+	
 	mTrans[i][0] = false;
 	mTrans[i][1] = false;
 	mTrans[i][2] = true;
@@ -108,7 +118,7 @@ void KIconEffect::init()
 	    mTrans[i][j] = config->readBoolEntry(*it2 + "SemiTransparent");
 
 	}
-    }
+    }    
 }
 
 bool KIconEffect::hasEffect(int group, int state) const
@@ -118,19 +128,27 @@ bool KIconEffect::hasEffect(int group, int state) const
 
 QString KIconEffect::fingerprint(int group, int state) const
 {
-    QString s, tmp;
-    s += tmp.setNum(mEffect[group][state]);
-    s += ":";
-    s += tmp.setNum(mValue[group][state]);
-    s += ":";
-    s += mTrans[group][state] ? QString::fromLatin1("trans")
-	    : QString::fromLatin1("notrans");
-    if (mEffect[group][state] == Colorize)
+    if ( group >= KIcon::LastGroup ) return "";
+    QString cached = d->mKey[group][state];
+    if (cached.isEmpty())
     {
-	s += ":";
-	s += mColor[group][state].name();
+        QString tmp;
+        cached = tmp.setNum(mEffect[group][state]);
+        cached += ':';
+        cached += tmp.setNum(mValue[group][state]);
+        cached += ':';
+        cached += mTrans[group][state] ? QString::fromLatin1("trans")
+            : QString::fromLatin1("notrans");
+        if (mEffect[group][state] == Colorize)
+        {
+            cached += ':';
+            cached += mColor[group][state].name();
+        }
+    
+        d->mKey[group][state] = cached;    
     }
-    return s;
+    
+    return cached;
 }
 
 QImage KIconEffect::apply(QImage image, int group, int state) const
@@ -342,7 +360,7 @@ void KIconEffect::semiTransparent(QImage &img)
 	int width  = img.width();
 	int height = img.height();
 	
-	if (qt_use_xrender)
+	if (qt_use_xrender && qt_has_xft )
 	  for (y=0; y<height; y++)
 	  {
 #ifdef WORDS_BIGENDIAN
@@ -408,7 +426,7 @@ void KIconEffect::semiTransparent(QImage &img)
 
 void KIconEffect::semiTransparent(QPixmap &pix)
 {
-    if ( qt_use_xrender )
+    if ( qt_use_xrender && qt_has_xft )
     {
 	QImage img=pix.convertToImage();
 	semiTransparent(img);
