@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kiconloader.h,v 1.101 2002/03/05 23:13:26 rich Exp $
+ * $Id: kiconloader.h,v 1.115 2002/11/22 01:23:20 antlarr Exp $
  *
  * This file is part of the KDE project, module kdecore.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -86,6 +86,13 @@ public:
      * icon search path for the "User" group. The default argument adds the
      * directories of the current application.
      * @param the KStandardDirs object to use. If null the global one is used
+     *
+     * Usually, you use the default iconloader, which can be accessed via
+     * @ref KGlobal::iconLoader(), so you hardly ever have to create an
+     * iconloader object yourself. That one is the current KInstance's 
+     * (typically KApplication's) iconloader.
+     * @see KGlobal::iconLoader()
+     * @see KInstance::iconLoader()
      */
     KIconLoader(const QString& appname=QString::null, KStandardDirs *dirs = 0);
 
@@ -111,12 +118,15 @@ public:
      * @param group The icon group. This will specify the size of and effects to
      * be applied to the icon.
      * @param size If nonzero, this overrides the size specified by @p group.
+     *             See @ref KIcon::StdSizes.
      * @param state The icon state: @p DefaultState, @p ActiveState or
      * @p DisabledState. Depending on the user's preferences, the iconloader
      * may apply a visual effect to hint about its state.
      * @param path_store If not null, the path of the icon is stored here.
      * @param canReturnNull Can return a null pixmap? If false, the
      * "unknown" pixmap is returned when no appropriate icon has been found.
+     * @return the QPixmap. Can be null when not found, depending on
+     *         @p canReturnNull.
      */
     QPixmap loadIcon(const QString& name, KIcon::Group group, int size=0,
 		     int state=KIcon::DefaultState, QString *path_store=0L,
@@ -130,16 +140,44 @@ public:
      * @param group The icon group. This will specify the size of and effects to
      * be applied to the icon.
      * @param size If nonzero, this overrides the size specified by @p group.
+     *             See @ref KIcon::StdSizes.
+     * @param canReturnNull Can return a null iconset? If false, iconset
+     * containing the "unknown" pixmap is returned when no appropriate icon has
+     * been found.
+     * @return the icon set. Can be null when not found, depending on
+     *          @p canReturnNull.
+     * @since 3.1
+     */
+    QIconSet loadIconSet(const QString& name, KIcon::Group group, int size,
+                         bool canReturnNull);
+
+    // KDE4 merge as (const QString&,KIcon::Group,int=0,bool=false);
+    /**
+     * Creates an icon set, that will do on-demand loading of the icon.
+     * Loading itself is done by calling @ref loadIcon .
+     *
+     * @param name The name of the icon, without extension.
+     * @param group The icon group. This will specify the size of and effects to
+     * be applied to the icon.
+     * @param size If nonzero, this overrides the size specified by @p group.
+     *             See @ref KIcon::StdSizes.
+     * @return the icon set. Can be null when not found
      */
     QIconSet loadIconSet(const QString& name, KIcon::Group group, int size=0);
 
     /**
      * Returns the path of an icon.
-     * @param name The name of the icon, without extension.
+     * @param name The name of the icon, without extension. If an absolute
+     * path is supplied for this parameter, iconPath will return it
+     * directly.
      * @param group_or_size If positive, search icons whose size is
      * specified by the icon group @p group_or_size. If negative, search
      * icons whose size is - @p group_or_size.
-     * @param canReturnNull Can return a null pixamp?
+     *             See @ref KIcon::Group and @ref KIcon::StdSizes
+     * @param canReturnNull Can return a null string? If not, a path to the
+     *                      "unknown" icon will be returned.
+     * @return the path of an icon, can be null or the "unknown" icon when
+     *         not found, depending on @p canReturnNull.
      */
     QString iconPath(const QString& name, int group_or_size,
 		     bool canReturnNull=false) const;
@@ -149,15 +187,17 @@ public:
      * @param name The name of the icon.
      * @param group The icon group. See @ref loadIcon().
      * @param size Override the default size for @p group.
-     * @return A QMovie object.
+     *             See @ref KIcon::StdSizes.
+     * @return A QMovie object. Can be null if not found.
      */
     QMovie loadMovie(const QString& name, KIcon::Group group, int size=0) const;
-    
+
     /**
      * Returns the path to an animated icon.
      * @param name The name of the icon.
      * @param group The icon group. See @ref loadIcon().
      * @param size Override the default size for @p group.
+     *             See @ref KIcon::StdSizes.
      * @return the full path to the movie, ready to be passed to QMovie's constructor.
      * Empty string if not found.
      */
@@ -169,6 +209,7 @@ public:
      * @param name The name of the icon.
      * @param group The icon group. See @ref loadIcon().
      * @param size Override the default size for @p group.
+     *             See @ref KIcon::StdSizes.
      * @return A QStringList containing the absolute path of all the frames
      * making up the animation.
      */
@@ -177,8 +218,12 @@ public:
     /**
      * Queries all available icons for a specific group, having a specific
      * context.
-     * @param group_or_size The icon group or size. See @ref #iconPath.
+     * @param group_or_size If positive, search icons whose size is
+     * specified by the icon group @p group_or_size. If negative, search
+     * icons whose size is - @p group_or_size.
+     *             See @ref KIcon::Group and @ref KIcon::StdSizes
      * @param context The icon context.
+     * @return a list of all icons
      */
     QStringList queryIcons(int group_or_size, KIcon::Context context=KIcon::Any) const;
 
@@ -186,7 +231,9 @@ public:
      * Queries all available icons for a specific context.
      * @param group_or_size The icon preferred group or size. If available
      * at this group or size, those icons will be returned, in other case,
-     * icons of undefined size will be returned.
+     * icons of undefined size will be returned. Positive numbers are groups,
+     * negative numbers are negated sizes. See @ref KIcon::Group and
+     *    @ref KIcon::StdSizes
      * @param context The icon context.
      * @return A QStringList containing the icon names
      * available for that context
@@ -195,6 +242,17 @@ public:
 				    KIcon::Context context=KIcon::Any) const;
 
     /**
+     * Returns a list of all icons (*.png or *.xpm extension) in the
+     * given directory.
+     * @param iconsDir the directory to search in
+     * @return A QStringList containing the icon paths
+     * @since 3.1
+     */
+    QStringList queryIconsByDir( const QString& iconsDir ) const;
+
+    /**
+     * Returns the current size of the group.
+     * @param group the group to check.
      * @return the current size for an icon group.
      */
     int currentSize(KIcon::Group group) const;
@@ -202,31 +260,83 @@ public:
     /**
      * Returns a pointer to the current theme. Can be used to query
      * available and default sizes for groups.
+     * @return a pointer to the current theme. 0 if no theme set.
      */
     KIconTheme *theme() const;
 
     /**
      * Returns a pointer to the KIconEffect object used by the icon loader.
+     * @return the KIconEffect.
      */
     KIconEffect *iconEffect() const;
 
     /**
-     * Called by KInstance::newIconLoader to reconfigure the icon loader
+     * Called by KInstance::newIconLoader to reconfigure the icon loader.
+     * @param _appname the new application name
+     * @param _dirs the new standard directories. If 0, the directories
+     *              from @ref KGlobal will be taken.
      */
     void reconfigure( const QString& _appname, KStandardDirs *_dirs );
 
     /**
      * Returns the unknown icon. An icon that is used when no other icon
      * can be found.
+     * @return the unknown pixmap
      */
     static QPixmap unknown();
 
     /**
      * Returns if the user wants to use blend the icons with the background
      *  using the alpha channel information for a given group.
+     * @param group the group to check
+     * @return true if alpha blending is desired
+     * @obsolete
      */
     bool alphaBlending( KIcon::Group group ) const;
 
+    /**
+     * Adds all the default themes from other desktops at the end of
+     * the list of icon themes.
+     * @since 3.1
+     */
+    void addExtraDesktopThemes();
+
+    /**
+     * Returns if the default icon themes of other desktops have been added
+     * to the list of icon themes where icons are searched.
+     * @since 3.1
+     */ 
+    bool extraDesktopThemesAdded() const;
+
+    /**
+     * Enables on-demand icon loading for QIconSets using @ref QIconFactory.
+     * Icons loaded via @ref loadIconSet() will be loaded as soon as they
+     * need to be displayed, not earlier.
+     *
+     * Note that enabling or disabling this only affects @ref loadIconSet()
+     * calls after this setting is changed.
+     *
+     * The default is disabled, as the iconloader object must not be 
+     * destroyed before all those iconsets are destroyed.
+     *
+     * (Some broken applications use temporary KIconLoader objects).
+     * Every @ref KInstance 's iconloader has this feature enabled.
+     *
+     * @see isDelayedIconSetLoadingEnabled()
+     * @see QIconFactory
+     * @since 3.1
+     */
+    void enableDelayedIconSetLoading( bool enable );
+
+    /**
+     * @return whether icons for QIconSets will be loaded on demand.
+     * @see enableDelayedIconSetLoading()
+     * @see QIconFactory
+     * @since 3.1
+     */
+    bool isDelayedIconSetLoadingEnabled() const;
+
+
  private:
     /**
      * @internal
@@ -248,18 +358,37 @@ public:
 
     /**
      * @internal
-     * adds themes installed in the application's directory. Only locolor
-     * and hicolor are currently supported to be installed in kde_datadir
+     * Adds themes installed in the application's directory.
      **/
     void addAppThemes(const QString& appname);
 
     /**
-     * adds all themes that are part of this node and the themes
+     * Adds all themes that are part of this node and the themes
      * below (the fallbacks of the theme) in the tree.
      * @internal
      */
     void addBaseThemes(KIconThemeNode *node, const QString &appname);
 
+    /**
+     * @internal
+     * return the path for the unknown icon in that size
+     * @since 3.1
+     */
+    QString unknownIconPath( int size ) const;
+
+    /**
+     * Checks if name ends in one of the supported icon formats (i.e. .png)
+     * and returns the name without the extension if it does.
+     * @since 3.1
+     */
+    QString removeIconExtension(const QString &name) const;
+
+    /**
+     * Loads all the different sizes for an iconset.
+     */
+    QIconSet loadIconSetNonDelayed( const QString& name, KIcon::Group group,
+                                    int size, bool canReturnNull );
+    
     // @internal the data object
     KIconLoaderPrivate *d;
 };
