@@ -43,6 +43,7 @@ public:
     }
 
     KMimeSourceFactory* mimeSourceFactory;
+    QString configName;
     bool ownAboutdata;
 };
 
@@ -143,10 +144,30 @@ KStandardDirs *KInstance::dirs() const
 KConfig	*KInstance::config() const
 {
     if( _config == 0 ) {
-	if ( !_name.isEmpty() )
-	    _config = new KConfig( _name + "rc");
-	else
-	    _config = new KConfig();
+        if ( !d->configName.isEmpty() )
+        {
+            _config = new KConfig( d->configName );
+            // Check whether custom config files are allowed.
+            _config->setGroup( "KDE Action Restrictions" );
+            if (_config->readBoolEntry( "custom_config", true))
+            {
+               _config->setGroup(QString::null);
+            }
+            else
+            {
+               delete _config;
+               _config = 0;
+            }
+
+        }
+
+        if ( _config == 0 )
+        {
+	    if ( !_name.isEmpty() )
+	        _config = new KConfig( _name + "rc");
+	    else
+	        _config = new KConfig();
+	}
         if (_dirs)
             if (_dirs->addCustomized(_config))
                 _config->reparseConfiguration();
@@ -155,10 +176,16 @@ KConfig	*KInstance::config() const
     return _config;
 }
 
+void KInstance::setConfigName(const QString &configName)
+{
+    d->configName = configName;
+}
+
 KIconLoader *KInstance::iconLoader() const
 {
     if( _iconLoader == 0 ) {
 	_iconLoader = new KIconLoader( _name, dirs() );
+    _iconLoader->enableDelayedIconSetLoading( true );
     }
 
     return _iconLoader;
