@@ -1,6 +1,8 @@
+// -*- c-basic-offset: 2 -*-
 /* This file is part of the KDE libraries
     Copyright (C) 1997 Stephan Kulow <coolo@kde.org>
     Copyright (C) 1999-2001 Hans Petter Bieker <bieker@kde.org>
+    Copyright (c) 2002 Lukas Tinkl <lukas@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -45,7 +47,7 @@ class KCatalogue;
  *  language.
  *
  *  The argument must be an UTF-8 encoded string (If you only use
- *  characters that are in US-ASCII you're on the safe side. But
+ *  characters that are in US-ASCII, you're on the safe side. But
  *  for e.g. german umlauts or french accents should be recoded to
  *  UTF-8)
  **/
@@ -66,11 +68,13 @@ QString i18n(const char *index, const char *text);
  **/
 QString i18n(const char *singular, const char *plural, unsigned long n);
 
-// Qt3's uic generates i18n( "msg", "comment" ) calls which conflict
-// with our i18n method. we use uic -tr tr2i18n to redirect
-// to the right i18n() function
+/**
+ * Qt3's uic generates i18n( "msg", "comment" ) calls which conflict
+ * with our i18n method. We use uic -tr tr2i18n to redirect
+ * to the right i18n() function
+**/
 inline QString tr2i18n(const char* message, const char* =0) {
-  return i18n( message);
+  return i18n(message);
 }
 
 /**
@@ -81,7 +85,8 @@ inline QString tr2i18n(const char* message, const char* =0) {
   * KLocale supports translating, as well as specifying the format
   * for numbers, currency, time, and date.
   *
-  * @author Stephan Kulow <coolo@kde.org>, Preston Brown <pbrown@kde.org>, Hans Petter Bieker <bieker@kde.org>
+  * @author Stephan Kulow <coolo@kde.org>, Preston Brown <pbrown@kde.org>,
+  * Hans Petter Bieker <bieker@kde.org>, Lukas Tinkl <lukas.tinkl@suse.cz>
   * @short class for supporting locale settings and national language
   */
 class KLocale
@@ -168,6 +173,16 @@ public:
    */
   QString translate( const char *index, const char *fallback) const;
 
+  /**
+   * Used to get the correct, translated singular or plural of a
+   * word.
+   * @param singular the singular form of the word, for example "file".
+   * @param plural the plural form of the word. Must contain a "%n" that will
+   *               be replaced by the number @n, for example "%n files"
+   * @param n the number
+   * @return the correct singular or plural for the selected language,
+   *         depending on n
+   */
   QString translate( const char *singular, const char *plural,
 		     unsigned long n) const;
 
@@ -311,7 +326,7 @@ public:
    * If and only if the currency symbol precedes a negative value,
    * this will be true.
    *
-   * @return Where to print the currency symbol for negative numbers.
+   * @return True if the currency symbol precedes negative numbers.
    */
   bool negativePrefixCurrencySymbol() const;
 
@@ -341,9 +356,11 @@ public:
    *
    * @param num The number we want to format
    * @param currency The currency symbol you want.
-   * @param digits Number of fractional digits.
+   * @param digits Number of fractional digits, or -1 for the default
+   *               value
    *
    * @return The number of money as a localized string
+   * @see fracDigits()
    */
   QString formatMoney(double num,
 		      const QString & currency = QString::null,
@@ -387,17 +404,36 @@ public:
   QString formatNumber(const QString &numStr) const;
 #endif
 
+  /**
+   * Use this to determine whether nouns are declined in
+   * locale's language. This property should remain
+   * read-only (no setter function)
+   *
+   * @return If nouns are declined
+   * @since 3.1
+   */
+   bool nounDeclension() const;
+
   /**
    * Returns a string formatted to the current locale's conventions
    * regarding dates.
    *
    * @param pDate The date to be formated.
-   * @param shotFormat True for non text dates.
+   * @param shortFormat True for non text dates.
    *
    * @return The date as a string
    */
   QString formatDate(const QDate &pDate, bool shortFormat = false) const;
 
+  /**
+   * Use this to determine whether in dates a possessive form of month
+   * name is preferred ("of January" rather than "January")
+   *
+   * @return If possessive form should be used
+   * @since 3.1
+  */
+  bool dateMonthNamePossessive() const;
+
   /**
    * Returns a string formatted to the current locale's conventions
    * regarding times.
@@ -418,11 +454,23 @@ public:
   bool use12Clock() const;
 
   /**
+   * @deprecated
+   *
+   * Please use the @ref weekStartDay method instead.
+   *
    * Use this to determine if the user wants the week to start on Monday.
    *
    * @return true if the week starts on Monday
    */
-  bool weekStartsMonday() const;
+  bool weekStartsMonday() const; //### remove for KDE 4.0
+
+  /**
+   * Use this to determine which day is the first day of the week.
+   *
+   * @return an integer (Monday=1..Sunday=7)
+   * @since 3.1
+   */
+  int weekStartDay() const;
 
   /**
    * Returns a string containing the name of the month name.
@@ -434,13 +482,26 @@ public:
    */
   QString monthName(int i, bool shortName = false) const;
 
+  /**
+   * Returns a string containing the possessive form of the month name.
+   * ("of January", "of February", etc.)
+   * It's needed in long format dates in some languages.
+   *
+   * @param i the month number of the year starting at 1/January.
+   * @param shortName we will return the short version of the string.
+   *
+   * @return The possessive form of the name of the month
+   * @since 3.1
+  */
+  QString monthNamePossessive(int i, bool shortName = false) const;
+
   /**
    * Returns a string containing the name of the week day.
    *
    * @param i the day number of the week starting at 1/Monday.
    * @param shortName we will return the short version of the string.
    *
-   * @return The name of the week
+   * @return The name of the day
    */
   QString weekDayName(int i, bool shortName = false) const;
 
@@ -463,6 +524,7 @@ public:
    *
    * @param numStr the string we want to convert.
    * @param ok the boolean that is set to false if it's not a number.
+   *           If @p ok is 0, it will be ignored
    *
    * @return The string converted to a double
    */
@@ -473,6 +535,7 @@ public:
    *
    * @param numStr the string we want to convert.
    * @param ok the boolean that is set to false if it's not a number.
+   *           If @p ok is 0, it will be ignored
    *
    * @return The string converted to a double
    */
@@ -484,6 +547,7 @@ public:
    *
    * @param str the string we want to convert.
    * @param ok the boolean that is set to false if it's not a valid date.
+   *           If @p ok is 0, it will be ignored
    *
    * @return The string converted to a QDate
    */
@@ -501,6 +565,7 @@ public:
    *
    * @param str the string we want to convert.
    * @param ok the boolean that is set to false if it's not a valid time.
+   *           If @p ok is 0, it will be ignored
    *
    * @return The string converted to a QTime
    */
@@ -603,44 +668,108 @@ public:
   /**
    * Changes the current date format.
    *
+   * The format of the date is a string which contains variables that will
+   * be replaced:
+   * @li %Y with the century (e.g. "19" for "1984")
+   * @li %y with the lower 2 digits of the year (e.g. "84" for "1984")
+   * @li %n with the month (January="1", December="12")
+   * @li %m with the month with two digits (January="01", December="12")
+   * @li %e with the day of the month (e.g. "1" on the first of march)
+   * @li %d with the day of the month with two digits(e.g. "01" on the first of march)
+   * @li %b with the short form of the month (e.g. "Jan" for January)
+   * @li %a with the short form of the weekday (e.g. "Wed" for Wednesday)
+   * @li %A with the long form of the weekday (e.g. "Wednesday" for Wednesday)
+   * Everything else in the format string will be taken as is.
+   * For example, March 20th 1989 with the format "%y:%m:%d" results
+   * in "89:03:20".
+   *
    * @param format The new date format
    */
   void setDateFormat(const QString & format);
   /**
    * Changes the current short date format.
    *
+   * The format of the date is a string which contains variables that will
+   * be replaced:
+   * @li %Y with the century (e.g. "19" for "1984")
+   * @li %y with the lower 2 digits of the year (e.g. "84" for "1984")
+   * @li %n with the month (January="1", December="12")
+   * @li %m with the month with two digits (January="01", December="12")
+   * @li %e with the day of the month (e.g. "1" on the first of march)
+   * @li %d with the day of the month with two digits(e.g. "01" on the first of march)
+   * @li %b with the short form of the month (e.g. "Jan" for January)
+   * @li %a with the short form of the weekday (e.g. "Wed" for Wednesday)
+   * @li %A with the long form of the weekday (e.g. "Wednesday" for Wednesday)
+   * Everything else in the format string will be taken as is.
+   * For example, March 20th 1989 with the format "%y:%m:%d" results
+   * in "89:03:20".
+   *
    * @param format The new short date format
    */
   void setDateFormatShort(const QString & format);
+  /**
+   * Changes the form of month name used in dates.
+   *
+   * @param possessive True if possessive forms should be used
+   * @since 3.1
+   */
+  void setDateMonthNamePossessive(bool possessive);
   /**
    * Changes the current time format.
    *
+   * The format of the time is string a which contains variables that will
+   * be replaced:
+   * @li %H with the hour in 24h format and 2 digits (e.g. 5pm is "17", 5am is "05")
+   * @li %k with the hour in 24h format and one digits (e.g. 5pm is "17", 5am is "5")
+   * @li %I with the hour in 12h format and 2 digits (e.g. 5pm is "05", 5am is "05")
+   * @li %l with the hour in 12h format and one digits (e.g. 5pm is "5", 5am is "5")
+   * @li %M with the minute with 2 digits (e.g. the minute of 07:02:09 is "02")
+   * @li %S with the seconds with 2 digits  (e.g. the minute of 07:02:09 is "09")
+   * @li %p with pm or am (e.g. 17.00 is "pm", 05.00 is "am")
+   * Everything else in the format string will be taken as is.
+   * For example, 5.23pm with the format "%H:%M" results
+   * in "17:23".
+   *
    * @param format The new time format
    */
   void setTimeFormat(const QString & format);
 
   /**
+   * @deprecated
+   *
+   * Please use @ref setWeekStartDay instead.
+   *
    * Changes how KLocale defines the first day in week.
    *
    * @param start True if Monday is the first day in the week
    */
-  void setWeekStartsMonday(bool start);
+  void setWeekStartsMonday(bool start); //### remove for KDE 4.0
+  /**
+   * Changes how KLocale defines the first day in week.
+   *
+   * @param day first day of the week (Monday=1..Sunday=7) as integer
+   * @since 3.1
+   */
+  void setWeekStartDay(int day);
   /**
    * Returns the currently selected date format.
    *
    * @return Current date format.
+   * @see setDateFormat()
    */
   QString dateFormat() const;
   /**
    * Returns the currently selected short date format.
    *
    * @return Current short date format.
+   * @see setDateFormatShort()
    */
   QString dateFormatShort() const;
   /**
    * Returns the currently selected time format.
    *
    * @return Current time format.
+   * @see setTimeFormat()
    */
   QString timeFormat() const;
 
@@ -769,19 +898,59 @@ public:
    */
   void insertCatalogue(const QString& catalogue);
 
+  /**
+   * Removes a catalog for translation lookup.
+   * @param catalogue The catalogue to remove.
+   * @see insertCatalogue()
+   */
   void removeCatalogue(const QString &catalogue);
 
+  /**
+   * Sets the active catalog for translation lookup.
+   * @param catalogue The catalogue to activate.
+   */
   void setActiveCatalogue(const QString &catalogue);
 
   /**
    * Translates a message as a QTranslator is supposed to.
    * The parameters are similar to i18n(), but the result
    * value has other semantics (it can be QString::null)
+   * @since 3.1
    **/
-  QString translateQt(const char *context, 
-		      const char *sourceText, 
+  QString translateQt(const char *context,
+		      const char *sourceText,
 		      const char *message) const;
 
+  /**
+   * Returns list of all known ISO 639-1 codes.
+   * @return a list of all language codes
+   * @since 3.1
+   */
+  QStringList allLanguagesTwoAlpha() const;
+
+  /**
+   * Convert a ISO 639-1 code to a human readable form.
+   * @param code the language ISO 639-1 code
+   * @return the human readable form
+   * @since 3.1
+   */
+  QString twoAlphaToLanguageName(const QString &code) const;
+
+  /**
+   * Returns list of all known country codes.
+   * @return a list of all country codes
+   * @since 3.1
+   */
+  QStringList allCountriesTwoAlpha() const;
+
+  /**
+   * Convert a country code to a human readable form.
+   * @param code the country code
+   * @return the human readable form of the country name
+   * @since 3.1
+   */
+  QString twoAlphaToCountryName(const QString &code) const;
+
   /**
    * Returns the parts of the parameter str understood as language setting
    * the format is language_COUNTRY.charset
@@ -798,7 +967,10 @@ public:
 
   /**
    * Use this to as main catalogue for *all* KLocales, if not the appname
-   * will be used.
+   * will be used. This function is best to be the very first instruction
+   * in your program's main function as it only has an effect before the
+   * first KLocale object is created (and this is in common KDE applications
+   * quite early).
    *
    * @param catalogue Catalogue to override all other main catalogues.
    */
@@ -826,6 +998,7 @@ public:
    */
   static QString defaultCountry();
 
+
   /**
    * @internal Called from KConfigBackend to initialize language.
    */
@@ -872,15 +1045,15 @@ private:
 
   /**
    * @internal Figures out which encoding the user prefers for filenames
-   * and sets up the appropriate QFile encoding and decoding functions. 
+   * and sets up the appropriate QFile encoding and decoding functions.
    */
   void initFileNameEncoding(KConfig *config);
-  
+
   /**
    * @internal A QFile filename encoding function (QFile::encodeFn).
    */
   static QCString encodeFileNameUTF8( const QString & fileName );
-  
+
   /**
    * @internal QFile filename decoding function (QFile::decodeFn).
    */
@@ -962,7 +1135,7 @@ private:
   QString m_language;
   QString m_country;
 
-  bool m_weekStartsMonday;
+  bool m_weekStartsMonday; //### remove for KDE 4.0
   bool m_positivePrefixCurrencySymbol;
   bool m_negativePrefixCurrencySymbol;
 
