@@ -2,32 +2,33 @@
    Copyright (C) 2000-2001 Dawit Alemayehu <adawit@kde.org>
    Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
 
-   This program is free software; you can redistribute it and/or modify it
-   under the terms of the GNU Lesser General Public License (LGPL) as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU Lesser General Public License (LGPL)
+   version 2 as published by the Free Software Foundation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
+   You should have received a copy of the GNU Library General Public
+   License along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-   The KMD5 class is based upon a C++ implementation of "RSA
-   Data Security, Inc. MD5 Message-Digest Algorithm" by Mordechai
-   T. Abzug,	Copyright (c) 1995.  This implementation passes the
-   test-suite supplied with RFC 1321.
-
-   RFC 1321 "MD5 Message-Digest Algorithm" Copyright (C) 1991-1992,
+   RFC 1321 "MD5 Message-Digest Algorithm" Copyright (C) 1991-1992.
    RSA Data Security, Inc. Created 1991. All rights reserved.
 
+   The KMD5 class is based on a C++ implementation of
+   "RSA Data Security, Inc. MD5 Message-Digest Algorithm" by
+   Mordechai T. Abzug,	Copyright (c) 1995.  This implementation
+   passes the test-suite as defined in RFC 1321.
+
    The encoding and decoding utilities in KCodecs with the exception of
-   quoted-printable were ported from the HTTPClient java package by Ronald
-   Tschalr Copyright (C) 1996-1999. The quoted-printable codec as described
-   in RFC 2045, section 6.7. is by Rik Hemsley (C) 2001.
+   quoted-printable are based on the java implementation in HTTPClient
+   package by Ronald Tschalr Copyright (C) 1996-1999.
+
+   The quoted-printable codec as described in RFC 2045, section 6.7. is by
+   Rik Hemsley (C) 2001.
 */
 
 #include <config.h>
@@ -443,7 +444,7 @@ void KCodecs::base64Encode( const QByteArray& in, QByteArray& out,
     }
 }
 
-QCString KBase64::base64Decode( const QCString& str )
+QCString KCodecs::base64Decode( const QCString& str )
 {
     if ( str.isEmpty() )
         return "";
@@ -453,14 +454,14 @@ QCString KBase64::base64Decode( const QCString& str )
     return base64Decode( in );
 }
 
-QCString KBase64::base64Decode( const QByteArray& in )
+QCString KCodecs::base64Decode( const QByteArray& in )
 {
     QByteArray out;
     base64Decode( in, out );
     return QCString( out.data(), out.size()+1 );
 }
 
-void KBase64::base64Decode( const QByteArray& in, QByteArray& out )
+void KCodecs::base64Decode( const QByteArray& in, QByteArray& out )
 {
     out.resize(0);
     if ( in.isEmpty() )
@@ -500,7 +501,7 @@ void KBase64::base64Decode( const QByteArray& in, QByteArray& out )
     {
         // Adhere to RFC 2045 and ignore characters
         // that are not part of the encoding table.
-        char ch = data[idx];
+        unsigned char ch = data[idx];
         if ((ch > 47 && ch < 58) || (ch > 64 && ch < 91) ||
             (ch > 96 && ch < 123) || ch == '+' || ch == '/' || ch == '=')
         {
@@ -693,17 +694,17 @@ void KCodecs::uudecode( const QByteArray& in, QByteArray& out )
     while ( sidx < len )
     {
         // get line length (in number of encoded octets)
-        line_len = UUDecMap[data[sidx++]];
+        line_len = UUDecMap[ (unsigned char) data[sidx++]];
         // ascii printable to 0-63 and 4-byte to 3-byte conversion
         end = didx+line_len;
         char A, B, C, D;
         if (end > 2) {
           while (didx < end-2)
           {
-             A = UUDecMap[data[sidx]];
-             B = UUDecMap[data[sidx+1]];
-             C = UUDecMap[data[sidx+2]];
-             D = UUDecMap[data[sidx+3]];
+             A = UUDecMap[(unsigned char) data[sidx]];
+             B = UUDecMap[(unsigned char) data[sidx+1]];
+             C = UUDecMap[(unsigned char) data[sidx+2]];
+             D = UUDecMap[(unsigned char) data[sidx+3]];
              out[didx++] = ( ((A << 2) & 255) | ((B >> 4) & 003) );
              out[didx++] = ( ((B << 4) & 255) | ((C >> 2) & 017) );
              out[didx++] = ( ((C << 6) & 255) | (D & 077) );
@@ -713,15 +714,15 @@ void KCodecs::uudecode( const QByteArray& in, QByteArray& out )
 
         if (didx < end)
         {
-            A = UUDecMap[data[sidx]];
-            B = UUDecMap[data[sidx+1]];
+            A = UUDecMap[(unsigned char) data[sidx]];
+            B = UUDecMap[(unsigned char) data[sidx+1]];
             out[didx++] = ( ((A << 2) & 255) | ((B >> 4) & 003) );
         }
 
         if (didx < end)
         {
-            B = UUDecMap[data[sidx+1]];
-            C = UUDecMap[data[sidx+2]];
+            B = UUDecMap[(unsigned char) data[sidx+1]];
+            C = UUDecMap[(unsigned char) data[sidx+2]];
             out[didx++] = ( ((B << 4) & 255) | ((C >> 2) & 017) );
         }
 
@@ -844,8 +845,8 @@ void KMD5::finalize ()
         0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
     };
 
-    //encode (bits, m_count, 8);
-    memcpy( bits, m_count, 8 );
+    encode (bits, m_count, 8);
+    //memcpy( bits, m_count, 8 );
 
     // Pad out to 56 mod 64.
     index = static_cast<Q_UINT32>((m_count[0] >> 3) & 0x3f);
@@ -856,8 +857,8 @@ void KMD5::finalize ()
     update (reinterpret_cast<const char*>(bits), 8);
 
     // Store state in digest
-    //encode (m_digest, m_state, 16);
-    memcpy( m_digest, m_state, 16 );
+    encode (m_digest, m_state, 16);
+    //memcpy( m_digest, m_state, 16 );
 
     // Fill sensitive information with zero's
     memset ( (void *)m_buffer, 0, sizeof(*m_buffer));
@@ -953,6 +954,7 @@ void KMD5::transform( const unsigned char block[64] )
 
     decode (x, block, 64);
     //memcpy( x, block, 64 );
+
     Q_ASSERT(!m_finalized);  // not just a user error, since the method is private
 
     /* Round 1 */
