@@ -3,31 +3,32 @@
    Copyright (C) 2001 Rik Hemsley (rikkus) <rik@kde.org>
 
    This program is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Lesser General Public License (LGPL) as
-   published by the Free Software Foundation; either version 2 of the
-   License, or (at your option) any later version.
+   it under the terms of the GNU Lesser General Public License (LGPL)
+   version 2 as published by the Free Software Foundation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
 
-   You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
+   You should have received a copy of the GNU Library General Public
+   License along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-   The KMD5 class is based on a C++ implementation of
-   "RSA Data Security, Inc. MD5 Message-Digest Algorithm" by
-   Mordechai T. Abzug,	Copyright (c) 1995.  This implementation
-   passes the test-suite as defined by RFC 1321.
-
    RFC 1321 "MD5 Message-Digest Algorithm" Copyright (C) 1991-1992.
    RSA Data Security, Inc. Created 1991. All rights reserved.
 
+   The KMD5 class is based on a C++ implementation of
+   "RSA Data Security, Inc. MD5 Message-Digest Algorithm" by
+   Mordechai T. Abzug,	Copyright (c) 1995.  This implementation
+   passes the test-suite as defined in RFC 1321.
+
    The encoding and decoding utilities in KCodecs with the exception of
-   quoted-printable were ported from the HTTPClient java package by Ronald
-   Tschalr Copyright (C) 1996-1999. The quoted-printable codec as described
-   in RFC 2045, section 6.7. is by Rik Hemsley (C) 2001.
+   quoted-printable are based on the java implementation in HTTPClient
+   package by Ronald Tschalr Copyright (C) 1996-1999.
+
+   The quoted-printable codec as described in RFC 2045, section 6.7. is by
+   Rik Hemsley (C) 2001.
 */
 
 #ifndef _KMDBASE_H
@@ -89,7 +90,7 @@ public:
    * Same as above except it accepts a null terminated
    * string instead an array.
    *
-   * @param in      data to be encoded.
+   * @param str     data to be encoded.
    * @param useCRLF if true the input data is expected to have
    *                CRLF line breaks and the output will have CRLF line
    *                breaks, too.
@@ -294,8 +295,8 @@ public:
    * output array will be lost.
    *
    * @param in        the data to be encoded using base64.
-   * @param insertLFs limit the number of characters per line.
    * @param out       the container for the encoded data.
+   * @param insertLFs limit the number of characters per line.
    */
   static void base64Encode( const QByteArray& in, QByteArray& out,
                             bool insertLFs = false );
@@ -437,7 +438,7 @@ public:
    * before you read the digest. After reading the digest, you
    * can <b>not</b> add more data!
    *
-   * @param input  message to be added to digest
+   * @param in     message to be added to digest
    * @param len    the length of the given message.
    */
   void update(const char* in, int len = -1) { update(reinterpret_cast<const unsigned char*>(in), len); }
@@ -450,14 +451,14 @@ public:
   /**
    * @overload
    *
-   * @param input  message to be added to the digest (QByteArray).
+   * @param in     message to be added to the digest (QByteArray).
    */
   void update(const QByteArray& in );
 
   /**
    * @overload
    *
-   * @param input  message to be added to the digest (QByteArray).
+   * @param in     message to be added to the digest (QByteArray).
    */
   void update(const QCString& in );
 
@@ -530,7 +531,7 @@ protected:
    *  Performs the real update work.  Note
    *  that length is implied to be 64.
    */
-  void transform( const unsigned char* buffer );
+  void transform( const unsigned char buffer[64] );
 
   /**
    * finalizes the digest
