@@ -30,7 +30,7 @@
 #include <kdebug.h>
 #include <kstaticdeleter.h>
 
-static const char * const daemonName="knotify";
+static const char daemonName[] = "knotify";
 
 static bool sendNotifyEvent(const QString &message, const QString &text,
                  int present, int level, const QString &sound,
@@ -138,9 +138,9 @@ QString KNotifyClient::getFile(const QString &eventname, int present)
 	switch (present)
 	{
 	case (Sound):
-		return eventsfile.readEntry("soundfile");
+		return eventsfile.readPathEntry("soundfile");
 	case (Logfile):
-		return eventsfile.readEntry("logfile");
+		return eventsfile.readPathEntry("logfile");
 	}
 
 	return QString::null;
@@ -169,9 +169,9 @@ QString KNotifyClient::getDefaultFile(const QString &eventname, int present)
 	switch (present)
 	{
 	case (Sound):
-		return eventsfile.readEntry("default_sound");
+		return eventsfile.readPathEntry("default_sound");
 	case (Logfile):
-		return eventsfile.readEntry("default_logfile");
+		return eventsfile.readPathEntry("default_logfile");
 	}
 
 	return QString::null;
@@ -179,8 +179,11 @@ QString KNotifyClient::getDefaultFile(const QString &eventname, int present)
 
 bool KNotifyClient::startDaemon()
 {
-  if (!kapp->dcopClient()->isApplicationRegistered(daemonName))
+  static bool firstTry = true;
+  if (firstTry && !kapp->dcopClient()->isApplicationRegistered(daemonName)) {
+    firstTry = false;
     return KApplication::startServiceByDesktopName(daemonName) == 0;
+  }
   return true;
 }
 
