@@ -56,6 +56,8 @@ KProcessController::KProcessController()
 	printf(strerror(errno));
 
   fcntl(fd[0], F_SETFL, O_NONBLOCK);
+  fcntl(fd[0], F_SETFD, FD_CLOEXEC);
+  fcntl(fd[1], F_SETFD, FD_CLOEXEC);
 
   notifier = new QSocketNotifier(fd[0], QSocketNotifier::Read);
   notifier->setEnabled(true);
@@ -144,6 +146,8 @@ struct waitdata
 void KProcessController::theSigCHLDHandler(int arg)
 {
   struct waitdata wd;
+//  int status;
+//  pid_t this_pid;
   int saved_errno;
 
   saved_errno = errno;
@@ -188,7 +192,7 @@ void KProcessController::slotDoHousekeeping(int )
 {
   // NOTE: It can happen that QSocketNotifier fires while
   // we have already read from the socket. Deal with it.
-  unsigned int bytes_read = 0;
+  int bytes_read = 0;
   // read pid and status from the pipe.
   struct waitdata wd;
   do {
@@ -202,7 +206,7 @@ void KProcessController::slotDoHousekeeping(int )
 	return;           // it makes no sense to continue here!
     }
   } while (bytes_read <= 0);
-
+  
   if (bytes_read != sizeof(wd)) {
 	fprintf(stderr,
 	       "Error: Could not read info from signal handler %d <> %d!\n",
@@ -248,7 +252,7 @@ void KProcessController::delayedChildrenCleanup()
         if( !(*it)->isRunning() || (*it)->pid() != wd.pid )
             continue;
         // it's KProcess, handle it
-          ::write(fd[1], &wd, sizeof(wd));
+        ::write(fd[1], &wd, sizeof(wd));
         break;
       }
   }
