@@ -60,7 +60,7 @@ class KProcessPrivate;
  *not interested in any notification to determine whether the
  *child process has already exited or not.
  *
- *@li  KProcess::NotifyOnExit -- The child process is invoked both the
+ *@li  KProcess::NotifyOnExit -- The child process is invoked and both the
  *child and the parent process run concurrently.
  *
  *When the child process exits, the KProcess instance
@@ -155,7 +155,7 @@ public:
    * If communication for more than one channel is required,
    * the values have to be or'ed together, for example to get
    * communication with stdout as well as with stdin, you would
-   * specify @p Stdin @p | @p Stdout
+   * specify @p Stdin | @p Stdout
    *
    * If @p NoRead is specified in conjunction with @p Stdout,
    * no data is actually read from @p Stdout but only
@@ -224,6 +224,8 @@ public:
    *  p << "ls" << "-l" << "/usr/local/bin"
    *  </pre>
    *
+   * @param arg the argument to add
+   * @return a reference to this KProcess
    **/
   KProcess &operator<<(const QString& arg);
   /**
@@ -232,12 +234,16 @@ public:
   KProcess &operator<<(const char * arg);
   /**
    * Similar to previous method, takes a QCString, supposed to be in locale 8 bit already.
+   * @param arg the argument to add
+   * @return a reference to this KProcess
    */
   KProcess &operator<<(const QCString & arg);
 
   /**
    * Sets the executable and the command line argument list for this process,
    * in a single method call, or add a list of arguments.
+   * @param arg the arguments to add
+   * @return a reference to this KProcess
    **/
   KProcess &operator<<(const QStringList& args);
 
@@ -261,6 +267,7 @@ public:
    *  @li The starting of the process failed (could not fork).
    *  @li The executable was not found.
    *
+   *  @param runmode The Run-mode for the process.
    *  @param comm  Specifies which communication links should be
    *  established to the child process (stdin/stdout/stderr). By default,
    *  no communication takes place and the respective communication
@@ -276,12 +283,13 @@ public:
    * Stop the process (by sending it a signal).
    *
    * @param signo	The signal to send. The default is SIGTERM.
-   * @return @p true if the signal was delivered successfully.
+   * @return true if the signal was delivered successfully.
   */
   virtual bool kill(int signo = SIGTERM);
 
   /**
-     @return @p true if the process is (still) considered to be running
+   * Checks whether the process is running.
+   * @return true if the process is (still) considered to be running
   */
   bool isRunning() const;
 
@@ -293,6 +301,7 @@ public:
    *
    *  Calling it before any child process has been started by this
    *  KProcess instance causes pid() to return 0.
+   * @return the pid of the process or 0 if no process has been started yet.
    **/
   pid_t pid() const;
 
@@ -313,7 +322,7 @@ public:
   void resume();
 
   /**
-   * @return @p true if the process has already finished and has exited
+   * @return true if the process has already finished and has exited
    *  "voluntarily", ie: it has not been killed by a signal.
    *
    * Note that you should check @ref KProcess::exitStatus() to determine
@@ -326,9 +335,10 @@ public:
    *
    * Please use
    * @ref KProcess::normalExit() to check whether the process has exited
-   * cleanly (i.e., @ref KProcess::normalExit() returns @p true) before calling
+   * cleanly (i.e., @ref KProcess::normalExit() returns true) before calling
    * this function because if the process did not exit normally,
    * it does not have a valid exit status.
+   * @return the exit status of the process
   */
   int  exitStatus() const;
 
@@ -356,6 +366,9 @@ public:
    * again until either a @ref wroteStdin() signal indicates that the
    * data has been sent or a @ref processHasExited() signal shows that
    * the child process is no longer alive...
+   * @param buffer the buffer to write. Do not free or modify it until
+   * you got a @ref wroteStdin() or @ref processHasExited() signal
+   * @return false if an error has occurred
    **/
   bool writeStdin(const char *buffer, int buflen);
 
@@ -363,7 +376,7 @@ public:
    * This causes the stdin file descriptor of the child process to be
    * closed indicating an "EOF" to the child.
    *
-   * @return @p false if no communication to the process's stdin
+   * @return false if no communication to the process's stdin
    *  had been specified in the call to @ref start().
   */
   bool closeStdin();
@@ -372,7 +385,7 @@ public:
    * This causes the stdout file descriptor of the child process to be
    * closed.
    *
-   * @return @p false if no communication to the process's stdout
+   * @return false if no communication to the process's stdout
    *  had been specified in the call to @ref start().
   */
   bool closeStdout();
@@ -381,34 +394,38 @@ public:
    * This causes the stderr file descriptor of the child process to be
    * closed.
    *
-   * @return @p false if no communication to the process's stderr
+   * @return false if no communication to the process's stderr
    *  had been specified in the call to @ref start().
   */
   bool closeStderr();
 
   /**
    * Lets you see what your arguments are for debugging.
+   * @return the list of arguments
    */
-
   const QValueList<QCString> &args() { return arguments; }
 
   /**
    * Controls whether the started process should drop any
    * setuid/segid privileges or whether it should keep them
    *
-   * The default is @p false : drop privileges
+   * The default is false : drop privileges
+   * @param true to keep the privileges
    */
   void setRunPrivileged(bool keepPrivileges);
 
   /**
    * Returns whether the started process will drop any
    * setuid/segid privileges or whether it will keep them
+   * @return true if the process runs privileged
    */
   bool runPrivileged() const;
   
   /**
    * Modifies the environment of the process to be started.
    * This function must be called before starting the process.
+   * @param name the name of the environment variable
+   * @param value the new value for the environment variable
    */
   void setEnvironment(const QString &name, const QString &value);
 
@@ -416,9 +433,38 @@ public:
    * Changes the current working directory (CWD) of the process 
    * to be started.
    * This function must be called before starting the process.
+   * @param dir the new directory
    */
   void setWorkingDirectory(const QString &dir);
 
+  /**
+   * Specify whether to start the command via a shell or directly.
+   * The default is to start the command directly.
+   * If @p useShell is true @p shell will be used as shell, or
+   * if shell is empty, the standard shell is used.
+   * @p quote A flag indicating whether to quote the arguments.
+   *
+   * When using a shell, the caller should make sure that all filenames etc.
+   * are properly quoted when passed as argument.
+   * @see quote()
+   * @param useShell true if the command should be started via a shell
+   * @param shell the path to the shell that will execute the process, or
+   *              0 to use the standard shell
+   * @since 3.1
+   */
+  void setUseShell(bool useShell, const char *shell = 0);
+
+  /**
+   * This function can be used to quote an argument string such that
+   * the shell processes it properly. This is e. g. necessary for
+   * user-provided file names which may contain spaces or quotes.
+   * It also prevents expansion of wild cards and environment variables.
+   * @param arg the argument to quite
+   * @return the quoted argument
+   * @since 3.1
+   */
+  static QString quote(const QString &arg);
+
   /**
    * Detaches KProcess from child process. All communication is closed.
    * No exit notification is emitted any more for the child process.
@@ -428,12 +474,15 @@ public:
    */
   void detach(); 
 
+
+
 signals:
 
   /**
    * Emitted after the process has terminated when
    * the process was run in the @p NotifyOnExit  (==default option to
    * @ref start()) or the @ref Block mode.
+   * @param proc a pointer to the process that has exited
    **/
   void processExited(KProcess *proc);
 
@@ -446,11 +495,14 @@ signals:
    * these signals, the respective communication link (stdout/stderr)
    * has to be turned on in @ref start().
    *
+   * @param proc a pointer to the process that has received the output
    * @param buffer The data received.
    * @param buflen The number of bytes that are available.
    *
    * You should copy the information contained in @p buffer to your private
    * data structures before returning from this slot.
+   * Example:
+   *     QString myBuf = QString::fromLatin1(buffer, buflen);
    **/
   void receivedStdout(KProcess *proc, char *buffer, int buflen);
 
@@ -468,6 +520,8 @@ signals:
    * to it, otherwise this signal will not be emitted.
    * 
    * The data still has to be read from file descriptor @p fd.
+   * @param fd the file descriptor that provides the data
+   * @param len the number of bytes that have been read from fd must be written here
    **/
   void receivedStdout(int fd, int &len);
 
@@ -479,11 +533,12 @@ signals:
    * these signals, the respective communication link (stdout/stderr)
    * has to be turned on in @ref start().
    *
-   * @param buffer The data received.
-   * @param buflen The number of bytes that are available.
-   *
    * You should copy the information contained in @p buffer to your private
    * data structures before returning from this slot.
+   *
+   * @param proc a pointer to the process that has received the data
+   * @param buffer The data received.
+   * @param buflen The number of bytes that are available.
   */
   void receivedStderr(KProcess *proc, char *buffer, int buflen);
 
@@ -491,6 +546,7 @@ signals:
    * Emitted after all the data that has been
    * specified by a prior call to @ref writeStdin() has actually been
    * written to the child process.
+   * @param proc a pointer to the process
    **/
   void wroteStdin(KProcess *proc);
 
@@ -500,12 +556,14 @@ protected slots:
  /**
   * This slot gets activated when data from the child's stdout arrives.
   * It usually calls "childOutput"
+  * @param the file descriptor for the output
   */
   void slotChildOutput(int fdno);
 
  /**
   * This slot gets activated when data from the child's stderr arrives.
   * It usually calls "childError"
+  * @param the file descriptor for the output
   */
   void slotChildError(int fdno);
   /*
@@ -516,6 +574,7 @@ protected slots:
    * Called when another bulk of data can be sent to the child's
    * stdin. If there is no more data to be sent to stdin currently
    * available, this function must disable the QSocketNotifier "innot".
+   * @param dummy ignore this argument
    */
   void slotSendData(int dummy);
 
@@ -683,6 +742,28 @@ protected:
 
 
 private:
+  /**
+   * Searches for a valid shell. 
+   * Here is the algorithm used for finding an executable shell:
+   *
+   *    @li Try the executable pointed to by the "SHELL" environment
+   *    variable with white spaces stripped off
+   *
+   *    @li If your process runs with uid != euid or gid != egid, a shell
+   *    not listed in /etc/shells will not used.
+   *
+   *    @li If no valid shell could be found, "/bin/sh" is used as a last resort.
+   * @since 3.1
+   */
+  QCString searchShell();
+
+  /**
+   * Used by @ref searchShell in order to find out whether the shell found
+   * is actually executable at all.
+   * @since 3.1
+   */
+  bool isExecutable(const QCString &filename);
+
   // Disallow assignment and copy-construction
   KProcess( const KProcess& );
   KProcess& operator= ( const KProcess& );
@@ -696,33 +777,15 @@ private:
 class KShellProcessPrivate;
 
 /**
-* This class is similar to @ref KProcess. The only difference is that
-* KShellProcess runs the specified executable through a UN*X shell so
-* that standard shell mechanisms like wild card matching, use of pipes
-* and environment variable expansion will work.
+* @obsolete
 *
-* For example, you could run commands like the following through
-* KShellProcess:
-*
-* <pre>
-*   ls ~/HOME/ *.lyx | sort | uniq |wc -l
-* </pre>
-*
-* KShellProcess tries really hard to find a valid executable shell. Here
-* is the algorithm used for finding an executable shell:
-*
-*    @li Try the executable pointed to by the "SHELL" environment
-*    variable with white spaces stripped off
-*
-*    @li If your process runs with uid != euid or gid != egid, a shell
-*    not listed in /etc/shells will not used.
-*
-*    @li If no valid shell could be found, "/bin/sh" is used as a last resort.
+* This class is obsolete. Use KProcess and KProcess::setUseShell(true)
+* instead.
 *
 *   @short A class derived from @ref KProcess to start child
 *   	processes through a shell.
 *   @author Christian Czezakte <e9025461@student.tuwien.ac.at>
-*   @version $Id: kprocess.h,v 1.54 2002/03/05 23:13:26 rich Exp $
+*   @version $Id: kprocess.h,v 1.60 2002/09/28 12:28:47 tjansen Exp $
 */
 class KShellProcess: public KProcess
 {
@@ -734,8 +797,7 @@ public:
    * Constructor
    *
    * By specifying the name of a shell (like "/bin/bash") you can override
-   * the mechanism for finding a valid shell as described in the detailed
-   * description of this class.
+   * the mechanism for finding a valid shell as described in KProcess::searchShell()
    */
   KShellProcess(const char *shellname=0);
 
@@ -762,18 +824,6 @@ public:
 
 private:
 
-  /**
-   * Searches for a valid shell. See the general description of this
-   * class for information on how the search is actually performed.
-   */
-  QCString searchShell();
-
-  /**
-   * Used by @ref searchShell in order to find out whether the shell found
-   * is actually executable at all.
-   */
-  bool isExecutable(const QCString &filename);
-
   QCString shell;
 
   // Disallow assignment and copy-construction
