@@ -29,7 +29,6 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include "klibloader.h"
-#include "kstaticdeleter.h"
 #include <kconfig.h>
 #include <kapplication.h>
 
@@ -89,10 +88,11 @@ class KSocksTable {
    QMap<SymbolKeys,QString>  symbols;
    // The name of this library
    QString                   myname;
+   bool                      hasWorkingAsyncConnect;
 };
 
 
-KSocksTable::KSocksTable() : myname("Unknown") {
+KSocksTable::KSocksTable() : myname("Unknown"), hasWorkingAsyncConnect(true) {
 }
 
 
@@ -162,6 +162,7 @@ class KDanteSocksTable : public KSocksTable {
 };
 
 KDanteSocksTable::KDanteSocksTable() : KSocksTable() {
+  hasWorkingAsyncConnect = false;
   myname = i18n("Dante SOCKS client");
   symbols.insert(S_SOCKSinit,   "SOCKSinit");
   symbols.insert(S_connect,     "Rconnect");
@@ -192,7 +193,6 @@ KDanteSocksTable::~KDanteSocksTable() {
 
 KSocks *KSocks::_me = 0;
 bool KSocks::_disabled = false;
-static KStaticDeleter<KSocks> med;
 
 void KSocks::disable() 
 { 
@@ -201,13 +201,14 @@ void KSocks::disable()
 }
 
 KSocks *KSocks::self() {
+  // Note that we don't use a static deleter here. It makes no sense and tends to cause crashes.
   if (!_me) {
      if (kapp) {
         KConfigGroup cfg(kapp->config(), "Socks");
-        _me = med.setObject(new KSocks(&cfg));
+        _me = new KSocks(&cfg);
      } else {
         _disabled = true;
-        _me = med.setObject(new KSocks(0));
+        _me = new KSocks(0);
      }
   }
   return _me;
@@ -223,7 +224,7 @@ void KSocks::setConfig(KConfigBase *config)
      _disabled = false;
   }
   if (!_me)
-    _me = med.setObject(new KSocks(config));
+    _me = new KSocks(config);
 }
 
 bool KSocks::activated() { return (_me != 0L); }
@@ -275,7 +276,7 @@ KSocks::KSocks(KConfigBase *config) : _socksLib(0L), _st(0L) {
           */
 
    if (_meth == 4) {         // try to load^H^H^H^Hguess at a custom library
-      _socksLib = ll->library(config->readEntry("SOCKS_lib", "").latin1());
+      _socksLib = ll->library(config->readPathEntry("SOCKS_lib", "").latin1());
       if (_socksLib && _socksLib->symbol("Rconnect")) {  // Dante compatible?
          _st = new KDanteSocksTable;       
          _useSocks = true;
@@ -403,13 +404,12 @@ KSocks::KSocks(KConfigBase *config) : _socksLib(0L), _st(0L) {
 
 KSocks::~KSocks() {
    stopSocks();
-   _me = med.setObject(0L);
+   _me = 0;
 }
 
-
 void KSocks::die() {
    if (_me == this) {
-      _me = med.setObject(0L);
+      _me = 0;
       delete this;
    }
 }
@@ -450,6 +450,10 @@ void KSocks::enableSocks() {
       _useSocks = true;
 }
 
+bool KSocks::hasWorkingAsyncConnect()
+{
+   return (_useSocks && _st) ? _st->hasWorkingAsyncConnect : true;
+}
 
 
 /*
