@@ -20,7 +20,7 @@
 
 /*
  * Author: Stephan Kulow <coolo@kde.org> and Sirtaj Singh Kang <taj@kde.org>
- * Version:	$Id: kstandarddirs.cpp,v 1.151.2.1 2003/01/08 16:15:51 waba Exp $
+ * Version:	$Id: kstandarddirs.cpp,v 1.151.2.3 2003/06/16 09:31:43 waba Exp $
  * Generated:	Thu Mar  5 16:05:28 EST 1998
  */
 
@@ -85,6 +85,8 @@ KStandardDirs::KStandardDirs( ) : addedCustoms(false), d(0)
 
 KStandardDirs::~KStandardDirs()
 {
+    delete d;
+    d = 0L;
 }
 
 bool KStandardDirs::isRestrictedResource(const char *type, const QString& relPath) const
@@ -1019,8 +1021,11 @@ void KStandardDirs::addKDEDefaults()
 
     }
 
-    fixHomeDir(localKdeDir);
-    addPrefix(localKdeDir);
+    if (localKdeDir != "-/")
+    {
+        fixHomeDir(localKdeDir);
+        addPrefix(localKdeDir);
+    }
 
     for (QStringList::ConstIterator it = kdedirList.begin();
 	 it != kdedirList.end(); it++)
