@@ -32,105 +32,106 @@ class KConfig;
 class KStandardDirsPrivate;
 
 /**
-* @short Site-independent access to standard KDE directories.
-* @author Stephan Kulow <coolo@kde.org> and Sirtaj Singh Kang <taj@kde.org>
-* @version $Id: kstandarddirs.h,v 1.91 2002/02/14 20:22:18 pfeiffer Exp $
-*
-* This is one of the most central classes in kdelibs as
-* it provides a basic service: It knows where the files
-* reside on the user's hard disk. And it's meant to be the
-* only one that knows -- to make the real location as
-* transparent as possible to both the user and the applications.
-*
-* To this end it insulates the application from all information
-* and applications always refer to a file with a resource type
-* (e.g. icon) and a filename (e.g. khexdit.xpm). In an ideal world
-* the application would make no assumption where this file is and
-* leave it up to @ref KStandardDirs::findResource("apps", "Home.desktop")
-* to apply this knowledge to return /opt/kde/share/applnk/Home.desktop
-* or locate("data", "kgame/background.jpg") to return
-* /opt/kde/share/apps/kgame/background.jpg
-*
-* The main idea behind KStandardDirs is that there are several
-* toplevel prefixes below which the files lie. One of these prefixes is
-* the one where the user installed kdelibs, one is where the
-* application was installed, and one is $HOME/.kde, but there
-* may be even more. Under these prefixes there are several well
-* defined suffixes where specific resource types are to be found.
-* For example, for the resource type "html" the suffixes could be
-* share/doc/HTML and share/doc/kde/HTML.
-* So the search algorithm basicly appends to each prefix each registered
-* suffix and tries to locate the file there.
-* To make the thing even more complex, it's also possible to register
-* absolute paths that KStandardDirs looks up after not finding anything
-* in the former steps. They can be useful if the user wants to provide
-* specific directories that aren't in his $HOME/.kde directory for,
-* for example, icons.
-*
-* @sect Standard resources that kdelibs allocates are:
-*
-* @li apps - Applications menu (.desktop files).
-* @li cache - Cached information (e.g. favicons, web-pages)
-* @li cgi - CGIs to run from kdehelp.
-* @li config - Configuration files.
-* @li data - Where applications store data.
-* @li exe - Executables in $prefix/bin. @ref #findExe for a function that takes $PATH into account.
-* @li html - HTML documentation.
-* @li icon - Icons, see @ref KIconLoader.
-* @li lib - Libraries.
-* @li locale - Translation files for @ref KLocale.
-* @li mime - Mime types.
-* @li module - Module (dynamically loaded library).
-* @li qtplugins - Qt plugins (dynamically loaded objects for Qt)
-* @li services - Services.
-* @li servicetypes - Service types.
-* @li scripts - Application scripting additions.
-* @li sound - Application sounds.
-* @li templates - Templates
-* @li wallpaper - Wallpapers.
-* @li tmp - Temporary files (specfic for both current host and current user)
-* @li socket - UNIX Sockets (specific for both current host and current user)
-*
-* A type that is added by the class @ref KApplication if you use it, is
-* appdata. This one makes the use of the type data a bit easier as it
-* appends the name of the application.
-* So while you had to @ref locate("data", "appname/filename") so you can
-* also write @ref locate("appdata", "filename") if your KApplication instance
-* is called "appname" (as set via KApplication's constructor or KAboutData, if
-* you use the global KStandardDirs object @ref KGlobal::dirs()). 
-* Please note though that you cannot use the "appdata"
-* type if you intend to use it in an applet for Kicker because 'appname' would
-* be "Kicker" instead of the applet's name. Therefore, for applets, you've got
-* to work around this by using @ref locate("data", "appletname/filename").
-*
-* @sect KStandardDirs supports the following environment variables:
-*
-* @li KDEDIRS: This may set an additional number of directory prefixes to
-*          search for resources. The directories should be seperated
-*          by ':'. The directories are searched in the order they are
-*          specified.
-* @li KDEDIR:  Used for backwards compatibility. As KDEDIRS but only a single
-*          directory may be specified. If KDEDIRS is set KDEDIR is
-*          ignored.
-* @li KDEHOME: The directory where changes are saved to. This directory is
-*          used to search for resources first. If KDEHOME is not
-*          specified it defaults to "$HOME/.kde"
-* @li KDEROOTHOME: Like KDEHOME, but used for the root user. 
-*          If KDEROOTHOME is not set it defaults to the .kde directory in the
-*          home directory of root, usually "/root/.kde".
-*          Note that the setting of $HOME is ignored in this case.
-*
-**/
+ * @short Site-independent access to standard KDE directories.
+ * @author Stephan Kulow <coolo@kde.org> and Sirtaj Singh Kang <taj@kde.org>
+ * @version $Id: kstandarddirs.h,v 1.100.2.1 2003/01/08 16:15:51 waba Exp $
+ *
+ * This is one of the most central classes in kdelibs as
+ * it provides a basic service: It knows where the files
+ * reside on the user's hard disk. And it's meant to be the
+ * only one that knows -- to make the real location as
+ * transparent as possible to both the user and the applications.
+ *
+ * To this end it insulates the application from all information
+ * and applications always refer to a file with a resource type
+ * (e.g. icon) and a filename (e.g. khexdit.xpm). In an ideal world
+ * the application would make no assumption where this file is and
+ * leave it up to @ref KStandardDirs::findResource("apps", "Home.desktop")
+ * to apply this knowledge to return /opt/kde/share/applnk/Home.desktop
+ * or ::locate("data", "kgame/background.jpg") to return
+ * /opt/kde/share/apps/kgame/background.jpg
+ *
+ * The main idea behind KStandardDirs is that there are several
+ * toplevel prefixes below which the files lie. One of these prefixes is
+ * the one where the user installed kdelibs, one is where the
+ * application was installed, and one is $HOME/.kde, but there
+ * may be even more. Under these prefixes there are several well
+ * defined suffixes where specific resource types are to be found.
+ * For example, for the resource type "html" the suffixes could be
+ * share/doc/HTML and share/doc/kde/HTML.
+ * So the search algorithm basicly appends to each prefix each registered
+ * suffix and tries to locate the file there.
+ * To make the thing even more complex, it's also possible to register
+ * absolute paths that KStandardDirs looks up after not finding anything
+ * in the former steps. They can be useful if the user wants to provide
+ * specific directories that aren't in his $HOME/.kde directory for,
+ * for example, icons.
+ *
+ * @sect Standard resources that kdelibs allocates are:
+ *
+ * @li apps - Applications menu (.desktop files).
+ * @li cache - Cached information (e.g. favicons, web-pages)
+ * @li cgi - CGIs to run from kdehelp.
+ * @li config - Configuration files.
+ * @li data - Where applications store data.
+ * @li exe - Executables in $prefix/bin. @ref #findExe for a function that takes $PATH into account.
+ * @li html - HTML documentation.
+ * @li icon - Icons, see @ref KIconLoader.
+ * @li lib - Libraries.
+ * @li locale - Translation files for @ref KLocale.
+ * @li mime - Mime types.
+ * @li module - Module (dynamically loaded library).
+ * @li qtplugins - Qt plugins (dynamically loaded objects for Qt)
+ * @li services - Services.
+ * @li servicetypes - Service types.
+ * @li scripts - Application scripting additions.
+ * @li sound - Application sounds.
+ * @li templates - Templates
+ * @li wallpaper - Wallpapers.
+ * @li tmp - Temporary files (specfic for both current host and current user)
+ * @li socket - UNIX Sockets (specific for both current host and current user)
+ *
+ * A type that is added by the class @ref KApplication if you use it, is
+ * appdata. This one makes the use of the type data a bit easier as it
+ * appends the name of the application.
+ * So while you had to ::locate("data", "appname/filename") so you can
+ * also write ::locate("appdata", "filename") if your KApplication instance
+ * is called "appname" (as set via KApplication's constructor or KAboutData, if
+ * you use the global KStandardDirs object @ref KGlobal::dirs()).
+ * Please note though that you cannot use the "appdata"
+ * type if you intend to use it in an applet for Kicker because 'appname' would
+ * be "Kicker" instead of the applet's name. Therefore, for applets, you've got
+ * to work around this by using ::locate("data", "appletname/filename").
+ *
+ * @sect KStandardDirs supports the following environment variables:
+ *
+ * @li KDEDIRS: This may set an additional number of directory prefixes to
+ *          search for resources. The directories should be seperated
+ *          by ':'. The directories are searched in the order they are
+ *          specified.
+ * @li KDEDIR:  Used for backwards compatibility. As KDEDIRS but only a single
+ *          directory may be specified. If KDEDIRS is set KDEDIR is
+ *          ignored.
+ * @li KDEHOME: The directory where changes are saved to. This directory is
+ *          used to search for resources first. If KDEHOME is not
+ *          specified it defaults to "$HOME/.kde"
+ * @li KDEROOTHOME: Like KDEHOME, but used for the root user.
+ *          If KDEROOTHOME is not set it defaults to the .kde directory in the
+ *          home directory of root, usually "/root/.kde".
+ *          Note that the setting of $HOME is ignored in this case.
+ *
+ * @see KGlobalSettings
+ */
 class KStandardDirs
 {
 public:
         /**
-	 * KStandardDirs constructor. It just initializes the caches.
+	 * KStandardDirs' constructor. It just initializes the caches.
 	 **/
 	KStandardDirs( );
 
 	/**
-	 * KStandardDirs destructor.
+	 * KStandardDirs' destructor.
 	 */
 	virtual ~KStandardDirs();
 
@@ -162,11 +163,11 @@ public:
 	 * files of this type.
 	 * @param relativename Specifies a directory relative to the root
 	 * of the KFSSTND.
+	 * @return true if successful, false otherwise.
 	 */
 	bool addResourceType( const char *type,
 			      const QString& relativename );
 
-
 	/**
 	 * Adds absolute path at the end of the search path for
 	 * particular types (for example in case of icons where
@@ -180,7 +181,7 @@ public:
 	 * of this type.
 	 * @param absdir Points to directory where to look for this specific
 	 * type. Non-existant directories may be saved but pruned.
-	 *
+	 * @return true if successful, false otherwise.
 	 */
 	bool addResourceDir( const char *type,
 			     const QString& absdir);
@@ -206,6 +207,24 @@ public:
 	QString findResource( const char *type,
 			      const QString& filename ) const;
 
+	/**
+	 * Checks whether a resource is restricted as part of the KIOSK
+	 * framework. When a resource is restricted it means that user-
+	 * specific files in the resource are ignored.
+	 *
+	 * E.g. by restricting the "wallpaper" resource, only system-wide
+	 * installed wallpapers will be found by this class. Wallpapers
+	 * installed under the $KDEHOME directory will be ignored.
+	 *
+	 * @param type The type of the resource to check
+	 * @param relPath A relative path in the resource.
+	 *
+	 * @return True if the resource is restricted.
+	 * @since 3.1
+	 */
+	bool isRestrictedResource( const char *type,
+			      const QString& relPath=QString::null ) const;
+
         /**
          * Returns a number that identifies this version of the resource.
          * When a change is made to the resource this number will change.
@@ -253,6 +272,8 @@ public:
 	 * path of the subdir libkdecore.la is found first in
 	 * (e.g. /opt/kde/lib/)
 	 *
+	 * @param type The type of the wanted resource
+	 * @param filename A relative filename of the resource.
 	 * @return The directory where the file specified in the second
 	 *         argument is located, or QString::null if the type
 	 *         of resource specified is unknown or the resource
@@ -271,7 +292,8 @@ public:
 	 * @param type The type of resource to locate directories for.
 	 * @param filter Only accept filenames that fit to filter. The filter
 	 *        may consist of an optional directory and a @ref QRegExp
-	 *        wildcard expression. E.g. "images\*.jpg"
+	 *        wildcard expression. E.g. "images\*.jpg". Use QString::null
+	 *        if you do not want a filter.
 	 * @param recursive Specifies if the function should decend
 	 *        into subdirectories.
 	 * @param uniq If specified,  only return items which have
@@ -295,14 +317,15 @@ public:
 	 * @param type The type of resource to locate directories for.
 	 * @param filter Only accept filenames that fit to filter. The filter
 	 *        may consist of an optional directory and a @ref QRegExp
-	 *        wildcard expression. E.g. "images\*.jpg"
+	 *        wildcard expression. E.g. "images\*.jpg". Use QString::null
+	 *        if you do not want a filter.
 	 * @param recursive Specifies if the function should decend
 	 *        into subdirectories.
 	 * @param uniq If specified,  only return items which have
 	 *        unique suffixes.
 	 * @param list Of relative paths for the given type.
 	 * @param relPaths The list to store the relative paths into
-	 *        These can be used later to @ref locate the file
+	 *        These can be used later to ::locate() the file
 	 *
 	 * @return A list of directories matching the resource specified,
 	 *         or an empty list if the resource type is unknown.
@@ -319,16 +342,16 @@ public:
 	 * A valid executable must
 	 * be a file and have its executable bit set.
 	 *
-	 * @see findAllExe()
 	 * @param appname The name of the executable file for which to search.
 	 * @param pathstr The path which will be searched. If this is
-	 * 		0 (default), the $PATH environment variable will
+	 * 		null (default), the $PATH environment variable will
 	 *		be searched.
 	 * @param ignoreExecBit	If true, an existing file will be returned
 	 *			even if its executable bit is not set.
 	 *
 	 * @return The path of the executable. If it was not found,
 	 *         it will return QString::null.
+	 * @see findAllExe()
 	 */
 	static QString findExe( const QString& appname,
 				const QString& pathstr=QString::null,
@@ -337,8 +360,6 @@ public:
 	/**
 	 * Finds all occurences of an executable in the system path.
 	 *
-	 * @see	findExe()
-	 *
 	 * @param list	Will be filled with the pathnames of all the
 	 *		executables found. Will be empty if the executable
 	 *		was not found.
@@ -351,6 +372,8 @@ public:
 	 *			even if its executable bit is not set.
 	 *
 	 * @return The number of executables found, 0 if none were found.
+	 *
+	 * @see	findExe()
 	 */
 	static int findAllExe( QStringList& list, const QString& appname,
 			       const QString& pathstr=QString::null,
@@ -382,6 +405,7 @@ public:
 	 * This function is used internally by almost all other function as
 	 * it serves and fills the directories cache.
          *
+	 * @param type The type of resource
 	 * @return The list of possible directories for the specified @p type.
 	 * The function updates the cache if possible.  If the resource
 	 * type specified is unknown, it will return an empty list.
@@ -423,7 +447,7 @@ public:
          * Converts an absolute path to a path relative to a certain
          * resource.
          *
-         * If "abs = locate(resource, rel)"
+         * If "abs = ::locate(resource, rel)"
          * then "rel = relativeLocation(resource, abs)" and vice versa.
          *
          * @param type The type of resource.
@@ -444,6 +468,7 @@ public:
 	 *
 	 * @param dir Absolute path of the directory to be made.
 	 * @param mode Directory permissions.
+	 * @return true if successful, false otherwise
 	 */
 	static bool makeDir(const QString& dir, int mode = 0755);
 
@@ -469,7 +494,7 @@ public:
 	 * @li lib - lib
 	 *
 	 * @returns Static default for the specified resource.  You
-	 *          should probably be using @ref locate() or @ref locateLocal()
+	 *          should probably be using locate() or locateLocal()
 	 *          instead.
 	 * @see locate()
 	 * @see locateLocal()
@@ -482,19 +507,30 @@ public:
 	QString kfsstnd_prefixes();
 
 	/**
-	 * @returns the toplevel directory in which KStandardDirs
+	 * Returns the toplevel directory in which KStandardDirs
 	 * will store things. Most likely $HOME/.kde
-	 *
 	 * Don't use this function if you can use locateLocal
+	 * @return the toplevel directory
 	 */
 	QString localkdedir() const;
 
 	/**
-	 * checks for existence and accessability
-	 * faster than creating a QFileInfo first
+	 * Checks for existence and accessability.
+	 * Faster than creating a QFileInfo first.
+	 * @param fullPath the path to check
+	 * @return true if the directory exists
 	 */
 	static bool exists(const QString &fullPath);
 
+        /**
+         * Expands all symbolic links and resolves references to 
+         * '/./', '/../' and extra  '/' characters in @p dirname
+         * and returns the canonicalized absolute pathname.
+         * The resulting path will have no symbolic link, '/./' 
+         * or '/../' components.
+	 * @since 3.1
+         */
+        static QString realPath(const QString &dirname);
  private:
 
 	QStringList prefixes;
@@ -512,12 +548,16 @@ public:
 
 	bool addedCustoms;
 
+        class KStandardDirsPrivate;
 	KStandardDirsPrivate *d;
 
 	void checkConfig() const;
+	void applyDataRestrictions(const QString &) const;
 };
 
 /**
+ * \addtogroup locates Locate Functions
+ *  @{
  * On The Usage Of 'locate' and 'locateLocal'
  *
  * Typical KDE applications use resource files in one out of
@@ -527,15 +567,18 @@ public:
  *    default is supplied but the user can override this
  *    default in his local .kde directory:
  *
+ *    \code
  *    // Code example
  *    myFile = locate("appdata", "groups.lst");
  *    myData =  myReadGroups(myFile); // myFile may be null
+ *    \endcode
  *
  * 2) A resource file is read and written. If the user has no
  *    local version of the file the system default is used.
  *    The resource file is always written to the users local
  *    .kde directory.
  *
+ *    \code
  *    // Code example
  *    myFile = locate("appdata", "groups.lst")
  *    myData =  myReadGroups(myFile);
@@ -544,12 +587,14 @@ public:
  *    ...
  *    myFile = locateLocal("appdata", "groups.lst");
  *    myWriteGroups(myFile, myData);
+ *    \endcode
  *
  * 3) A resource file is read and written. No system default
  *    is used if the user has no local version of the file.
  *    The resource file is always written to the users local
  *    .kde directory.
  *
+ *    \code
  *    // Code example
  *    myFile = locateLocal("appdata", "groups.lst");
  *    myData =  myReadGroups(myFile);
@@ -558,15 +603,18 @@ public:
  *    ...
  *    myFile = locateLocal("appdata", "groups.lst");
  *    myWriteGroups(myFile, myData);
+ *    \endcode
  **/
 
-/**
+/*!
+ * \relates KStandardDirs
  * This function is just for convenience. It simply calls
- * instance->dirs()->findResource(type, filename).
+ *instance->dirs()->\link KStandardDirs::findResource() findResource\endlink(type, filename).
  **/
 QString locate( const char *type, const QString& filename, const KInstance* instance = KGlobal::instance() );
 
-/**
+/*!
+ * \relates KStandardDirs
  * This function is much like locate. However it returns a
  * filename suitable for writing to. No check is made if the
  * specified filename actually exists. Missing directories
@@ -576,4 +624,6 @@ QString locate( const char *type, const QString& filename, const KInstance* inst
  **/
 QString locateLocal( const char *type, const QString& filename, const KInstance* instance = KGlobal::instance() );
 
+/*! @} */
+
 #endif // SSK_KSTDDIRS_H
