@@ -458,7 +458,7 @@ KStringHandler::perlSplit(const QString & sep, const QString & s, uint max)
   return l;
 }
 
-  QStringList 
+  QStringList
 KStringHandler::perlSplit(const QChar & sep, const QString & s, uint max)
 {
   bool ignoreMax = 0 == max;
@@ -511,3 +511,28 @@ KStringHandler::perlSplit(const QRegExp & sep, const QString & s, uint max)
   return l;
 }
 
+ QString
+KStringHandler::tagURLs( const QString& text )
+{
+    /*static*/ QRegExp urlEx("(www\\.(?!\\.)|(f|ht)tp(|s)://)[\\d\\w\\./,:_~\\?=&;#@\\-\\+\\%]+[\\d\\w/]");
+
+    QString richText( text );
+    int urlPos = 0, urlLen;
+    while ((urlPos = urlEx.search(richText, urlPos)) >= 0)
+    {
+        urlLen = urlEx.matchedLength();
+        QString href = richText.mid( urlPos, urlLen );
+        // Qt doesn't support (?<=pattern) so we do it here
+        if((urlPos > 0) && richText[urlPos-1].isLetterOrNumber()){
+            urlPos++;
+            continue;
+        }
+        // Don't use QString::arg since %01, %20, etc could be in the string
+        QString anchor = "<a href=\"" + href + "\">" + href + "</a>";
+        richText.replace( urlPos, urlLen, anchor );
+
+
+        urlPos += anchor.length();
+    }
+    return richText;
+}
