@@ -17,7 +17,7 @@
  **/
 
 #ifndef __ksycoca_h__
-#define __ksycoca_h__ "$Id: ksycoca.h,v 1.63 2002/11/18 03:37:14 mueller Exp $"
+#define __ksycoca_h__ "$Id: ksycoca.h,v 1.63.2.2 2003/05/05 21:03:52 mueller Exp $"
 
 #include <dcopobject.h>
 #include <qobject.h>
@@ -34,7 +34,7 @@ class KSycocaFactoryList;
  * If the existing file is outdated, it will not get read
  * but instead we'll ask kded to regenerate a new one...
 */
-#define KSYCOCA_VERSION 60
+#define KSYCOCA_VERSION 61
 
 /**
  * @internal
@@ -114,6 +114,11 @@ public:
     */
    virtual bool isBuilding() { return false; }
 
+   /**
+    * @internal - disables launching of kbuildsycoca
+    */
+   void disableAutoRebuild();
+
    /**
     * Determine relative path for a .desktop file from a full path and a resource name
     */
