@@ -18,7 +18,7 @@
  **/
 
 #ifndef __kurl_h__
-#define __kurl_h__ "$Id: kurl.h,v 1.102.2.1 2002/12/26 17:21:00 mutz Exp $"
+#define __kurl_h__ "$Id: kurl.h,v 1.102.2.2 2003/02/22 09:54:36 kalass Exp $"
 
 #include <qstring.h>
 #include <qvaluelist.h>
@@ -591,7 +591,7 @@ public:
    * Returns the URL as string in human-friendly format.
    * Example: http://localhost:8080/test.cgi?test=hello world&name=fred
    * @return A human readable URL, with no non-necessary encodings/escaped
-   * characters.
+   * characters. Password will not be shown.
    */
   QString prettyURL( int _trailing = 0) const;
 
@@ -600,7 +600,7 @@ public:
    * Returns the URL as string, escaped for HTML.
    * @return A human readable URL, with no non-necessary encodings/escaped
    * characters which is html encoded for safe inclusion in html or
-   * rich text.
+   * rich text. Password will not be shown.
    */
   QString htmlURL() const;
 
@@ -608,7 +608,7 @@ public:
    * Returns the URL as string, escaped for HTML.
    * Example: http://localhost:8080/test.cgi?test=hello world&name=fred
    * @return A human readable URL, with no non-necessary encodings/escaped
-   * characters.
+   * characters. Password will not be shown.
    */
   QString prettyURL( int _trailing, AdjustementFlags _flags) const;
   // ### BIC: Merge the two above
