@@ -45,7 +45,7 @@ class KWinModulePrivate;
  *
  * @short Base class for KDE Window Manager modules.
  * @author Matthias Ettrich (ettrich@kde.org)
- * @version $Id: kwinmodule.h,v 1.15 2001/12/06 13:03:57 faure Exp $
+ * @version $Id: kwinmodule.h,v 1.16 2002/09/27 22:50:16 tjansen Exp $
  */
 class KWinModule : public QObject
 {
@@ -56,6 +56,7 @@ public:
     /**
      * Creates a KWinModule object and connects to the window
      * manager.
+     * @param parent the parent for the @ref QObject
      **/
     KWinModule( QObject* parent = 0 );
 
@@ -80,6 +81,7 @@ public:
      *     ... do something here,  (*it) is the current WId.
      *       }
      * </pre>
+     * @return the list of all toplevel windows
      */
     const QValueList<WId>& windows() const;
 
@@ -87,37 +89,48 @@ public:
      * Returns the list of all toplevel windows currently managed by the
      * window manager in the current stacking order (from lower to
      * higher). May be useful for pagers.
+     * @return the list of all toplevel windows in stacking order
      */
     const QValueList<WId>& stackingOrder() const;
 
     /**
-     * Test to see if @p WId still managed at present.
+     * Test to see if @p id still managed at present.
+     * @param id the window id to test
+     * @return true if the window id is still managed
      **/
-    bool hasWId(WId) const;
+    bool hasWId(WId id) const;
 
     /**
      * Returns a list of the system tray windows.
+     * @return a list of all system tray windows
      **/
     const QValueList<WId>& systemTrayWindows() const;
 
     /**
      * Returns the current virtual desktop.
+     * @return the current virtual desktop
      **/
     int currentDesktop() const;
 
     /**
      * Returns the number of virtual desktops.
+     * @return the number of virtual desktops
      **/
     int numberOfDesktops() const;
 
     /**
      * Returns the currently active window, or 0 if no window is active.
+     * @return the window id of the active window, or 0 if no window is 
+     *  active
      **/
     WId activeWindow() const;
 
     /**
      * Returns the workarea for the specified desktop, or the current
      * work area if no desktop has been specified.
+     * @param desktop the number of the desktop to check, -1 for the
+     *        current desktop
+     * @return the size and position of the desktop
      **/
     QRect workArea( int desktop = - 1 ) const;
 
@@ -126,16 +139,25 @@ public:
      * Returns the workarea for the specified desktop, or the current
      * work area if no desktop has been specified. Excludes struts of
      * clients in the exclude List.
+     * 
+     * @param clients the list of clients whose struts will be excluded
+     * @param desktop the number of the desktop to check, -1 for the
+     *        current desktop
+     * @return the size and position of the desktop
      **/
-    QRect workArea( const QValueList<WId>&, int desktop = -1) const;
+    QRect workArea( const QValueList<WId> &excludes, int desktop = -1) const;
 
     /**
      * Returns the name of the specified desktop.
+     * @param desktop the number of the desktop
+     * @return the name of the desktop
      **/
     QString desktopName( int desktop ) const;
 
     /**
      * Sets the name of the specified desktop.
+     * @param desktop the number of the desktop
+     * @param name the new name for the desktop
      **/
     void setDesktopName( int desktop, const QString& name );
 
@@ -146,6 +168,7 @@ public:
      * Useful for swallowing legacy applications, for example java
      * applets.
      *
+     * @param title the title of the window
      */
     void doNotManage( const QString& title );
 
@@ -154,21 +177,25 @@ signals:
 
     /**
      * Switched to another virtual desktop.
+     * @param desktop the number of the new desktop
      */
-    void currentDesktopChanged( int );
+    void currentDesktopChanged( int desktop);
 
     /**
      * A window has been added.
+     * @param id the id of the the window 
      */
-    void windowAdded(WId);
+    void windowAdded(WId id);
 
     /**
      * A window has been removed.
+     * @param id the id of the window that has been removed
      */
-    void windowRemoved(WId);
+    void windowRemoved(WId id);
 
     /**
      * Hint that <Window> is active (= has focus) now.
+     * @param id the id of the window that is active
      */
     void activeWindowChanged(WId);
 
@@ -179,18 +206,21 @@ signals:
 
     /**
      * The number of desktops changed.
+     * @param num the new number of desktops
      */
-    void numberOfDesktopsChanged(int);
+    void numberOfDesktopsChanged(int num);
 
     /**
      * Emitted when a dock window has been added.
+     * @param id the id of the new system tray window
      */
-    void systemTrayWindowAdded(WId);
+    void systemTrayWindowAdded(WId id);
 
     /**
      * Emitted when a dock window has been removed.
+     * @param id the id of the former system tray window
      */
-    void systemTrayWindowRemoved(WId);
+    void systemTrayWindowRemoved(WId id);
 
     /**
      * The workarea has changed.
@@ -215,13 +245,16 @@ signals:
      *
      * The unsigned int parameter contains the NET properties that
      * were modified (see netem_def.h).
+     * @param id the id of the window
+     * @param properties the properties that were modified
      */
-    void windowChanged(WId, unsigned int );
+    void windowChanged(WId id, unsigned int properties);
 
     /**
      * The window changed somehow.
+     * @param id the id of the window
      */
-    void windowChanged(WId );
+    void windowChanged(WId id);
     
 private:
     KWinModulePrivate* d;
