@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (C) 2000,2001 Thiago Macieira <thiagom@mail.com>
  *
- *  $Id: netsupp.cpp,v 1.32 2002/02/17 15:11:17 thiago Exp $
+ *  $Id: netsupp.cpp,v 1.33.2.1 2002/12/10 16:43:58 lunakl Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -103,6 +103,8 @@ void kde_freeaddrinfo(struct kde_addrinfo *ai)
   if (ai->origin == KAI_LOCALUNIX)
     {
       struct addrinfo *p, *last = NULL;
+      /* We've added one AF_UNIX socket in here, to the
+       * tail of the linked list. We have to find it */
       for (p = ai->data; p; p = p->ai_next)
 	{
 	  if (p->ai_family == AF_UNIX)
@@ -353,7 +355,8 @@ int kde_getaddrinfo(const char *name, const char *service,
     *result = res;
   else
     {
-      freeaddrinfo(res->data);
+      if (res->data != NULL)
+	freeaddrinfo(res->data);
       free(res);
     }
   return err;
@@ -952,7 +955,7 @@ int getnameinfo(const struct sockaddr *sa, ksocklen_t salen,
 
       if (servlen && serv != NULL)
 	*serv = '\0';
-      if (host == NULL || hostlen < strlen(s._sun->sun_path))
+      if (host != NULL && hostlen > strlen(s._sun->sun_path))
 	strcpy(host, s._sun->sun_path);
 
       return 0;
@@ -1034,7 +1037,7 @@ const char* inet_ntop(int af, const void *cp, char *buf, size_t len)
     {
       sprintf(buf2, "%u.%u.%u.%u", data[0], data[1], data[2], data[3]);
 
-      if (len >= strlen(buf2))
+      if (len > strlen(buf2))
 	{
 	  strcpy(buf, buf2);
 	  return buf;
@@ -1103,7 +1106,7 @@ const char* inet_ntop(int af, const void *cp, char *buf, size_t len)
 	    }
 	}
 
-      if (strlen(buf2) <= len)
+      if (strlen(buf2) < len)
 	{
 	  strcpy(buf, buf2);
 	  return buf;
