@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: cupsinfos.cpp,v 1.10 2002/02/28 10:35:32 goffioul Exp $
+ *  $Id: cupsinfos.cpp,v 1.11 2002/10/08 16:17:15 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,6 +22,7 @@
 #include "cupsinfos.h"
 #include "kmfactory.h"
 #include "kmtimer.h"
+#include "messagewindow.h"
 
 #include <kio/passdlg.h>
 #include <klocale.h>
@@ -93,6 +94,9 @@ const char* CupsInfos::getPasswordCB()
 	if (count_ == 0 && !password_.isEmpty()) return password_.latin1();
 	else
 	{
+		// to avoid focus/modality problem, message windows must be removed
+		MessageWindow::removeAll();
+
 		QString	msg = i18n("<p>The access to the requested resource on the CUPS server running on <b>%1</b> (port <b>%2</b>) requires a password.</p>").arg(host_).arg(port_);
 		bool ok(false);;
 		KIO::PasswordDialog	dlg(msg,login_);
