@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmcupsmanager.h,v 1.12 2002/06/16 17:54:39 goffioul Exp $
+ *  $Id: kmcupsmanager.h,v 1.12.2.1 2003/02/27 17:27:18 staikos Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -75,6 +75,9 @@ protected slots:
 	void slotConnectionSuccess();
 	void slotAsyncConnect();
 
+	void hostPingSlot();
+	void hostPingFailedSlot();
+
 protected:
 	// the real printer listing job is done here
 	void listPrinters();
@@ -95,6 +98,8 @@ private:
 	KLibrary	*m_cupsdconf;
 	KMPrinter	*m_currentprinter;
 	QSocket *m_socket;
+	bool m_hostSuccess;
+	bool m_lookupDone;
 };
 
 #endif
