@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmcupsuimanager.cpp,v 1.22 2002/02/21 14:12:26 goffioul Exp $
+ *  $Id: kmcupsuimanager.cpp,v 1.25 2002/08/29 15:48:13 cumming Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -44,6 +44,7 @@
 #include "kmwusers.h"
 #include "kmpropusers.h"
 #include "kpschedulepage.h"
+#include "kptagspage.h"
 
 #include "kprinterpropertydialog.h"
 #include "kpgeneralpage.h"
@@ -86,13 +87,13 @@ void KMCupsUiManager::setupWizard(KMWizard *wizard)
 	backend->addBackend(KMWizard::Local,i18n("&Local printer (parallel, serial, USB)"),false);
 	backend->addBackend(KMWizard::LPD,i18n("&Remote LPD queue"),false);
 	backend->addBackend(KMWizard::SMB,i18n("&SMB shared printer (Windows)"),false,KMWizard::Password);
-	backend->addBackend(KMWizard::TCP,i18n("&Network printer (TCP)"),false);
-	backend->addBackend(KMWizard::IPP,i18n("Remote &CUPS server (IPP/HTTP)"),false,KMWizard::Password);
+	backend->addBackend(KMWizard::TCP,i18n("Ne&twork printer (TCP)"),false);
+	backend->addBackend(KMWizard::IPP,i18n("Re&mote CUPS server (IPP/HTTP)"),false,KMWizard::Password);
 	backend->addBackend(KMWizard::Custom+1,i18n("Network printer w/&IPP (IPP/HTTP)"),false);
 	backend->addBackend(KMWizard::Custom+2,i18n("S&erial Fax/Modem printer"),false);
-	backend->addBackend(KMWizard::Custom+5,i18n("&Other Printer Type"),false);
+	backend->addBackend(KMWizard::Custom+5,i18n("Other &printer type"),false);
 	backend->addBackend();
-	backend->addBackend(KMWizard::Class,i18n("C&lass of printers"),false);
+	backend->addBackend(KMWizard::Class,i18n("Cl&ass of printers"),false);
 
 	IppRequest	req;
 	QString		uri;
@@ -165,6 +166,7 @@ int KMCupsUiManager::pluginPageCap()
 void KMCupsUiManager::setupPrintDialogPages(QPtrList<KPrintDialogPage>* pages)
 {
 	pages->append(new KPSchedulePage());
+	pages->append(new KPTagsPage());
 }
 
 void KMCupsUiManager::setupJobViewer(QListView *lv)
