@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmpropbanners.cpp,v 1.5 2001/11/12 20:44:44 danimo Exp $
+ *  $Id: kmpropbanners.cpp,v 1.7 2002/09/11 12:24:07 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -22,6 +22,7 @@
 #include "kmpropbanners.h"
 #include "kmprinter.h"
 #include "kmwizard.h"
+#include "kmwbanners.h"
 
 #include <qlabel.h>
 #include <qlayout.h>
@@ -48,7 +49,7 @@ KMPropBanners::KMPropBanners(QWidget *parent, const char *name)
 	main_->addWidget(m_stopbanner,1,1);
 
 	m_title = i18n("Banners");
-	m_header = i18n("Banner settings");
+	m_header = i18n("Banner Settings");
 	m_pixmap = "editcopy";
 }
 
@@ -61,8 +62,10 @@ void KMPropBanners::setPrinter(KMPrinter *p)
 	if (p && p->isPrinter())
 	{
 		QStringList	l = QStringList::split(',',p->option("kde-banners"),false);
-		m_startbanner->setText((l.count() > 0 ? l[0] : QString::fromLatin1("none")));
-		m_stopbanner->setText((l.count() > 1 ? l[1] : QString::fromLatin1("none")));
+		while ( l.count() < 2 )
+			l.append( "none" );
+		m_startbanner->setText(i18n(mapBanner(l[0]).utf8()));
+		m_stopbanner->setText(i18n(mapBanner(l[1]).utf8()));
 		emit enable(true);
 		emit enableChange(p->isLocal());
 	}
