@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: driveritem.cpp,v 1.5.2.1 2002/08/09 12:57:33 goffioul Exp $
+ *  $Id: driveritem.cpp,v 1.7 2002/10/21 12:42:23 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -132,11 +132,22 @@ bool DriverItem::updateConflict()
 		}
 		else
 		{
-			if ( isSelected() )
-				updateText();
 			m_conflict = (m_item->conflict());
 		}
 	}
 	repaint();
 	return m_conflict;
 }
+
+void DriverItem::updateTextRecursive()
+{
+	if ( m_item->isOption() )
+		updateText();
+
+	DriverItem *item = static_cast<DriverItem*>( firstChild() );
+	while ( item )
+	{
+		item->updateTextRecursive();
+		item = static_cast<DriverItem*>( item->nextSibling() );
+	}
+}
