@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kpcopiespage.cpp,v 1.13 2002/04/25 11:03:23 binner Exp $
+ *  $Id: kpcopiespage.cpp,v 1.13.2.1 2003/03/13 23:42:40 waba Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -35,6 +35,8 @@
 #include <qtooltip.h>
 #include <qwhatsthis.h>
 #include <qlayout.h>
+
+#include <kapplication.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kseparator.h>
@@ -116,6 +118,12 @@ KPCopiesPage::KPCopiesPage(KPrinter *prt, QWidget *parent, const char *name)
 	connect(m_rangeedit,SIGNAL(textChanged(const QString&)),SLOT(slotRangeEntered()));
 	connect(m_collate,SIGNAL(clicked()),SLOT(slotCollateClicked()));
 	connect(m_order,SIGNAL(clicked()),SLOT(slotCollateClicked()));
+	
+	if (!kapp->authorize("print/copies"))
+	{
+		setTitle(i18n("Pages"));
+		m_copybox->hide();
+	}
 }
 
 KPCopiesPage::~KPCopiesPage()
