@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kpgeneralpage.cpp,v 1.13 2002/02/14 10:36:58 goffioul Exp $
+ *  $Id: kpgeneralpage.cpp,v 1.17 2002/09/30 14:42:09 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -101,10 +101,10 @@ static const char*	default_size[] = {
 };
 #define	DEFAULT_SOURCE	8
 static const char*	default_source[] = {
-	"Upper", I18N_NOOP("Upper tray"),
-	"Lower", I18N_NOOP("Lower tray"),
-	"MultiPurpose", I18N_NOOP("Multi-purpose tray"),
-	"LargeCapacity", I18N_NOOP("Large capacity tray")
+	"Upper", I18N_NOOP("Upper Tray"),
+	"Lower", I18N_NOOP("Lower Tray"),
+	"MultiPurpose", I18N_NOOP("Multi-Purpose Tray"),
+	"LargeCapacity", I18N_NOOP("Large Capacity Tray")
 };
 #define	DEFAULT_TYPE	4
 static const char*	default_type[] = {
@@ -133,8 +133,8 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent, const c
 	m_papertypelabel->setBuddy(m_papertype);
 	m_inputslotlabel->setBuddy(m_inputslot);
 	m_orientbox = new QButtonGroup(0, Qt::Vertical, i18n("Orientation"), this);
-	m_duplexbox = new QButtonGroup(0, Qt::Vertical, i18n("Duplex printing"), this);
-	m_nupbox = new QButtonGroup(0, Qt::Vertical, i18n("Pages per sheet"), this);
+	m_duplexbox = new QButtonGroup(0, Qt::Vertical, i18n("Duplex Printing"), this);
+	m_nupbox = new QButtonGroup(0, Qt::Vertical, i18n("Pages per Sheet"), this);
 	m_bannerbox = new QGroupBox(0, Qt::Vertical, i18n("Banners"), this);
 	QRadioButton	*m_portrait = new QRadioButton(i18n("&Portrait"), m_orientbox);
 	QRadioButton	*m_landscape = new QRadioButton(i18n("&Landscape"), m_orientbox);
@@ -193,6 +193,7 @@ KPGeneralPage::KPGeneralPage(KMPrinter *pr, DrMain *dr, QWidget *parent, const c
 	lay4->addWidget(m_duplong, 1, 0);
 	lay4->addWidget(m_dupshort, 2, 0);
 	lay4->addMultiCellWidget(m_duplexpix, 0, 2, 1, 1);
+	lay4->setRowStretch( 0, 1 );
 	QGridLayout	*lay5 = new QGridLayout(m_nupbox->layout(), 3, 2, 5);
 	lay5->addWidget(m_nup1, 0, 0);
 	lay5->addWidget(m_nup2, 1, 0);
@@ -239,10 +240,21 @@ void KPGeneralPage::initialize()
 		opt = (DrListOption*)driver()->findOption("Duplex");
 		if (opt)
 		{
+			if ( opt->choices()->count() == 2 )
+			{
+				// probably a On/Off option instead of the standard PS one
+				QButton *btn = m_duplexbox->find( DUPLEX_SHORT_ID );
+				m_duplexbox->remove( btn );
+				btn->hide();
+				//delete btn;
+				m_duplexbox->find( DUPLEX_NONE_ID )->setText( i18n( "Disabled" ) );
+				m_duplexbox->find( DUPLEX_LONG_ID )->setText( i18n( "Enabled" ) );
+				m_duplexpix->hide();
+			}
 			if (opt->currentChoice())
 			{
 				int	ID(DUPLEX_NONE_ID);
-				if (opt->currentChoice()->name() == "DuplexNoTumble") ID = DUPLEX_LONG_ID;
+				if (opt->currentChoice()->name() == "DuplexNoTumble" || opt->currentChoice()->name() == "On") ID = DUPLEX_LONG_ID;
 				else if (opt->currentChoice()->name() == "DuplexTumble") ID = DUPLEX_SHORT_ID;
 				m_duplexbox->setButton(ID);
 				slotDuplexChanged(ID);
@@ -285,7 +297,6 @@ void KPGeneralPage::initialize()
 	else
 		m_bannerbox->setEnabled(false);
 
-
 	slotOrientationChanged(ORIENT_PORTRAIT_ID);
 	slotNupChanged(NUP_1_ID);
 }
@@ -319,7 +330,7 @@ void KPGeneralPage::setOptions(const QMap<QString,QString>& opts)
 		if (m_duplexbox->isEnabled() && !value.isEmpty())
 		{
 			int	ID(0);
-			if (value == "DuplexNoTumble") ID = 1;
+			if (value == "DuplexNoTumble" || value == "On") ID = 1;
 			else if (value == "DuplexTumble") ID = 2;
 			m_duplexbox->setButton(ID);
 			slotDuplexChanged(ID);
@@ -384,6 +395,11 @@ void KPGeneralPage::setOptions(const QMap<QString,QString>& opts)
 			slotNupChanged(ID);
 		}
 	}
+
+	if ( m_orientbox->isEnabled() )
+		m_orientbox->setDisabled( opts[ "kde-orientation-fixed" ] == "1" );
+	if ( m_pagesize->isEnabled() )
+		m_pagesize->setDisabled( opts[ "kde-pagesize-fixed" ] == "1" );
 }
 
 void KPGeneralPage::getOptions(QMap<QString,QString>& opts, bool incldef)
@@ -411,10 +427,11 @@ void KPGeneralPage::getOptions(QMap<QString,QString>& opts, bool incldef)
 
 		if (m_duplexbox->isEnabled() && (opt=(DrListOption*)driver()->findOption("Duplex")) != NULL)
 		{
+			bool twoChoices = ( m_duplexbox->count() == 2 );
 			switch (m_duplexbox->id(m_duplexbox->selected()))
 			{
-				case DUPLEX_NONE_ID: value = "None"; break;
-				case DUPLEX_LONG_ID: value = "DuplexNoTumble"; break;
+				case DUPLEX_NONE_ID: value = ( twoChoices ? "Off" : "None" ); break;
+				case DUPLEX_LONG_ID: value = ( twoChoices ? "On" : "DuplexNoTumble" ); break;
 				case DUPLEX_SHORT_ID: value = "DuplexTumble"; break;
 			}
 			if (incldef || value != opt->get("default")) opts["Duplex"] = value;
