@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kprintdialog.cpp,v 1.60 2002/10/08 16:17:15 goffioul Exp $
+ *  $Id: kprintdialog.cpp,v 1.60.2.1 2003/03/13 23:42:40 waba Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -200,9 +200,32 @@ KPrintDialog::KPrintDialog(QWidget *parent, const char *name)
 	connect( d->m_file, SIGNAL( openFileDialog( KURLRequester* ) ), SLOT( slotOpenFileDialog() ) );
 	connect( KMFactory::self()->manager(), SIGNAL( updatePossible( bool ) ), SLOT( slotUpdatePossible( bool ) ) );
 
-	KConfig	*config = KGlobal::config();
-	config->setGroup("KPrinter Settings");
-	expandDialog(!config->readBoolEntry("DialogReduced", (KMFactory::self()->settings()->application != KPrinter::StandAlone)));
+	if (!kapp->authorize("print/system"))
+	{
+		d->m_plugin->hide();
+	}
+
+	if (!kapp->authorize("print/options"))
+	{
+		d->m_options->hide();
+	}
+
+	if (!kapp->authorize("print/selection"))
+	{
+		d->m_plugin->hide();
+		d->m_options->hide();
+
+		d->m_extbtn->hide();
+		m_pbox->hide();
+		
+		expandDialog(true);
+	}
+	else
+	{
+		KConfig	*config = KGlobal::config();
+		config->setGroup("KPrinter Settings");
+		expandDialog(!config->readBoolEntry("DialogReduced", (KMFactory::self()->settings()->application != KPrinter::StandAlone)));
+	}
 }
 
 KPrintDialog::~KPrintDialog()
