@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kprintpreview.cpp,v 1.22 2002/09/14 02:48:48 ccheney Exp $
+ *  $Id: kprintpreview.cpp,v 1.22.2.1 2003/06/29 21:43:00 deller Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -246,7 +246,7 @@ bool KPrintPreview::preview(const QString& file, bool previewOnly, WId parentId)
 	KPreviewProc	proc;
 	if (externalPreview)
 	{
-		exe = conf->readEntry("PreviewCommand", "gv");
+		exe = conf->readPathEntry("PreviewCommand", "gv");
 		if (KStandardDirs::findExe(exe).isEmpty())
 		{
 			QString	msg = i18n("The preview program %1 cannot be found. "
