@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmlpdmanager.cpp,v 1.16.4.2 2002/12/05 12:51:38 waba Exp $
+ *  $Id: kmlpdmanager.cpp,v 1.16.4.3 2003/06/29 21:43:00 deller Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -279,9 +279,9 @@ QString KMLpdManager::programName(int f)
 	conf->setGroup("LPD");
 	switch (f)
 	{
-		case 0: return conf->readEntry("LpdCommand","/usr/sbin/lpc");
-		case 1: return conf->readEntry("LpdQueue","lpq");
-		case 2: return conf->readEntry("LpdRemove","lprm");
+		case 0: return conf->readPathEntry("LpdCommand","/usr/sbin/lpc");
+		case 1: return conf->readPathEntry("LpdQueue","lpq");
+		case 2: return conf->readPathEntry("LpdRemove","lprm");
 	}
 	return QString::null;
 }
