@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmmainview.h,v 1.20 2002/03/01 01:24:35 goffioul Exp $
+ *  $Id: kmmainview.h,v 1.26 2002/10/08 16:17:15 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -38,6 +38,8 @@ class KToolBar;
 class KAction;
 class PluginComboBox;
 class QBoxLayout;
+class MessageWindow;
+class QMenuBar;
 
 class KMMainView : public QWidget, public KPReloadObject
 {
@@ -72,13 +74,17 @@ public slots:
 	void slotRefresh();
 	void slotToolSelected(int);
 	void slotToggleFilter(bool);
+	void slotHelp();
 
 protected slots:
-	void slotPrinterSelected(KMPrinter*);
-	void slotRightButtonClicked(KMPrinter*, const QPoint&);
+	void slotPrinterSelected(const QString&);
+	void slotRightButtonClicked(const QString&, const QPoint&);
 	void slotToggleToolBar(bool);
+	void slotToggleMenuBar(bool);
 	void slotChangeView(int);
 	void slotChangeDirection(int);
+	void slotUpdatePossible( bool );
+	void slotInit();
 
 protected:
 	void initActions();
@@ -88,9 +94,11 @@ protected:
 	void loadParameters();
 	void reload();
 	void configChanged();
-	void aboutToReload();
+	//void aboutToReload();
 	void loadPluginActions();
 	void removePluginActions();
+	void createMessageWindow( const QString&, int delay = 500 );
+	void destroyMessageWindow();
 
 private:
 	KMPrinterView	*m_printerview;
@@ -104,6 +112,9 @@ private:
 	QStringList	m_toollist;
 	bool		m_first;
 	QBoxLayout	*m_boxlayout;
+	class KMainWindowPrivate;
+	KMainWindowPrivate *d;
+	KToolBar *m_menubar;
 };
 
 #endif
