@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwdriverselect.h,v 1.2 2001/03/24 07:27:49 waba Exp $
+ *  $Id: kmwdriverselect.h,v 1.3 2002/05/13 16:44:04 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -26,9 +26,11 @@
 #include "kmdbentry.h"
 
 class KListBox;
+class QPushButton;
 
 class KMWDriverSelect : public KMWizardPage
 {
+	Q_OBJECT
 public:
 	KMWDriverSelect(QWidget *parent = 0, const char *name = 0);
 
@@ -36,9 +38,13 @@ public:
 	void initPrinter(KMPrinter*);
 	void updatePrinter(KMPrinter*);
 
+protected slots:
+	void slotDriverComment();
+
 private:
 	KListBox	*m_list;
 	KMDBEntryList	*m_entries;
+	QPushButton	*m_drivercomment;
 };
 
 #endif
