@@ -40,16 +40,19 @@ public:
 
 protected slots:
 	void slotPortSelected(QListViewItem*);
+	void slotTextChanged( const QString& );
 
 protected:
 	void initialize();
+	QListViewItem* lookForItem( const QString& );
 
 protected:
 	KListView	*m_ports;
 	QLineEdit	*m_localuri;
 	QStringList	m_uris;
-	QListViewItem	*m_parents[3];
+	QListViewItem	*m_parents[4];
 	bool		m_initialized;
+	bool m_block;
 };
 
 #endif
