@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwpassword.cpp,v 1.3 2001/11/12 20:45:05 danimo Exp $
+ *  $Id: kmwpassword.cpp,v 1.5 2002/08/12 19:38:47 binner Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -35,7 +35,7 @@
 KMWPassword::KMWPassword(QWidget *parent, const char *name)
 : KMWizardPage(parent,name)
 {
-	m_title = i18n("User identification");
+	m_title = i18n("User Identification");
 	m_ID = KMWizard::Password;
 	m_nextpage = KMWizard::SMB;
 
@@ -80,7 +80,7 @@ bool KMWPassword::isValid(QString& msg)
 {
 	if (!m_guest->isChecked() && m_login->text().isEmpty())
 	{
-		msg = i18n("User name is empty !");
+		msg = i18n("User name is empty!");
 		return false;
 	}
 	return true;
