@@ -2,7 +2,7 @@
  *  This file is part of the KDE libraries
  *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
  *
- *  $Id: kmwsocket.h,v 1.3 2001/04/18 16:22:31 kulow Exp $
+ *  $Id: kmwsocket.h,v 1.4 2002/06/20 11:36:49 goffioul Exp $
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -26,9 +26,8 @@
 
 class KListView;
 class QListViewItem;
-class QProgressBar;
 class QLineEdit;
-class KMWSocketUtil;
+class NetworkScanner;
 
 class KMWSocket : public KMWizardPage
 {
@@ -41,15 +40,14 @@ public:
 	void updatePrinter(KMPrinter*);
 
 protected slots:
-	void slotSettings();
-	void slotScan();
 	void slotPrinterSelected(QListViewItem*);
+	void slotScanStarted();
+	void slotScanFinished();
 
 private:
 	KListView	*m_list;
-	QProgressBar	*m_bar;
+	NetworkScanner *m_scanner;
 	QLineEdit	*m_printer, *m_port;
-	KMWSocketUtil	*m_util;
 };
 
 #endif
