@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: client.cpp,v 1.38 2002/04/10 08:55:23 espie Exp $
+ * $Id: client.cpp,v 1.38.2.1 2003/02/24 16:09:43 lunakl Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -227,7 +227,7 @@ int KDEsuClient::exec(const QCString &prog, const QCString &user, const QCString
     cmd += escape(prog);
     cmd += " ";
     cmd += escape(user);
-    if (!options.isEmpty())
+    if (!options.isEmpty() || !env.isEmpty())
     {
        cmd += " ";
        cmd += escape(options);
