@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kcookie.cpp,v 1.18 2002/01/08 01:24:31 waba Exp $
+ * $Id: kcookie.cpp,v 1.19 2002/11/21 11:01:59 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -94,8 +94,11 @@ void KCookie::getXCookie()
 	return;
     }
 #ifdef Q_WS_X11 // No need to mess with X Auth stuff
-    QCString cmd;
-    cmd.sprintf("xauth list %s", m_Display.data());
+    QCString disp = m_Display;
+    if (disp.left(10) == "localhost:")
+       disp = disp.mid(9);
+
+    QCString cmd = "xauth list "+disp;
     blockSigChild(); // pclose uses waitpid()
     if (!(f = popen(cmd, "r"))) 
     {
