@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: ssh.cpp,v 1.21 2002/07/05 12:40:18 coolo Exp $
+ * $Id: ssh.cpp,v 1.21.2.1 2003/02/24 16:09:43 lunakl Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -129,10 +129,6 @@ int SshProcess::exec(const char *password, int check)
 	return 0;
     }
 
-    // Notify the taskbar that an app has been started.
-    QString suffix = i18n("(as %1@%2)").arg(m_User).arg(m_Host);
-    notifyTaskbar(suffix);
-
     setExitString("Waiting for forwarded connections to terminate");
     ret = waitForChild();
     return ret;
