@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: su.cpp,v 1.26.4.1 2003/02/24 16:09:43 lunakl Exp $
+ * $Id: su.cpp,v 1.26.4.2 2003/07/09 09:27:27 waba Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -81,7 +81,15 @@ int SuProcess::exec(const char *password, int check)
     args += "-c";
     args += QCString(__KDE_BINDIR) + "/kdesu_stub";
 
-    if (StubProcess::exec(__PATH_SU, args) < 0)
+    QCString command = __PATH_SU;
+    if (::access(__PATH_SU, X_OK) != 0)
+    {
+       command = QFile::encodeName(KGlobal::dirs()->findExe("su"));
+       if (command.isEmpty())
+          return check ? SuNotFound : -1;
+    }
+
+    if (StubProcess::exec(command, args) < 0)
     {
 	return check ? SuNotFound : -1;
     }
@@ -97,8 +105,10 @@ int SuProcess::exec(const char *password, int check)
     {
 	if (ret == 1)
 	{
-	    kill(m_Pid, SIGTERM);
-	    waitForChild();
+	    if (kill(m_Pid, SIGTERM) == 0)
+               waitForChild();
+            else
+	       close(fd());
 	}
 	return ret;
     }
@@ -112,9 +122,11 @@ int SuProcess::exec(const char *password, int check)
 
     if (ret == 2)
     {
-	kill(m_Pid, SIGTERM);
-	waitForChild();
-	return SuIncorrectPassword;
+       if (kill(m_Pid, SIGTERM) == 0)
+          waitForChild();
+       else
+          close(fd());
+       return SuIncorrectPassword;
     }
 
     ret = ConverseStub(check);
@@ -125,9 +137,11 @@ int SuProcess::exec(const char *password, int check)
 	return ret;
     } else if (ret == 1)
     {
-	kill(m_Pid, SIGTERM);
-	waitForChild();
-	return SuIncorrectPassword;
+        if (kill(m_Pid, SIGTERM) == 0)
+           waitForChild();
+        else
+           close(fd());
+        return SuIncorrectPassword;
     }
 
     if (check == 1)
