@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: su.h,v 1.10 2000/09/15 17:24:16 jansen Exp $
+ * $Id: su.h,v 1.14 2002/03/05 23:13:27 rich Exp $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 1999,2000 Geert Jansen <jansen@kde.org>
@@ -18,22 +18,24 @@
 #include "stub.h"
 
 /**
- * Execute a command under elevated privileges, using su.
+ * Executes a command under elevated privileges, using su.
  */
 
 class SuProcess: public StubProcess
 {
 public:
-    SuProcess(QCString user=0, QCString command=0);
+    SuProcess(const QCString &user=0, const QCString &command=0);
     ~SuProcess();
 
     enum Errors { SuNotFound=1, SuNotAllowed, SuIncorrectPassword };
 
-    /** Execute the command. This will wait for the command to finish. */
+    /**
+     * Executes the command. This will wait for the command to finish.
+     */
     int exec(const char *password, int check=0);
 
     /** 
-     * Check if the stub is installed and the password is correct.
+     * Checks if the stub is installed and the password is correct.
      * @return Zero if everything is correct, nonzero otherwise.
      */
     int checkInstall(const char *password);
@@ -43,12 +45,12 @@ public:
      */
     int checkNeedPassword();
 
-protected:
-    virtual QCStringList dcopServer();
-
 private:
     int ConverseSU(const char *password);
 
+protected:
+    virtual void virtual_hook( int id, void* data );
+private:
     class SuProcessPrivate;
     SuProcessPrivate *d;
 };
