@@ -274,7 +274,7 @@ void KCharSelectTable::gotoLeft()
 //==================================================================
 void KCharSelectTable::gotoRight()
 {
-    if ( focusPos.x() < 31 ) {
+    if ( focusPos.x() < numCols()-1 ) {
 	QPoint oldPos = focusPos;
 
 	focusPos.setX( focusPos.x() + 1 );
@@ -310,7 +310,7 @@ void KCharSelectTable::gotoUp()
 //==================================================================
 void KCharSelectTable::gotoDown()
 {
-    if ( focusPos.y() < 7 ) {
+    if ( focusPos.y() < numRows()-1 ) {
 	QPoint oldPos = focusPos;
 
 	focusPos.setY( focusPos.y() + 1 );
@@ -334,7 +334,6 @@ KCharSelect::KCharSelect( QWidget *parent, const char *name, const QString &_fon
     : QVBox( parent, name )
 {
     setSpacing( KDialog::spacingHint() );
-    setMargin( KDialog::marginHint() );
     QHBox *bar = new QHBox( this );
     bar->setSpacing( KDialog::spacingHint() );
 
