@@ -274,8 +274,8 @@ void KCompletionBox::hide()
 
 QSize KCompletionBox::sizeHint() const
 {
-    int ih = itemHeight();
-    int h = QMIN( 15 * ih, (int) count() * ih ) +1;
+    int ih = itemHeight() +1;
+    int h = QMIN( 15 * ih, (int) count() * ih ) +2;
     h = QMAX( h, KListBox::minimumSizeHint().height() );
 
     int w = (d->m_parent) ? d->m_parent->width() : KListBox::minimumSizeHint().width();
