@@ -21,8 +21,6 @@
 #include <qcursor.h>
 #include <qiconview.h>
 
-#include <kdebug.h>
-
 /**
  * This Widget extends the functionality of QIconView to honor the system
  * wide settings for Single Click/Double Click mode, Auto Selection and
@@ -40,6 +38,7 @@
  **/
 class KIconView : public QIconView
 {
+  friend class KIconViewItem;
   Q_OBJECT
   Q_ENUMS( Mode )
   Q_PROPERTY( Mode mode READ mode WRITE setMode )
@@ -76,11 +75,9 @@ public:
   Mode mode() const;
 
   /**
-   * Returns the index of @p item or -1 if @p item doesn't exist
-   * in this icon view.
+   * Reimplemented for internal purposes
    */
-  //BCI: Remove this function. The bug(crash for nonexistent items) will hopefully be fixed then.
-  int itemIndex( const QIconViewItem *item ) const;
+  virtual void setFont( const QFont & );
 
 signals:
 
@@ -125,7 +122,6 @@ signals:
 protected slots:
   void slotOnItem( QIconViewItem *item );
   void slotOnViewport();
-
   void slotSettingsChanged(int);
 
   /**
@@ -141,8 +137,20 @@ protected:
   virtual void contentsMousePressEvent( QMouseEvent *e );
   virtual void contentsMouseDoubleClickEvent ( QMouseEvent * e );
   virtual void contentsMouseReleaseEvent( QMouseEvent *e );
-    
-  QCursor oldCursor;
+
+private slots:
+  void slotMouseButtonClicked( int btn, QIconViewItem *item, const QPoint &pos );
+
+private:
+  /**
+   * @internal. For use by KIconViewItem.
+   */
+  QFontMetrics *itemFontMetrics() const;
+  /**
+   * @internal. For use by KIconViewItem.
+   */
+  QPixmap selectedIconPixmap( QPixmap *pix, const QColor &col ) const;
+
   bool m_bUseSingle;
   bool m_bChangeCursorOverItem;
 
@@ -151,12 +159,51 @@ protected:
   QTimer* m_pAutoSelect;
   int m_autoSelectDelay;
 
-private slots:
-  void slotMouseButtonClicked( int btn, QIconViewItem *item, const QPoint &pos );
-
+protected:
+  virtual void virtual_hook( int id, void* data );
 private:
   class KIconViewPrivate;
   KIconViewPrivate *d;
 };
 
+class KWordWrap;
+/**
+ * KIconViewItem exists to improve the word-wrap functionality of QIconViewItem
+ * Use KIconViewItem instead of QIconViewItem for any iconview item you might have :)
+ *
+ * @short A variant of QIconViewItem that wraps words better.
+ * @author David Faure <david@mandrakesoft.com>
+ */
+class KIconViewItem : public QIconViewItem
+{
+public:
+    // Need to redefine all the constructors - I want Java !
+    KIconViewItem( QIconView *parent )
+        : QIconViewItem( parent ) { init(); } // We need to call it because the parent ctor won't call our reimplementation :(((
+    KIconViewItem( QIconView *parent, QIconViewItem *after )
+        : QIconViewItem( parent, after ) { init(); }
+    KIconViewItem( QIconView *parent, const QString &text )
+        : QIconViewItem( parent, text ) { init(); }
+    KIconViewItem( QIconView *parent, QIconViewItem *after, const QString &text )
+        : QIconViewItem( parent, after, text ) { init(); }
+    KIconViewItem( QIconView *parent, const QString &text, const QPixmap &icon )
+        : QIconViewItem( parent, text, icon ) { init(); }
+    KIconViewItem( QIconView *parent, QIconViewItem *after, const QString &text, const QPixmap &icon )
+        : QIconViewItem( parent, after, text, icon ) { init(); }
+    KIconViewItem( QIconView *parent, const QString &text, const QPicture &picture )
+        : QIconViewItem( parent, text, picture ) { init(); }
+    KIconViewItem( QIconView *parent, QIconViewItem *after, const QString &text, const QPicture &picture )
+        : QIconViewItem( parent, after, text, picture ) { init(); }
+    virtual ~KIconViewItem();
+
+protected:
+    void init();
+    virtual void calcRect( const QString& text_ = QString::null );
+    virtual void paintItem( QPainter *p, const QColorGroup &c );
+private:
+    KWordWrap* m_wordWrap;
+    class KIconViewItemPrivate;
+    KIconViewItemPrivate *d;
+};
+
 #endif
