@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*************************************************************************
- * $Id: kled.h,v 1.21 2002/03/04 00:51:49 lunakl Exp $
+ * $Id: kled.h,v 1.22 2002/05/21 15:58:49 porten Exp $
  *************************************************************************/
 
 #ifndef _KLED_H_
@@ -41,9 +41,7 @@ class QColor;
 class KLed : public QWidget
 {
     Q_OBJECT
-    Q_ENUMS( State )
-    Q_ENUMS( Shape )
-    Q_ENUMS( Look )
+    Q_ENUMS( State Shape Look )
     Q_PROPERTY( State state READ state WRITE setState )
     Q_PROPERTY( Shape shape READ shape WRITE setShape )
     Q_PROPERTY( Look look READ look WRITE setLook )
