@@ -45,6 +45,7 @@ KLineEditDlg::KLineEditDlg( const QString&_text, const QString& _value,
 
   edit = new KLineEdit( plainPage(), 0L );
   edit->setMinimumWidth(edit->sizeHint().width() * 3);
+  label->setBuddy(edit);  // please "scheck" style
   //  connect( edit, SIGNAL(returnPressed()), SLOT(accept()) );
   connect( edit, SIGNAL(textChanged(const QString&)),
 	   SLOT(slotTextChanged(const QString&)) );
@@ -52,6 +53,11 @@ KLineEditDlg::KLineEditDlg( const QString&_text, const QString& _value,
 
   connect( this, SIGNAL(user1Clicked()), this, SLOT(slotClear()) );
   edit->setText( _value );
+  if ( _value.isEmpty() )
+  {
+      enableButtonOK( false );
+      enableButton(KDialogBase::User1, false);
+  }
   edit->setSelection(0, edit->text().length());
   edit->setFocus();
 }
@@ -142,6 +148,7 @@ void KLineEditDlg::slotTextChanged(const QString &text)
     on = !text.isEmpty();
   }
   enableButtonOK( on );
+  enableButton(KDialogBase::User1, text.length());
 }
 
 QString KLineEditDlg::text() const
