@@ -31,10 +31,10 @@ Q_OBJECT
 public:
 	KListViewLineEdit(KListView *parent);
 	~KListViewLineEdit();
-	
+
 signals:
 	void done(QListViewItem*, int);
-	
+
 public slots:
 	void terminate();
 	void load(QListViewItem *i, int c);
@@ -42,10 +42,19 @@ public slots:
 protected:
 	virtual void focusOutEvent(QFocusEvent *);
 	virtual void keyPressEvent(QKeyEvent *e);
+	virtual void paintEvent(QPaintEvent *e);
+	virtual bool event (QEvent *pe);
+
+	/// @since 3.1
+	void selectNextCell (QListViewItem *pi, int column, bool forward);
+	void terminate(bool commit);
 	QListViewItem *item;
 	int col;
 	KListView *p;
 
+protected slots:
+	void slotSelectionChanged();
+
 };
 
 #endif
