@@ -15,7 +15,7 @@
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
 
-    $Id: kmainwindow.h,v 1.58.2.3 2002/12/13 14:27:22 faure Exp $
+    $Id: kmainwindow.h,v 1.58.2.4 2003/03/03 14:39:42 lunakl Exp $
 
 */
 
@@ -579,9 +579,11 @@ protected:
 
        Default implementation returns @p true. Returning @p false will
        cancel the exiting. In the latter case, the last window will
-       remain visible.
+       remain visible. If KApplication::sessionSaving() is true, refusing
+       the exit will also cancel KDE logout.
 
        @see queryClose()
+       @see KApplication::sessionSaving()
      */
     virtual bool queryExit();
 
@@ -593,7 +595,8 @@ protected:
        safe to close it, i.e. without the user losing some data.
 
        Default implementation returns true. Returning @p false will cancel
-       the closing.
+       the closing, and, if KApplication::sessionSaving() is true, it will also
+       cancel KDE logout.
 
        Reimplement this function to prevent the user from losing data.
        Example:
@@ -612,6 +615,7 @@ protected:
     </pre>
 
    @see queryExit()
+   @see KApplication::sessionSaving()
 
     */
     virtual bool queryClose();
