@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 /*
- * $Id: kmessagebox.cpp,v 1.62 2002/10/09 20:44:27 kloecker Exp $
+ * $Id: kmessagebox.cpp,v 1.62.2.1 2003/05/29 22:38:56 pfeiffer Exp $
  *
  */
 #include <qcheckbox.h>
@@ -52,7 +52,7 @@
   * as well as audible notification via @ref KNotifyClient
   *
   * @author Waldo Bastian (bastian@kde.org)
-  * @version $Id: kmessagebox.cpp,v 1.62 2002/10/09 20:44:27 kloecker Exp $
+  * @version $Id: kmessagebox.cpp,v 1.62.2.1 2003/05/29 22:38:56 pfeiffer Exp $
   */
 
 #ifdef __GNUC__
@@ -258,7 +258,7 @@ KMessageBox::questionYesNoList(QWidget *parent, const QString &text,
                        parent, "questionYesNo", true, true,
                        buttonYes, buttonNo);
 
-    bool checkboxResult;
+    bool checkboxResult = false;
     int result = createKMessageBox(dialog, QMessageBox::Information, text, strlist,
                        dontAskAgainName.isEmpty() ? QString::null : i18n("&Do not ask again"),
                        &checkboxResult, options);
@@ -328,7 +328,7 @@ KMessageBox::questionYesNoCancel(QWidget *parent,
                        parent, "questionYesNoCancel", true, true,
                        buttonYes, buttonNo);
 
-    bool checkboxResult;
+    bool checkboxResult = false;
     int result = createKMessageBox(dialog, QMessageBox::Information,
                        text, QStringList(),
                        dontAskAgainName.isEmpty() ? QString::null : i18n("&Do not ask again"),
@@ -402,7 +402,7 @@ KMessageBox::warningYesNo(QWidget *parent, const QString &text,
                        parent, "warningYesNo", true, true,
                        buttonYes, buttonNo);
 
-    bool checkboxResult;
+    bool checkboxResult = false;
     int result = createKMessageBox(dialog, QMessageBox::Warning, text, QStringList(),
                        dontAskAgainName.isEmpty() ? QString::null : i18n("&Do not ask again"),
                        &checkboxResult, options);
@@ -482,7 +482,7 @@ KMessageBox::warningContinueCancelList(QWidget *parent, const QString &text,
                        parent, "warningYesNo", true, true,
                        buttonContinue, KStdGuiItem::cancel() );
 
-    bool checkboxResult;
+    bool checkboxResult = false;
     int result = createKMessageBox(dialog, QMessageBox::Warning, text, strlist,
                        dontAskAgainName.isEmpty() ? QString::null : i18n("&Do not ask again"),
                        &checkboxResult, options);
@@ -547,7 +547,7 @@ KMessageBox::warningYesNoCancel(QWidget *parent, const QString &text,
                        parent, "warningYesNoCancel", true, true,
                        buttonYes, buttonNo);
 
-    bool checkboxResult;
+    bool checkboxResult = false;
     int result = createKMessageBox(dialog, QMessageBox::Warning, text, QStringList(),
                        dontAskAgainName.isEmpty() ? QString::null : i18n("&Do not ask again"),
                        &checkboxResult, options);
@@ -690,7 +690,7 @@ KMessageBox::informationList(QWidget *parent,const QString &text, const QStringL
                        parent, "information", true, true,
                        KStdGuiItem::ok() );
 
-    bool checkboxResult;
+    bool checkboxResult = false;
 
     createKMessageBox(dialog, QMessageBox::Information, text, strlist,
 		dontShowAgainName.isEmpty() ? QString::null : i18n("&Do not show this message again"),
