@@ -22,7 +22,7 @@
 #include <kconfig.h>
 #include <kglobal.h>
 #include <kipc.h>
-#include <kapp.h>
+#include <kapplication.h>
 
 #include "kpushbutton.h"
 
@@ -101,7 +101,7 @@ void KPushButton::init( const KGuiItem &item )
 
 bool KPushButton::needIcons()
 {
-    return s_useIcons && d->item.hasIconSet();;
+    return s_useIcons && d->item.hasIconSet();
 }
 
 void KPushButton::readSettings()
