@@ -17,17 +17,19 @@
  *
  */
 
+#include <qstyle.h>
 
 #include <kdebug.h>
+#include <kapplication.h>
 
-#include "kseparator.h"
+#include "kseparator.moc"
 
 
 KSeparator::KSeparator(QWidget* parent, const char* name, WFlags f)
    : QFrame(parent, name, f)
 {
-   this->setLineWidth(1);
-   this->setMidLineWidth(0);
+   setLineWidth(1);
+   setMidLineWidth(0);
    setOrientation( HLine );
 }
 
@@ -47,6 +49,7 @@ void KSeparator::setOrientation(int orientation)
 {
    switch(orientation)
    {
+      case Vertical:
       case VLine:
          setFrameStyle( QFrame::VLine | QFrame::Sunken );
          setMinimumSize(2, 0);
@@ -55,6 +58,7 @@ void KSeparator::setOrientation(int orientation)
       default:
          kdWarning() << "KSeparator::setOrientation(): invalid orientation, using default orientation HLine" << endl;
          
+      case Horizontal:
       case HLine:
          setFrameStyle( QFrame::HLine | QFrame::Sunken );
          setMinimumSize(0, 2);
@@ -75,6 +79,29 @@ int KSeparator::orientation() const
    return 0;
 }
 
+void KSeparator::drawFrame(QPainter *p)
+{
+   QPoint	p1, p2;
+   QRect	r     = frameRect();
+   const QColorGroup & g = colorGroup();
+
+   if ( frameStyle() & HLine ) {
+      p1 = QPoint( r.x(), r.height()/2 );
+      p2 = QPoint( r.x()+r.width(), p1.y() );
+   }
+   else {
+      p1 = QPoint( r.x()+r.width()/2, 0 );
+      p2 = QPoint( p1.x(), r.height() );
+   }
+
+#if QT_VERSION < 300
+   style().drawSeparator( p, p1.x(), p1.y(), p2.x(), p2.y(), g, true, 1, midLineWidth() );
+#else
+   QStyleOption opt( lineWidth(), midLineWidth() );
+   style().drawPrimitive( QStyle::PE_Separator, p, QRect( p1, p2 ), g,
+		          QStyle::Style_Sunken, opt );
+#endif
+}
 
 
 QSize KSeparator::sizeHint() const
@@ -88,7 +115,6 @@ QSize KSeparator::sizeHint() const
    return QSize(-1, -1);
 }
 
-
-
-
+void KSeparator::virtual_hook( int, void* )
+{ /*BASE::virtual_hook( id, data );*/ }
 
