@@ -20,14 +20,11 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: ktoolbarradiogroup.cpp,v 1.5 2000/06/02 20:59:07 granroth Exp $
-#ifdef HAVE_CONFIG_H
+// $Id: ktoolbarradiogroup.cpp,v 1.7 2000/07/11 19:24:15 reggie Exp $
 #include <config.h>
-#endif
 
 #include "ktoolbarradiogroup.h"
 #include "ktoolbar.h"
-#include "ktoolbaritem.h"
 #include "ktoolbarbutton.h"
 
 /*************************************************************************
@@ -50,13 +47,9 @@ KToolBarRadioGroup::~KToolBarRadioGroup()
 
 void KToolBarRadioGroup::addButton (int id)
 {
-  KToolBarItemList::Iterator it(tb->items()->begin());
-  for ( ; it != tb->items()->end(); ++it)
-    if ((*it)->ID() == id )
-    {
-      buttons->insert(id, (KToolBarButton *) (*it)->getItem());
-      ((KToolBarButton *) (*it)->getItem())->setRadio(true);
-    }
+    KToolBarButton *b = tb->getButton( id );
+    b->setRadio( TRUE );
+    buttons->insert( id, b );
 }
 
 void KToolBarRadioGroup::removeButton (int id)
