@@ -20,9 +20,11 @@
 #define _KXMLGUICLIENT_H
 
 #include <qdom.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qmap.h>
+#include <qstringlist.h>
 
+class QWidget;
 class KAction;
 class KActionCollection;
 class KInstance;
@@ -30,8 +32,15 @@ class KXMLGUIClientPrivate;
 class KXMLGUIFactory;
 class KXMLGUIBuilder;
 
+/**
+ *
+ * A KXMLGUIClient can be used with @ref KXMLGUIFactory to create a
+ * GUI from actions and an XML document, and can be dynamically merged
+ * with other KXMLGUIClients.
+ */
 class KXMLGUIClient
 {
+    friend class KEditToolbarWidget; // for setXMLFile(3 args)
 public:
   /**
    * Constructs a KXMLGUIClient which can be used with a
@@ -54,26 +63,26 @@ public:
   KXMLGUIClient( KXMLGUIClient *parent );
 
   /**
-   * Destructor
+   * Destructs the KXMLGUIClient.
    */
   virtual ~KXMLGUIClient();
 
   /**
-   * Retrieve an action of the client by name.
+   * Retrieves an action of the client by name.  If not found, it looks in its child clients.
    * This method is provided for convenience, as it uses @ref #actionCollection()
    * to get the action object.
    */
   KAction* action( const char* name ) const;
 
   /**
-   * Retrieve an action for a given @ref QDomElement. The default
+   * Retrieves an action for a given @ref QDomElement. The default
    * implementation uses the "name" attribute to query the action
    * object via the other action() method.
    */
   virtual KAction *action( const QDomElement &element ) const;
 
   /**
-   * Retrieve the entire action collection for the GUI client
+   * Retrieves the entire action collection for the GUI client
    */
   virtual KActionCollection* actionCollection() const;
 
@@ -121,7 +130,7 @@ public:
    */
   void setFactory( KXMLGUIFactory *factory );
   /**
-   * Retrieve a pointer to the @ref KXMLGUIFactory this client is
+   * Retrieves a pointer to the @ref KXMLGUIFactory this client is
    * associated with (will return 0L if the client's GUI has not been built
    * by a KXMLGUIFactory.
    */
@@ -143,14 +152,14 @@ public:
   void insertChildClient( KXMLGUIClient *child );
 
   /**
-   * Remove the given @p child from the client's children list.
+   * Removes the given @p child from the client's children list.
    */
   void removeChildClient( KXMLGUIClient *child );
 
   /**
-   * Retrieve a list of all child clients.
+   * Retrieves a list of all child clients.
    */
-  const QList<KXMLGUIClient> *childClients();
+  const QPtrList<KXMLGUIClient> *childClients();
 
   /**
    * A client can have an own @ref KXMLGUIBuilder.
@@ -163,13 +172,13 @@ public:
   void setClientBuilder( KXMLGUIBuilder *builder );
 
   /**
-   * Retrieve the client's GUI builder or 0L if no client specific
-   * uilder has been assigned via @ref #setClientBuilder()
+   * Retrieves the client's GUI builder or 0L if no client specific
+   * builder has been assigned via @ref #setClientBuilder()
    */
   KXMLGUIBuilder *clientBuilder() const;
 
   /**
-   * Force this client to re-read its XML resource file.  This is
+   * Forces this client to re-read its XML resource file.  This is
    * intended to be used when you know that the resource file has
    * changed and you will soon be rebuilding the GUI.  It has no
    * useful effect with non-KParts GUIs, so don't bother using it
@@ -177,14 +186,84 @@ public:
    */
   void reloadXML();
 
-  void plugActionList( const QString &name, const QList<KAction> &actionList );
+  /**
+   * ActionLists are a way for XMLGUI to support dynamic lists of
+   * actions.  E.g. if you are writing a file manager, and there is a
+   * menu file whose contents depend on the mimetype of the file that
+   * is selected, then you can achieve this using ActionLists. It
+   * works as follows:
+   * In your xxxui.rc file ( the one that you set in @ref setXMLFile()
+   * ), you put an <ActionList name="xxx"> tag.  E.g.
+   * \verbatim
+   * <kpartgui name="xxx_part" version="1">
+   * <MenuBar>
+   *   <Menu name="file">
+   *     ...  <!-- some useful actions-->
+   *     <ActionList name="xxx_file_actionlist" />
+   *     ...  <!-- even more useful actions-->
+   *   </Menu>
+   *   ...
+   * </MenuBar>
+   * </kpartgui>
+   * \endverbatim
+   *
+   * This tag will get expanded to a list of actions.  In the example
+   * above ( a file manager with a dynamic file menu ), you would call
+   * \code
+   * QPtrList<KAction> file_actions;
+   * for( ... )
+   *   if( ... )
+   *     file_actions.append( cool_action );
+   * unplugActionList( "xxx_file_actionlist" );
+   * plugActionList( "xxx_file_actionlist", file_actions );
+   * \endcode
+   * every time a file is selected, unselected or ...
+   *
+   * \note You should not call createGUI() after calling this
+   *       function.  In fact, that would remove the newly added
+   *       actionlists again...
+   * \note Forgetting to call unplugActionList() before
+   *       plugActionList() would leave the previous actions in the
+   *       menu too..
+   */
+  void plugActionList( const QString &name, const QPtrList<KAction> &actionList );
+
+  /**
+   * The complement of \ref plugActionList() ...
+   */
   void unplugActionList( const QString &name );
 
   static QString findMostRecentXMLFile( const QStringList &files, QString &doc );
 
+  void addStateActionEnabled(const QString& state, const QString& action);
+
+  void addStateActionDisabled(const QString& state, const QString& action);
+
+  enum ReverseStateChange { StateNoReverse, StateReverse };
+  struct StateChange
+  {
+    QStringList actionsToEnable;
+    QStringList actionsToDisable;
+  };
+
+  StateChange getActionsToChangeForState(const QString& state);
+
+  /// @since 3.1
+  void beginXMLPlug( QWidget * );
+  /// @since 3.1
+  void endXMLPlug();
+  /// @since 3.1
+  void prepareXMLUnplug( QWidget * );
+
 protected:
   /**
-   * Set the instance (@ref KInstance) for this part.
+   * Returns true if client was added to super client list.
+   * Returns false if client was already in list.
+   */
+  //bool addSuperClient( KXMLGUIClient * );
+
+  /**
+   * Sets the instance (@ref KInstance) for this part.
    *
    * Call this first in the inherited class constructor.
    * (At least before @ref setXMLFile().)
@@ -192,7 +271,7 @@ protected:
   virtual void setInstance( KInstance *instance );
 
   /**
-   * Set the name of the rc file containing the XML for the part.
+   * Sets the name of the rc file containing the XML for the part.
    *
    * Call this in the Part-inherited class constructor.
    *
@@ -208,7 +287,7 @@ protected:
   virtual void setLocalXMLFile( const QString &file );
 
   /**
-   * Set the XML for the part.
+   * Sets the XML for the part.
    *
    * Call this in the Part-inherited class constructor if you
    *  don't call @ref setXMLFile().
@@ -216,7 +295,7 @@ protected:
   virtual void setXML( const QString &document, bool merge = false );
 
   /**
-   * Set the Document for the part, describing the layout of the GUI.
+   * Sets the Document for the part, describing the layout of the GUI.
    *
    * Call this in the Part-inherited class constructor if you don't call
    * @ref setXMLFile or @ref setXML .
@@ -230,6 +309,22 @@ protected:
    */
   virtual void conserveMemory();
 
+  /**
+   * Actions can collectively be assigned a "State". To accomplish this
+   * the respective actions are tagged as <enable> or <disable> in
+   * a <State> </State> group of the XMLfile. During program execution the
+   * programmer can call stateChanged() to set actions to a defined state.
+   *
+   * @param newstate Name of a State in the XMLfile.
+   * @param reverse If the flag reverse is set to StateReverse, the State is reversed.
+   * (actions to be enabled will be disabled and action to be disabled will be enabled)
+   * Default is reverse=false.
+   */
+   virtual void stateChanged(const QString &newstate, ReverseStateChange reverse = StateNoReverse);
+
+   // Use this one for KDE 4.0
+   //virtual void stateChanged(const QString &newstate, bool reverse = false);
+
 private:
   struct DocStruct
   {
@@ -251,6 +346,12 @@ private:
 
   static QString findVersionNumber( const QString &_xml );
 
+  // Actions to enable/disable on a state change
+  QMap<QString,StateChange> m_actionsStateMap;
+
+protected:
+  virtual void virtual_hook( int id, void* data );
+private:
   KXMLGUIClientPrivate *d;
 };
 
