@@ -534,15 +534,14 @@ void BuildHelper::processElement( const QDomElement &e )
     QString tag( e.tagName().lower() );
     QString currName( e.attribute( attrName ) );
 
-    bool isActionTag = false;
+    bool isActionTag = ( tag == tagAction );
 
-    if ( ( isActionTag = ( tag == tagAction ) ) ||
-           customTags.findIndex( tag ) != -1 )
+    if ( isActionTag || customTags.findIndex( tag ) != -1 )
         processActionOrCustomElement( e, isActionTag );
-   else if ( containerTags.findIndex( tag ) != -1 )
+    else if ( containerTags.findIndex( tag ) != -1 )
         processContainerElement( e, tag, currName );
     else if ( tag == tagMerge || tag == tagDefineGroup || tag == tagActionList )
-        processMergeElement( tag, currName );
+        processMergeElement( tag, currName, e );
     else if ( tag == tagState )
         processStateElement( e );
 }
@@ -576,36 +575,45 @@ void BuildHelper::processActionOrCustomElement( const QDomElement &e, bool isAct
 
     containerClient = parentNode->findChildContainerClient( m_state.guiClient, group, it );
 
+    bool guiElementCreated = false;
     if ( isActionTag )
-        processActionElement( e, idx );
+        guiElementCreated = processActionElement( e, idx );
     else
-        processCustomElement( e, idx );
+        guiElementCreated = processCustomElement( e, idx );
 
-    // adjust any following merging indices and the current running index for the container
-    parentNode->adjustMergingIndices( 1, it );
+    if ( guiElementCreated )
+        // adjust any following merging indices and the current running index for the container
+        parentNode->adjustMergingIndices( 1, it );
 }
 
-void BuildHelper::processActionElement( const QDomElement &e, int idx )
+bool BuildHelper::processActionElement( const QDomElement &e, int idx )
 {
+    assert( m_state.guiClient );
+
     // look up the action and plug it in
     KAction *action = m_state.guiClient->action( e );
 
     if ( !action )
-        return;
+        return false;
 
     action->plug( parentNode->container, idx );
 
     // save a reference to the plugged action, in order to properly unplug it afterwards.
     containerClient->actions.append( action );
+
+    return true;
 }
 
-void BuildHelper::processCustomElement( const QDomElement &e, int idx )
+bool BuildHelper::processCustomElement( const QDomElement &e, int idx )
 {
     assert( parentNode->builder );
 
     int id = parentNode->builder->createCustomElement( parentNode->container, idx, e );
-    if ( id != 0 )
-        containerClient->customElements.append( id );
+    if ( id == 0 )
+        return false;
+
+    containerClient->customElements.append( id );
+    return true;
 }
 
 void BuildHelper::processStateElement( const QDomElement &element )
@@ -642,7 +650,7 @@ void BuildHelper::processStateElement( const QDomElement &element )
     }
 }
 
-void BuildHelper::processMergeElement( const QString &tag, const QString &name )
+void BuildHelper::processMergeElement( const QString &tag, const QString &name, const QDomElement &e )
 {
     static const QString &tagDefineGroup = KGlobal::staticQString( "definegroup" );
     static const QString &tagActionList = KGlobal::staticQString( "actionlist" );
@@ -676,13 +684,16 @@ void BuildHelper::processMergeElement( const QString &tag, const QString &name )
 
     MergingIndexList::Iterator mIt( parentNode->mergingIndices.end() );
 
+    QString group( e.attribute( attrGroup ) );
+    if ( !group.isEmpty() ) 
+        group.prepend( attrGroup );
+
     // calculate the index of the new merging index. Usually this does not need any calculation,
     // we just want the last available index (i.e. append) . But in case the <Merge> tag appears
     // "inside" another <Merge> tag from a previously build client, then we have to use the
     // "parent's" index. That's why we call calcMergingIndex here.
     MergingIndex newIdx;
-    newIdx.value = parentNode->calcMergingIndex( QString::null /* ### allow group for <merge/> ? */ ,
-                                                  mIt, m_state, ignoreDefaultMergingIndex );
+    newIdx.value = parentNode->calcMergingIndex( group, mIt, m_state, ignoreDefaultMergingIndex );
     newIdx.mergingName = mergingName;
     newIdx.clientName = m_state.clientName;
 
