@@ -1,5 +1,5 @@
 /*
-    $Id: kfontdialogtest.cpp,v 1.6 1999/11/27 15:56:43 porten Exp $
+    $Id: kfontdialogtest.cpp,v 1.8 2002/01/24 07:41:34 waba Exp $
 
     Requires the Qt widget libraries, available at no cost at 
     http://www.troll.no
@@ -24,7 +24,7 @@
 */
 
 
-#include <kapp.h>
+#include <kapplication.h>
 #include "kfontdialog.h"
 #include <kconfig.h>
 
@@ -42,6 +42,8 @@
 
   QFont font = aConfig.readFontEntry( "Chosen" );
   int nRet = KFontDialog::getFont(font);
+  int flags;
+  nRet = KFontDialog::getFontDiff(font, flags);
   aConfig.writeEntry( "Chosen", font, true );
 
   aConfig.sync();
