@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: css_ruleimpl.h,v 1.18 2002/04/11 08:53:07 knoll Exp $
+ * $Id: css_ruleimpl.h,v 1.18.2.2 2003/07/15 10:42:17 mueller Exp $
  */
 #ifndef _CSS_css_ruleimpl_h_
 #define _CSS_css_ruleimpl_h_
@@ -31,7 +31,7 @@
 
 namespace khtml {
     class CachedCSSStyleSheet;
-};
+}
 
 namespace DOM {
 
@@ -230,6 +230,6 @@ protected:
     QPtrList<CSSRuleImpl> m_lstCSSRules;
 };
 
-}; // namespace
+} // namespace
 
 #endif
