@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: css_stylesheetimpl.h,v 1.24 2002/04/11 08:53:07 knoll Exp $
+ * $Id: css_stylesheetimpl.h,v 1.24.2.1 2003/05/18 12:34:36 mueller Exp $
  */
 #ifndef _CSS_css_stylesheetimpl_h_
 #define _CSS_css_stylesheetimpl_h_
@@ -33,7 +33,7 @@
 namespace khtml {
     class CachedCSSStyleSheet;
     class DocLoader;
-};
+}
 
 namespace DOM {
 
@@ -172,7 +172,7 @@ protected:
 };
 
 
-}; // namespace
+} // namespace
 
 #endif
 
