@@ -6,7 +6,7 @@
  *               2001 Andreas Schlapbach (schlpbch@iam.unibe.ch)
  *               2001 Dirk Mueller (mueller@kde.org)
  *
- * $Id: cssparser.cpp,v 1.231.2.1 2003/01/03 21:09:23 mueller Exp $
+ * $Id: cssparser.cpp,v 1.231.2.3 2003/06/26 20:57:57 staikos Exp $
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -469,7 +469,7 @@ StyleBaseImpl::parseSelector2(const QChar *curP, const QChar *endP,
                         if (doc->isHTMLDocument())
                             attr = attr.lower();
                         const DOMString dattr(attr);
-                        cs->attr = doc->attrId(0, dattr.implementation(), false);
+                        cs->attr = doc->attrId(0, dattr.implementation(), false, 0);
                     }
                     else {
                         cs->attr = khtml::getAttrID(attr.lower().ascii(), attr.length());
@@ -547,7 +547,7 @@ StyleBaseImpl::parseSelector2(const QChar *curP, const QChar *endP,
                 if (doc->isHTMLDocument())
                     tag = tag.lower();
                 const DOMString dtag(tag);
-                cs->tag = doc->tagId(0, dtag.implementation(), false);
+                cs->tag = doc->tagId(0, dtag.implementation(), false, 0);
             }
             else {
                 cs->tag = khtml::getTagID(tag.lower().ascii(), tag.length());
@@ -1905,7 +1905,8 @@ bool StyleBaseImpl::parseValue( const QChar *curP, const QChar *endP, int propId
       case CSS_PROP_TABLE_LAYOUT:         // auto | fixed | inherit
       {
 	  const struct css_value *cssval = findValue(val, len);
-	  if (cssval->id == CSS_VAL_AUTO || cssval->id == CSS_VAL_FIXED)
+	  if (cssval && 
+              (cssval->id == CSS_VAL_AUTO || cssval->id == CSS_VAL_FIXED))
 	      parsedValue = new CSSPrimitiveValueImpl(cssval->id);
 	  break;
       }
