@@ -2224,7 +2224,7 @@ void CSSStyleSelector::applyRule( DOM::CSSProperty *prop )
     {
         FontDef fontDef = style->htmlFont().fontDef;
         int oldSize;
-        float size = 0;
+        int size = 0;
 
         float toPix = paintDeviceMetrics->logicalDpiY()/72.;
         if (toPix  < 96./72.) toPix = 96./72.;
@@ -2241,20 +2241,20 @@ void CSSStyleSelector::applyRule( DOM::CSSProperty *prop )
         } else if(primitiveValue->getIdent()) {
             switch(primitiveValue->getIdent())
             {
-            case CSS_VAL_XX_SMALL: size = m_fontSizes[0]; break;
-            case CSS_VAL_X_SMALL:  size = m_fontSizes[1]; break;
-            case CSS_VAL_SMALL:    size = m_fontSizes[2]; break;
-            case CSS_VAL_MEDIUM:   size = m_fontSizes[3]; break;
-            case CSS_VAL_LARGE:    size = m_fontSizes[4]; break;
-            case CSS_VAL_X_LARGE:  size = m_fontSizes[5]; break;
-            case CSS_VAL_XX_LARGE: size = m_fontSizes[6]; break;
+            case CSS_VAL_XX_SMALL: size = int( m_fontSizes[0] ); break;
+            case CSS_VAL_X_SMALL:  size = int( m_fontSizes[1] ); break;
+            case CSS_VAL_SMALL:    size = int( m_fontSizes[2] ); break;
+            case CSS_VAL_MEDIUM:   size = int( m_fontSizes[3] ); break;
+            case CSS_VAL_LARGE:    size = int( m_fontSizes[4] ); break;
+            case CSS_VAL_X_LARGE:  size = int( m_fontSizes[5] ); break;
+            case CSS_VAL_XX_LARGE: size = int( m_fontSizes[6] ); break;
             case CSS_VAL__KONQ_XXX_LARGE:  size = ( m_fontSizes[6]*5 )/3; break;
             case CSS_VAL_LARGER:
                 // ### use the next bigger standardSize!!!
-                size = oldSize * 1.2;
+                size = ( oldSize * 5 ) / 4;
                 break;
             case CSS_VAL_SMALLER:
-                size = oldSize / 1.2;
+                size = ( oldSize * 4 ) / 5;
                 break;
             default:
                 return;
@@ -2262,26 +2262,28 @@ void CSSStyleSelector::applyRule( DOM::CSSProperty *prop )
 
         } else {
             int type = primitiveValue->primitiveType();
-            if(type > CSSPrimitiveValue::CSS_PERCENTAGE && type < CSSPrimitiveValue::CSS_DEG)
-                size = primitiveValue->computeLengthFloat(parentStyle, paintDeviceMetrics);
+            if(type > CSSPrimitiveValue::CSS_PERCENTAGE && type < CSSPrimitiveValue::CSS_DEG) {
+                if (!khtml::printpainter && element && element->getDocument()->view())
+                    size = int( primitiveValue->computeLengthFloat(parentStyle, paintDeviceMetrics) *
+                                element->getDocument()->view()->part()->zoomFactor() ) / 100;
+                else size = int( primitiveValue->computeLengthFloat(parentStyle, paintDeviceMetrics) );
+            }
             else if(type == CSSPrimitiveValue::CSS_PERCENTAGE)
-                size = (primitiveValue->getFloatValue(CSSPrimitiveValue::CSS_PERCENTAGE)
+                size = int(primitiveValue->getFloatValue(CSSPrimitiveValue::CSS_PERCENTAGE)
                         * parentStyle->font().pixelSize()) / 100;
             else
                 return;
 
-            if (!khtml::printpainter && element && element->getDocument()->view())
-                size *= element->getDocument()->view()->part()->zoomFactor() / 100.0;
         }
 
-        if(size <= 0) return;
+        if(size < 1) return;
 
         // we never want to get smaller than the minimum font size to keep fonts readable
         if(size < minFontSize ) size = minFontSize;
 
         //kdDebug( 6080 ) << "computed raw font size: " << size << endl;
 
-	fontDef.size = int(size);
+	fontDef.size = size;
         if (style->setFontDef( fontDef ))
 	fontDirty = true;
         return;
