@@ -1,4 +1,4 @@
-/**
+/*
  * This file is part of the DOM implementation for KDE.
  *
  * (C) 1999 Lars Knoll (knoll@kde.org)
@@ -23,7 +23,7 @@
  * http://www.w3.org/TR/2000/CR-DOM-Level-2-20000510/
  * Copyright  2000 W3C (MIT, INRIA, Keio), All Rights Reserved.
  *
- * $Id: css_extensions.h,v 1.4 2000/08/21 13:46:01 pmk Exp $
+ * $Id: css_extensions.h,v 1.6 2001/10/06 20:56:48 gehrmab Exp $
  */
 #ifndef _CSS_css_extensions_h_
 #define _CSS_css_extensions_h_
@@ -433,7 +433,7 @@ public:
      *
      * @return
      */
-    void setInherit() (  );
+    void setInherit();
 };
 
 
