@@ -23,7 +23,7 @@
  * http://www.w3.org/TR/2000/CR-DOM-Level-2-20000510/
  * Copyright  2000 W3C (MIT, INRIA, Keio), All Rights Reserved.
  *
- * $Id: css_stylesheet.h,v 1.13 2002/04/08 17:53:37 knoll Exp $
+ * $Id: css_stylesheet.h,v 1.13.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _CSS_css_stylesheet_h_
 #define _CSS_css_stylesheet_h_
@@ -487,6 +487,6 @@ protected:
     DocumentStyleImpl *impl;
 };
 
-}; // namespace
+} // namespace
 
 #endif
