@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: dom_doc.h,v 1.28 2002/05/30 07:37:13 faure Exp $
+ * $Id: dom_doc.h,v 1.28.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _DOM_Document_h_
 #define _DOM_Document_h_
@@ -936,5 +936,5 @@ protected:
     DocumentType(DocumentTypeImpl *impl);
 };
 
-}; //namespace
+} //namespace
 #endif
