@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: dom_element.h,v 1.26 2002/05/21 12:40:18 mueller Exp $
+ * $Id: dom_element.h,v 1.26.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _DOM_ELEMENT_h_
 #define _DOM_ELEMENT_h_
@@ -561,5 +561,5 @@ protected:
     Element(ElementImpl *_impl);
 };
 
-}; //namespace
+} //namespace
 #endif
