@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_misc.h,v 1.9 2002/01/09 21:55:35 mueller Exp $
+ * $Id: dom_misc.h,v 1.9.4.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _DOM_RefCountImpl_h_
 #define _DOM_RefCountImpl_h_
@@ -54,6 +54,6 @@ protected:
     unsigned int _ref;
 };
 
-}; // namespace
+} // namespace
 
 #endif
