@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_node.cpp,v 1.44.2.1 2003/01/03 21:09:23 mueller Exp $
+ * $Id: dom_node.cpp,v 1.44.2.2 2003/06/27 20:05:48 faure Exp $
  */
 
 #include "dom/dom_doc.h"
@@ -105,7 +105,12 @@ Node NamedNodeMap::removeNamedItemNS( const DOMString &namespaceURI, const DOMSt
 {
     if (!impl) throw DOMException(DOMException::NOT_FOUND_ERR);
     int exceptioncode = 0;
-    Node r = impl->removeNamedItem(impl->mapId(namespaceURI, localName, true), exceptioncode);
+    NodeImpl::Id id = impl->mapId(namespaceURI, localName, true);
+    NodeImpl* oldItem = impl->getNamedItem(id);
+    if (!oldItem) throw DOMException(DOMException::NOT_FOUND_ERR);
+
+    Node r(oldItem->cloneNode(true));
+    impl->removeNamedItem(id, exceptioncode);
     if (exceptioncode)
         throw DOMException(exceptioncode);
     return r;
