@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: dom_node.h,v 1.28 2002/10/22 18:59:06 faure Exp $
+ * $Id: dom_node.h,v 1.28.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _DOM_Node_h_
 #define _DOM_Node_h_
@@ -950,5 +950,5 @@ protected:
 typedef unsigned long long DOMTimeStamp;
 
 
-}; //namespace
+} //namespace
 #endif
