@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: dom_xml.h,v 1.10 2001/05/28 14:30:27 pmk Exp $
+ * $Id: dom_xml.h,v 1.10.8.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef _DOM_XML_h
 #define _DOM_XML_h
@@ -309,5 +309,5 @@ protected:
     ProcessingInstruction(ProcessingInstructionImpl *i);
 };
 
-}; //namespace
+} //namespace
 #endif
