@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_block.cpp,v 1.11.2.1 2002/04/16 17:43:04 mueller Exp $
+ * $Id: html_block.cpp,v 1.13.2.1 2003/01/03 21:09:23 mueller Exp $
  */
 // --------------------------------------------------------------------------
 
@@ -30,15 +30,18 @@ using namespace DOM;
 
 #include "misc/htmlhashes.h"
 
-HTMLBlockquoteElement::HTMLBlockquoteElement() : HTMLElement()
+HTMLBlockquoteElement::HTMLBlockquoteElement()
+    : HTMLElement()
 {
 }
 
-HTMLBlockquoteElement::HTMLBlockquoteElement(const HTMLBlockquoteElement &other) : HTMLElement(other)
+HTMLBlockquoteElement::HTMLBlockquoteElement(const HTMLBlockquoteElement &other)
+    : HTMLElement(other)
 {
 }
 
-HTMLBlockquoteElement::HTMLBlockquoteElement(HTMLBlockquoteElementImpl *impl) : HTMLElement(impl)
+HTMLBlockquoteElement::HTMLBlockquoteElement(HTMLElementImpl *impl)
+    : HTMLElement(impl)
 {
 }
 
@@ -200,17 +203,17 @@ HTMLHeadingElement::HTMLHeadingElement(const HTMLHeadingElement &other) : HTMLEl
 {
 }
 
-HTMLHeadingElement::HTMLHeadingElement(HTMLHeadingElementImpl *impl) : HTMLElement(impl)
+HTMLHeadingElement::HTMLHeadingElement(HTMLElementImpl *impl) : HTMLElement(impl)
 {
 }
 
 HTMLHeadingElement &HTMLHeadingElement::operator = (const Node &other)
 {
-    if(other.elementId() != ID_H1 ||
-       other.elementId() != ID_H2 ||
-       other.elementId() != ID_H3 ||
-       other.elementId() != ID_H4 ||
-       other.elementId() != ID_H5 ||
+    if(other.elementId() != ID_H1 &&
+       other.elementId() != ID_H2 &&
+       other.elementId() != ID_H3 &&
+       other.elementId() != ID_H4 &&
+       other.elementId() != ID_H5 &&
        other.elementId() != ID_H6 )
     {
 	if ( impl ) impl->deref();
@@ -252,7 +255,7 @@ HTMLParagraphElement::HTMLParagraphElement(const HTMLParagraphElement &other) :
 {
 }
 
-HTMLParagraphElement::HTMLParagraphElement(HTMLParagraphElementImpl *impl) : HTMLElement(impl)
+HTMLParagraphElement::HTMLParagraphElement(HTMLElementImpl *impl) : HTMLElement(impl)
 {
 }
 
