@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: html_document.h,v 1.18 2002/01/05 13:25:30 mueller Exp $
+ * $Id: html_document.h,v 1.18.4.1 2003/05/18 12:34:37 mueller Exp $
  */
 
 #ifndef HTML_DOCUMENT_H
@@ -288,6 +288,6 @@ public:
     HTMLCollection all() const;
 };
 
-}; //namespace
+} //namespace
 
 #endif
