@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_form.cpp,v 1.32.2.1 2002/04/16 17:43:04 mueller Exp $
+ * $Id: html_form.cpp,v 1.37.2.1 2003/01/03 21:09:23 mueller Exp $
  */
 // --------------------------------------------------------------------------
 
@@ -48,7 +48,7 @@ HTMLButtonElement::HTMLButtonElement(HTMLButtonElementImpl *impl) : HTMLElement(
 
 HTMLButtonElement &HTMLButtonElement::operator = (const Node &other)
 {
-    assignOther( other, ID_BUTTON );	
+    assignOther( other, ID_BUTTON );
     return *this;
 }
 
@@ -64,8 +64,7 @@ HTMLButtonElement::~HTMLButtonElement()
 
 HTMLFormElement HTMLButtonElement::form() const
 {
-    if(!impl) return 0;
-    return static_cast<HTMLButtonElementImpl*>(impl)->form();
+    return Element::form();
 }
 
 DOMString HTMLButtonElement::accessKey() const
@@ -122,7 +121,9 @@ DOMString HTMLButtonElement::type() const
 DOMString HTMLButtonElement::value() const
 {
     if(!impl) return DOMString();
-    return static_cast<ElementImpl*>(impl)->getAttribute(ATTR_VALUE);
+    DOMString s = static_cast<ElementImpl*>(impl)->getAttribute(ATTR_VALUE);
+    if (s.isNull()) return DOMString("");
+    return s;
 }
 
 void HTMLButtonElement::setValue( const DOMString &value )
@@ -162,8 +163,7 @@ HTMLFieldSetElement::~HTMLFieldSetElement()
 
 HTMLFormElement HTMLFieldSetElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLFieldSetElementImpl *)impl)->form();
+    return Element::form();
 }
 
 // --------------------------------------------------------------------------
@@ -317,7 +317,10 @@ HTMLInputElement::~HTMLInputElement()
 DOMString HTMLInputElement::defaultValue() const
 {
     if(!impl) return DOMString();
-    return ((ElementImpl *)impl)->getAttribute(ATTR_VALUE);
+    DOMString s = static_cast<ElementImpl*>(impl)->getAttribute(ATTR_VALUE);
+    if (s.isNull()) return DOMString("");
+    return s;
+
 }
 
 void HTMLInputElement::setDefaultValue( const DOMString &value )
@@ -339,8 +342,7 @@ void HTMLInputElement::setDefaultChecked( bool _defaultChecked )
 
 HTMLFormElement HTMLInputElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLInputElementImpl *)impl)->form();
+    return Element::form();
 }
 
 DOMString HTMLInputElement::accept() const
@@ -450,6 +452,7 @@ void HTMLInputElement::setReadOnly( bool _readOnly )
 	static_cast<ElementImpl*>(impl)->setAttribute(ATTR_READONLY, _readOnly ? "" : 0);
 }
 
+/* The next two are provided for backwards compatibility. */
 DOMString HTMLInputElement::size() const
 {
     if(!impl) return DOMString();
@@ -461,6 +464,17 @@ void HTMLInputElement::setSize( const DOMString &value )
     if(impl) static_cast<ElementImpl*>(impl)->setAttribute(ATTR_SIZE, value);
 }
 
+long HTMLInputElement::getSize() const
+{
+    if(!impl) return 0;
+    return static_cast<ElementImpl*>(impl)->getAttribute(ATTR_SIZE).toInt();
+}
+
+void HTMLInputElement::setSize( long value )
+{
+    if(impl) static_cast<ElementImpl*>(impl)->setAttribute(ATTR_SIZE, QString::number(value));
+}
+
 DOMString HTMLInputElement::src() const
 {
     if(!impl) return DOMString();
@@ -579,16 +593,6 @@ HTMLLabelElement::~HTMLLabelElement()
 {
 }
 
-
-HTMLFormElement HTMLLabelElement::form() const
-{
-    if(!impl) return 0;
-    ElementImpl *formElement = ((HTMLLabelElementImpl *)impl)->formElement();
-    if (!formElement)
-	return 0;
-    return ((HTMLGenericFormElementImpl *)formElement)->form();
-}
-
 DOMString HTMLLabelElement::accessKey() const
 {
     if(!impl) return DOMString();
@@ -643,8 +647,7 @@ HTMLLegendElement::~HTMLLegendElement()
 
 HTMLFormElement HTMLLegendElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLLegendElementImpl *)impl)->form();
+    return Element::form();
 }
 
 DOMString HTMLLegendElement::accessKey() const
@@ -790,8 +793,7 @@ long HTMLSelectElement::length() const
 
 HTMLFormElement HTMLSelectElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLSelectElementImpl *)impl)->form();
+    return Element::form();
 }
 
 HTMLCollection HTMLSelectElement::options() const
@@ -863,7 +865,13 @@ void HTMLSelectElement::setTabIndex( long _tabIndex )
 
 void HTMLSelectElement::add( const HTMLElement &element, const HTMLElement &before )
 {
-    if(impl) static_cast<HTMLSelectElementImpl*>(impl)->add( element, before );
+    if (!impl)
+        throw DOMException(DOMException::NOT_FOUND_ERR);
+
+    int exceptioncode = 0;
+    static_cast<HTMLSelectElementImpl*>(impl)->add( element, before, exceptioncode );
+    if ( exceptioncode )
+        throw DOMException( exceptioncode );
 }
 
 void HTMLSelectElement::remove( long index )
@@ -926,8 +934,7 @@ void HTMLTextAreaElement::setDefaultValue( const DOMString &value )
 
 HTMLFormElement HTMLTextAreaElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLTextAreaElementImpl *)impl)->form();
+    return Element::form();
 }
 
 DOMString HTMLTextAreaElement::accessKey() const
@@ -1083,8 +1090,7 @@ HTMLOptionElement::~HTMLOptionElement()
 
 HTMLFormElement HTMLOptionElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLOptionElementImpl *)impl)->form();
+    return Element::form();
 }
 
 bool HTMLOptionElement::defaultSelected() const
@@ -1191,17 +1197,16 @@ HTMLIsIndexElement::~HTMLIsIndexElement()
 
 HTMLFormElement HTMLIsIndexElement::form() const
 {
-    if(!impl) return 0;
-    return ((HTMLIsIndexElementImpl *)impl)->form();
+    return Element::form();
 }
 
 DOMString HTMLIsIndexElement::prompt() const
 {
     if(!impl) return DOMString();
-    return static_cast<ElementImpl*>(impl)->getAttribute(ATTR_PROMPT);
+    return static_cast<HTMLIsIndexElementImpl*>(impl)->prompt();
 }
 
 void HTMLIsIndexElement::setPrompt( const DOMString &value )
 {
-    if(impl) static_cast<ElementImpl*>(impl)->setAttribute(ATTR_PROMPT, value);
+    if(impl) static_cast<HTMLIsIndexElementImpl*>(impl)->setPrompt(value);
 }
