@@ -18,13 +18,14 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_head.cpp,v 1.16 2002/09/23 19:28:27 faure Exp $
+ * $Id: html_head.cpp,v 1.16.2.1 2003/01/23 03:56:17 mueller Exp $
  */
 // --------------------------------------------------------------------------
 
 #include "dom/html_head.h"
 #include "html/html_headimpl.h"
 #include "misc/htmlhashes.h"
+#include "xml/dom_docimpl.h"
 
 using namespace DOM;
 
@@ -59,7 +60,8 @@ HTMLBaseElement::~HTMLBaseElement()
 DOMString HTMLBaseElement::href() const
 {
     if(!impl) return DOMString();
-    return ((ElementImpl *)impl)->getAttribute(ATTR_HREF);
+    DOMString href = static_cast<ElementImpl*>(impl)->getAttribute(ATTR_HREF);
+    return href.length() ? impl->getDocument()->completeURL(href.string()) : href;
 }
 
 void HTMLBaseElement::setHref( const DOMString &value )
@@ -134,7 +136,8 @@ void HTMLLinkElement::setCharset( const DOMString &value )
 DOMString HTMLLinkElement::href() const
 {
     if(!impl) return DOMString();
-    return ((ElementImpl *)impl)->getAttribute(ATTR_HREF);
+    DOMString href = static_cast<ElementImpl*>(impl)->getAttribute(ATTR_HREF);
+    return href.length() ? impl->getDocument()->completeURL(href.string()) : href;
 }
 
 void HTMLLinkElement::setHref( const DOMString &value )
