@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_misc.cpp,v 1.16.2.1 2002/04/16 17:43:04 mueller Exp $
+ * $Id: html_misc.cpp,v 1.17.2.1 2003/01/03 21:09:24 mueller Exp $
  */
 // --------------------------------------------------------------------------
 
@@ -89,6 +89,22 @@ void HTMLBaseFontElement::setSize( const DOMString &value )
     if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_SIZE, value);
 }
 
+long HTMLBaseFontElement::getSize() const
+{
+    if(!impl) return 0;
+    return ((ElementImpl *)impl)->getAttribute(ATTR_SIZE).toInt();
+}
+
+void HTMLBaseFontElement::setSize( long _value )
+{
+    if ( impl )
+    {
+        DOMString value( QString::number( _value ) );
+        ((ElementImpl *)impl)->setAttribute(ATTR_SIZE, value);
+    }
+}
+
+
 // --------------------------------------------------------------------------
 
 HTMLCollection::HTMLCollection()
@@ -111,9 +127,9 @@ HTMLCollection::HTMLCollection(NodeImpl *base, int type)
 HTMLCollection &HTMLCollection::operator = (const HTMLCollection &other)
 {
     if(impl != other.impl) {
-    if(impl) impl->deref();
-    impl = other.impl;
-    if(impl) impl->ref();
+        if(impl) impl->deref();
+        impl = other.impl;
+        if(impl) impl->ref();
     }
     return *this;
 }
