@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_object.cpp,v 1.12.2.1 2002/04/16 17:43:04 mueller Exp $
+ * $Id: html_object.cpp,v 1.13.2.1 2003/01/03 21:09:24 mueller Exp $
  */
 
 #include "dom/dom_doc.h"
@@ -133,6 +133,17 @@ void HTMLAppletElement::setHspace( const DOMString &value )
     if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_HSPACE, value);
 }
 
+long HTMLAppletElement::getHspace() const
+{
+    if(!impl) return 0;
+    return ((ElementImpl *)impl)->getAttribute(ATTR_HSPACE).toInt();
+}
+
+void HTMLAppletElement::setHspace( long value )
+{
+    if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_HSPACE, QString::number(value));
+}
+
 DOMString HTMLAppletElement::name() const
 {
     if(!impl) return DOMString();
@@ -166,6 +177,18 @@ void HTMLAppletElement::setVspace( const DOMString &value )
     if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_VSPACE, value);
 }
 
+long HTMLAppletElement::getVspace() const
+{
+    if(!impl) return 0;
+    return ((ElementImpl *)impl)->getAttribute(ATTR_VSPACE).toInt();
+}
+
+void HTMLAppletElement::setVspace( long value )
+{
+    if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_VSPACE, QString::number(value));
+}
+
+
 DOMString HTMLAppletElement::width() const
 {
     if(!impl) return DOMString();
@@ -329,6 +352,17 @@ void HTMLObjectElement::setHspace( const DOMString &value )
     if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_HSPACE, value);
 }
 
+long HTMLObjectElement::getHspace() const
+{
+    if(!impl) return 0;
+    return ((ElementImpl *)impl)->getAttribute(ATTR_HSPACE).toInt();
+}
+
+void HTMLObjectElement::setHspace( long value )
+{
+    if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_HSPACE, QString::number(value));
+}
+
 DOMString HTMLObjectElement::name() const
 {
     if(!impl) return DOMString();
@@ -398,6 +432,17 @@ void HTMLObjectElement::setVspace( const DOMString &value )
     if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_VSPACE, value);
 }
 
+long HTMLObjectElement::getVspace() const
+{
+    if(!impl) return 0;
+    return ((ElementImpl *)impl)->getAttribute(ATTR_VSPACE).toInt();
+}
+
+void HTMLObjectElement::setVspace( long value )
+{
+    if(impl) ((ElementImpl *)impl)->setAttribute(ATTR_VSPACE, QString::number(value));
+}
+
 DOMString HTMLObjectElement::width() const
 {
     if(!impl) return DOMString();
