@@ -25,7 +25,7 @@
  * Technology , Institut National de Recherche en Informatique et en
  * Automatique , Keio University ). All Rights Reserved.
  *
- * $Id: html_table.h,v 1.9 2002/10/03 10:33:02 faure Exp $
+ * $Id: html_table.h,v 1.9.2.1 2003/05/18 12:34:37 mueller Exp $
  */
 #ifndef HTML_TABLE_H
 #define HTML_TABLE_H
@@ -992,6 +992,6 @@ public:
     void deleteRow ( long index );
 };
 
-}; //namespace
+} //namespace
 
 #endif
