@@ -179,6 +179,6 @@ namespace KJS {
     DOM::MutationEvent toMutationEvent() const { return static_cast<DOM::MutationEvent>(event); }
   };
 
-}; // namespace
+} // namespace
 
 #endif
