@@ -119,7 +119,7 @@ namespace KJS {
     };
     const ClassInfo MimeType::info = { "MimeType", 0, 0, 0 };
 
-};
+}
 
 
 QPtrList<PluginBase::PluginInfo> *KJS::PluginBase::plugins = 0;
@@ -240,7 +240,7 @@ PluginBase::PluginBase(ExecState *exec)
             PluginInfo *plugin = new PluginInfo;
 
             plugin->name = c.readEntry("name");
-            plugin->file = c.readEntry("file");
+            plugin->file = c.readPathEntry("file");
             plugin->desc = c.readEntry("description");
 
             //kdDebug(6070) << "plugin : " << plugin->name << " - " << plugin->desc << endl;
