@@ -2,7 +2,8 @@
 /*
  *  This file is part of the KDE libraries
  *  Copyright (C) 1999-2001 Harri Porten (porten@kde.org)
- *  Copyright (C) 2001 Peter Kelly (pmk@post.com)
+ *  Copyright (C) 2001,2003 Peter Kelly (pmk@post.com)
+ *  Copyright (C) 2001-2003 David Faure (faure@kde.org)
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Library General Public
@@ -45,7 +46,8 @@ class KJSProxyImpl : public KJSProxy {
 public:
   KJSProxyImpl(KHTMLPart *part);
   virtual ~KJSProxyImpl();
-  virtual QVariant evaluate(QString filename, int baseLine, const QString&str, const DOM::Node &n);
+  virtual QVariant evaluate(QString filename, int baseLine, const QString &, const DOM::Node &n,
+			    Completion *completion = 0);
   virtual void clear();
   virtual DOM::EventListener *createHTMLEventHandler(QString sourceUrl, QString code);
   virtual void finishedWithEvent(const DOM::Event &event);
@@ -111,7 +113,7 @@ KJSProxyImpl::~KJSProxyImpl()
 }
 
 QVariant KJSProxyImpl::evaluate(QString filename, int baseLine,
-                                const QString&str, const DOM::Node &n) {
+                                const QString&str, const DOM::Node &n, Completion *completion) {
   // evaluate code. Returns the JS return value or an invalid QVariant
   // if there was none, an error occured or the type couldn't be converted.
 
@@ -148,6 +150,9 @@ QVariant KJSProxyImpl::evaluate(QString filename, int baseLine,
 
   bool success = ( comp.complType() == Normal ) || ( comp.complType() == ReturnValue );
 
+  if (completion)
+    *completion = comp;
+
 #ifdef KJS_DEBUGGER
     //    KJSDebugWin::instance()->setCode(QString::null);
 #endif
