@@ -4,16 +4,16 @@
  *  Copyright (C) 2001 Peter Kelly (pmk@post.com)
  *
  *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Lesser General Public
+ *  modify it under the terms of the GNU Library General Public
  *  License as published by the Free Software Foundation; either
  *  version 2 of the License, or (at your option) any later version.
  *
  *  This library is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Lesser General Public License for more details.
+ *  Library General Public License for more details.
  *
- *  You should have received a copy of the GNU Lesser General Public
+ *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
@@ -46,7 +46,7 @@ const ClassInfo DOMNodeIterator::info = { "NodeIterator", 0, &DOMNodeIteratorTab
 @end
 */
 DEFINE_PROTOTYPE("DOMNodeIterator",DOMNodeIteratorProto)
-IMPLEMENT_PROTOFUNC(DOMNodeIteratorProtoFunc)
+IMPLEMENT_PROTOFUNC_DOM(DOMNodeIteratorProtoFunc)
 IMPLEMENT_PROTOTYPE(DOMNodeIteratorProto,DOMNodeIteratorProtoFunc)
 
 DOMNodeIterator::DOMNodeIterator(ExecState *exec, DOM::NodeIterator ni)
@@ -82,11 +82,7 @@ Value DOMNodeIterator::getValueProperty(ExecState *exec, int token) const
 
 Value DOMNodeIteratorProtoFunc::tryCall(ExecState *exec, Object &thisObj, const List &)
 {
-  if (!thisObj.inherits(&KJS::DOMNodeIterator::info)) {
-    Object err = Error::create(exec,TypeError);
-    exec->setException(err);
-    return err;
-  }
+  KJS_CHECK_THIS( KJS::DOMNodeIterator, thisObj );
   DOM::NodeIterator nodeIterator = static_cast<DOMNodeIterator *>(thisObj.imp())->toNodeIterator();
   switch (id) {
   case DOMNodeIterator::PreviousNode:
@@ -129,6 +125,12 @@ const ClassInfo NodeFilterConstructor::info = { "NodeFilterConstructor", 0, &Nod
   SHOW_NOTATION		DOM::NodeFilter::SHOW_NOTATION	DontDelete|ReadOnly
 @end
 */
+
+NodeFilterConstructor::NodeFilterConstructor(ExecState* exec)
+  : DOMObject(exec->interpreter()->builtinObjectPrototype())
+{
+}
+
 Value NodeFilterConstructor::tryGet(ExecState *exec, const UString &p) const
 {
   return DOMObjectLookupGetValue<NodeFilterConstructor,DOMObject>(exec,p,&NodeFilterConstructorTable,this);
@@ -154,7 +156,7 @@ const ClassInfo DOMNodeFilter::info = { "NodeFilter", 0, 0, 0 };
 @end
 */
 DEFINE_PROTOTYPE("DOMNodeFilter",DOMNodeFilterProto)
-IMPLEMENT_PROTOFUNC(DOMNodeFilterProtoFunc)
+IMPLEMENT_PROTOFUNC_DOM(DOMNodeFilterProtoFunc)
 IMPLEMENT_PROTOTYPE(DOMNodeFilterProto,DOMNodeFilterProtoFunc)
 
 DOMNodeFilter::DOMNodeFilter(ExecState *exec, DOM::NodeFilter nf)
@@ -167,11 +169,7 @@ DOMNodeFilter::~DOMNodeFilter()
 
 Value DOMNodeFilterProtoFunc::tryCall(ExecState *exec, Object &thisObj, const List &args)
 {
-  if (!thisObj.inherits(&KJS::DOMNodeFilter::info)) {
-    Object err = Error::create(exec,TypeError);
-    exec->setException(err);
-    return err;
-  }
+  KJS_CHECK_THIS( KJS::DOMNodeFilter, thisObj );
   DOM::NodeFilter nodeFilter = static_cast<DOMNodeFilter *>(thisObj.imp())->toNodeFilter();
   switch (id) {
     case DOMNodeFilter::AcceptNode:
@@ -207,7 +205,7 @@ const ClassInfo DOMTreeWalker::info = { "TreeWalker", 0, &DOMTreeWalkerTable, 0
 @end
 */
 DEFINE_PROTOTYPE("DOMTreeWalker",DOMTreeWalkerProto)
-IMPLEMENT_PROTOFUNC(DOMTreeWalkerProtoFunc)
+IMPLEMENT_PROTOFUNC_DOM(DOMTreeWalkerProtoFunc)
 IMPLEMENT_PROTOTYPE(DOMTreeWalkerProto,DOMTreeWalkerProtoFunc)
 
 DOMTreeWalker::DOMTreeWalker(ExecState *exec, DOM::TreeWalker tw)
@@ -255,11 +253,7 @@ void DOMTreeWalker::tryPut(ExecState *exec, const UString &propertyName,
 
 Value DOMTreeWalkerProtoFunc::tryCall(ExecState *exec, Object &thisObj, const List &)
 {
-  if (!thisObj.inherits(&KJS::DOMTreeWalker::info)) {
-    Object err = Error::create(exec,TypeError);
-    exec->setException(err);
-    return err;
-  }
+  KJS_CHECK_THIS( KJS::DOMTreeWalker, thisObj );
   DOM::TreeWalker treeWalker = static_cast<DOMTreeWalker *>(thisObj.imp())->toTreeWalker();
   switch (id) {
     case DOMTreeWalker::ParentNode:
