@@ -92,7 +92,7 @@ namespace KJS {
     QCString m_name;
   };
 #endif
-}; // namespace KJS
+} // namespace KJS
 
 #include "kjs_window.lut.h"
 
@@ -1170,14 +1170,14 @@ Value Window::openWindow(ExecState *exec, const List& args)
     uargs.frameName = args.size() > 1 ?
                       args[1].toString(exec).qstring()
                       : QString("_blank");
-    if ( uargs.frameName == "_top" )
+    if ( uargs.frameName.lower() == "_top" )
     {
       while ( p->parentPart() )
         p = p->parentPart();
       Window::retrieveWindow(p)->goURL(exec, url.url(), false /*don't lock history*/);
       return Window::retrieve(p);
     }
-    if ( uargs.frameName == "_parent" )
+    if ( uargs.frameName.lower() == "_parent" )
     {
       if ( p->parentPart() )
         p = p->parentPart();
@@ -1205,7 +1205,7 @@ Value Window::openWindow(ExecState *exec, const List& args)
         }
       }
       uargs.serviceType = QString::null;
-      if (uargs.frameName == "_blank")
+      if (uargs.frameName.lower() == "_blank")
         uargs.frameName = QString::null;
       if (!url.isEmpty())
         emit khtmlpart->browserExtension()->openURLRequest(url,uargs);
@@ -1262,8 +1262,10 @@ Value WindowFunc::tryCall(ExecState *exec, Object &thisObj, const List &args)
   case Window::Open:
     return window->openWindow(exec, args);
   case Window::Focus: {
-    if(widget)
+    if(widget) {
+      widget->topLevelWidget()->raise();
       widget->setActiveWindow();
+    }
     return Undefined();
   }
   case Window::Blur:
