@@ -223,6 +223,6 @@ namespace KJS {
   };
 #endif
 
-}; // namespace
+} // namespace
 
 #endif
