@@ -30,6 +30,7 @@
 
 #include "khtmlview.h"
 #include "khtml_part.h"
+#include "khtmlpart_p.h"
 #include "khtml_settings.h"
 #include "misc/htmlattrs.h"
 #include "misc/htmlhashes.h"
@@ -84,7 +85,7 @@ HTMLDocumentImpl::~HTMLDocumentImpl()
 DOMString HTMLDocumentImpl::referrer() const
 {
     if ( view() )
-        return view()->part()->referrer();
+        return view()->part()->pageReferrer();
     return DOMString();
 }
 
@@ -141,7 +142,7 @@ DOMString HTMLDocumentImpl::cookie() const
     stream << URL() << windowId;
     if (!kapp->dcopClient()->call("kcookiejar", "kcookiejar",
                                   "findDOMCookies(QString,long int)", params,
-                                  replyType, reply)) 
+                                  replyType, reply))
     {
        kdWarning(6010) << "Can't communicate with cookiejar!" << endl;
        return DOMString();
@@ -232,9 +233,12 @@ bool HTMLDocumentImpl::childAllowed( NodeImpl *newChild )
     return (newChild->id() == ID_HTML || newChild->id() == ID_COMMENT);
 }
 
-ElementImpl *HTMLDocumentImpl::createElement( const DOMString &name )
+ElementImpl *HTMLDocumentImpl::createElement( const DOMString &name, int* pExceptioncode )
 {
-    return createHTMLElement(name);
+    ElementImpl* e = createHTMLElement( name );
+    if ( e )
+        return e;
+    return DOM::DocumentImpl::createElement( name, pExceptioncode );
 }
 
 void HTMLDocumentImpl::slotHistoryChanged()
@@ -298,6 +302,9 @@ void HTMLDocumentImpl::close()
         if (b && b->id() == ID_FRAMESET)
             getDocument()->dispatchWindowEvent(EventImpl::LOAD_EVENT, false, false);
 
+        // don't update rendering if we're going to redirect anyway
+        if ( view() && ( view()->part()->d->m_redirectURL.isNull() ||
+                         view()->part()->d->m_delayRedirect > 1 ) )
         updateRendering();
     }
 }
