@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_elementimpl.h,v 1.60.2.2 2003/01/13 22:04:47 mueller Exp $
+ * $Id: html_elementimpl.h,v 1.60.2.3 2003/05/18 12:34:39 mueller Exp $
  */
 #ifndef HTML_ELEMENTIMPL_H
 #define HTML_ELEMENTIMPL_H
@@ -79,6 +79,6 @@ protected:
     ushort _id;
 };
 
-}; //namespace
+} //namespace
 
 #endif
