@@ -20,7 +20,6 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_formimpl.cpp,v 1.300.2.4 2003/01/18 20:02:51 mueller Exp $
  */
 
 #undef FORMS_DEBUG
@@ -50,6 +49,7 @@
 #include <kdebug.h>
 #include <kmimetype.h>
 #include <kmessagebox.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <netaccess.h>
 #include <kfileitem.h>
@@ -76,7 +76,7 @@ HTMLFormElementImpl::HTMLFormElementImpl(DocumentPtr *doc, bool implicit)
     m_doingsubmit = false;
     m_inreset = false;
     m_enctype = "application/x-www-form-urlencoded";
-    m_boundary = "----------0xKhTmLbOuNdArY";
+    m_boundary = "----------" + KApplication::randomString( 42 + 13 );
     m_acceptcharset = "UNKNOWN";
 }
 
@@ -85,6 +85,9 @@ HTMLFormElementImpl::~HTMLFormElementImpl()
     QPtrListIterator<HTMLGenericFormElementImpl> it(formElements);
     for (; it.current(); ++it)
         it.current()->m_form = 0;
+    QPtrListIterator<HTMLImageElementImpl> it2(imgElements);
+    for (; it2.current(); ++it2)
+        it2.current()->m_form = 0;
 }
 
 NodeImpl::Id HTMLFormElementImpl::id() const
@@ -249,7 +252,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
                 else
                 {
                     QCString hstr("--");
-                    hstr += m_boundary.string().latin1();
+                    hstr += m_boundary.latin1();
                     hstr += "\r\n";
                     hstr += "Content-Disposition: form-data; name=\"";
                     hstr += (*it).data();
@@ -264,7 +267,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
                         if (path.length()) fileUploads << path;
                         QString onlyfilename = path.mid(path.findRev('/')+1);
 
-                        hstr += ("; filename=\"" + onlyfilename + "\"").ascii();
+                        hstr += fixUpfromUnicode(codec, "; filename=\"" + onlyfilename + "\"");
                         if(!static_cast<HTMLInputElementImpl*>(current)->value().isEmpty())
                         {
                             hstr += "\r\nContent-Type: ";
@@ -303,7 +306,7 @@ QByteArray HTMLFormElementImpl::formData(bool& ok)
     }
 
     if (m_multipart)
-        enc_string = ("--" + m_boundary.string() + "--\r\n").ascii();
+        enc_string = ("--" + m_boundary + "--\r\n").ascii();
 
     int old_size = form_data.size();
     form_data.resize( form_data.size() + enc_string.length() );
@@ -333,14 +336,12 @@ void HTMLFormElementImpl::setEnctype( const DOMString& type )
     m_encCharset = QString::null;
 }
 
-void HTMLFormElementImpl::setBoundary( const DOMString& bound )
-{
-    m_boundary = bound;
-}
-
 void HTMLFormElementImpl::submitFromKeyboard()
 {
-    // Activate the first submit button - like other browsers do
+    // Activate the first submit button
+    // if there is none, do a submit anyway if not more
+    // than one <input type=text> or <input type=password>
+    unsigned int inputtext = 0;
     for (QPtrListIterator<HTMLGenericFormElementImpl> it(formElements); it.current(); ++it) {
         if (it.current()->id() == ID_BUTTON) {
             HTMLButtonElementImpl* current = static_cast<HTMLButtonElementImpl *>(it.current());
@@ -350,14 +351,22 @@ void HTMLFormElementImpl::submitFromKeyboard()
             }
         } else if (it.current()->id() == ID_INPUT) {
             HTMLInputElementImpl* current = static_cast<HTMLInputElementImpl *>(it.current());
-            if (current->inputType() == HTMLInputElementImpl::SUBMIT && !current->disabled()) {
+            switch(current->inputType())  {
+            case HTMLInputElementImpl::SUBMIT:
+            case HTMLInputElementImpl::IMAGE:
                 current->activate();
                 return;
+            case HTMLInputElementImpl::TEXT:
+            case HTMLInputElementImpl::PASSWORD:
+                ++inputtext;
+            default:
+                break;
             }
         }
     }
 
-    prepareSubmit();
+    if (inputtext <= 1)
+        prepareSubmit();
 }
 
 bool HTMLFormElementImpl::prepareSubmit()
@@ -413,7 +422,7 @@ void HTMLFormElementImpl::submit(  )
             view->part()->submitForm( "post", url.string(), form_data,
                                       m_target.string(),
                                       enctype().string(),
-                                      boundary().string() );
+                                      m_boundary );
         }
         else {
             view->part()->submitForm( "get", url.string(), form_data,
@@ -512,6 +521,16 @@ void HTMLFormElementImpl::removeFormElement(HTMLGenericFormElementImpl *e)
     formElements.remove(e);
 }
 
+void HTMLFormElementImpl::registerImgElement(HTMLImageElementImpl *e)
+{
+    imgElements.append(e);
+}
+
+void HTMLFormElementImpl::removeImgElement(HTMLImageElementImpl *e)
+{
+    imgElements.remove(e);
+}
+
 // -------------------------------------------------------------------------
 
 HTMLGenericFormElementImpl::HTMLGenericFormElementImpl(DocumentPtr *doc, HTMLFormElementImpl *f)
@@ -988,10 +1007,10 @@ void HTMLInputElementImpl::parseAttribute(AttributeImpl *attr)
         m_maxLen = -1;
         if (!attr->val()) break;
         bool ok;
-        m_maxLen = attr->val()->toInt(&ok);
-        if (!ok)
-            m_maxLen = -1;
-        else if (m_maxLen < 0)
+        int ml = attr->val()->toInt(&ok);
+        if (ml > 0 && ml < 1024)
+            m_maxLen = ml;
+        else if (ok && ml <= 0)
             m_maxLen = 0;
         setChanged();
     }
@@ -1187,17 +1206,17 @@ bool HTMLInputElementImpl::encoding(const QTextCodec* codec, khtml::encodingList
 
         case IMAGE:
 
-            if(m_clicked && clickX() != -1)
+            if(m_clicked)
             {
                 m_clicked = false;
                 QString astr(nme.isEmpty() ? QString::fromLatin1("x") : nme + ".x");
 
                 encoding += fixUpfromUnicode(codec, astr);
-                astr.setNum(clickX());
+                astr.setNum(KMAX( clickX(), 0 ));
                 encoding += fixUpfromUnicode(codec, astr);
                 astr = nme.isEmpty() ? QString::fromLatin1("y") : nme + ".y";
                 encoding += fixUpfromUnicode(codec, astr);
-                astr.setNum(clickY());
+                astr.setNum(KMAX( clickY(), 0 ) );
                 encoding += fixUpfromUnicode(codec, astr);
 
                 return true;
@@ -1331,9 +1350,8 @@ void HTMLInputElementImpl::defaultEventHandler(EventImpl *evt)
         // on the element, or presses enter while it is the active element. Javascript code wishing to activate the element
         // must dispatch a DOMActivate event - a click event will not do the job.
         if ((evt->id() == EventImpl::DOMACTIVATE_EVENT) &&
-            (m_type == IMAGE || m_type == SUBMIT || m_type == RESET)){
+            (m_type == IMAGE || m_type == SUBMIT || m_type == RESET))
             activate();
-        }
     }
     HTMLGenericFormElementImpl::defaultEventHandler(evt);
 }
@@ -1571,7 +1589,7 @@ DOMString HTMLSelectElementImpl::value( )
             && static_cast<HTMLOptionElementImpl*>(items[i])->selected())
             return static_cast<HTMLOptionElementImpl*>(items[i])->value();
     }
-    return DOMString();
+    return DOMString("");
 }
 
 void HTMLSelectElementImpl::setValue(DOMStringImpl* /*value*/)
@@ -2118,6 +2136,7 @@ void HTMLTextAreaElementImpl::attach()
     assert(parentNode());
 
     addCSSProperty(CSS_PROP_COLOR, "text");
+    addCSSProperty( CSS_PROP_FONT_FAMILY, "monospace" );
 
     RenderStyle* _style = getDocument()->styleSelector()->styleForElement(this);
     _style->ref();
