@@ -20,12 +20,12 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_formimpl.h,v 1.129.2.3 2003/01/18 20:02:51 mueller Exp $
  */
 #ifndef HTML_FORMIMPL_H
 #define HTML_FORMIMPL_H
 
 #include "html/html_elementimpl.h"
+#include "html/html_imageimpl.h"
 #include "dom/html_element.h"
 
 #include <qvaluelist.h>
@@ -72,20 +72,16 @@ public:
     DOMString enctype() const { return m_enctype; }
     void setEnctype( const DOMString & );
 
-    DOMString boundary() const { return m_boundary; }
-    void setBoundary( const DOMString & );
-
     bool autoComplete() const { return m_autocomplete; }
 
     virtual void parseAttribute(AttributeImpl *attr);
 
     void radioClicked( HTMLGenericFormElementImpl *caller );
 
-    void registerFormElement(khtml::RenderFormElement *);
-    void removeFormElement(khtml::RenderFormElement *);
-
     void registerFormElement(HTMLGenericFormElementImpl *);
     void removeFormElement(HTMLGenericFormElementImpl *);
+    void registerImgElement(HTMLImageElementImpl *);
+    void removeImgElement(HTMLImageElementImpl *);
 
     void submitFromKeyboard();
     bool prepareSubmit();
@@ -97,9 +93,10 @@ public:
 
 private:
     QPtrList<HTMLGenericFormElementImpl> formElements;
+    QPtrList<HTMLImageElementImpl> imgElements;
     DOMString m_target;
     DOMString m_enctype;
-    DOMString m_boundary;
+    QString m_boundary;
     DOMString m_acceptcharset;
     QString m_encCharset;
     bool m_post : 1;
@@ -407,7 +404,7 @@ private:
 protected:
     mutable QMemArray<HTMLGenericFormElementImpl*> m_listItems;
     short m_minwidth;
-    short m_size : 15;
+    signed short m_size : 15;
     bool m_multiple : 1;
     bool m_recalcListItems;
 };
@@ -548,6 +545,6 @@ public:
 };
 
 
-}; //namespace
+} //namespace
 
 #endif
