@@ -21,6 +21,7 @@
  */
 
 #include "html/html_imageimpl.h"
+#include "html/html_formimpl.h"
 #include "html/html_documentimpl.h"
 
 #include "misc/htmlhashes.h"
@@ -51,6 +52,19 @@ using namespace khtml;
 
 // -------------------------------------------------------------------------
 
+HTMLImageElementImpl::HTMLImageElementImpl(DocumentPtr *doc, HTMLFormElementImpl *f)
+    : HTMLElementImpl(doc), ismap(false), m_form(f)
+{
+    if (m_form)
+        m_form->registerImgElement(this);
+}
+
+HTMLImageElementImpl::~HTMLImageElementImpl()
+{
+    if (m_form)
+        m_form->removeImgElement(this);
+}
+
 NodeImpl::Id HTMLImageElementImpl::id() const
 {
     return ID_IMG;
@@ -215,7 +229,6 @@ bool HTMLImageElementImpl::complete() const
     return false;
 }
 
-
 // -------------------------------------------------------------------------
 
 HTMLMapElementImpl::HTMLMapElementImpl(DocumentPtr *doc)
