@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_imageimpl.h,v 1.61.2.2 2003/01/13 22:04:47 mueller Exp $
+ * $Id: html_imageimpl.h,v 1.61.2.4 2003/06/24 22:00:24 faure Exp $
  */
 #ifndef HTML_IMAGEIMPL_H
 #define HTML_IMAGEIMPL_H
@@ -33,13 +33,15 @@
 namespace DOM {
 
 class DOMString;
+class HTMLFormElementImpl;
 
 class HTMLImageElementImpl
     : public HTMLElementImpl
 {
+    friend class HTMLFormElementImpl;
 public:
-    HTMLImageElementImpl(DocumentPtr *doc)
-        : HTMLElementImpl(doc), ismap(false) {}
+    HTMLImageElementImpl(DocumentPtr *doc, HTMLFormElementImpl *f = 0);
+    ~HTMLImageElementImpl();
 
     virtual Id id() const;
 
@@ -61,6 +63,7 @@ public:
 protected:
     DOMString usemap;
     bool ismap;
+    HTMLFormElementImpl *m_form;
 };
 
 
@@ -120,6 +123,6 @@ private:
 };
 
 
-}; //namespace
+} //namespace
 
 #endif
