@@ -42,16 +42,6 @@
 using namespace khtml;
 using namespace DOM;
 
-HTMLAnchorElementImpl::HTMLAnchorElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-    m_hasTarget = false;
-}
-
-HTMLAnchorElementImpl::~HTMLAnchorElementImpl()
-{
-}
-
 NodeImpl::Id HTMLAnchorElementImpl::id() const
 {
     return ID_A;
@@ -59,29 +49,34 @@ NodeImpl::Id HTMLAnchorElementImpl::id() const
 
 void HTMLAnchorElementImpl::defaultEventHandler(EventImpl *evt)
 {
+    bool keydown = evt->id() == EventImpl::KHTML_KEYPRESS_EVENT ||
+                   evt->id() == EventImpl::KHTML_KEYDOWN_EVENT;
+
     // React on clicks and on keypresses.
-    // Don't make this KEYUP_EVENT again, it makes khtml follow links it shouldn't,
-    // when pressing Enter in the combo.
-    if ( ( evt->id() == EventImpl::KHTML_CLICK_EVENT ||
-         ( evt->id() == EventImpl::KHTML_KEYDOWN_EVENT && m_focused)) && m_hasAnchor) {
+    // Don't make this KEYUP_EVENT again, it makes khtml follow links
+    // it shouldn't, when pressing Enter in the combo.
+    if ( ( (evt->id() == EventImpl::CLICK_EVENT && static_cast<MouseEventImpl*>(evt)->detail() == 1) ||
+         ( keydown && m_focused)) && m_hasAnchor) {
+
         MouseEventImpl *e = 0;
-        if ( evt->id() == EventImpl::KHTML_CLICK_EVENT )
+        if ( evt->id() == EventImpl::CLICK_EVENT )
             e = static_cast<MouseEventImpl*>( evt );
 
-        KeyEventImpl *k = 0;
-        if (evt->id() == EventImpl::KHTML_KEYDOWN_EVENT)
-            k = static_cast<KeyEventImpl *>( evt );
+        TextEventImpl *k = 0;
+        if (keydown)
+            k = static_cast<TextEventImpl *>( evt );
 
         QString utarget;
         QString url;
-
         if ( e && e->button() == 2 ) {
 	    HTMLElementImpl::defaultEventHandler(evt);
 	    return;
         }
 
         if ( k ) {
-            if (k->virtKeyVal() != KeyEventImpl::DOM_VK_ENTER) {
+            if (k->virtKeyVal() != TextEventImpl::DOM_VK_ENTER) {
+                if (k->qKeyEvent)
+                    k->qKeyEvent->ignore();
                 HTMLElementImpl::defaultEventHandler(evt);
                 return;
             }
@@ -125,6 +120,8 @@ void HTMLAnchorElementImpl::defaultEventHandler(EventImpl *evt)
                     state |= Qt::ShiftButton;
                 if ( e->altKey() )
                     state |= Qt::AltButton;
+                if (  e->metaKey() )
+                    state |= Qt::MetaButton;
 
                 if ( e->button() == 0 )
                     button = Qt::LeftButton;
@@ -143,7 +140,6 @@ void HTMLAnchorElementImpl::defaultEventHandler(EventImpl *evt)
                 state |= Qt::ControlButton;
 	    }
 
-            getDocument()->view()->resetCursor();
             getDocument()->view()->part()->
                 urlSelected( url, button, state, utarget );
         }
@@ -174,14 +170,6 @@ void HTMLAnchorElementImpl::parseAttribute(AttributeImpl *attr)
 
 // -------------------------------------------------------------------------
 
-HTMLBRElementImpl::HTMLBRElementImpl(DocumentPtr *doc) : HTMLElementImpl(doc)
-{
-}
-
-HTMLBRElementImpl::~HTMLBRElementImpl()
-{
-}
-
 NodeImpl::Id HTMLBRElementImpl::id() const
 {
     return ID_BR;
@@ -194,7 +182,8 @@ void HTMLBRElementImpl::parseAttribute(AttributeImpl *attr)
     case ATTR_CLEAR:
     {
         DOMString str = attr->value();
-        if( strcasecmp (str,"all")==0 || str.isEmpty() ) str = "both";
+        if( str.isEmpty() ) str = "none";
+        else if( strcasecmp (str,"all")==0 ) str = "both";
         addCSSProperty(CSS_PROP_CLEAR, str);
         break;
     }
@@ -210,24 +199,20 @@ void HTMLBRElementImpl::attach()
     assert(parentNode());
 
     if (parentNode()->renderer()) {
-        m_render = new RenderBR(this);
-        m_render->setStyle(getDocument()->styleSelector()->styleForElement(this));
-        parentNode()->renderer()->addChild(m_render, nextRenderer());
+        RenderStyle* style = getDocument()->styleSelector()->styleForElement(  this );
+        style->ref();
+        if(  style->display() != NONE ) {
+          m_render = new RenderBR( this );
+          m_render->setStyle( style );
+          parentNode()->renderer()->addChild( m_render, nextRenderer() );
+        }
+        style->deref();
     }
     NodeImpl::attach();
 }
 
 // -------------------------------------------------------------------------
 
-HTMLFontElementImpl::HTMLFontElementImpl(DocumentPtr *doc)
-    : HTMLElementImpl(doc)
-{
-}
-
-HTMLFontElementImpl::~HTMLFontElementImpl()
-{
-}
-
 NodeImpl::Id HTMLFontElementImpl::id() const
 {
     return ID_FONT;
