@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_inlineimpl.h,v 1.41.4.1 2003/01/03 21:09:26 mueller Exp $
+ * $Id: html_inlineimpl.h,v 1.41.4.2 2003/05/18 12:34:39 mueller Exp $
  */
 #ifndef HTML_INLINEIMPL_H
 #define HTML_INLINEIMPL_H
@@ -70,6 +70,6 @@ public:
     virtual void parseAttribute(AttributeImpl *attr);
 };
 
-}; //namespace
+} //namespace
 
 #endif
