@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_listimpl.cpp,v 1.31 2002/02/27 19:13:38 knoll Exp $
+ * $Id: html_listimpl.cpp,v 1.32.2.1 2003/01/03 21:09:26 mueller Exp $
  */
 #include "html_listimpl.h"
 
@@ -101,22 +101,13 @@ NodeImpl::Id HTMLLIElementImpl::id() const
     return ID_LI;
 }
 
-
 void HTMLLIElementImpl::parseAttribute(AttributeImpl *attr)
 {
     switch(attr->id())
     {
     case ATTR_VALUE:
-        isValued = true;
-        requestedValue = attr->val() ? attr->val()->toInt() : 0;
-
-        if(m_render && m_render->isListItem())
-        {
-            RenderListItem *list = static_cast<RenderListItem *>(m_render);
-            // ### work out what to do when attribute removed - use default of some sort?
-
-            list->setValue(requestedValue);
-        }
+        if(m_render && m_render->isListItem() && m_render->style()->display() == LIST_ITEM)
+            static_cast<RenderListItem*>(m_render)->setValue(attr->value().toInt());
         break;
     case ATTR_TYPE:
         if ( strcmp( attr->value(), "a" ) == 0 )
@@ -144,19 +135,10 @@ void HTMLLIElementImpl::attach()
     HTMLElementImpl::attach();
 
     if ( m_render && m_render->style()->display() == LIST_ITEM ) {
-	// If we are first, and the OL has a start attr.
-	if (parentNode() && parentNode()->id() == ID_OL) {
-	    HTMLOListElementImpl *ol = static_cast<HTMLOListElementImpl *>(parentNode());
-
-	    if(ol->firstChild() && ol->firstChild() == this &&  m_render)
-		static_cast<RenderListItem*>(m_render)->setValue(ol->start());
-	}
-
-	// If we had a value attr.
-	if (isValued && m_render)
-	    static_cast<RenderListItem*>(m_render)->setValue(requestedValue);
+        DOMString v = getAttribute(ATTR_VALUE);
+        if (!v.isEmpty())
+            static_cast<RenderListItem*>(m_render)->setValue(v.implementation()->toInt());
     }
-
 }
 
 
