@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_miscimpl.h,v 1.22 2002/04/11 08:56:40 knoll Exp $
+ * $Id: html_miscimpl.h,v 1.22.2.2 2003/06/24 22:00:24 faure Exp $
  */
 #ifndef HTML_MISCIMPL_H
 #define HTML_MISCIMPL_H
@@ -125,11 +125,10 @@ protected:
     virtual NodeImpl *nextNamedItemInternal( const DOMString &name ) const;
 private:
     NodeImpl* getNamedFormItem(int attr_id, const DOMString& name, int duplicateNumber) const;
-    NodeImpl* getNamedImgItem(NodeImpl* current, int attr_id, const DOMString& name, int& duplicateNumber) const;
     mutable int currentPos;
 };
 
 
-}; //namespace
+} //namespace
 
 #endif
