@@ -41,6 +41,7 @@
 #include "rendering/render_table.h"
 
 #include <kdebug.h>
+#include <kglobal.h>
 
 using namespace khtml;
 using namespace DOM;
@@ -53,10 +54,12 @@ HTMLTableElementImpl::HTMLTableElementImpl(DocumentPtr *doc)
     foot = 0;
     firstBody = 0;
 
+#if 0
     rules = None;
     frame = Void;
+#endif
+    padding = 1;
 
-    incremental = false;
     m_noBorder = true;
     m_solid = false;
 
@@ -65,7 +68,7 @@ HTMLTableElementImpl::HTMLTableElementImpl(DocumentPtr *doc)
     // only difference to 100% correct is that in strict mode <font> elements are propagated into tables.
     if ( getDocument()->parseMode() != DocumentImpl::Strict ) {
         addCSSProperty( CSS_PROP_FONT_SIZE, CSS_VAL_MEDIUM );
-        addCSSProperty( CSS_PROP_COLOR, getDocument()->textColor() );
+        addCSSProperty( CSS_PROP_COLOR, "-konq-text" );
         addCSSProperty( CSS_PROP_FONT_FAMILY, "konq_default" );
     }
 }
@@ -149,7 +152,7 @@ HTMLElementImpl *HTMLTableElementImpl::createTHead(  )
     if(!head)
     {
         int exceptioncode = 0;
-        head = new HTMLTableSectionElementImpl(docPtr(), ID_THEAD);
+        head = new HTMLTableSectionElementImpl(docPtr(), ID_THEAD, true /* implicit */);
         if(foot)
             insertBefore( head, foot, exceptioncode );
         if(firstBody)
@@ -174,7 +177,7 @@ HTMLElementImpl *HTMLTableElementImpl::createTFoot(  )
     if(!foot)
     {
         int exceptioncode = 0;
-        foot = new HTMLTableSectionElementImpl(docPtr(), ID_TFOOT);
+        foot = new HTMLTableSectionElementImpl(docPtr(), ID_TFOOT, true /*implicit */);
         if(firstBody)
             insertBefore( foot, firstBody, exceptioncode );
         else
@@ -212,48 +215,103 @@ void HTMLTableElementImpl::deleteCaption(  )
     tCaption = 0;
 }
 
-HTMLElementImpl *HTMLTableElementImpl::insertRow( long index )
+HTMLElementImpl *HTMLTableElementImpl::insertRow( long index, int &exceptioncode )
 {
+    // The DOM requires that we create a tbody if the table is empty
+    // (cf DOM2TS HTMLTableElement31 test)
+    // (note: this is different from "if the table has no sections", since we can have
+    // <TABLE><TR>)
+    if(!firstBody && !head && !foot && !hasChildNodes())
+        setTBody( new HTMLTableSectionElementImpl(docPtr(), ID_TBODY, true /* implicit */) );
+
+    //kdDebug(6030) << k_funcinfo << index << endl;
     // IE treats index=-1 as default value meaning 'append after last'
     // This isn't in the DOM. So, not implemented yet.
     HTMLTableSectionElementImpl* section = 0L;
+    HTMLTableSectionElementImpl* lastSection = 0L;
     NodeImpl *node = firstChild();
-    for ( ; node ; node = node->nextSibling() )
+    bool append = index == -1;
+    for ( ; node && (index>=0 || append) ; node = node->nextSibling() )
     {
         if ( node->id() == ID_THEAD || node->id() == ID_TFOOT || node->id() == ID_TBODY )
         {
             section = static_cast<HTMLTableSectionElementImpl *>(node);
-            if ( section->numRows() > index )
-                break;
-            else
-                index -= section->numRows();
+            lastSection = section;
+            //kdDebug(6030) << k_funcinfo << "section id=" << node->id() << " rows:" << section->numRows() << endl;
+            if ( !append )
+            {
+                int rows = section->numRows();
+                if ( rows > index )
+                    break;
+                else
+                    index -= rows;
+                //kdDebug(6030) << "       index is now " << index << endl;
+            }
         }
+        // Note: we now can have both TR and sections (THEAD/TBODY/TFOOT) as children of a TABLE
+        else if ( node->id() == ID_TR )
+        {
+            section = 0L;
+            //kdDebug(6030) << k_funcinfo << "row" << endl;
+            if (!append && !index)
+            {
+                // Insert row right here, before "node"
+                HTMLTableRowElementImpl* row = new HTMLTableRowElementImpl(docPtr());
+                insertBefore(row, node, exceptioncode );
+                return row;
+            }
+            if ( !append )
+                index--;
+            //kdDebug(6030) << "       index is now " << index << endl;
+        }
+        section = 0L;
     }
-    if (!section) {
-        section = new HTMLTableSectionElementImpl(docPtr(), ID_TBODY);
-        setTBody( section );
+    // Index == 0 means "insert before first row in current section"
+    // or "append after last row" (if there's no current section anymore)
+    if ( !section && ( index == 0 || append ) )
+    {
+        section = lastSection;
+        index = section ? section->numRows() : 0;
+    }
+    if ( section && ( index >= 0 || append ) ) {
+        //kdDebug(6030) << "Inserting row into section " << section << " at index " << index << endl;
+        return section->insertRow( index, exceptioncode );
+    } else {
+        // No more sections => index is too big
+        exceptioncode = DOMException::INDEX_SIZE_ERR;
+        return 0L;
     }
-    return section->insertRow( index );
 }
 
-void HTMLTableElementImpl::deleteRow( long index )
+void HTMLTableElementImpl::deleteRow( long index, int &exceptioncode )
 {
     HTMLTableSectionElementImpl* section = 0L;
     NodeImpl *node = firstChild();
+    bool lastRow = index == -1;
+    HTMLTableSectionElementImpl* lastSection = 0L;
     for ( ; node ; node = node->nextSibling() )
     {
         if ( node->id() == ID_THEAD || node->id() == ID_TFOOT || node->id() == ID_TBODY )
         {
             section = static_cast<HTMLTableSectionElementImpl *>(node);
-            if ( section->numRows() > index )
-                break;
-            else
-                index -= section->numRows();
+            lastSection = section;
+            int rows = section->numRows();
+            if ( !lastRow )
+            {
+                if ( rows > index )
+                    break;
+                else
+                    index -= rows;
+            }
         }
+        section = 0L;
     }
-    if ( section && index >= 0 && index < section->numRows() )
-        section->deleteRow( index );
-    // ## TODO error checking, returning exceptioncode
+    if ( lastRow )
+        lastSection->deleteRow( -1, exceptioncode );
+    else if ( section && index >= 0 && index < section->numRows() )
+        section->deleteRow( index, exceptioncode );
+    else
+        exceptioncode = DOMException::INDEX_SIZE_ERR;
 }
 
 NodeImpl *HTMLTableElementImpl::addChild(NodeImpl *child)
@@ -269,24 +327,19 @@ NodeImpl *HTMLTableElementImpl::addChild(NodeImpl *child)
         break;
     case ID_COL:
     case ID_COLGROUP:
-        {
-        // these have to come before the table definition!
         if(head || foot || firstBody)
             return 0;
-        HTMLElementImpl::addChild(child);
-        // ###
-        }
-        return child;
+	{
+	    int exceptioncode = 0;
+	    return appendChild(child, exceptioncode);
+	}
     case ID_THEAD:
-        //      if(incremental && !columnPos[totalCols]);// calcColWidth();
         return setTHead(static_cast<HTMLTableSectionElementImpl *>(child));
         break;
     case ID_TFOOT:
-        //if(incremental && !columnPos[totalCols]);// calcColWidth();
         return setTFoot(static_cast<HTMLTableSectionElementImpl *>(child));
         break;
     case ID_TBODY:
-        //if(incremental && !columnPos[totalCols]);// calcColWidth();
         return setTBody(static_cast<HTMLTableSectionElementImpl *>(child));
         break;
     }
@@ -300,7 +353,7 @@ void HTMLTableElementImpl::parseAttribute(AttributeImpl *attr)
     {
     case ATTR_WIDTH:
         if (!attr->value().isEmpty())
-            addCSSLength(CSS_PROP_WIDTH, attr->value());
+            addCSSLength( CSS_PROP_WIDTH, attr->value() );
         else
             removeCSSProperty(CSS_PROP_WIDTH);
         break;
@@ -401,22 +454,24 @@ void HTMLTableElementImpl::parseAttribute(AttributeImpl *attr)
         break;
    case ATTR_CELLSPACING:
         if (!attr->value().isEmpty())
-            addCSSLength(CSS_PROP_BORDER_SPACING, attr->value());
+            addCSSLength(CSS_PROP_BORDER_SPACING, attr->value(), true);
         else
             removeCSSProperty(CSS_PROP_BORDER_SPACING);
         break;
     case ATTR_CELLPADDING:
         if (!attr->value().isEmpty()) {
-            addCSSLength(CSS_PROP_PADDING_TOP, attr->value());
-            addCSSLength(CSS_PROP_PADDING_LEFT, attr->value());
-            addCSSLength(CSS_PROP_PADDING_BOTTOM, attr->value());
-            addCSSLength(CSS_PROP_PADDING_RIGHT, attr->value());
+            addCSSLength(CSS_PROP_PADDING_TOP, attr->value(), true);
+            addCSSLength(CSS_PROP_PADDING_LEFT, attr->value(), true);
+            addCSSLength(CSS_PROP_PADDING_BOTTOM, attr->value(), true);
+            addCSSLength(CSS_PROP_PADDING_RIGHT, attr->value(), true);
+	    padding = kMax( 0, attr->value().toInt() );
         }
         else {
             removeCSSProperty(CSS_PROP_PADDING_TOP);
             removeCSSProperty(CSS_PROP_PADDING_LEFT);
             removeCSSProperty(CSS_PROP_PADDING_BOTTOM);
             removeCSSProperty(CSS_PROP_PADDING_RIGHT);
+	    padding = 1;
         }
         break;
     case ATTR_COLS:
@@ -448,10 +503,8 @@ void HTMLTableElementImpl::parseAttribute(AttributeImpl *attr)
     }
 }
 
-void HTMLTableElementImpl::init()
+void HTMLTableElementImpl::attach()
 {
-    HTMLElementImpl::init();
-
     if (!m_noBorder) {
         int v = m_solid ? CSS_VAL_SOLID : CSS_VAL_OUTSET;
         addCSSProperty(CSS_PROP_BORDER_TOP_STYLE, v);
@@ -459,6 +512,10 @@ void HTMLTableElementImpl::init()
         addCSSProperty(CSS_PROP_BORDER_LEFT_STYLE, v);
         addCSSProperty(CSS_PROP_BORDER_RIGHT_STYLE, v);
     }
+
+    HTMLElementImpl::attach();
+    if ( m_render && m_render->isTable() )
+	static_cast<RenderTable *>(m_render)->setCellPadding( padding );
 }
 
 // --------------------------------------------------------------------------
@@ -504,6 +561,12 @@ void HTMLTablePartElementImpl::parseAttribute(AttributeImpl *attr)
             removeCSSProperty(CSS_PROP_VERTICAL_ALIGN);
         break;
     }
+    case ATTR_HEIGHT:
+        if (!attr->value().isEmpty())
+            addCSSLength(CSS_PROP_HEIGHT, attr->value());
+        else
+            removeCSSProperty(CSS_PROP_HEIGHT);
+        break;
     case ATTR_NOSAVE:
 	break;
     default:
@@ -514,15 +577,15 @@ void HTMLTablePartElementImpl::parseAttribute(AttributeImpl *attr)
 // -------------------------------------------------------------------------
 
 HTMLTableSectionElementImpl::HTMLTableSectionElementImpl(DocumentPtr *doc,
-                                                         ushort tagid)
+                                                         ushort tagid, bool implicit)
     : HTMLTablePartElementImpl(doc)
 {
     _id = tagid;
+    m_implicit = implicit;
 }
 
 HTMLTableSectionElementImpl::~HTMLTableSectionElementImpl()
 {
-    nrows = 0;
 }
 
 NodeImpl::Id HTMLTableSectionElementImpl::id() const
@@ -533,39 +596,57 @@ NodeImpl::Id HTMLTableSectionElementImpl::id() const
 
 // these functions are rather slow, since we need to get the row at
 // the index... but they aren't used during usual HTML parsing anyway
-HTMLElementImpl *HTMLTableSectionElementImpl::insertRow( long index )
+HTMLElementImpl *HTMLTableSectionElementImpl::insertRow( long index, int& exceptioncode )
 {
-    nrows++;
-
-    HTMLTableRowElementImpl *r = new HTMLTableRowElementImpl(docPtr());
-
+    HTMLTableRowElementImpl *r = 0L;
     NodeListImpl *children = childNodes();
-    int exceptioncode = 0;
-    if(!children || (int)children->length() <= index)
-        appendChild(r, exceptioncode);
-    else {
-        NodeImpl *n;
-        if(index < 1)
-            n = firstChild();
-        else
-            n = children->item(index);
-        insertBefore(r, n, exceptioncode );
+    int numRows = children ? (int)children->length() : 0;
+    //kdDebug(6030) << k_funcinfo << "index=" << index << " numRows=" << numRows << endl;
+    if ( index < -1 || index > numRows ) {
+        exceptioncode = DOMException::INDEX_SIZE_ERR; // per the DOM
     }
-    if(children) delete children;
+    else
+    {
+        r = new HTMLTableRowElementImpl(docPtr());
+        if ( numRows == index || index == -1 )
+            appendChild(r, exceptioncode);
+        else {
+            NodeImpl *n;
+            if(index < 1)
+                n = firstChild();
+            else
+                n = children->item(index);
+            insertBefore(r, n, exceptioncode );
+        }
+    }
+    delete children;
     return r;
 }
 
-void HTMLTableSectionElementImpl::deleteRow( long index )
+void HTMLTableSectionElementImpl::deleteRow( long index, int &exceptioncode )
 {
-    if(index < 0) return;
     NodeListImpl *children = childNodes();
-    if(children && (int)children->length() > index)
-    {
-        nrows--;
-        int exceptioncode = 0;
+    int numRows = children ? (int)children->length() : 0;
+    if ( index == -1 ) index = numRows - 1;
+    if( index >= 0 && index < numRows )
         HTMLElementImpl::removeChild(children->item(index), exceptioncode);
+    else
+        exceptioncode = DOMException::INDEX_SIZE_ERR;
+    delete children;
+}
+
+
+int HTMLTableSectionElementImpl::numRows() const
+{
+    int rows = 0;
+    const NodeImpl *n = firstChild();
+    while (n) {
+        if (n->id() == ID_TR)
+            rows++;
+        n = n->nextSibling();
     }
-    if(children) delete children;
+
+    return rows;
 }
 
 // -------------------------------------------------------------------------
@@ -622,35 +703,41 @@ long HTMLTableRowElementImpl::sectionRowIndex() const
     return rIndex;
 }
 
-HTMLElementImpl *HTMLTableRowElementImpl::insertCell( long index )
+HTMLElementImpl *HTMLTableRowElementImpl::insertCell( long index, int &exceptioncode )
 {
-    HTMLTableCellElementImpl *c = new HTMLTableCellElementImpl(docPtr(), ID_TD);
-
+    HTMLTableCellElementImpl *c = 0L;
     NodeListImpl *children = childNodes();
-    int exceptioncode = 0;
-    if(!children || (int)children->length() <= index)
-        appendChild(c, exceptioncode);
-    else {
-        NodeImpl *n;
-        if(index < 1)
-            n = firstChild();
-        else
-            n = children->item(index);
-        insertBefore(c, n, exceptioncode);
+    int numCells = children ? children->length() : 0;
+    if ( index < -1 || index > numCells )
+        exceptioncode = DOMException::INDEX_SIZE_ERR; // per the DOM
+    else
+    {
+        c = new HTMLTableCellElementImpl(docPtr(), ID_TD);
+        if(numCells == index || index == -1)
+            appendChild(c, exceptioncode);
+        else {
+            NodeImpl *n;
+            if(index < 1)
+                n = firstChild();
+            else
+                n = children->item(index);
+            insertBefore(c, n, exceptioncode);
+        }
     }
-    if(children) delete children;
+    delete children;
     return c;
 }
 
-void HTMLTableRowElementImpl::deleteCell( long index )
+void HTMLTableRowElementImpl::deleteCell( long index, int &exceptioncode )
 {
-    if(index < 0) return;
     NodeListImpl *children = childNodes();
-    if(children && (int)children->length() > index) {
-        int exceptioncode = 0;
+    int numCells = children ? children->length() : 0;
+    if ( index == -1 ) index = numCells-1;
+    if( index >= 0 && index < numCells )
         HTMLElementImpl::removeChild(children->item(index), exceptioncode);
-    }
-    if(children) delete children;
+    else
+        exceptioncode = DOMException::INDEX_SIZE_ERR;
+    delete children;
 }
 
 // -------------------------------------------------------------------------
@@ -695,16 +782,10 @@ void HTMLTableCellElementImpl::parseAttribute(AttributeImpl *attr)
         break;
     case ATTR_WIDTH:
         if (!attr->value().isEmpty())
-            addCSSLength(CSS_PROP_WIDTH, attr->value());
+            addCSSLength( CSS_PROP_WIDTH, attr->value() );
         else
             removeCSSProperty(CSS_PROP_WIDTH);
         break;
-    case ATTR_HEIGHT:
-        if (!attr->value().isEmpty())
-            addCSSLength(CSS_PROP_HEIGHT, attr->value());
-        else
-            removeCSSProperty(CSS_PROP_HEIGHT);
-        break;
     case ATTR_NOSAVE:
 	break;
     default:
@@ -712,10 +793,8 @@ void HTMLTableCellElementImpl::parseAttribute(AttributeImpl *attr)
     }
 }
 
-void HTMLTableCellElementImpl::init()
+void HTMLTableCellElementImpl::attach()
 {
-    HTMLTablePartElementImpl::init();
-
     HTMLElementImpl* p = static_cast<HTMLElementImpl*>(parentNode());
     while(p && p->id() != ID_TABLE)
         p = static_cast<HTMLElementImpl*>(p->parentNode());
@@ -737,12 +816,14 @@ void HTMLTableCellElementImpl::init()
                 addCSSProperty(CSS_PROP_BORDER_COLOR, "inherit");
         }
     }
+
+    HTMLTablePartElementImpl::attach();
 }
 
 // -------------------------------------------------------------------------
 
 HTMLTableColElementImpl::HTMLTableColElementImpl(DocumentPtr *doc, ushort i)
-    : HTMLElementImpl(doc)
+    : HTMLTablePartElementImpl(doc)
 {
     _id = i;
     _span = (_id == ID_COLGROUP ? 0 : 1);
@@ -758,29 +839,6 @@ NodeImpl::Id HTMLTableColElementImpl::id() const
 }
 
 
-NodeImpl *HTMLTableColElementImpl::addChild(NodeImpl *child)
-{
-#ifdef DEBUG_LAYOUT
-    kdDebug( 6030 ) << nodeName().string() << "(Table)::addChild( " << child->nodeName().string() << " )" << endl;
-#endif
-
-    switch(child->id())
-    {
-    case ID_COL:
-    {
-        // these have to come before the table definition!
-        HTMLElementImpl::addChild(child);
-        return child;
-    }
-    default:
-        return 0;
-        break;
-        // ####
-    }
-    return child;
-
-}
-
 void HTMLTableColElementImpl::parseAttribute(AttributeImpl *attr)
 {
     switch(attr->id())
@@ -790,7 +848,7 @@ void HTMLTableColElementImpl::parseAttribute(AttributeImpl *attr)
         break;
     case ATTR_WIDTH:
         if (!attr->value().isEmpty())
-            addCSSLength(CSS_PROP_WIDTH, attr->value());
+            addCSSLength(CSS_PROP_WIDTH, attr->value(), false, true );
         else
             removeCSSProperty(CSS_PROP_WIDTH);
         break;
@@ -801,7 +859,7 @@ void HTMLTableColElementImpl::parseAttribute(AttributeImpl *attr)
             removeCSSProperty(CSS_PROP_VERTICAL_ALIGN);
         break;
     default:
-        HTMLElementImpl::parseAttribute(attr);
+        HTMLTablePartElementImpl::parseAttribute(attr);
     }
 
 }
