@@ -22,7 +22,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: html_tableimpl.h,v 1.65 2002/11/13 08:51:14 knoll Exp $
+ * $Id: html_tableimpl.h,v 1.65.2.1 2003/05/18 12:34:39 mueller Exp $
  */
 #ifndef HTML_TABLEIMPL_H
 #define HTML_TABLEIMPL_H
@@ -250,7 +250,7 @@ public:
     virtual void parseAttribute(AttributeImpl *attr);
 };
 
-}; //namespace
+} //namespace
 
 #endif
 
