@@ -27,7 +27,7 @@
 //----------------------------------------------------------------------------
 //
 // KDE HTML Widget - Tokenizers
-// $Id: htmltokenizer.cpp,v 1.248.2.6 2003/04/15 01:45:19 mueller Exp $
+// $Id: htmltokenizer.cpp,v 1.248.2.7 2003/08/29 11:41:51 mueller Exp $
 
 //#define TOKEN_DEBUG 1
 //#define TOKEN_DEBUG 2
@@ -213,6 +213,7 @@ void HTMLTokenizer::begin()
     noMoreData = false;
     brokenComments = false;
     brokenServer = false;
+    brokenScript = false;
     lineno = 0;
     scriptStartLineno = 0;
     tagStartLineno = 0;
@@ -1051,7 +1052,7 @@ void HTMLTokenizer::parseTag(DOMStringIt &src)
 
             if(tagID >= ID_CLOSE_TAG)
                 tagID -= ID_CLOSE_TAG;
-            else if ( beginTag && tagID == ID_SCRIPT ) {
+            else if ( beginTag && !brokenScript && tagID == ID_SCRIPT ) {
                 AttributeImpl* a = 0;
                 scriptSrc = scriptSrcCharset = QString::null;
                 if ( currToken.attrs && /* potentially have a ATTR_SRC ? */
@@ -1466,19 +1467,21 @@ void HTMLTokenizer::end()
 void HTMLTokenizer::finish()
 {
     // do this as long as we don't find matching comment ends
-    while((comment || server) && scriptCode && scriptCodeSize)
+    while((title || script || comment || server) && scriptCode && scriptCodeSize)
     {
         // we've found an unmatched comment start
         if (comment)
             brokenComments = true;
-        else
+        else if (server)
+            brokenServer = true;
+        else if (script)
             brokenServer = true;
         checkScriptBuffer();
         scriptCode[ scriptCodeSize ] = 0;
         scriptCode[ scriptCodeSize + 1 ] = 0;
         int pos;
         QString food;
-        if (script || style) {
+        if (title || script || style) {
             food.setUnicode(scriptCode, scriptCodeSize);
         }
         else if (server) {
@@ -1492,7 +1495,9 @@ void HTMLTokenizer::finish()
         KHTML_DELETE_QCHAR_VEC(scriptCode);
         scriptCode = 0;
         scriptCodeSize = scriptCodeMaxSize = scriptCodeResync = 0;
-        comment = server = false;
+        if ( script )
+            scriptHandler();
+        comment = script = title = server = false;
         if ( !food.isEmpty() )
             write(food, true);
     }
