@@ -50,8 +50,6 @@ public class KJASProtocolHandler
     private int cmd_index;
     private final static char sep = (char) 0;
 
-    private byte[] currentcommand = null;
-
     public KJASProtocolHandler( InputStream  _commands,
                                 OutputStream _signals )
     {
@@ -146,6 +144,9 @@ public class KJASProtocolHandler
             final String appletName = getArg( command );
             final String className  = getArg( command );
             final String baseURL    = getArg( command );
+            final String username   = getArg( command );
+            final String password   = getArg( command );
+            final String authname   = getArg( command );
             final String codeBase   = getArg( command );
             final String archives   = getArg( command );
             final String width      = getArg( command );
@@ -179,7 +180,8 @@ public class KJASProtocolHandler
             if( context != null )
             {
                 context.createApplet( appletID, appletName, className,
-                                      baseURL, codeBase, archives,
+                                      baseURL, username, password, authname,
+                                      codeBase, archives,
                                       width, height, title, params );
             }
 
@@ -256,6 +258,7 @@ public class KJASProtocolHandler
         {
             String contextID = getArg( command );
             String appletID  = getArg( command );
+            int ticketnr = Integer.parseInt( getArg( command ) );
             int objid  = Integer.parseInt( getArg( command ) );
             String name  = getArg( command );
             int [] ret_type_obj = { -1, 0 };
@@ -265,12 +268,13 @@ public class KJASProtocolHandler
             if ( context != null )
                 ret_type_obj = context.getMember(appletID, objid, name, value);
             Main.debug( "GetMember " + name + "=" + value.toString());
-            sendMemberValue(contextID, GetMember, ret_type_obj[0], ret_type_obj[1], value.toString()); 
+            sendMemberValue(contextID, GetMember, ticketnr, ret_type_obj[0], ret_type_obj[1], value.toString()); 
         } else
         if (cmd_code_value == PutMember)
         {
             String contextID = getArg( command );
             String appletID  = getArg( command );
+            int ticketnr = Integer.parseInt( getArg( command ) );
             int objid  = Integer.parseInt( getArg( command ) );
             String name  = getArg( command );
             String value  = getArg( command );
@@ -279,36 +283,41 @@ public class KJASProtocolHandler
             if ( context != null )
                 ret = context.putMember(appletID, objid, name, value);
             Main.debug( "PutMember " + name + "=" + value);
-            sendPutMember(contextID, ret); 
+            sendPutMember(contextID, ticketnr, ret); 
         } else
         if (cmd_code_value == CallMember)
         {
-            currentcommand = command;
-            new Thread() {
+            new Thread("CallMember") {
+                int ticketnr, objid;
+                String contextID, appletID, name;
+                java.util.List args = new java.util.Vector();
                 public void run() {
-                    String contextID = getArg( currentcommand );
-                    String appletID  = getArg( currentcommand );
-                    int objid  = Integer.parseInt( getArg( currentcommand ) );
-                    String name  = getArg( currentcommand );
                     int [] ret_type_obj = { -1, 0 };
                     StringBuffer value = new StringBuffer();
-                    java.util.List args = new java.util.Vector();
-                    try { // fix getArg
-                        String param = getArg(currentcommand);
-                        while (param != null) {
-                            args.add(param);
-                            param = getArg(currentcommand);
-                        }
-                    } catch (Exception e) {}
                     int type = 0;
 
                     KJASAppletContext context = (KJASAppletContext) contexts.get( contextID );
                     if ( context != null )
                         ret_type_obj = context.callMember(appletID, objid, name, value, args);
                     Main.debug( "CallMember " + name + "=" + value.toString());
-                    sendMemberValue(contextID, CallMember, ret_type_obj[0], ret_type_obj[1], value.toString()); 
+                    sendMemberValue(contextID, CallMember, ticketnr, ret_type_obj[0], ret_type_obj[1], value.toString()); 
                 }
-            }.start();
+                void startIt(byte [] cmd) {
+                    contextID = getArg( cmd );
+                    appletID  = getArg( cmd );
+                    ticketnr = Integer.parseInt( getArg( cmd ) );
+                    objid  = Integer.parseInt( getArg( cmd ) );
+                    name  = getArg( cmd );
+                    try { // fix getArg
+                        String param = getArg(cmd);
+                        while (param != null) {
+                            args.add(param);
+                            param = getArg(cmd);
+                        }
+                    } catch (Exception e) {}
+                    start();
+                }
+            }.startIt(command);
         /*    if ( context != null )
                 ret_type_obj = context.callMember(appletID, objid, name, value, args);
             Main.debug( "CallMember " + name + "=" + value.toString());
@@ -670,13 +679,14 @@ public class KJASProtocolHandler
 
         signals.print( chars );
     }
-    public void sendMemberValue( String contextID, int cmd, int type, int rid, String value )
+    public void sendMemberValue( String contextID, int cmd, int ticketnr, int type, int rid, String value )
     {
         Main.debug( "sendMemberValue, contextID = " + contextID + " value = " + value + " type=" + type + " rid=" + rid );
 
+        String strticket = new String("" + ticketnr);
         String strtype = new String("" + type);
         String strobj = new String("" + rid);
-        int length = contextID.length() + value.length() + strtype.length() + strobj.length() + 6;
+        int length = contextID.length() + value.length() + strtype.length() + strobj.length() + strticket.length() + 7;
         char[] chars = new char[ length + 8 ]; //for length of message
         char[] tmpchar = getPaddedLength( length );
         int index = 0;
@@ -691,6 +701,11 @@ public class KJASProtocolHandler
         index += tmpchar.length;
         chars[index++] = sep;
 
+        tmpchar = strticket.toCharArray();
+        System.arraycopy( tmpchar, 0, chars, index, tmpchar.length );
+        index += tmpchar.length;
+        chars[index++] = sep;
+
         tmpchar = strtype.toCharArray();
         System.arraycopy( tmpchar, 0, chars, index, tmpchar.length );
         index += tmpchar.length;
@@ -743,12 +758,13 @@ public class KJASProtocolHandler
         sendAudioClipCommand(contextId, url, AudioClipStopCode);
     }
 
-    public void sendPutMember( String contextID, boolean success )
+    public void sendPutMember( String contextID, int ticketnr, boolean success )
     {
         Main.debug("sendPutMember, contextID = " + contextID + " success = " + success);
 
         String strret = new String(success ? "1" : "0");
-        int length = contextID.length() + strret.length() + 4;
+        String strticket = new String("" + ticketnr);
+        int length = contextID.length() + strret.length() + strticket.length() + 5;
         char[] chars = new char[ length + 8 ]; //for length of message
         char[] tmpchar = getPaddedLength( length );
         int index = 0;
@@ -763,6 +779,11 @@ public class KJASProtocolHandler
         index += tmpchar.length;
         chars[index++] = sep;
 
+        tmpchar = strticket.toCharArray();
+        System.arraycopy( tmpchar, 0, chars, index, tmpchar.length );
+        index += tmpchar.length;
+        chars[index++] = sep;
+
         tmpchar = strret.toCharArray();
         System.arraycopy( tmpchar, 0, chars, index, tmpchar.length );
         index += tmpchar.length;
