@@ -58,7 +58,7 @@ namespace DOM
   class Node;
   class HTMLEventListener;
   class EventListener;
-};
+}
 
 namespace khtml
 {
@@ -76,20 +76,20 @@ namespace khtml
   class RenderWidget;
   class CSSStyleSelector;
   class HTMLTokenizer;
-};
+}
 
 namespace KJS {
     class Window;
     class WindowFunc;
     class JSEventListener;
     class DOMDocument;
-};
+}
 
 namespace KParts
 {
   class PartManager;
   class LiveConnectExtension;
-};
+}
 
 /**
  * This class is khtml's main class. It features an almost complete
@@ -140,7 +140,7 @@ namespace KParts
  *
  * @short HTML Browser Widget
  * @author Lars Knoll (knoll@kde.org)
- * @version $Id: khtml_part.h,v 1.197.2.4 2003/02/03 01:17:33 pmk Exp $
+ * @version $Id: khtml_part.h,v 1.197.2.6 2003/07/10 12:13:14 waba Exp $
  * */
 class KHTMLPart : public KParts::ReadOnlyPart
 {
@@ -701,6 +701,11 @@ public:
    */
   QString referrer() const;
 
+  /**
+   * Referrer used to obtain this page.
+   */
+  QString pageReferrer() const;
+
   /**
    * Last-modified date (in raw string format), if received in the [HTTP] headers.
    */
