@@ -33,7 +33,7 @@
 #include <kmimetype.h>
 #include <klocale.h>
 
-K_EXPORT_COMPONENT_FACTORY( khtmlimagepart, KHTMLImageFactory );
+K_EXPORT_COMPONENT_FACTORY( khtmlimagepart, KHTMLImageFactory )
 
 KInstance *KHTMLImageFactory::s_instance = 0;
 
