@@ -243,10 +243,7 @@ void KHTMLToolTip::maybeTip(const QPoint& p)
             QString s = static_cast<DOM::ElementImpl*>( node )->getAttribute( ATTR_TITLE ).string();
             region |= QRect( m_view->contentsToViewport( node->getRect().topLeft() ), node->getRect().size() );
             if ( !s.isEmpty() ) {
-                QRect r(m_view->rect());
-                r.moveTopLeft(p + QPoint(2, 16));
-                r.setWidth(-1);
-                tip( region, s, r );
+                tip( region, QStyleSheet::convertFromPlainText( s, QStyleSheetItem::WhiteSpaceNormal ) );
                 break;
             }
         }
