@@ -21,11 +21,13 @@
 //----------------------------------------------------------------------------
 //
 // KDE HTML Widget -- decoder for input stream
-// $Id: decoder.cpp,v 1.55 2002/03/15 22:53:09 mueller Exp $
+// $Id: decoder.cpp,v 1.59 2002/11/22 03:05:38 mueller Exp $
 
 #undef DECODE_DEBUG
 //#define DECODE_DEBUG
 
+#include <assert.h>
+
 #include "decoder.h"
 using namespace khtml;
 
@@ -312,6 +314,8 @@ void Decoder::setEncoding(const char *_encoding, bool force)
 	haveEncoding = force;
     delete m_decoder;
     m_decoder = m_codec->makeDecoder();
+    if (m_codec->mibEnum() == 1000) // utf 16
+        haveEncoding = false; // force auto detection
 #ifdef DECODE_DEBUG
     kdDebug(6005) << "Decoder::encoding used is" << m_codec->name() << endl;
 #endif
@@ -342,14 +346,12 @@ QString Decoder::decode(const char *data, int len)
             m_decoder = m_codec->makeDecoder();
         } else {
 
-            if(m_codec->mibEnum() != 1000) // utf16
-            {
-                // ### hack for a bug in QTextCodec. It cut's the input stream
-                // in case there are \0 in it. ZDNET has them inside... :-(
+            if(m_codec->mibEnum() != 1000) {  // utf16
+                // replace '\0' by spaces, for buggy pages
                 char *d = const_cast<char *>(data);
                 int i = len - 1;
                 while(i >= 0) {
-                    if(*(d+i) == 0) *(d+i) = ' ';
+                    if(d[i] == 0) d[i] = ' ';
                     i--;
                 }
             }
@@ -427,6 +429,8 @@ QString Decoder::decode(const char *data, int len)
 		    }
                     case ID_SCRIPT:
                     case (ID_SCRIPT+ID_CLOSE_TAG):
+                    case ID_NOSCRIPT:
+                    case (ID_NOSCRIPT+ID_CLOSE_TAG):
                     case ID_STYLE:
                     case (ID_STYLE+ID_CLOSE_TAG):
                     case ID_LINK:
@@ -521,7 +525,7 @@ QString Decoder::decode(const char *data, int len)
     // the hell knows, why the output does sometimes have a QChar::null at
     // the end...
     if(out[out.length()-1] == QChar::null)
-        out.truncate(out.length() - 1);
+        assert(0);
     return out;
 }
 
