@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_box.h,v 1.57.2.2 2003/01/13 22:04:49 mueller Exp $
+ * $Id: render_box.h,v 1.57.2.3 2003/05/18 12:34:40 mueller Exp $
  */
 #ifndef RENDER_BOX_H
 #define RENDER_BOX_H
@@ -139,6 +139,6 @@ protected:
 };
 
 
-}; //namespace
+} //namespace
 
 #endif
