@@ -18,17 +18,15 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_br.cpp,v 1.13 2001/07/12 21:05:10 knoll Exp $
+ * $Id: render_br.cpp,v 1.15 2002/01/14 19:56:45 mueller Exp $
  */
 #include "render_br.h"
-#include "dom_stringimpl.h"
-#include "qfontmetrics.h"
 
 using namespace khtml;
 
 
-RenderBR::RenderBR()
-    : RenderText(new DOM::DOMStringImpl(QChar('\n')))
+RenderBR::RenderBR(DOM::NodeImpl* node)
+    : RenderText(node, new DOM::DOMStringImpl(QChar('\n')))
 {
     m_hasReturn = true;
 }
