@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_flow.h,v 1.72.2.2 2003/01/13 22:04:49 mueller Exp $
+ * $Id: render_flow.h,v 1.72.2.3 2003/05/18 12:34:40 mueller Exp $
  */
 #ifndef RENDER_FLOW_H
 #define RENDER_FLOW_H
@@ -171,6 +171,6 @@ private:
 };
 
 
-}; //namespace
+} //namespace
 
 #endif
