@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_form.cpp,v 1.198.2.9 2003/05/20 06:18:31 staikos Exp $
+ * $Id: render_form.cpp,v 1.198.2.10 2003/08/28 23:53:15 mueller Exp $
  */
 
 #include <kdebug.h>
@@ -474,8 +474,11 @@ void RenderLineEdit::updateFromElement()
     int ml = element()->maxLength();
     if ( ml < 0 || ml > 1024 )
         ml = 1024;
-    if ( widget()->maxLength() != ml )
+    if ( widget()->maxLength() != ml ) {
+        widget()->blockSignals( true );
         widget()->setMaxLength( ml );
+        widget()->blockSignals( false );
+    }
 
     if (element()->value().string() != widget()->text()) {
         widget()->blockSignals(true);
