@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_frames.cpp,v 1.144.2.2 2003/01/17 10:02:31 mueller Exp $
+ * $Id: render_frames.cpp,v 1.144.2.5 2003/03/06 04:17:01 staikos Exp $
  */
 //#define DEBUG_LAYOUT
 
@@ -153,12 +153,12 @@ void RenderFrameSet::layout( )
             // percentage ones and distribute remaining over relative
             for(int i = 0; i< gridLen; ++i)
                 if (grid[i].isFixed()) {
-                    gridLayout[i] = kMin(grid[i].value > 0 ? grid[i].value : 0, remainingLen[k]);
+                    gridLayout[i] = kMin(grid[i].value() > 0 ? grid[i].value() : 0, remainingLen[k]);
                     remainingLen[k] -= gridLayout[i];
                     totalFixed += gridLayout[i];
                 }
                 else if(grid[i].isRelative()) {
-                    totalRelative += grid[i].value > 1 ? grid[i].value : 1;
+                    totalRelative += grid[i].value() > 1 ? grid[i].value() : 1;
                     countRelative++;
                 }
 
@@ -166,7 +166,7 @@ void RenderFrameSet::layout( )
                 if(grid[i].isPercent()) {
                     gridLayout[i] = kMin(kMax(grid[i].width(availableLen[k]), 0), remainingLen[k]);
                     remainingLen[k] -= gridLayout[i];
-                    totalPercent += grid[i].value;
+                    totalPercent += grid[i].value();
                     countPercent++;
                 }
 
@@ -176,7 +176,7 @@ void RenderFrameSet::layout( )
                 int remaining = remainingLen[k];
                 for (int i = 0; i < gridLen; ++i)
                     if (grid[i].isRelative()) {
-                        gridLayout[i] = ((grid[i].value > 1 ? grid[i].value : 1) * remaining) / totalRelative;
+                        gridLayout[i] = ((grid[i].value() > 1 ? grid[i].value() : 1) * remaining) / totalRelative;
                         remainingLen[k] -= gridLayout[i];
                     }
             }
@@ -187,8 +187,8 @@ void RenderFrameSet::layout( )
                 int total = countPercent ? totalPercent : totalFixed;
                 if (!total) total = 1;
                 for (int i = 0; i < gridLen; ++i)
-                    if (grid[i].type == distributeType) {
-                        int toAdd = (remainingLen[k] * grid[i].value) / total;
+                    if (grid[i].type() == distributeType) {
+                        int toAdd = (remainingLen[k] * grid[i].value()) / total;
                         gridLayout[i] += toAdd;
                     }
             }
@@ -627,6 +627,10 @@ void RenderPartObject::updateWidget()
 
       params.append( QString::fromLatin1("__KHTML__CLASSID=\"%1\"").arg( o->classId ) );
       params.append( QString::fromLatin1("__KHTML__CODEBASE=\"%1\"").arg( o->getAttribute(ATTR_CODEBASE).string() ) );
+      if (!o->getAttribute(ATTR_WIDTH).isEmpty())
+          params.append( QString::fromLatin1("WIDTH=\"%1\"").arg( o->getAttribute(ATTR_WIDTH).string() ) );
+      if (!o->getAttribute(ATTR_HEIGHT).isEmpty())
+          params.append( QString::fromLatin1("HEIGHT=\"%1\"").arg( o->getAttribute(ATTR_HEIGHT).string() ) );
 
       if ( !embed )
       {
@@ -695,6 +699,7 @@ void RenderPartObject::updateWidget()
           }
           part->requestObject( this, url, serviceType, params );
       }
+      o->setLiveConnect(part->liveConnectExtension(this));
   }
   else if ( element()->id() == ID_EMBED ) {
 
