@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_html.h,v 1.10.4.2 2003/01/13 22:04:49 mueller Exp $
+ * $Id: render_html.h,v 1.10.4.3 2003/05/18 12:34:40 mueller Exp $
  */
 #ifndef RENDER_HTML
 #define RENDER_HTML
@@ -55,6 +55,6 @@ private:
         QScrollView* m_view;
 };
 
-}; // namespace khtml
+} // namespace khtml
 
 #endif
