@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_image.h,v 1.36.2.2 2003/01/13 22:04:49 mueller Exp $
+ * $Id: render_image.h,v 1.36.2.3 2003/05/18 12:34:40 mueller Exp $
  */
 #ifndef RENDER_IMAGE_H
 #define RENDER_IMAGE_H
@@ -93,6 +93,6 @@ private:
 };
 
 
-}; //namespace
+} //namespace
 
 #endif
