@@ -1,8 +1,9 @@
 /**
  * This file is part of the DOM implementation for KDE.
  *
- * Copyright (C) 1999 Lars Knoll (knoll@kde.org)
+ * Copyright (C) 1999-2002 Lars Knoll (knoll@kde.org)
  *           (C) 1999 Antti Koivisto (koivisto@kde.org)
+ *           (C) 2000-2002 Dirk Mueller (mueller@kde.org)
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -19,17 +20,17 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_list.cpp,v 1.74.2.1 2002/06/17 18:30:01 mueller Exp $
+ * $Id: render_list.cpp,v 1.80.2.2 2003/01/10 18:01:37 knoll Exp $
  */
 
-#include "render_list.h"
+#include "rendering/render_list.h"
 #include "rendering/render_root.h"
-
-#include <qpainter.h>
-
+#include "html/html_listimpl.h"
 #include "misc/helper.h"
+#include "misc/htmltags.h"
 
 #include <kdebug.h>
+#include <kglobal.h>
 
 //#define BOX_DEBUG
 
@@ -172,79 +173,25 @@ void RenderListItem::calcListValue()
             RenderListItem *item = static_cast<RenderListItem *>(o);
             m_marker->m_value = item->value() + 1;
         }
+        else if (parent()->element() && parent()->element()->id() == ID_OL)
+            m_marker->m_value = static_cast<DOM::HTMLOListElementImpl*>(parent()->element())->start();
         else
             m_marker->m_value = 1;
     }
 }
 
-
 void RenderListItem::layout( )
 {
     KHTMLAssert( !layouted() );
     KHTMLAssert( minMaxKnown() );
 
-    if ( !checkChildren() ) {
-        m_height = 0;
-        //kdDebug(0) << "empty item" << endl;
-        return;
-    }
     if (m_marker && !m_marker->layouted())
         m_marker->layout();
     RenderFlow::layout();
-}
 
-// this function checks if there is other rendered contents in the list item than a marker. If not, the whole
-// list item will not get printed.
-bool RenderListItem::checkChildren() const
-{
-    //kdDebug(0) << " checkCildren" << endl;
-    if(!firstChild())
-        return false;
-    RenderObject *o = firstChild();
-    while(o->firstChild())
-        o = o->firstChild();
-    while (!o->nextSibling() && o->parent() != static_cast<const RenderObject*>(this))
-        o = o->parent();
-    //o = o->nextSibling();
-    while( o ) {
-        //kdDebug(0) << "checking " << renderName() << endl;
-        if ( o->isText() || o->isReplaced() ) {
-            //kdDebug(0) << "found" << endl;
-            return true;
-        }
-        RenderObject *next = o->firstChild();
-        if ( !next )
-            next = o->nextSibling();
-        while ( !next && o->parent() != static_cast<const RenderObject*>(this) ) {
-            o = o->parent();
-            next =  o->nextSibling();
-        }
-        if( !next )
-            break;
-        o = next;
-    }
-    //kdDebug(0) << "not found" << endl;
-    return false;
-}
-
-void RenderListItem::print(QPainter *p, int _x, int _y, int _w, int _h,
-                             int _tx, int _ty)
-{
-    if ( !m_height )
-        return;
-
-#ifdef DEBUG_LAYOUT
-    kdDebug( 6040 ) << nodeName().string() << "(LI)::print()" << endl;
-#endif
-    RenderFlow::print(p, _x, _y, _w, _h, _tx, _ty);
-}
-
-void RenderListItem::printObject(QPainter *p, int _x, int _y,
-                                    int _w, int _h, int _tx, int _ty)
-{
-    // ### this should scale with the font size in the body... possible?
-    //m_marker->printIcon(p, _tx, _ty);
-    RenderFlow::printObject(p, _x, _y, _w, _h, _tx, _ty);
+    m_height = kMax ( m_height, int ( lineHeight( true ) ) );
+    if (m_marker)
+        m_height = kMax( m_height, m_marker->height() );
 }
 
 // -----------------------------------------------------------
@@ -281,19 +228,19 @@ void RenderListMarker::setStyle(RenderStyle *s)
 }
 
 
-void RenderListMarker::print(QPainter *p, int _x, int _y, int _w, int _h,
+void RenderListMarker::paint(QPainter *p, int _x, int _y, int _w, int _h,
                              int _tx, int _ty)
 {
-    printObject(p, _x, _y, _w, _h, _tx, _ty);
+    paintObject(p, _x, _y, _w, _h, _tx, _ty);
 }
 
-void RenderListMarker::printObject(QPainter *p, int, int _y,
+void RenderListMarker::paintObject(QPainter *p, int, int _y,
                                     int, int _h, int _tx, int _ty)
 {
     if (style()->visibility() != VISIBLE) return;
 
 #ifdef DEBUG_LAYOUT
-    kdDebug( 6040 ) << nodeName().string() << "(ListMarker)::printObject(" << _tx << ", " << _ty << ")" << endl;
+    kdDebug( 6040 ) << nodeName().string() << "(ListMarker)::paintObject(" << _tx << ", " << _ty << ")" << endl;
 #endif
     p->setFont(style()->font());
     const QFontMetrics fm = p->fontMetrics();
@@ -304,7 +251,7 @@ void RenderListMarker::printObject(QPainter *p, int, int _y,
     {
         if (_ty < _y)
         {
-            // This has been printed already we suppose.
+            // This has been painted already we suppose.
             return;
         }
         if (_ty + m_height + paddingBottom() + borderBottom() >= _y+_h)
@@ -312,26 +259,35 @@ void RenderListMarker::printObject(QPainter *p, int, int _y,
             RenderRoot *rootObj = root();
             if (_ty < rootObj->truncatedAt())
                 rootObj->setTruncatedAt(_ty);
-            // Let's print this on the next page.
-            return; 
+            // Let's paint this on the next page.
+            return;
         }
     }
-    
 
-    int xoff = 0;
+
+    int xoff = m_x;
     int yoff = fm.ascent() - offset;
 
-    if(style()->listStylePosition() != INSIDE) {
-        xoff = -7 - offset;
-        if(style()->direction() == RTL)
-            xoff = -xoff + parent()->width();
-    }
 
     if ( m_listImage && !m_listImage->isErrorImage()) {
-        p->drawPixmap( QPoint( _tx + xoff, _ty ), m_listImage->pixmap());
+	if ( style()->listStylePosition() != INSIDE ) {
+	    if ( style()->direction() == LTR )
+		xoff = - m_listImage->pixmap().width();
+	    else
+		xoff = parent()->width();
+	}
+	p->drawPixmap( QPoint( _tx + xoff, _ty ), m_listImage->pixmap());
         return;
     }
 
+    if(style()->listStylePosition() != INSIDE) {
+	if(style()->direction() == RTL)
+	    xoff = 7 + parent()->width();
+	else
+	    xoff = -7 - offset;
+
+    }
+
 #ifdef BOX_DEBUG
     p->setPen( Qt::red );
     p->drawRect( _tx + xoff, _ty + yoff, offset, offset );
@@ -377,6 +333,11 @@ void RenderListMarker::layout()
 {
     KHTMLAssert( !layouted() );
     // ### KHTMLAssert( minMaxKnown() );
+    if (m_listImage)
+        m_height = m_listImage->pixmap().height();
+    else
+        m_height = style()->fontMetrics().ascent();
+
     if ( !minMaxKnown() )
 	calcMinMaxWidth();
     setLayouted();
@@ -406,8 +367,7 @@ void RenderListMarker::calcMinMaxWidth()
 
     if(m_listImage) {
         if(style()->listStylePosition() == INSIDE)
-            m_width = m_listImage->pixmap().width() + 5;
-        m_height = m_listImage->pixmap().height();
+            m_width = m_listImage->pixmap().width();
 	setMinMaxKnown();
         return;
     }
@@ -420,16 +380,14 @@ void RenderListMarker::calcMinMaxWidth()
     }
 
     const QFontMetrics &fm = style()->fontMetrics();
-    m_height = fm.ascent();
 
     switch(style()->listStyleType())
     {
     case DISC:
     case CIRCLE:
     case SQUARE:
-        if(style()->listStylePosition() == INSIDE) {
-            m_width = m_height; //fm.ascent();
-        }
+        if(style()->listStylePosition() == INSIDE)
+            m_width = fm.ascent();
     	goto end;
     case ARMENIAN:
     case GEORGIAN:
