@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_object.cpp,v 1.195.2.1 2003/01/10 18:01:37 knoll Exp $
+ * $Id: render_object.cpp,v 1.195.2.2 2003/02/04 08:15:05 mueller Exp $
  */
 
 #include "rendering/render_object.h"
@@ -983,14 +983,14 @@ short RenderObject::lineHeight( bool firstLine ) const
         lh = style()->lineHeight();
 
     // its "unset", choose nice default
-    if ( lh.value < 0 )
+    if ( lh.value() < 0 )
         return style()->fontMetrics().lineSpacing();
 
     if ( lh.isPercent() )
         return lh.minWidth( style()->font().pixelSize() );
 
     // its fixed
-    return lh.value;
+    return lh.value();
 }
 
 short RenderObject::baselinePosition( bool firstLine ) const
