@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_style.h,v 1.78.2.3 2003/02/09 14:09:59 rnolden Exp $
+ * $Id: render_style.h,v 1.78.2.4 2003/08/17 14:38:51 mueller Exp $
  */
 #ifndef RENDERSTYLE_H
 #define RENDERSTYLE_H
@@ -519,7 +519,7 @@ protected:
                 EVisibility _visibility : 2;
                 ETextAlign _text_align : 3;
                 ETextTransform _text_transform : 2;
-                int _text_decoration : 4;
+                unsigned _text_decoration : 4;
                 ECursor _cursor_style : 5;
 
                 EDirection _direction : 1;
@@ -529,7 +529,7 @@ protected:
                 // non CSS2 inherited
                 bool _visuallyOrdered : 1;
                 bool _htmlHacks :1;
-                int _unused : 1;
+                unsigned _unused : 1;
             } f;
             Q_UINT32 _iflags;
         };
@@ -560,7 +560,7 @@ protected:
                 bool _hasActive : 1;
                 bool _clipSpecified : 1;
                 EUnicodeBidi _unicodeBidi : 2;
-                int _unused : 1;
+                unsigned _unused : 1;
             } f;
             Q_UINT32 _niflags;
         };
@@ -728,7 +728,7 @@ public:
     Length textIndent() const { return inherited->indent; }
     ETextAlign textAlign() const { return inherited_flags.f._text_align; }
     ETextTransform textTransform() const { return inherited_flags.f._text_transform; }
-    int textDecoration() const { return inherited_flags.f._text_decoration; }
+    unsigned textDecoration() const { return inherited_flags.f._text_decoration; }
     const QColor &textDecorationColor() const { return inherited->decoration_color; }
     int wordSpacing() const { return inherited->font.wordSpacing; }
     int letterSpacing() const { return inherited->font.letterSpacing; }
@@ -838,7 +838,7 @@ public:
     void setTextIndent(Length v) { SET_VAR(inherited,indent,v) }
     void setTextAlign(ETextAlign v) { inherited_flags.f._text_align = v; }
     void setTextTransform(ETextTransform v) { inherited_flags.f._text_transform = v; }
-    void setTextDecoration(int v) { inherited_flags.f._text_decoration = v; }
+    void setTextDecoration(unsigned v) { inherited_flags.f._text_decoration = v; }
     void setTextDecorationColor(const QColor &v) { SET_VAR(inherited,decoration_color,v) }
     void setDirection(EDirection v) { inherited_flags.f._direction = v; }
     void setLineHeight(Length v) { SET_VAR(inherited,line_height,v) }
