@@ -22,7 +22,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: render_table.h,v 1.79.2.1 2003/01/10 18:01:38 knoll Exp $
+ * $Id: render_table.h,v 1.79.2.3 2003/08/17 14:38:51 mueller Exp $
  */
 #ifndef RENDER_TABLE_H
 #define RENDER_TABLE_H
@@ -37,7 +37,7 @@
 
 namespace DOM {
     class DOMString;
-};
+}
 
 namespace khtml {
 
@@ -245,8 +245,8 @@ public:
     QMemArray<RowStruct> grid;
     QMemArray<int> rowPos;
 
+    signed short cRow : 16;
     ushort cCol : 15;
-    short cRow : 16;
     bool needCellRecalc : 1;
 
     void recalcCells();
@@ -363,9 +363,9 @@ protected:
     short _col;
     ushort rSpan;
     ushort cSpan;
-    int _topExtra : 31;
+    signed int _topExtra : 31;
     bool nWrap : 1;
-    int _bottomExtra : 31;
+    signed int _bottomExtra : 31;
     bool m_widthChanged : 1;
 };
 
@@ -400,6 +400,6 @@ protected:
     short _span;
 };
 
-};
+}
 #endif
 
