@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: table_layout.cpp,v 1.24.2.2 2003/02/04 08:15:05 mueller Exp $
+ * $Id: table_layout.cpp,v 1.24.2.3 2003/07/18 16:06:39 staikos Exp $
  */
 #include "table_layout.h"
 #include "render_table.h"
@@ -170,7 +170,7 @@ int FixedTableLayout::calcWidthArray( int tableWidth )
 	section = table->firstBody;
     if ( !section )
 	section = table->foot;
-    if ( section ) {
+    if ( section && section->firstChild() ) {
 	cCol = 0;
 	// get the first cell in the first row
 	child = section->firstChild()->firstChild();
