@@ -19,7 +19,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom2_eventsimpl.h,v 1.24.2.2 2003/01/27 13:27:55 faure Exp $
+ * $Id: dom2_eventsimpl.h,v 1.24.2.3 2003/05/18 12:34:40 mueller Exp $
  */
 
 #ifndef _DOM_EventsImpl_h_
@@ -399,5 +399,5 @@ private:
     RegisteredEventListener & operator=( const RegisteredEventListener & );
 };
 
-}; //namespace
+} //namespace
 #endif
