@@ -454,7 +454,7 @@ DocumentFragmentImpl *RangeImpl::processContents ( ActionType action, int &excep
             while (n && i < m_endOffset) { // delete until m_endOffset
 		NodeImpl *next = n->nextSibling();
                 if (action == EXTRACT_CONTENTS)
-                    fragment->appendChild(n,exceptioncode); // will remove n from it's parent
+                    fragment->appendChild(n,exceptioncode); // will remove n from its parent
                 else if (action == CLONE_CONTENTS)
                     fragment->appendChild(n->cloneNode(true),exceptioncode);
                 else
@@ -578,7 +578,7 @@ DocumentFragmentImpl *RangeImpl::processContents ( ActionType action, int &excep
             for (; n; n = prev ) {
                 prev = n->previousSibling();
                 if (action == EXTRACT_CONTENTS)
-                    rightContents->insertBefore(n,rightContents->firstChild(),exceptioncode); // will remove n from it's parent
+                    rightContents->insertBefore(n,rightContents->firstChild(),exceptioncode); // will remove n from its parent
                 else if (action == CLONE_CONTENTS)
                     rightContents->insertBefore(n->cloneNode(true),rightContents->firstChild(),exceptioncode);
                 else
@@ -599,7 +599,7 @@ DocumentFragmentImpl *RangeImpl::processContents ( ActionType action, int &excep
             for (; n; n = prev ) {
                 prev = n->previousSibling();
                 if (action == EXTRACT_CONTENTS)
-                    rightContents->insertBefore(n,rightContents->firstChild(),exceptioncode); // will remove n from it's parent
+                    rightContents->insertBefore(n,rightContents->firstChild(),exceptioncode); // will remove n from its parent
                 else if (action == CLONE_CONTENTS)
                     rightContents->insertBefore(n->cloneNode(true),rightContents->firstChild(),exceptioncode);
                 else
@@ -814,7 +814,9 @@ DOMString RangeImpl::toString( int &exceptioncode )
         if(n->nodeType() == DOM::Node::TEXT_NODE ||
            n->nodeType() == DOM::Node::CDATA_SECTION_NODE) {
 
-            DOMString str = static_cast<TextImpl *>(n)->data().copy();
+            DOMString str;
+            if (static_cast<TextImpl *>(n)->string())
+               str = static_cast<TextImpl *>(n)->string()->copy();
             if (n == m_endContainer)
                 str.truncate(m_endOffset);
             if (n == m_startContainer)
