@@ -21,7 +21,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom2_rangeimpl.h,v 1.16 2002/04/11 08:56:40 knoll Exp $
+ * $Id: dom2_rangeimpl.h,v 1.16.2.1 2003/07/15 10:42:18 mueller Exp $
  */
 
 #ifndef _DOM2_RangeImpl_h_
@@ -102,7 +102,7 @@ private:
     bool containedByReadOnly();
 };
 
-}; // namespace
+} // namespace
 
 #endif
 
