@@ -1202,7 +1202,7 @@ NodeImpl *NodeBaseImpl::removeChild ( NodeImpl *oldChild, int &exceptioncode )
 void NodeBaseImpl::removeChildren()
 {
     NodeImpl *n, *next;
-    for( n = _first; n != 0; n = next )
+    for( n = _first; n; n = next )
     {
         next = n->nextSibling();
         if (n->attached())
@@ -1212,6 +1212,9 @@ void NodeBaseImpl::removeChildren()
         n->setParent(0);
         if( !n->refCount() )
             delete n;
+        else
+            for ( NodeImpl* c = n; c; c = c->traverseNextNode( n ) )
+                c->removedFromDocument();
     }
     _first = _last = 0;
 }
@@ -1399,8 +1402,15 @@ NodeListImpl* NodeBaseImpl::getElementsByTagNameNS ( DOMStringImpl* namespaceURI
     if (namespaceURI && namespaceURI->l && namespaceURI->s[0] == '*')
         idMask &= ~NodeImpl_IdNSMask;
 
-    return new TagNodeListImpl( this,
-                                getDocument()->tagId(namespaceURI, localName, true), idMask);
+    Id id = 0; // 0 means "all items"
+    if ( (idMask & NodeImpl_IdLocalMask) || namespaceURI ) // not getElementsByTagName("*")
+    {
+        id = getDocument()->tagId( namespaceURI, localName, true /*readonly*/, 0 );
+        if ( !id ) // not found -> we want to return an empty list, not "all items"
+            id = (Id)-1;
+    }
+
+    return new TagNodeListImpl( this, id, idMask );
 }
 
 // I don't like this way of implementing the method, but I didn't find any
@@ -1720,8 +1730,8 @@ NodeImpl *TagNodeListImpl::item ( unsigned long index ) const
 
 bool TagNodeListImpl::nodeMatches( NodeImpl *testNode ) const
 {
-    return ( testNode->isElementNode() && m_id &&
-             (testNode->id() & m_idMask) == m_id);
+    return testNode->isElementNode() &&
+           ((testNode->id() & m_idMask) == m_id);
 }
 
 NameNodeListImpl::NameNodeListImpl(NodeImpl *n, const DOMString &t )
@@ -1837,7 +1847,7 @@ NodeImpl *GenericRONamedNodeMapImpl::getNamedItemNS( const DOMString &namespaceU
                                                      int &/*exceptioncode*/ ) const
 {
     NodeImpl::Id searchId = m_doc->tagId(namespaceURI.implementation(),
-                                                   localName.implementation(), true);
+                                         localName.implementation(), true, 0);
 
     QPtrListIterator<NodeImpl> it(*m_contents);
     for (; it.current(); ++it)
