@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_nodeimpl.h,v 1.137.2.1 2003/01/03 21:09:29 mueller Exp $
+ * $Id: dom_nodeimpl.h,v 1.137.2.4 2003/06/30 10:24:54 faure Exp $
  */
 #ifndef _DOM_NodeImpl_h_
 #define _DOM_NodeImpl_h_
@@ -45,7 +45,7 @@ class QTextStream;
 namespace khtml {
     class RenderStyle;
     class RenderObject;
-};
+}
 
 namespace DOM {
 
@@ -591,5 +591,5 @@ protected:
 };
 #endif
 
-}; //namespace
+} //namespace
 #endif
