@@ -20,7 +20,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_stringimpl.cpp,v 1.48 2002/09/22 04:28:35 cumming Exp $
+ * $Id: dom_stringimpl.cpp,v 1.48.2.1 2003/04/03 01:28:26 mueller Exp $
  */
 
 #include "dom_stringimpl.h"
@@ -265,5 +265,19 @@ DOMStringImpl *DOMStringImpl::capitalize()
     return c;
 }
 
+int DOMStringImpl::toInt(bool* ok) const
+{
+    // match \s*[+-]?\d*
+    unsigned i = 0;
+    while (i < l && s[i].isSpace())
+        ++i;
+    if (i < l && (s[i] == '+' || s[i] == '-'))
+        ++i;
+    while (i < l && s[i].isDigit())
+        ++i;
+
+    return QConstString(s, i).string().toInt(ok);
+}
+
 
 
