@@ -18,7 +18,7 @@
  * the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  *
- * $Id: dom_xmlimpl.h,v 1.20.4.1 2003/01/03 21:09:29 mueller Exp $
+ * $Id: dom_xmlimpl.h,v 1.20.4.2 2003/05/18 12:34:41 mueller Exp $
  */
 
 #ifndef _DOM_XmlImpl_h_
@@ -31,7 +31,7 @@
 
 namespace khtml {
 class CachedCSSStyleSheet;
-};
+}
 
 namespace DOM {
 
@@ -172,6 +172,6 @@ protected:
     QString m_attrString;
 };
 
-}; //namespace
+} //namespace
 
 #endif
