@@ -30,12 +30,17 @@
 #include <string.h>
 #include <unistd.h>
 
+#if defined(HAVE_NSGETENVIRON) && defined(HAVE_CRT_EXTERNS_H)
+# include <sys/time.h>
+# include <crt_externs.h>
+# define environ (*_NSGetEnviron())
+#endif
+
 /* _PATH_KMEM should be defined in <paths.h> */
 #ifndef _PATH_KMEM
 # define _PATH_KMEM	"/dev/kmem"
 #endif
 
-#define newstr(s)	strcpy((char*)malloc(strlen(s) + 1), s)
 #define SPACELEFT(buf, ptr)	(sizeof buf - ((ptr) - buf))
 
 
@@ -133,7 +138,9 @@ void
 kdeinit_initsetproctitle(int argc, char **argv, char **envp)
 {
 	register int i, envpsize = 0;
+#if !defined(HAVE_NSGETENVIRON) || !defined(HAVE_CRT_EXTERNS_H)
 	extern char **environ;
+#endif
 
 	/*
 	**  Move the environment so setproctitle can use the space at
@@ -143,8 +150,11 @@ kdeinit_initsetproctitle(int argc, char **argv, char **envp)
 	for (i = 0; envp[i] != NULL; i++)
 		envpsize += strlen(envp[i]) + 1;
 	environ = (char **) malloc(sizeof (char *) * (i + 1));
+	if (environ == NULL)
+        	return;
+
 	for (i = 0; envp[i] != NULL; i++)
-		environ[i] = newstr(envp[i]);
+		environ[i] = strdup(envp[i]);
 	environ[i] = NULL;
 
 	/*
