@@ -8,10 +8,10 @@ const int kfile_area = 250;
 #define DefaultMixDirsAndFiles false
 #define DefaultShowStatusLine false
 #define DefaultShowHidden false
-#define DefaultCaseInsensitive false
+#define DefaultCaseInsensitive true
 #define DefaultDirsFirst true
 #define DefaultSortReversed false
-#define DefaultRecentURLsNumber 10
+#define DefaultRecentURLsNumber 15
 #define DefaultDirectoryFollowing true
 #define ConfigGroup QString::fromLatin1("KFileDialog Settings")
 #define RecentURLs QString::fromLatin1("Recent URLs")
@@ -24,5 +24,6 @@ const int kfile_area = 250;
 #define AutoDirectoryFollowing QString::fromLatin1("Automatic directory following")
 #define PathComboCompletionMode QString::fromLatin1("PathCombo Completionmode")
 #define LocationComboCompletionMode QString::fromLatin1("LocationCombo Completionmode")
+#define ShowSpeedbar QString::fromLatin1("Show Speedbar")
 
 #endif
