@@ -68,7 +68,7 @@ struct KFileDialogPrivate;
  * by subclassing. It uses geometry management to ensure that subclasses
  * can easily add children that will be incorporated into the layout.
  *
- * @image kfiledialog.png KFileDialog
+ * \image html kfiledialog.png "KDE File Dialog"
  *
  * @short A file selection dialog.
  *
@@ -100,10 +100,10 @@ public:
       *         @li QString::null to start in the current working
       *		    directory, or the last directory where a file has been
       *		    selected.
-      *         @li ':<keyword>' to start in the directory last used
+      *         @li ':&lt;keyword&gt;' to start in the directory last used
       *             by a filedialog in the same application that specified
       *             the same keyword.
-      *         @li '::<keyword' to start in the direcotry last used
+      *         @li '::&lt;keyword&gt;' to start in the direcotry last used
       *             by a filedialog in any application that specified the
       *             same keyword.
       *
@@ -111,13 +111,53 @@ public:
                       which files to display.
       * See @ref setFilter() for details on how to use this argument.
       *
-      * @param acceptURLs If set to @p false, @ref KFileDialog will
+      * @param acceptURLs If set to @p false, the dialog will
       * just accept files on the local filesystem.
       */
     KFileDialog(const QString& startDir, const QString& filter,
 		QWidget *parent, const char *name,
 		bool modal);
 
+    /**
+      * Constructs a file dialog.
+      *
+      * The parameters here are identical to the first constructor except
+      * for the addition of a QWidget parameter.
+      *
+      * Historical note: The original version of KFileDialog did not have this extra
+      * parameter. It was added later, and, in order to maintain binary compatibility,
+      * it was placed in a new constructor instead of added to the original one.
+      *
+      * @param startDir This can either be
+      *         @li The URL of the directory to start in.
+      *         @li QString::null to start in the current working
+      *		    directory, or the last directory where a file has been
+      *		    selected.
+      *         @li ':&lt;keyword&gt;' to start in the directory last used
+      *             by a filedialog in the same application that specified
+      *             the same keyword.
+      *         @li '::&lt;keyword&gt;' to start in the direcotry last used
+      *             by a filedialog in any application that specified the
+      *             same keyword.
+      *
+      * @param filter A shell glob or a mime-type-filter that specifies
+      *               which files to display.
+      * See @ref setFilter() for details on how to use this argument.
+      *
+      * @param acceptURLs If set to @p false, the dialog will
+      * just accept files on the local filesystem.
+      *
+      * @param widget A widget, or a widget of widgets, for displaying custom
+      *               data in the dialog. This can be used, for example, to
+      *               display a check box with the caption "Open as read-only".
+      *               When creating this widget, you don't need to specify a parent,
+      *               since the widget's parent will be set automatically by KFileDialog.
+      * @since 3.1
+      */
+    KFileDialog(const QString& startDir, const QString& filter,
+		QWidget *parent, const char *name,
+		bool modal, QWidget* widget);
+
     /**
      * Destructs the file dialog.
      */
@@ -172,7 +212,10 @@ public:
      * a save-as dialog. So setOperationMode( KFileDialog::Saving ); sets
      * setKeepLocation for example.
      *
-     * The default mode is @p Other.
+     * The mode @p Saving, together with a default filter set via
+     * @ref setMimeFilter() will make the filter combobox read-only.
+     *
+     * The default mode is @p Opening.
      *
      * Call this method right after instantiating KFileDialog.
      *
@@ -218,23 +261,26 @@ public:
      * If no | is found in the expression, just the namefilter is
      * shown. Examples:
      *
-     * <pre>
+     * <code>
      * kfile->setFilter("*.cpp|C++ Source Files\n*.h|Header files");
      * kfile->setFilter("*.cpp");
      * kfile->setFilter("*.cpp|Sources (*.cpp)");
      * kfile->setFilter("*.cpp *.cc *.C|C++ Source Files\n*.h *.H|Header files");
-     * </pre>
+     * </code>
      *
      * Note: The text to display is not parsed in any way. So, if you
      * want to show the suffix to select by a specific filter, you must
      * repeat it.
      *
-     * If the filter contains a '/', a mimetype-filter is assumed. You can
-     * specify multiple mimetypes like this (separated with space):
+     * If the filter contains an unescaped '/', a mimetype-filter is assumed.
+     * If you would like a '/' visible in your filter it can be escaped with
+     * a '\'. You can specify multiple mimetypes like this (separated with
+     * space):
      *
-     * <pre>
+     * <code>
      * kfile->setFilter( "image/png text/html text/plain" );
-     * </pre>
+     * kfile->setFilter( "*.cue|CUE\\/BIN Files (*.cue)" );
+     * </code>
      *
      * @see #filterChanged
      * @see #setMimeFilter
@@ -345,13 +391,16 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param filter This is a space seperated list of shell globs.
+     * You can set the text to be displayed for the glob, and
+     * provide multiple globs.  See @ref setFilter() for details on
+     * how to do this...
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -373,13 +422,16 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param filter This is a space seperated list of shell globs.
+     * You can set the text to be displayed for the glob, and
+     * provide multiple globs.  See @ref setFilter() for details on
+     * how to do this...
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -400,13 +452,16 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param filter This is a space seperated list of shell globs.
+     * You can set the text to be displayed for the glob, and
+     * provide multiple globs.  See @ref setFilter() for details on
+     * how to do this...
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -428,13 +483,16 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param filter This is a space seperated list of shell globs.
+     * You can set the text to be displayed for the glob, and
+     * provide multiple globs.  See @ref setFilter() for details on
+     * how to do this...
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -457,13 +515,16 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param filter This is a space seperated list of shell globs.
+     * You can set the text to be displayed for the glob, and
+     * provide multiple globs.  See @ref setFilter() for details on
+     * how to do this...
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -486,13 +547,16 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param filter This is a space seperated list of shell globs.
+     * You can set the text to be displayed for the glob, and
+     * provide multiple globs.  See @ref setFilter() for details on
+     * how to do this...
      * @param parent The widget the dialog will be centered on initially.
      * @param caption The name of the dialog widget.
      */
@@ -504,18 +568,15 @@ public:
      * Creates a modal file dialog and returns the selected
      * directory or an empty string if none was chosen.
      *
-     * Note that with this
-     * method the user need not select an existing directory.
-     *
      * @param startDir This can either be
      *         @li The URL of the directory to start in.
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param parent The widget the dialog will be centered on initially.
@@ -525,6 +586,31 @@ public:
 					QWidget * parent = 0,
 					const QString& caption= QString::null);
 
+    /**
+     * Creates a modal file dialog and returns the selected
+     * directory or an empty string if none was chosen.
+     *
+     * Contrary to @ref getExistingDirectory(), this method allows the
+     * selection of a remote directory.
+     *
+     * @param startDir This can either be
+     *         @li The URL of the directory to start in.
+     *         @li QString::null to start in the current working
+     *		    directory, or the last directory where a file has been
+     *		    selected.
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
+     *             by a filedialog in the same application that specified
+     *             the same keyword.
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
+     *             by a filedialog in any application that specified the
+     *             same keyword.
+     * @param parent The widget the dialog will be centered on initially.
+     * @param caption The name of the dialog widget.
+     * @since 3.1
+     */
+    static KURL getExistingURL(const QString & startDir = QString::null,
+                                  QWidget * parent = 0,
+                                  const QString& caption= QString::null);
     /**
      * Creates a modal file dialog with an image previewer and returns the
      * selected url or an empty string if none was chosen.
@@ -534,10 +620,10 @@ public:
      *         @li QString::null to start in the current working
      *		    directory, or the last directory where a file has been
      *		    selected.
-     *         @li ':<keyword>' to start in the directory last used
+     *         @li ':&lt;keyword&gt;' to start in the directory last used
      *             by a filedialog in the same application that specified
      *             the same keyword.
-     *         @li '::<keyword' to start in the direcotry last used
+     *         @li '::&lt;keyword&gt;' to start in the direcotry last used
      *             by a filedialog in any application that specified the
      *             same keyword.
      * @param parent The widget the dialog will be centered on initially.
@@ -560,21 +646,22 @@ public:
      * Sets the mode of the dialog.
      *
      * The mode is defined as (in kfile.h):
-     * <pre>    enum Mode {
-     *                      File         = 1,
-     *                      Directory    = 2,
-     *                      Files        = 4,
-     *                      ExistingOnly = 8,
-     *                      LocalOnly    = 16
-     *                    };
-     * </pre>
+     * <code>
+     *    enum Mode {
+     *         File         = 1,
+     *         Directory    = 2,
+     *         Files        = 4,
+     *         ExistingOnly = 8,
+     *         LocalOnly    = 16
+     *    };
+     * </code>
      * You can OR the values, e.g.
-     * <pre>
+     * <code>
      * KFile::Mode mode = static_cast<KFile::Mode>( KFile::Files |
      *                                              KFile::ExistingOnly |
      *                                              KFile::LocalOnly );
      * setMode( mode );
-     * </pre>
+     * </code>
      */
     void setMode( unsigned int m );
 
@@ -598,12 +685,12 @@ public:
      *
      * You can use this to insert custom
      * items into it, e.g.:
-     * <pre>
+     * <code>
      *      yourAction = new KAction( i18n("Your Action"), 0,
      *                                this, SLOT( yourSlot() ),
      *                                this, "action name" );
      *      yourAction->plug( kfileDialog->toolBar() );
-     * </pre>
+     * </code>
      */
     KToolBar *toolBar() const { return toolbar; }
 
@@ -625,6 +712,27 @@ public:
      */
     KActionCollection *actionCollection() const;
 
+    /**
+     * @returns the index of the path combobox so when inserting widgets into
+     * the dialog (e.g. subclasses) they can do so without hardcoding in an index
+     */
+    int pathComboIndex();
+
+    /**
+     * This method implements the logic to determine the user's default directory
+     * to be listed. E.g. the documents direcory, home directory or a recently 
+     * used directory.
+     * @param startDir A url/directory, to be used. May use the ':' and '::' syntax 
+     *        as documented in the @ref KFileDialog() constructor.
+     * @param recentDirClass If the ':' or '::' syntax is used, recentDirClass
+     *        will contain the string to be used later for @ref KRecentDir::dir()
+     * @return The URL that should be listed by default (e.g. by KFileDialog or
+     *         KDirSelectDialog).
+     * @since 3.1
+     */
+    static KURL getStartURL( const QString& startDir, QString& recentDirClass );
+
+
 signals:
     /**
       * Emitted when the user selects a file. It is only emitted in single-
@@ -677,6 +785,12 @@ protected:
      **/
     void addDirEntry(KFileItem *entry, bool disableUpdating);
 
+    /**
+      * Perform basic initialization tasks. Called by constructors.
+      * @since 3.1
+      */
+    void init(const QString& startDir, const QString& filter, QWidget* widget);
+
     /**
       * rebuild geometry managment.
       *
@@ -722,7 +836,12 @@ protected slots:
     void enterURL( const KURL& url );
     void enterURL( const QString& url );
     void locationActivated( const QString& url );
+
+    /**
+     * @deprecated
+     */
     void toolbarCallback(int);
+
     void slotFilterChanged();
     void pathComboChanged( const QString& );
     void fileHighlighted(const KFileItem *i);
@@ -732,17 +851,27 @@ protected slots:
 
     void dirCompletion( const QString& );
     void fileCompletion( const QString& );
+    /**
+     * @since 3.1
+     */
+    void toggleSpeedbar( bool );
 
+    /**
+     * @deprecated
+     */
     virtual void updateStatusLine(int dirs, int files);
+
     virtual void slotOk();
     virtual void accept();
     virtual void slotCancel();
 
     void addToRecentDocuments();
+    void initSpeedbar();
 
 private:
     KFileDialog(const KFileDialog&);
     KFileDialog operator=(const KFileDialog&);
+    static void initStatic();
 
 protected:
     KDirOperator *ops;
