@@ -43,6 +43,9 @@ public:
 		       const QPixmap &pixmap,
 		       KFileItem *fi )
 	: KIconViewItem( parent, text, pixmap ), inf( fi ) {}
+    /**
+     * @since 3.1
+     */
     KFileIconViewItem( QIconView *parent, KFileItem *fi )
 	: KIconViewItem( parent ), inf( fi ) {}
 
@@ -142,6 +145,12 @@ public slots:
      * into 'large rows' mode, if that isn't the current mode yet.
      */
     void showPreviews();
+    
+    /**
+     * Reimplemented for performance reasons.
+     * @since 3.1
+     */
+    virtual void arrangeItemsInGrid( bool updated = true );
 
 protected:
     /**
@@ -158,7 +167,7 @@ protected:
     virtual void showEvent( QShowEvent * );
 
     virtual bool eventFilter( QObject *o, QEvent *e );
-    
+
 private slots:
     void selected( QIconViewItem *item );
     void slotActivate( QIconViewItem * );
@@ -187,6 +196,7 @@ private:
     virtual void setSelected(QIconViewItem *i, bool a, bool b) { KIconView::setSelected(i, a, b); }
 
     bool canPreview( const KFileItem * ) const;
+    int iconSizeFor( const KFileItem * ) const;
     void stopPreview();
 
     void updateIcons();
@@ -197,7 +207,8 @@ private:
         return 0L;
     }
 
-    void initItem(KFileIconViewItem *item, const KFileItem *i );
+    void initItem(KFileIconViewItem *item, const KFileItem *i,
+                  bool updateTextAndPixmap );
 
 protected:
     virtual void virtual_hook( int id, void* data );
