@@ -20,7 +20,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: kopenwith.cpp,v 1.66.2.4 2003/02/19 17:10:25 waba Exp $
+// $Id: kopenwith.cpp,v 1.66.2.5 2003/06/29 21:43:01 deller Exp $
 
 #include <qfile.h>
 #include <qdir.h>
@@ -584,7 +584,7 @@ void KOpenWithDlg::slotOK()
   if (terminal->isChecked()) {
     KSimpleConfig conf(QString::fromLatin1("konquerorrc"), true);
     conf.setGroup(QString::fromLatin1("Misc Defaults"));
-    m_command = conf.readEntry(QString::fromLatin1("Terminal"), QString::fromLatin1("konsole"));
+    m_command = conf.readPathEntry(QString::fromLatin1("Terminal"), QString::fromLatin1("konsole"));
 
     m_command += QString::fromLatin1(" -e ");
     m_command += edit->url();
