@@ -20,7 +20,7 @@
 */
 
 #ifndef __connection_h__
-#define __connection_h__ "$Id: connection.h,v 1.28 2002/06/19 17:46:00 domi Exp $"
+#define __connection_h__ "$Id: connection.h,v 1.28.2.1 2003/05/17 11:19:22 mueller Exp $"
 
 #include <sys/types.h>
 
@@ -108,6 +108,6 @@ namespace KIO {
 	class ConnectionPrivate* d;
     };
 
-};
+}
 
 #endif
