@@ -40,11 +40,11 @@ namespace KIO { class Job; class ListJob; }
  * (icon container, tree view, ...) and it stores the items (as KFileItems).
  *
  * Typical usage :
- * Create an instance.
- * Connect to at least update, clear, newItem, and deleteItem.
- * Call openURL - the signals will be called.
- * Reuse the instance when opening a new url (openURL).
- * Destroy the instance when not needed anymore (usually destructor).
+ * @li Create an instance.
+ * @li Connect to at least update, clear, newItem, and deleteItem.
+ * @li Call openURL - the signals will be called.
+ * @li Reuse the instance when opening a new url (openURL).
+ * @li Destroy the instance when not needed anymore (usually destructor).
  *
  * Advanced usage : call openURL with _keep = true to list directories
  * without forgetting the ones previously read (e.g. for a tree view)
@@ -67,6 +67,8 @@ class KDirLister : public QObject
 public:
   /**
    * Create a directory lister.
+   * @param _delayedMimeTypes if true, mime types will be fetched on demand. If false,
+   *                          they will always be fetched immediately
    */
   KDirLister( bool _delayedMimeTypes = false );
 
@@ -79,9 +81,13 @@ public:
    * Run the directory lister on the given url.
    *
    * This method causes KDirLister to emit _all_ the items of @p _url, in any case.
-   * Depending on @p _keep either clear() or clear( const KURL & ) will be
+   * Depending on @p _keep either @ref clear() or @ref clear(const KURL &) will be
    * emitted first.
    *
+   * The @ref newItems() signal may be emitted more than once to supply you
+   * with KFileItems, up until the signal @ref completed() is emitted
+   * (and @ref isFinished() returns true).
+   *
    * @param _url          the directory URL.
    * @param _keep         if true the previous directories aren't forgotten
    *                      (they are still watched by kdirwatch and their items
@@ -91,10 +97,7 @@ public:
    *                      directory from the disk.
    *                      Use only when opening a dir not yet listed by this lister
    *                      without using the cache. Otherwise use updateDirectory.
-   *
-   * The @ref newItems() signal may be emitted more than once to supply you
-   * with KFileItems, up until the signal @ref completed() is emitted
-   * (and @ref isFinished() returns true).
+   * @return true if successful, false otherwise (e.g. invalid @p _url)
    */
   virtual bool openURL( const KURL& _url, bool _keep = false, bool _reload = false );
 
@@ -119,54 +122,86 @@ public:
   virtual void stop( const KURL& _url );
 
   /**
-   * @return whether KDirWatch is used to automatically update directories.
-   * This is enabled by default.
+   * Checks whether KDirWatch will automatically update directories. This is
+   * enabled by default.
+   * @return true if KDirWatch is used to automatically update directories.
    */
   bool autoUpdate() const;
 
   /**
    * Enable/disable automatic directory updating, when a directory changes
    * (using KDirWatch).
+   * @param enable true to enable, false to disable
    */
   virtual void setAutoUpdate( bool enable );
 
   /**
-   * Error handling.
+   * Check whether auto error handling is enabled.
+   * If enabled, it will show an error dialog to the user when an
+   * error occurs. It is turned on by default.
+   * @return true if auto error handling is enabled, false otherwise
+   * @see setAutoErrorHandlingEnabled()
    */
   bool autoErrorHandlingEnabled() const;
+
+  /**
+   * Enable or disable auto error handling is enabled.
+   * If enabled, it will show an error dialog to the user when an
+   * error occurs. It is turned on by default.
+   * @param enable true to enable auto error handling, false to disable
+   * @param parent the parent widget for the error dialogs, can be 0 for
+   *               top-level
+   * @see autoErrorHandlingEnabled()
+   */
   void setAutoErrorHandlingEnabled( bool enable, QWidget* parent );
 
   /**
-   * @return whether dotfiles are shown
+   * Checks whether hidden files (files beginning with a dot) will be
+   * shown.
+   * By default this option is disabled (hidden files will be not shown).
+   * @return true if dot files are shown, false otherwise
+   * @see setShowingDotFiles()
    */
   bool showingDotFiles() const;
 
   /**
    * Changes the "is viewing dot files" setting.
-   * Calls @ref updateDirectory() if setting changed
+   * Calls @ref updateDirectory() if setting changed.
+   * By default this option is disabled (hidden files will not be shown).
+   * @param _showDotFiles true to enable showing hidden files, false to
+   *        disable
+   * @see showingDotFiles()
    */
   virtual void setShowingDotFiles( bool _showDotFiles );
 
   /**
+   * Checks whether the KDirLister only lists directories or all
+   * files.
+   * By default this option is disabled (all files will be shown).
    * @return true if setDirOnlyMode(true) was called
    */
   bool dirOnlyMode() const;
 
   /**
-   * Call this with @p dirsOnly == true to list only directories
+   * Call this to list only directories.
+   * By default this option is disabled (all files will be shown).
+   * @param dirsOnly true to list only directories
    */
   virtual void setDirOnlyMode( bool dirsOnly );
 
   /**
-   * @return the url used by this instance to list the files, with _keep == true,
-   *         this is the first url opened (in e.g. a treeview this is the root).
-   * It might be different from the one given with @ref openURL() or @ref setURL()
-   * if there was a redirection.
+   * Returns the URL that is listed by this KDirLister.
+   * It might be different from the one given with @ref openURL().
+   * if there was a redirection. If you called @ref openURL() with
+   * @p _keep == true, this is the first url opened (in e.g. a treeview this is
+   * the root).
+   *
+   * @return the url used by this instance to list the files.
    */
   const KURL& url() const;
 
   /**
-   * actually emit the changes made with setShowingDotFiles, setDirOnlyMode,
+   * Actually emit the changes made with setShowingDotFiles, setDirOnlyMode,
    * setNameFilter and setMimeFilter.
    */
   virtual void emitChanges();
@@ -186,16 +221,18 @@ public:
 
   /**
    * Returns true if no io operation is currently in progress.
+   * @return true if finished, false otherwise
    */
   bool isFinished() const;
 
   /**
+   * Returns the file item of the URL.
    * @return the file item for url() itself (".")
    */
   KFileItem* rootItem() const;
 
   /**
-   * Find an item by its URL
+   * Find an item by its URL.
    * @param _url the item URL
    * @return the pointer to the KFileItem
    */
@@ -205,7 +242,7 @@ public:
 #endif
 
   /**
-   * Find an item by its name
+   * Find an item by its name.
    * @param name the item name
    * @return the pointer to the KFileItem
    */
@@ -216,30 +253,32 @@ public:
    *
    * You can set more than one filter by separating them with whitespace, e.g
    * "*.cpp *.h".
-   * Call setNameFilter( QString::null ) to disable filtering.
    * Note: the direcory is not automatically reloaded.
    *
+   * @param filer the new filter, QString::null to disable filtering
    * @see #matchesFilter
    */
-  virtual void setNameFilter( const QString& );
+  virtual void setNameFilter( const QString &filter );
 
   /**
-   * @return the current name filter, as set via @ref setNameFilter()
+   * Returns the current name filter, as set via @ref setNameFilter()
+   * @return the current name filter, can be QString::null if filtering
+   *         is turned off
    */
   const QString& nameFilter() const;
 
   /**
-   * Set mime-based filter to only list items matching the given mimetypes
+   * Set mime-based filter to only list items matching the given mimetypes.
    *
    * NOTE: setting the filter does not automatically reload direcory.
    * Also calling this function will not affect any named filter already set.
    *
+   * @param mimeList a list of mime-types.
+   *
    * @see #clearMimeFilter
    * @see #matchesMimeFilter
-   *
-   * @param a list of mime-types.
    */
-  virtual void setMimeFilter( const QStringList& );
+  virtual void setMimeFilter( const QStringList &mimeList );
 
   /**
    * Filtering should be done with KFileFilter. This will be implemented in a later
@@ -250,14 +289,13 @@ public:
    * NOTE: setting the filter does not automatically reload direcory.
    * Also calling this function will not affect any named filter already set.
    *
+   * @param mimeList a list of mime-types.
    * @see #clearMimeFilter
    * @see #matchesMimeFilter
-   *
-   * @param a list of mime-types.
    * @since 3.1
    * @internal
    */
-  void setMimeExcludeFilter(const QStringList &);
+  void setMimeExcludeFilter(const QStringList &mimeList );
 
 
   /**
@@ -268,12 +306,13 @@ public:
   virtual void clearMimeFilter();
 
   /**
-   * @return the list of mime based filters, as set via @ref setMimeFilter().
-   * Empty, when no mime filter is set.
+   * Returns the list of mime based filters, as set via @ref setMimeFilter().
+   * @return the list of mime based filters. Empty, when no mime filter is set.
    */
   const QStringList& mimeFilters() const;
 
   /**
+   * Checks whether @p name matches a filter in the list of name filters.
    * @return true if @p name matches a filter in the list,
    * otherwise false.
    * @see #setNameFilter
@@ -281,29 +320,31 @@ public:
   bool matchesFilter( const QString& name ) const;
 
   /**
+   * Checks whether @p mime matches a filter in the list of mime types
+   * @param mime the mimetype to find in the filter list.
    * @return true if @p name matches a filter in the list,
    * otherwise false.
-   * @see #setNameFilter.
-   *
-   * @param mime the mimetype to find in the filter list.
+   * @see #setMimeFilter.
    */
   bool matchesMimeFilter( const QString& mime ) const;
 
   /**
    * Pass the main window this object is associated with
    * this is used for caching authentication data
+   * @param window the window to associate with, 0 to disassociate
    * @since 3.1
    */
   void setMainWindow(QWidget *window);
 
   /**
    * Returns the main window associated with this object.
+   * @return the associated main window, or 0 if there is none
    * @since 3.1
    */
   QWidget *mainWindow();
 
   /**
-   * Used by @ref items() and @ref itemsForDir() to specify whether you want 
+   * Used by @ref items() and @ref itemsForDir() to specify whether you want
    * all items for a directory or just the filtered ones.
    */
   enum WhichItems
@@ -357,12 +398,13 @@ public:
 
 signals:
   /**
-   * Tell the view that we started to list _url. NOTE: this does _not_ imply that there
+   * Tell the view that we started to list @p _url. NOTE: this does _not_ imply that there
    * is really a job running! I.e. KDirLister::jobs() may return an empty list. In this case
    * the items are taken from the cache.
    *
    * The view knows that openURL should start it, so it might seem useless,
    * but the view also needs to know when an automatic update happens.
+   * @param _url the URL to list
    */
   void started( const KURL& _url );
 
@@ -395,12 +437,15 @@ signals:
   /**
    * Signal a redirection.
    * Only emitted if there's just one directory to list, i.e. most
-   * probably _keep == false
+   * probably @ref openURL() has been called with @p_keep == false.
+   * @param _url the new URL
    */
   void redirection( const KURL& _url );
 
   /**
    * Signal a redirection.
+   * @param oldUrl the original URL
+   * @param newUrl the new URL
    */
   void redirection( const KURL& oldUrl, const KURL& newUrl );
 
@@ -411,61 +456,71 @@ signals:
   void clear();
 
   /**
-   * Signal to empty the directory _url.
+   * Signal to empty the directory @p _url.
    * It is only emitted if the lister is holding more than one directory.
+   * @param _url the directory that will be emptied
    */
   void clear( const KURL& _url );
 
   /**
    * Signal new items.
+   * @param items a list of new items
    */
   void newItems( const KFileItemList& items );
 
   /**
    * Send a list of items filtered-out by mime-type.
+   * @param items the list of filtered items
    */
   void itemsFilteredByMime( const KFileItemList& items );
 
   /**
    * Signal an item to remove.
    *
-   * ATTENTION: if @p _fileItem == @p rootItem() the directory this lister
+   * ATTENTION: if @p _fileItem == @ref rootItem() the directory this lister
    *            is holding was deleted and you HAVE to release especially the
-   *            rootItem of this lister otherwise your app will CRASH!!
-   *            The clear() signals have been emitted already.
+   *            @ref rootItem() of this lister, otherwise your app will CRASH!!
+   *            The @ref clear() signals have been emitted already.
+   * @param the fileItem to delete
    */
   void deleteItem( KFileItem *_fileItem );
 
   /**
-   * Signal an item to refresh (its mimetype/icon/name has changed)
+   * Signal an item to refresh (its mimetype/icon/name has changed).
    * Note: KFileItem::refresh has already been called on those items.
+   * @param items the items to refresh
    */
   void refreshItems( const KFileItemList& items );
 
   /**
    * Emitted to display information about running jobs.
    * Examples of message are "Resolving host", "Connecting to host...", etc.
+   * @param msg the info message
    */
   void infoMessage( const QString& msg );
 
   /**
    * Progress signal showing the overall progress of the KDirLister.
    * This allows using a progress bar very easily. (see @ref KProgress)
+   * @param percent the progress in percent
    */
   void percent( int percent );
 
   /**
    * Emitted when we know the size of the jobs.
+   * @param size the total size in bytes
    */
   void totalSize( KIO::filesize_t size );
 
   /**
    * Regularly emitted to show the progress of this KDirLister.
+   * @param size the processed size in bytes
    */
   void processedSize( KIO::filesize_t size );
 
   /**
    * Emitted to display information about the speed of the jobs.
+   * @param bytes_per_second the speed in bytes/s
    */
   void speed( int bytes_per_second );
 
@@ -476,27 +531,50 @@ protected:
 
   /**
    * Called for every new item before emitting @ref newItems().
-   * @return true if the item is "ok".
-   * @return false if the item shall not be shown in a view, e.g.
-   * files not matching a pattern *.cpp (@ref KFileItem::isHidden())
    * You may reimplement this method in a subclass to implement your own
    * filtering.
    * The default implementation filters out ".." and everything not matching
    * the name filter(s)
+   * @return true if the item is "ok".
+   *         false if the item shall not be shown in a view, e.g.
+   * files not matching a pattern *.cpp (@ref KFileItem::isHidden())
    * @see #matchesFilter
    * @see #setNameFilter
    */
   virtual bool matchesFilter( const KFileItem * ) const;
 
+  /**
+   * Called for every new item before emitting @ref newItems().
+   * You may reimplement this method in a subclass to implement your own
+   * filtering.
+   * The default implementation filters out ".." and everything not matching
+   * the name filter(s)
+   * @return true if the item is "ok".
+   *         false if the item shall not be shown in a view, e.g.
+   * files not matching a pattern *.cpp (@ref KFileItem::isHidden())
+   * @see #matchesMimeFilter
+   * @see #setMimeFilter
+   */
   virtual bool matchesMimeFilter( const KFileItem * ) const;
 
   /**
-   * Called by the public matchesFilter/matchesMimeFilter to do the
+   * Called by the public @ref matchesFilter() to do the
    * actual filtering. Those methods may be reimplemented to customize
    * filtering.
+   * @param name the name to filter
+   * @param filers a list of regular expressions for filtering
    */
   virtual bool doNameFilter( const QString& name, const QPtrList<QRegExp>& filters ) const;
+
+  /**
+   * Called by the public @ref matchesMimeFilter() to do the
+   * actual filtering. Those methods may be reimplemented to customize
+   * filtering.
+   * @param mime the mime type to filter
+   * @param filters the list of mime types to filter
+   */
   virtual bool doMimeFilter( const QString& mime, const QStringList& filters ) const;
+
   /**
    * @internal
    */
@@ -522,8 +600,10 @@ private slots:
   void slotProcessedSize( KIO::Job *, KIO::filesize_t );
   void slotSpeed( KIO::Job *, unsigned long );
 
-  void slotJobToBeKilled( const KURL& );
-  void slotClearState();
+private:
+  void jobDone( KIO::ListJob *);
+  void jobStarted( KIO::ListJob *);
+  uint numJobs();
 
 private:
   virtual void addNewItem( const KFileItem *item );
