@@ -17,12 +17,12 @@
 class KDirWatchPrivate : public QObject
 {
   Q_OBJECT
+public:
 
   enum entryStatus { Normal = 0, NonExistent };
   enum entryMode { UnknownMode = 0, StatMode, DNotifyMode, FAMMode };
   enum { NoChange=0, Changed=1, Created=2, Deleted=4 };
 
-public:
   struct Client {
     KDirWatch* instance;
     int count;
@@ -85,10 +85,15 @@ public:
   int scanEntry(Entry* e);
   void emitEvent(Entry* e, int event, const QString &fileName = QString::null);
 
+  // Memory management - delete when last KDirWatch gets deleted
+  void ref() { m_ref++; }
+  bool deref() { return ( --m_ref == 0 ); }
+
 public slots:
   void slotRescan();
   void famEventReceived(); // for FAM
   void slotActivated(); // for DNOTIFY
+  void slotRemoveDelayed();
 
 public:
   QTimer *timer;
@@ -98,6 +103,7 @@ private:
   int freq;
   int statEntries;
   int m_nfsPollInterval, m_PollInterval;
+  int m_ref;
   bool useStat(Entry*);
 
   bool delayRemove;
@@ -114,12 +120,14 @@ private:
 
 #ifdef HAVE_DNOTIFY
   bool supports_dnotify;
+  bool rescan_all;
   int mPipe[2];
   QTimer mTimer;
   QSocketNotifier *mSn;
   QIntDict<Entry> fd_Entry;
 
   static void dnotify_handler(int, siginfo_t *si, void *);
+  static void dnotify_sigio_handler(int, siginfo_t *si, void *);
   bool useDNotify(Entry*);
 #endif
 };
