@@ -17,16 +17,22 @@
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  *
- *  $Id: kfilemetainfo.h,v 1.47.2.2 2002/12/14 04:20:39 pfeiffer Exp $
+ *  $Id: kfilemetainfo.h,v 1.47.2.3 2003/01/29 18:21:58 mcamen Exp $
  */
 #ifndef KILEMETAINFO_H
 #define KILEMETAINFO_H
 
+/* Hack for HPUX: Namespace pollution
+   m_unit is a define in <sys/sysmacros.h> */
+#define m_unit outouftheway_m_unit
+
 #include <qdict.h>
 #include <qvariant.h>
 #include <qobject.h>
 #include <qstring.h>
 
+#undef m_unit
+
 class QValidator;
 class KFilePlugin;
 class KFileMetaInfoGroup;
