@@ -496,7 +496,7 @@ QStringList KRun::processDesktopExec(const KService &_service, const KURL::List&
   }
 
   KConfigGroupSaver gs(KGlobal::config(), "General");
-  QString terminal = KGlobal::config()->readEntry("TerminalApplication", "konsole");
+  QString terminal = KGlobal::config()->readPathEntry("TerminalApplication", "konsole");
   
   if (terminal == "konsole")
     terminal += " -caption=%c %i %m";
@@ -597,8 +597,15 @@ static pid_t runCommandInternal( KProcess* proc, const KService* service, const
   if( startup_notify )
   {
       KStartupInfoData data;
-      data.addPid( pid );
-      KStartupInfo::sendChange( id, data );
+      if ( pid ) // successfully started
+      {
+          data.addPid( pid );
+          KStartupInfo::sendChange( id, data );
+      } else // not started (e.g. executable not found)
+      {
+          data.setHostname();
+          KStartupInfo::sendFinish( id, data );
+      }
       KStartupInfo::resetStartupEnv();
   }
   return pid;
@@ -636,6 +643,7 @@ static pid_t runTempService( const KService& _service, const KURL::List& _urls,
   {
       args = KRun::processDesktopExec(_service, _urls, false, tempFiles);
   }
+  //kdDebug(7010) << "runTempService: KProcess args=" << args << endl;
 
   KProcess * proc = new KProcess;
   for(QStringList::Iterator it = args.begin();
@@ -655,7 +663,8 @@ pid_t KRun::run( const KService& _service, const KURL::List& _urls )
 
 pid_t KRun::run( const KService& _service, const KURL::List& _urls, bool tempFiles )
 {
-  if (!KDesktopFile::isAuthorizedDesktopFile( _service.desktopEntryPath()))
+  if (!_service.desktopEntryPath().isEmpty() &&
+      !KDesktopFile::isAuthorizedDesktopFile( _service.desktopEntryPath()))
   {
      KMessageBox::sorry(0, i18n("You are not authorized to execute this service."));
      return 0;
