@@ -17,7 +17,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-// $Id: kservice.cpp,v 1.125 2002/11/22 01:28:43 antlarr Exp $
+// $Id: kservice.cpp,v 1.125.2.2 2003/07/09 16:11:28 waba Exp $
 
 #include <config.h>
 
@@ -74,7 +74,6 @@ KService::KService( const QString & _name, const QString &_exec, const QString &
 KService::KService( const QString & _fullpath )
  : KSycocaEntry( _fullpath)
 {
-  d = new KServicePrivate;
   KDesktopFile config( _fullpath );
 
   init(&config);
@@ -173,7 +172,7 @@ KService::init( KDesktopFile *config )
   if (pos != -1)
      name = name.left(pos);
 
-  m_strExec = config->readEntry( "Exec" );
+  m_strExec = config->readPathEntry( "Exec" );
   entryMap.remove("Exec");
   m_strName = config->readEntry( "Name" );
   //kdDebug() << "parsing " << entryPath() << " Name=" << m_strName << endl;
@@ -190,7 +189,7 @@ KService::init( KDesktopFile *config )
   entryMap.remove("Terminal");
   m_strTerminalOptions = config->readEntry( "TerminalOptions" ); // should be a property IMHO
   entryMap.remove("TerminalOptions");
-  m_strPath = config->readEntry( "Path" );
+  m_strPath = config->readPathEntry( "Path" );
   entryMap.remove("Path");
   m_strComment = config->readEntry( "Comment" );
   entryMap.remove("Comment");
