@@ -16,7 +16,7 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-// $Id: kservicegroup.cpp,v 1.19 2002/03/04 04:17:37 lunakl Exp $
+// $Id: kservicegroup.cpp,v 1.25 2002/11/19 21:07:31 bausi Exp $
 
 #include <kiconloader.h>
 #include <kglobal.h>
@@ -30,10 +30,24 @@
 #include "kservice.h"
 #include "ksycoca.h"
 
+class KServiceGroup::Private
+{
+public:
+  Private() { m_bNoDisplay = false; }
+  bool m_bNoDisplay;
+};
+
+KServiceGroup::KServiceGroup( const QString & name )
+ : KSycocaEntry(name), m_childCount(-1)
+{
+  d = new KServiceGroup::Private;
+  m_bDeleted = false;
+}
 
 KServiceGroup::KServiceGroup( const QString &configFile, const QString & _relpath )
  : KSycocaEntry(_relpath), m_childCount(-1)
 {
+  d = new KServiceGroup::Private;
   m_bDeleted = false;
 
   if (!configFile.isEmpty())
@@ -46,6 +60,7 @@ KServiceGroup::KServiceGroup( const QString &configFile, const QString & _relpat
      m_strIcon = config.readEntry( "Icon" );
      m_strComment = config.readEntry( "Comment" );
      m_bDeleted = config.readBoolEntry( "Hidden", false );
+     d->m_bNoDisplay = config.readBoolEntry( "NoDisplay", false );
      m_strBaseGroupName = config.readEntry( "X-KDE-BaseGroup" );
   }
   // Fill in defaults.
@@ -65,12 +80,14 @@ KServiceGroup::KServiceGroup( const QString &configFile, const QString & _relpat
 KServiceGroup::KServiceGroup( QDataStream& _str, int offset, bool deep ) :
     KSycocaEntry( _str, offset )
 {
+  d = new KServiceGroup::Private;
   m_bDeep = deep;
   load( _str );
 }
 
 KServiceGroup::~KServiceGroup()
 {
+  delete d;
 }
 
 int KServiceGroup::childCount()
@@ -100,12 +117,20 @@ int KServiceGroup::childCount()
 }
 
 
+bool KServiceGroup::noDisplay() const
+{
+    return d->m_bNoDisplay;
+}
+
 void KServiceGroup::load( QDataStream& s )
 {
   QStringList groupList;
-
+  Q_INT8 noDisplay;
   s >> m_strCaption >> m_strIcon >>
-       m_strComment >> groupList >> m_strBaseGroupName >> m_childCount;
+      m_strComment >> groupList >> m_strBaseGroupName >> m_childCount >>
+      noDisplay;
+
+  d->m_bNoDisplay = (noDisplay != 0);
 
   if (m_bDeep)
   {
@@ -161,8 +186,10 @@ void KServiceGroup::save( QDataStream& s )
 
   (void) childCount();
 
+  Q_INT8 noDisplay = d->m_bNoDisplay ? 1 : 0;
   s << m_strCaption << m_strIcon <<
-       m_strComment << groupList << m_strBaseGroupName << m_childCount;
+      m_strComment << groupList << m_strBaseGroupName << m_childCount <<
+      noDisplay;
 }
 
 KServiceGroup::List
@@ -200,26 +227,30 @@ KServiceGroup::entries(bool sort, bool excludeNoDisplay)
     KSortableValueList<SPtr,QCString> glist;
     for (List::ConstIterator it(group->m_serviceList.begin()); it != group->m_serviceList.end(); ++it)
     {
+        KSycocaEntry *p = (*it);
         // Choose the right list
-        KSortableValueList<SPtr,QCString> & list = (*it)->isType(KST_KServiceGroup) ? glist : slist;
-        QCString key( (*it)->name().length() * 4 + 1 );
-        // strxfrm() crashes on Solaris 
+        KSortableValueList<SPtr,QCString> & list = p->isType(KST_KServiceGroup) ? glist : slist;
+        QString name = p->isType(KST_KServiceGroup) ? 
+                                   static_cast<KServiceGroup *>(p)->caption() :
+                                   p->name();
+        QCString key( name.length() * 4 + 1 );
+        // strxfrm() crashes on Solaris
 #ifndef USE_SOLARIS
         // maybe it'd be better to use wcsxfrm() where available
-        size_t ln = strxfrm( key.data(), (*it)->name().local8Bit().data(), key.size());
+        size_t ln = strxfrm( key.data(), name.local8Bit().data(), key.size());
         if( ln != size_t( -1 ))
         {
             if( ln >= key.size())
             { // didn't fit?
                 key.resize( ln + 1 );
-                if( strxfrm( key.data(), (*it)->name().local8Bit().data(), key.size()) == size_t( -1 ))
-                    key = (*it)->name().local8Bit();
+                if( strxfrm( key.data(), name.local8Bit().data(), key.size()) == size_t( -1 ))
+                    key = name.local8Bit();
             }
         }
         else
 #endif
         {
-            key = (*it)->name().local8Bit();
+            key = name.local8Bit();
         }
         list.insert(key,SPtr(*it));
     }
@@ -229,7 +260,15 @@ KServiceGroup::entries(bool sort, bool excludeNoDisplay)
 
     List lsort;
     for(KSortableValueList<SPtr,QCString>::ConstIterator it = glist.begin(); it != glist.end(); ++it)
+    {
+        if (excludeNoDisplay)
+        {
+           KServiceGroup *serviceGroup = (KServiceGroup *)((KSycocaEntry *)((*it).value()));
+           if (serviceGroup->noDisplay())
+              continue;
+        }
         lsort.append((*it).value());
+    }
     for(KSortableValueList<SPtr,QCString>::ConstIterator it = slist.begin(); it != slist.end(); ++it)
     {
         if (excludeNoDisplay)
@@ -307,6 +346,13 @@ KServiceGroup::group(const QString &relPath)
    return KServiceGroupFactory::self()->findGroupByDesktopPath(relPath, true);
 }
 
+KServiceGroup::Ptr
+KServiceGroup::childGroup(const QString &parent)
+{
+   return KServiceGroupFactory::self()->findGroupByDesktopPath("#parent#"+parent, true);
+}
+
+
+
 void KServiceGroup::virtual_hook( int id, void* data )
 { KSycocaEntry::virtual_hook( id, data ); }
-
