@@ -90,9 +90,8 @@ namespace KIO {
 
     private:
         void determineNextFile();
-        void emitPreview(const QPixmap &pix);
+        void emitPreview(const QImage &thumb);
         void emitFailed(const KFileItem *item = 0);
-        void saveThumbnail(const QByteArray &imgData);
 
     protected:
 	virtual void virtual_hook( int id, void* data );
@@ -124,6 +123,6 @@ namespace KIO {
      * Same as above, but takes a URL list instead of KFileItemList
      */
     PreviewJob *filePreview( const KURL::List &items, int width, int height = 0, int iconSize = 0, int iconAlpha = 70, bool scale = true, bool save = true, const QStringList *enabledPlugins = 0 );
-};
+}
 
 #endif
