@@ -24,6 +24,9 @@
 #include "kio/slave.h"
 #include <qptrlist.h>
 #include <qdict.h>
+
+#include <dcopclient.h>
+
 #include <kdebug.h>
 #include <kglobal.h>
 #include <kprotocolmanager.h>
@@ -121,11 +124,11 @@ KIO::Scheduler::ProtocolInfoDict::get(const QString &protocol)
 
 
 Scheduler::Scheduler()
-          :QObject(0, "scheduler"),
+          :QObject(kapp, "scheduler"),
            DCOPObject( "KIO::Scheduler" ),
-           slaveTimer(this, "Scheduler::slaveTimer"),
-           coSlaveTimer(this, "Scheduler::coSlaveTimer"),
-           cleanupTimer(this, "Scheduler::cleanupTimer")
+           slaveTimer(0, "Scheduler::slaveTimer"),
+           coSlaveTimer(0, "Scheduler::coSlaveTimer"),
+           cleanupTimer(0, "Scheduler::cleanupTimer")
 {
     checkOnHold = true; // !! Always check with KLauncher for the first request.
     slaveOnHold = 0;
@@ -144,8 +147,6 @@ Scheduler::Scheduler()
 
 Scheduler::~Scheduler()
 {
-    //fprintf(stdout, "Destructing KIO::Scheduler...\n");
-
     protInfoDict->setAutoDelete(true);
     delete protInfoDict; protInfoDict = 0;
     delete idleSlaves; idleSlaves = 0;
@@ -589,7 +590,7 @@ if (!jobData)
           idleSlaves->append(slave);
           slave->setIdle();
           _scheduleCleanup();
-          slave->connection()->send( CMD_SLAVE_STATUS );
+//          slave->connection()->send( CMD_SLAVE_STATUS );
        }
     }
     if (protInfo->joblist.count())
@@ -627,13 +628,13 @@ void Scheduler::slotCleanIdleSlaves()
     {
         if (slave->idleTime() >= MAX_SLAVE_IDLE)
         {
-            // kdDebug(7006) << "Removing idle slave: " << slave->slaveProtocol() << " " << slave->host() << endl;
-            Slave *removeSlave = slave;
-            slave = idleSlaves->next();
-            idleSlaves->removeRef(removeSlave);
-            slaveList->removeRef(removeSlave);
-            removeSlave->connection()->close();
-            removeSlave->deref();
+           // kdDebug(7006) << "Removing idle slave: " << slave->slaveProtocol() << " " << slave->host() << endl;
+           Slave *removeSlave = slave;
+           slave = idleSlaves->next();
+           idleSlaves->removeRef(removeSlave);
+           slaveList->removeRef(removeSlave);
+           removeSlave->connection()->close();
+           removeSlave->deref();
         }
         else
         {
@@ -848,12 +849,54 @@ Scheduler::_checkSlaveOnHold(bool b)
     checkOnHold = b;
 }
 
+void
+Scheduler::_registerWindow(QWidget *wid)
+{
+   if (!wid)
+      return;
 
-static KStaticDeleter<Scheduler> ksds;
+   QObject *obj = static_cast<QObject *>(wid);
+   if (!m_windowList.contains(obj))
+   {
+      // We must store the window Id because by the time
+      // the destroyed signal is emitted we can no longer
+      // access QWidget::winId() (already destructed)
+      long windowId = wid->winId();
+      m_windowList.insert(obj, windowId);
+      connect(wid, SIGNAL(destroyed(QObject *)),
+              this, SLOT(slotUnregisterWindow(QObject*)));
+      QByteArray params;
+      QDataStream stream(params, IO_WriteOnly);
+      stream << windowId;
+      if( !kapp->dcopClient()->send( "kded", "kded",
+                    "registerWindowId(long int)", params ) )
+      kdDebug(7006) << "Could not register window with kded!" << endl;
+   }
+}
+
+void
+Scheduler::slotUnregisterWindow(QObject *obj)
+{
+   if (!obj)
+      return;
+
+   QMap<QObject *, long>::Iterator it = m_windowList.find(obj);
+   if (it == m_windowList.end())
+      return;
+   long windowId = it.data();
+   if (kapp)
+   {
+      QByteArray params;
+      QDataStream stream(params, IO_WriteOnly);
+      stream << windowId;
+      kapp->dcopClient()->send( "kded", "kded",
+                    "unregisterWindowId(long int)", params );
+   }
+}
 
 Scheduler* Scheduler::self() {
     if ( !instance ) {
-        instance = ksds.setObject(new Scheduler);
+        instance = new Scheduler;
     }
     return instance;
 }
