@@ -164,7 +164,7 @@ static void (*K_ERR_print_errors_fp)(FILE*) = NULL;
 static int (*K_PKCS7_verify)(PKCS7*,STACK_OF(X509)*,X509_STORE*,BIO*,BIO*,int) = NULL;
 
 #endif
-};
+}
 
 
 bool KOpenSSLProxy::hasLibSSL() const {
@@ -239,7 +239,7 @@ KConfig *cfg;
 
    cfg = new KConfig("cryptodefaults", false, false);
    cfg->setGroup("OpenSSL");
-   QString upath = cfg->readEntry("Path", "");
+   QString upath = cfg->readPathEntry("Path");
    if (!upath.isEmpty())
       libpaths << upath;
 
