@@ -23,7 +23,7 @@
 
 // this hack provided by Malte Starostik to avoid glibc/openssl bug
 // on some systems
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
 #include <unistd.h>
 #include <netinet/in.h>
 #include <sys/socket.h>
@@ -66,7 +66,7 @@ public:
   KSSLCertificate::KSSLValidation m_cert_vfy_res;
   QString proxyPeer;
 
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
     SSL *m_ssl;
     SSL_CTX *m_ctx;
     SSL_METHOD *m_meth;
@@ -80,7 +80,7 @@ KSSL::KSSL(bool init) {
   m_bInit = false;
   m_bAutoReconfig = true;
   m_cfg = new KSSLSettings();
-#ifdef HAVE_SSL  
+#ifdef KSSL_HAVE_SSL  
   d->m_ssl = NULL;
 #endif  
 
@@ -97,7 +97,7 @@ KSSL::~KSSL() {
 
 int KSSL::seedWithEGD() {
 int rc = 0;
-  #ifdef HAVE_SSL
+  #ifdef KSSL_HAVE_SSL
   if (m_cfg->useEGD() && !m_cfg->getEGDPath().isEmpty()) {
     rc = d->kossl->RAND_egd(m_cfg->getEGDPath().latin1());
     if (rc < 0) 
@@ -119,7 +119,7 @@ int rc = 0;
 
 
 bool KSSL::TLSInit() {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   // kdDebug(7029) << "KSSL TLS initialize" << endl;
   if (m_bInit) return false;
 
@@ -152,7 +152,7 @@ return false;
 
 
 bool KSSL::initialize() {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   kdDebug(7029) << "KSSL initialize" << endl;
   if (m_bInit) return false;
 
@@ -203,7 +203,7 @@ return false;
 
 
 void KSSL::close() {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   //kdDebug(7029) << "KSSL close" << endl;
   if (!m_bInit) return;
   if (d->m_ssl) {
@@ -231,7 +231,7 @@ bool KSSL::reInitialize() {
 
 bool KSSL::setVerificationLogic() {
 #if 0
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   //  SSL_set_verify_result(d->m_ssl, X509_V_OK);
   //  SSL_CTX_set_verify(d->m_ctx, SSL_VERIFY_PEER, X509Callback);
 #endif
@@ -240,16 +240,55 @@ bool KSSL::setVerificationLogic() {
 }
 
 
+int KSSL::accept(int sock) {
+#ifdef KSSL_HAVE_SSL
+  // kdDebug(7029) << "KSSL accept" << endl;
+  int rc;
+  if (!m_bInit) return -1;
+  d->m_ssl = d->kossl->SSL_new(d->m_ctx);
+  if (!d->m_ssl) return -1;
+
+/*
+  if (!setVerificationLogic())
+    return -1;
+*/
+
+  if (!d->lastInitTLS)
+    d->kossl->SSL_set_options(d->m_ssl, SSL_OP_NO_TLSv1);
+  d->kossl->SSL_set_options(d->m_ssl, SSL_OP_ALL);
+
+  rc = d->kossl->SSL_set_fd(d->m_ssl, sock);
+  if (rc == 0) return rc;
+
+  rc = d->kossl->SSL_accept(d->m_ssl);
+  if (rc == 1) {
+    setConnectionInfo();
+    setPeerInfo();
+    kdDebug(7029) << "KSSL connected OK" << endl;
+  } else {
+    kdDebug(7029) << "KSSL accept failed - rc = " << rc << endl;
+    kdDebug(7029) << "                      ERROR = " << d->kossl->SSL_get_error(d->m_ssl, rc) << endl;
+    return -1;
+  }
+  return rc;
+#else
+  return -1;
+#endif
+}
+
+
 int KSSL::connect(int sock) {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   // kdDebug(7029) << "KSSL connect" << endl;
   int rc;
   if (!m_bInit) return -1;
   d->m_ssl = d->kossl->SSL_new(d->m_ctx);
   if (!d->m_ssl) return -1;
 
+/*
   if (!setVerificationLogic())
     return -1;
+*/
 
   if (!d->lastInitTLS)
     d->kossl->SSL_set_options(d->m_ssl, SSL_OP_NO_TLSv1);
@@ -277,7 +316,7 @@ int KSSL::connect(int sock) {
 
 
 int KSSL::pending() {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   if (!m_bInit) return -1;
   return d->kossl->SSL_pending(d->m_ssl);
 #else
@@ -287,7 +326,7 @@ int KSSL::pending() {
 
 
 int KSSL::peek(void *buf, int len) {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   if (!m_bInit) return -1;
   return d->kossl->SSL_peek(d->m_ssl, buf, len);
 #else
@@ -297,7 +336,7 @@ int KSSL::peek(void *buf, int len) {
 
 
 int KSSL::read(void *buf, int len) {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   if (!m_bInit) return -1;
 
   int rc = d->kossl->SSL_read(d->m_ssl, (char *)buf, len);
@@ -306,6 +345,8 @@ int KSSL::read(void *buf, int len) {
     kdDebug(7029) << "SSL READ ERROR: " << err << endl;
     if (err != SSL_ERROR_NONE && err != SSL_ERROR_ZERO_RETURN && err != SSL_ERROR_SYSCALL)
       rc = -1;      // OpenSSL returns 0 on error too
+//    else if (err == SSL_ERROR_ZERO_RETURN)
+//      rc = 0;
   }
   return rc;
 #else
@@ -315,7 +356,7 @@ int KSSL::read(void *buf, int len) {
 
 
 int KSSL::write(const void *buf, int len) {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   if (!m_bInit) return -1;
 
   int rc = d->kossl->SSL_write(d->m_ssl, (const char *)buf, len);
@@ -350,7 +391,7 @@ bool KSSL::setSettings(KSSLSettings *settings) {
 }
 
 
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
 bool KSSL::m_bSSLWorks = true;
 #else
 bool KSSL::m_bSSLWorks = false;
@@ -362,9 +403,9 @@ bool KSSL::doesSSLWork() {
 
 
 void KSSL::setConnectionInfo() {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   SSL_CIPHER *sc;
-  char buf[1024];
+  char buf[1024];   // WARNING - is this making us non-thread-safe?  FIXME
 
   buf[0] = 0;  // for safety.
   sc = d->kossl->SSL_get_current_cipher(d->m_ssl);
@@ -386,7 +427,7 @@ void KSSL::setConnectionInfo() {
 
 
 void KSSL::setPeerInfo() {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
   m_pi.setPeerHost(d->proxyPeer);
   m_pi.m_cert.setCert(d->kossl->SSL_get_peer_certificate(d->m_ssl));
   STACK_OF(X509) *xs = d->kossl->SSL_get_peer_cert_chain(d->m_ssl);
@@ -416,7 +457,7 @@ KSSLPeerInfo& KSSL::peerInfo() {
 
 
 bool KSSL::setClientCertificate(KSSLPKCS12 *pkcs) {
-#ifdef HAVE_SSL
+#ifdef KSSL_HAVE_SSL
 	if (!pkcs || !pkcs->getCertificate()) return false;
 
   int rc;
