@@ -1,5 +1,5 @@
 /*
- *  $Id: kproxybindings.cpp,v 1.15 2002/08/01 15:24:51 coolo Exp $
+ *  $Id: kproxybindings.cpp,v 1.15.2.1 2003/04/07 14:32:39 mutz Exp $
  *  KJS-Bindings for Proxy Auto Configuration
  *
  *  Copyright (C) 2000 Malte Starostik <malte@kde.org>
@@ -148,7 +148,9 @@ Value KProxyFunc::call(ExecState *exec, Object &/*thisObj*/, const List &args)
             if (args.size() == 0)
             {
                 char hostname[256];
-                gethostname(hostname, 255);
+		hostname[0] = '\0';
+                if(!gethostname(hostname, sizeof(hostname)))
+		    hostname[sizeof(hostname)-1] = '\0';
                 UString addr = dnsResolve(hostname);
                 if (addr.isNull())
                     result = Undefined();
