@@ -19,7 +19,6 @@
 */
 // -*- mode: c++; c-basic-offset: 4 -*-
 
-#include <qtimer.h>
 #include <qregexp.h>
 
 #include <kconfig.h>
@@ -93,20 +92,25 @@ ProgressItem::ProgressItem( ListProgress* view, QListViewItem *after, QCString a
   m_sAppId = app_id;
   m_iJobId = job_id;
   m_visible = true;
+  m_defaultProgressVisible = true;
 
   // create dialog, but don't show it
   defaultProgress = new KIO::DefaultProgress( false );
   defaultProgress->setOnlyClean( true );
   connect ( defaultProgress, SIGNAL( stopped() ), this, SLOT( slotCanceled() ) );
-
+  connect ( &m_showTimer, SIGNAL( timeout() ), this, SLOT(slotShowDefaultProgress()) );
+  
   if ( showDefault ) {
-    QTimer::singleShot( 500, this, SLOT(slotShowDefaultProgress()) ); // start a 1/2 second timer
+    m_showTimer.start( 500, true );
   }
 }
 
 
 ProgressItem::~ProgressItem() {
-  delete defaultProgress;
+  if (defaultProgress->onlyClean())
+    defaultProgress->finished();
+  else
+    delete defaultProgress;
 }
 
 
@@ -226,6 +230,14 @@ void ProgressItem::setDeleting( const KURL& url ) {
   defaultProgress->slotDeleting( 0, url );
 }
 
+void ProgressItem::setTransferring( const KURL& url ) {
+  setText( listProgress->lv_operation, i18n("Loading") );
+  setText( listProgress->lv_url, url.url() );
+  setText( listProgress->lv_filename, url.fileName() );
+
+  defaultProgress->slotTransferring( 0, url );
+}
+
 void ProgressItem::setStating( const KURL& url ) {
   setText( listProgress->lv_operation, i18n("Examining") );
   setText( listProgress->lv_url, url.url() );
@@ -269,28 +281,55 @@ void ProgressItem::slotCanceled() {
   emit jobCanceled( this );
 }
 
-
+// Called 0.5s after the job has been started
 void ProgressItem::slotShowDefaultProgress() {
-  if ( m_visible )
-    defaultProgress->show();
+  if (defaultProgress)
+  {
+    if ( m_visible && m_defaultProgressVisible )
+      defaultProgress->show();
+    else
+      defaultProgress->hide();      
+  }
 }
 
 void ProgressItem::slotToggleDefaultProgress() {
-  if ( defaultProgress->isVisible() )
-    defaultProgress->hide();
-  else
-    defaultProgress->show();
+  setDefaultProgressVisible( !m_defaultProgressVisible );
 }
 
+// Called when a rename or skip dialog pops up
+// We want to prevent someone from killing the job in the uiserver then
 void ProgressItem::setVisible( bool visible ) {
+  if ( m_visible != visible )
+  {
     m_visible = visible;
-    if ( defaultProgress )
+    updateVisibility();
+  }
+}
+
+// Can be toggled by the user
+void ProgressItem::setDefaultProgressVisible( bool visible ) {
+  if ( m_defaultProgressVisible != visible )
+  {
+    m_defaultProgressVisible = visible;
+    updateVisibility();
+  }
+}
+
+// Update according to state
+void ProgressItem::updateVisibility()
+{
+  if (defaultProgress)
+  {
+    if ( m_visible && m_defaultProgressVisible )
     {
-        if ( visible )
-            defaultProgress->show();
-        else
-            defaultProgress->hide();
+      m_showTimer.start(250, true); // Show delayed
+    }      
+    else
+    {
+      m_showTimer.stop();
+      defaultProgress->hide();
     }
+  }
 }
 
 
@@ -368,9 +407,9 @@ UIServer::UIServer() : KMainWindow(0, ""), DCOPObject("UIServer")
   toolBar()->setBarPos( KToolBar::Left );
 
   // setup statusbar
-  statusBar()->insertItem( i18n(" Files : %1 ").arg( 555 ), ID_TOTAL_FILES);
-  statusBar()->insertItem( i18n(" Size : %1 kB ").arg( "134.56" ), ID_TOTAL_SIZE);
-  statusBar()->insertItem( i18n(" Time : 00:00:00 "), ID_TOTAL_TIME);
+  statusBar()->insertItem( i18n(" Files: %1 ").arg( 555 ), ID_TOTAL_FILES);
+  statusBar()->insertItem( i18n(" Size: %1 kB ").arg( "134.56" ), ID_TOTAL_SIZE);
+  statusBar()->insertItem( i18n(" Time: 00:00:00 "), ID_TOTAL_TIME);
   statusBar()->insertItem( i18n(" %1 kB/s ").arg("123.34"), ID_TOTAL_SPEED);
 
   // setup listview
@@ -399,7 +438,6 @@ UIServer::UIServer() : KMainWindow(0, ""), DCOPObject("UIServer")
 
 UIServer::~UIServer() {
   updateTimer->stop();
-  writeSettings();
 }
 
 
@@ -452,25 +490,26 @@ ProgressItem* UIServer::findItem( int id )
 
 void UIServer::setItemVisible( ProgressItem * item, bool visible )
 {
-  kdDebug(7024) << "setItemVisible " << visible << endl;
   item->setVisible( visible );
   // Check if we were the last one to be visible
-  // or the first one
-  if ( m_bShowList )
-  {
-    QListViewItemIterator it( listProgress );
-    for ( ; it.current(); ++it )
-      if ( ((ProgressItem*)it.current())->isVisible() )
-      {
-        kdDebug(7024) << "show " << endl;
-        listProgress->show();
-        return;
-      }
-    kdDebug(7024) << "hide " << endl;
-    listProgress->hide();
+  // or the first one -> hide/show the list in that case
+  // (Note that the user could have hidden the listview by hand yet, no time)
+  if ( m_bShowList ) {
+      m_bUpdateNewJob = true;
+      slotUpdate();
   }
 }
 
+// Called by Observer when opening a skip or rename dialog
+void UIServer::setJobVisible( int id, bool visible )
+{
+  kdDebug(7024) << "UIServer::setJobVisible id=" << id << " visible=" << visible << endl;
+  ProgressItem *item = findItem( id );
+  Q_ASSERT( item );
+  if ( item )
+      setItemVisible( item, visible );
+}
+
 void UIServer::jobFinished( int id )
 {
   kdDebug(7024) << "UIServer::jobFinished id=" << id << endl;
@@ -622,6 +661,16 @@ void UIServer::deleting( int id, KURL url )
   }
 }
 
+void UIServer::transferring( int id, KURL url )
+{
+  //kdDebug(7024) << "UIServer::transferring " << id << " " << url.url() << endl;
+
+  ProgressItem *item = findItem( id );
+  if ( item ) {
+    item->setTransferring( url );
+  }
+}
+
 void UIServer::creatingDir( int id, KURL dir )
 {
   kdDebug(7024) << "UIServer::creatingDir " << id << " " << dir.url() << endl;
@@ -700,16 +749,22 @@ void UIServer::slotUpdate() {
       break;
     }
 
-  if ( !visible ) {
+  if ( !visible || !m_bShowList ) {
     hide();
     updateTimer->stop();
     return;
   }
 
+  // Calling show() is conditional, so that users can close the window
+  // and it only pops up back when a new job is started
   if (m_bUpdateNewJob)
   {
     m_bUpdateNewJob=false;
     show();
+
+    // Make sure we'll be called back
+    if ( m_bShowList && !updateTimer->isActive() )
+      updateTimer->start( 1000 );
   }
 
   int iTotalFiles = 0;
@@ -736,10 +791,10 @@ void UIServer::slotUpdate() {
   }
 
   // update statusbar
-  statusBar()->changeItem( i18n( " Files : %1 ").arg( iTotalFiles ), ID_TOTAL_FILES);
-  statusBar()->changeItem( i18n( " Size : %1 ").arg( KIO::convertSize( iTotalSize ) ),
+  statusBar()->changeItem( i18n( " Files: %1 ").arg( iTotalFiles ), ID_TOTAL_FILES);
+  statusBar()->changeItem( i18n( " Size: %1 ").arg( KIO::convertSize( iTotalSize ) ),
                            ID_TOTAL_SIZE);
-  statusBar()->changeItem( i18n( " Time : %1 ").arg( totalRemTime.toString() ), ID_TOTAL_TIME);
+  statusBar()->changeItem( i18n( " Time: %1 ").arg( totalRemTime.toString() ), ID_TOTAL_TIME);
   statusBar()->changeItem( i18n( " %1/s ").arg( KIO::convertSize( iTotalSpeed ) ),
                            ID_TOTAL_SPEED);
 
@@ -748,11 +803,11 @@ void UIServer::slotUpdate() {
 void UIServer::setListMode( bool list )
 {
   m_bShowList = list;
-  ProgressItem *item;
   QListViewItemIterator it( listProgress );
   for ( ; it.current(); ++it ) {
-    item = (ProgressItem*) it.current();
-    item->setVisible( !list );
+    // When going to list mode -> hide all progress dialogs
+    // When going back to separate dialogs -> show them all
+    ((ProgressItem*) it.current())->setDefaultProgressVisible( !list );
   }
 
   if (m_bShowList)
@@ -941,15 +996,6 @@ void UIServer::readSettings() {
 }
 
 
-// This is useless IMHO (David)
-void UIServer::writeSettings() {
-  KConfig config("uiserverrc");
-  config.setGroup( "UIServer" );
-
-  config.writeEntry( "ShowList", m_bShowList );
-}
-
-
 void UIServer::cancelCurrent() {
   QListViewItemIterator it( listProgress );
   ProgressItem *item;
@@ -995,12 +1041,11 @@ int main(int argc, char **argv)
     app.disableSessionManagement();
     app.dcopClient()->setDaemonMode( true );
 
-    uiserver =  new UIServer;
+    uiserver = new UIServer;
 
     app.setMainWidget( uiserver );
 
     return app.exec();
 }
 
-
 #include "uiserver.moc"
