@@ -1,4 +1,4 @@
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kaboutdata.h>
 #include <kmessagebox.h>
