@@ -1,4 +1,4 @@
-// $Id: file.cc,v 1.124.2.5 2003/07/24 11:01:43 waba Exp $
+// $Id: file.cc,v 1.124.2.6 2003/09/01 07:42:28 coolo Exp $
 
 #include <config.h>
 
@@ -891,7 +891,13 @@ void FileProtocol::listDir( const KURL& url)
        to see for the user what the problem would be */
     char path_buffer[PATH_MAX];
     getcwd(path_buffer, PATH_MAX - 1);
-    chdir( _path.data() );
+    if ( chdir( _path.data() ) )  {
+        if (errno == EACCES)
+            error(ERR_ACCESS_DENIED, _path);
+        else
+            error(ERR_CANNOT_ENTER_DIRECTORY, _path);
+        finished();
+    }
 
     UDSEntry entry;
     QStrListIterator it(entryNames);
