@@ -17,7 +17,7 @@
     Boston, MA 02111-1307, USA.
 */
 
-// $Id: ftp.cc,v 1.172.2.7 2003/04/05 19:09:02 adawit Exp $
+// $Id: ftp.cc,v 1.172.2.8 2003/09/06 20:53:40 adawit Exp $
 
 #include "ftp.h"
 
@@ -477,9 +477,10 @@ bool Ftp::ftpLogin()
           tempbuf += QString::number(m_port).latin1();
         }
       }
-      kdDebug(7102) << "Sending Login name: " << user << endl;
-      bool loggedIn = (ftpSendCmd( tempbuf, 0 ) &&
-                       !strncmp( rspbuf, "230", 3));
+
+      kdDebug(7102) << "Sending Login name: " << tempbuf << endl;
+
+      bool loggedIn = (ftpSendCmd( tempbuf, 0 ) && !strncmp( rspbuf, "230", 3));
       bool needPass = !strncmp( rspbuf, "331", 3);
       // Prompt user for login info if we do not
       // get back a "230" or "331".
@@ -602,10 +603,29 @@ bool Ftp::ftpSendCmd( const QCString& cmd, int maxretries )
   buf += "\r\n";
 
   if ( cmd.left(4).lower() != "pass" ) // don't print out the password
-    kdDebug(7102) << cmd.data() << endl;
+    kdDebug(7102) << "ftpSendCmd: " << cmd.data() << endl;
+
   int num = KSocks::self()->write(sControl, buf.data(), buf.length());
-  if (num <= 0 )  {
-    error( ERR_COULD_NOT_WRITE, QString::null );
+
+  if (num < 1)  {
+    if (m_bLoggedOn)
+    {
+      error( ERR_CONNECTION_BROKEN, m_host );
+      return false;
+    }
+
+    if( sControl != 0 )
+    {
+      free( nControl );
+      if (ksControl != NULL)
+        delete ksControl;
+      sControl = 0;
+    }
+
+    // If we have not yet logged in, re-establish connection and
+    // attempt to send the command again...
+    if (!connect(m_host, m_port) ||
+        KSocks::self()->write(sControl, buf.data(), buf.length()) < 1)
     return false;
   }
 
@@ -625,14 +645,21 @@ bool Ftp::ftpSendCmd( const QCString& cmd, int maxretries )
       if (!m_bLoggedOn)
       {
         kdDebug(7102) << "Login failure, aborting" << endl;
+        error (ERR_COULD_NOT_LOGIN, m_host);
         return false;
       }
       kdDebug(7102) << "Logged back in, reissuing command" << endl;
       // On success, try the command again
       return ftpSendCmd( cmd, maxretries - 1 );
-    } else if (cmd != "quit")
+    }
+    else if (cmd != "quit")
     {
+      // Do not send error message if we have not already logged on. This
+      // stops the error page from appearing when the login is incorrect
+      // and a retry dialog is displayed...
+      if (m_bLoggedOn)
       error( ERR_SERVER_TIMEOUT, m_host );
+
       return false;
     }
   }
