@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: date_object.h,v 1.18.2.1 2003/01/11 18:41:30 porten Exp $
+ *  $Id: date_object.h,v 1.18.2.2 2003/05/17 11:19:24 mueller Exp $
  */
 
 #ifndef _DATE_OBJECT_H_
@@ -125,6 +125,6 @@ namespace KJS {
   Value timeClip(const Value &t);
   int local_timeoffset();
 
-}; // namespace
+} // namespace
 
 #endif
