@@ -18,7 +18,7 @@
  *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  *  Boston, MA 02111-1307, USA.
  *
- *  $Id: function.h,v 1.28 2002/06/19 08:20:59 domi Exp $
+ *  $Id: function.h,v 1.28.2.1 2003/05/17 11:19:24 mueller Exp $
  */
 
 #ifndef _KJS_FUNCTION_H_
@@ -124,6 +124,6 @@ namespace KJS {
 
 
 
-}; // namespace
+} // namespace
 
 #endif
