@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: number_object.h,v 1.15 2002/06/19 08:21:00 domi Exp $
+ *  $Id: number_object.h,v 1.15.2.1 2003/05/17 11:19:25 mueller Exp $
  */
 
 #ifndef _NUMBER_OBJECT_H_
@@ -95,6 +95,6 @@ namespace KJS {
     Object construct(const List &);
   };
 
-}; // namespace
+} // namespace
 
 #endif
