@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: object_object.cpp,v 1.20 2002/01/28 13:03:05 porten Exp $
+ *  $Id: object_object.cpp,v 1.23 2002/11/16 09:42:40 porten Exp $
  */
 
 #include "value.h"
@@ -41,6 +41,12 @@ ObjectPrototypeImp::ObjectPrototypeImp(ExecState *exec,
   Value protect(this);
   put(exec,"toString", Object(new ObjectProtoFuncImp(exec,funcProto,ObjectProtoFuncImp::ToString, 0)), DontEnum);
   put(exec,"valueOf",  Object(new ObjectProtoFuncImp(exec,funcProto,ObjectProtoFuncImp::ValueOf,  0)), DontEnum);
+#ifndef KJS_PURE_ECMA // standard compliance location is the Global object
+  // see http://www.devguru.com/Technologies/ecmascript/quickref/object.html
+  put(exec, "eval",
+      Object(new GlobalFuncImp(exec, funcProto,GlobalFuncImp::Eval, 1)),
+      DontEnum);
+#endif
 }
 
 
