@@ -17,7 +17,7 @@
  *  License along with this library; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  $Id: string_object.h,v 1.18 2002/06/19 08:21:00 domi Exp $
+ *  $Id: string_object.h,v 1.18.2.1 2003/05/17 11:19:25 mueller Exp $
  */
 
 #ifndef _STRING_OBJECT_H_
@@ -106,7 +106,7 @@ namespace KJS {
     virtual Value call(ExecState *exec, Object &thisObj, const List &args);
   };
 
-}; // namespace
+} // namespace
 
 #endif
 
