@@ -35,6 +35,7 @@
 #include <kdebug.h>
 #include <kxmlguifactory.h>
 #include <klocale.h>
+#include <kconfig.h>
 
 using namespace KParts;
 
@@ -44,6 +45,7 @@ public:
     PluginPrivate() : m_parentInstance( 0 ) {}
 
     const KInstance *m_parentInstance;
+    QString m_library; // filename of the library
 };
 
 Plugin::Plugin( QObject* parent, const char* name )
@@ -55,8 +57,6 @@ Plugin::Plugin( QObject* parent, const char* name )
 
 Plugin::~Plugin()
 {
-    if ( factory() )
-        factory()->removeClient( this );
     delete d;
 }
 
@@ -144,7 +144,7 @@ void Plugin::loadPlugins( QObject *parent, const QValueList<PluginInfo> &pluginI
    {
      QString library = (*pIt).m_document.documentElement().attribute( "library" );
 
-     if ( library.isEmpty() )
+     if ( library.isEmpty() || hasPlugin( parent, library ) )
        continue;
 
      Plugin *plugin = loadPlugin( parent, QFile::encodeName(library) );
@@ -154,6 +154,7 @@ void Plugin::loadPlugins( QObject *parent, const QValueList<PluginInfo> &pluginI
        plugin->d->m_parentInstance = instance;
        plugin->setXMLFile( (*pIt).m_relXMLFileName, false, false );
        plugin->setDOMDocument( (*pIt).m_document );
+
      }
    }
 
@@ -161,13 +162,17 @@ void Plugin::loadPlugins( QObject *parent, const QValueList<PluginInfo> &pluginI
 
 void Plugin::loadPlugins( QObject *parent, const QValueList<PluginInfo> &pluginInfos )
 {
-   loadPlugins(parent, pluginInfos, 0); 
+   loadPlugins(parent, pluginInfos, 0);
 }
 
 // static
 Plugin* Plugin::loadPlugin( QObject * parent, const char* libname )
 {
-    return ComponentFactory::createInstanceFromLibrary<Plugin>( libname, parent, libname );
+    Plugin* plugin = ComponentFactory::createInstanceFromLibrary<Plugin>( libname, parent, libname );
+    if ( !plugin )
+        return 0L;
+    plugin->d->m_library = libname;
+    return plugin;
 }
 
 QPtrList<KParts::Plugin> Plugin::pluginObjects( QObject *parent )
@@ -180,10 +185,9 @@ QPtrList<KParts::Plugin> Plugin::pluginObjects( QObject *parent )
   QObjectList *plugins = parent->queryList( "KParts::Plugin", 0, false, false );
 
   QObjectListIt it( *plugins );
-  while( it.current() )
+  for ( ; it.current() ; ++it )
   {
     objects.append( static_cast<Plugin *>( it.current() ) );
-    ++it;
   }
 
   delete plugins;
@@ -191,11 +195,89 @@ QPtrList<KParts::Plugin> Plugin::pluginObjects( QObject *parent )
   return objects;
 }
 
+bool Plugin::hasPlugin( QObject* parent, const QString& library )
+{
+  QObjectList *plugins = parent->queryList( "KParts::Plugin", 0, false, false );
+  QObjectListIt it( *plugins );
+  for ( ; it.current() ; ++it )
+  {
+      if ( static_cast<Plugin *>( it.current() )->d->m_library == library )
+      {
+          delete plugins;
+          return true;
+      }
+  }
+  delete plugins;
+  return false;
+}
+
 void Plugin::setInstance( KInstance *instance )
 {
     KGlobal::locale()->insertCatalogue( instance->instanceName() );
     KXMLGUIClient::setInstance( instance );
 }
 
+void Plugin::loadPlugins( QObject *parent, KXMLGUIClient* parentGUIClient, KInstance* instance, bool enableNewPluginsByDefault )
+{
+    KConfigGroup cfgGroup( instance->config(), "KParts Plugins" );
+    QValueList<PluginInfo> plugins = pluginInfos( instance );
+    QValueList<PluginInfo>::ConstIterator pIt = plugins.begin();
+    QValueList<PluginInfo>::ConstIterator pEnd = plugins.end();
+    for (; pIt != pEnd; ++pIt )
+    {
+        QDomElement docElem = (*pIt).m_document.documentElement();
+        QString library = docElem.attribute( "library" );
+
+        if ( library.isEmpty() )
+            continue;
+
+        // Check configuration
+        QString name = docElem.attribute( "name" );
+        bool pluginEnabled = cfgGroup.readBoolEntry( name + "Enabled", enableNewPluginsByDefault );
+
+        // search through already present plugins
+        QObjectList *pluginList = parent->queryList( "KParts::Plugin", 0, false, false );
+        QObjectListIt it( *pluginList );
+        bool pluginFound = false;
+        for ( ; it.current() ; ++it )
+        {
+            Plugin * plugin = static_cast<Plugin *>( it.current() );
+            if( plugin->d->m_library == library )
+            {
+                // delete and unload disabled plugins
+                if( !pluginEnabled )
+                {
+                    kdDebug( 1000 ) << "remove plugin " << name << endl;
+                    KXMLGUIFactory * factory = plugin->factory();
+                    if( factory )
+                        factory->removeClient( plugin );
+                    delete plugin;
+                }
+
+                pluginFound = true;
+                break;
+            }
+        }
+        delete pluginList;
+
+        // if the plugin is already loaded or if it's disabled in the
+        // configuration do nothing
+        if( pluginFound || !pluginEnabled )
+            continue;
+
+        kdDebug( 1000 ) << "load plugin " << name << endl;
+        Plugin *plugin = loadPlugin( parent, QFile::encodeName(library) );
+
+        if ( plugin )
+        {
+            plugin->d->m_parentInstance = instance;
+            plugin->setXMLFile( (*pIt).m_relXMLFileName, false, false );
+            plugin->setDOMDocument( (*pIt).m_document );
+            parentGUIClient->insertChildClient( plugin );
+        }
+    }
+}
+
+// vim:sw=4:et:sts=4
 
 #include "plugin.moc"
