@@ -13,7 +13,7 @@ class NotepadFactory : public KLibFactory
 public:
     NotepadFactory();
     virtual ~NotepadFactory();
-    virtual QObject* create( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
+    virtual QObject* createObject( QObject* parent = 0, const char* name = 0, const char* classname = "QObject", const QStringList &args = QStringList() );
 
     static KInstance* instance();
 
