@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: ksconfig.cpp,v 1.70.2.2 2003/04/25 08:38:42 livne Exp $
+// $Id: ksconfig.cpp,v 1.70.2.3 2003/09/05 10:46:36 livne Exp $
 
 #include <qcheckbox.h>
 #include <qcombobox.h>
@@ -131,6 +131,7 @@ KSpellConfig::KSpellConfig( QWidget *parent, const char *name,
   encodingcombo->insertItem ("KOI8-R");
   encodingcombo->insertItem ("KOI8-U");
   encodingcombo->insertItem ("CP1251");
+  encodingcombo->insertItem ("CP1255");
 
   connect (encodingcombo, SIGNAL (activated(int)), this,
 	   SLOT (sChangeEncoding(int)));
@@ -226,7 +227,7 @@ KSpellConfig::sChangeClient (int i)
       langfnames.clear();
       dictcombo->clear();
       dictcombo->insertItem(i18n("Hebrew"));
-      sChangeEncoding(KS_E_LATIN8);
+      sChangeEncoding(KS_E_CP1255);
     }
     else
       getAvailDictsAspell();
