@@ -17,7 +17,7 @@
    Boston, MA 02111-1307, USA.
 */
 
-// $Id: kspell.cpp,v 1.97.2.2 2003/04/25 08:38:42 livne Exp $
+// $Id: kspell.cpp,v 1.97.2.3 2003/09/05 10:46:37 livne Exp $
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -152,6 +152,9 @@ KSpell::KSpell (QWidget *_parent, const QString &_caption,
   case KS_E_CP1251:
       codec = QTextCodec::codecForName("CP1251");
       break;
+  case KS_E_CP1255:
+      codec = QTextCodec::codecForName("CP1255");
+      break;
   default:
      break;
   }
