@@ -1,7 +1,7 @@
 /*
- * $Id: highcolor.cpp,v 1.34.2.2 2002/07/05 16:32:35 gallium Exp $
+ * $Id: highcolor.cpp,v 1.46 2002/11/17 05:46:29 gallium Exp $
  *
- * KDE3 HighColor Style (version 0.99)
+ * KDE3 HighColor Style (version 1.0)
  * Copyright (C) 2001-2002 Karol Szwed      <gallium@kde.org>
  *           (C) 2001-2002 Fredrik Hglund  <fredrik@kde.org> 
  *
@@ -94,6 +94,7 @@ static const int itemHMargin     = 3;
 static const int itemVMargin     = 0;
 static const int arrowHMargin    = 6;
 static const int rightBorder     = 12;
+static const char* kdeToolbarWidget = "kde toolbar widget";
 
 // ---------------------------------------------------------------------------
 
@@ -194,6 +195,9 @@ void HighColorStyle::polish(QWidget* widget)
 		widget->setBackgroundMode(QWidget::NoBackground);
 	} else if (type == HighColor && widget->inherits("QToolBarExtensionWidget")) {
 		widget->installEventFilter(this);
+	} else if ( !qstrcmp( widget->name(), kdeToolbarWidget) ) {
+		widget->setBackgroundMode( NoBackground );	// We paint the whole background.
+		widget->installEventFilter(this);
 	}
 
 	KStyle::polish( widget );
@@ -209,6 +213,9 @@ void HighColorStyle::unPolish(QWidget* widget)
 		widget->setBackgroundMode(QWidget::PaletteBackground);
 	} else if (type == HighColor && widget->inherits("QToolBarExtensionWidget")) {
 		widget->removeEventFilter(this);
+	} else if ( !qstrcmp( widget->name(), kdeToolbarWidget) ) {
+		widget->removeEventFilter(this);
+		widget->setBackgroundMode( PaletteBackground );
 	}
 
 	KStyle::unPolish( widget );
@@ -770,8 +777,10 @@ void HighColorStyle::drawPrimitive( PrimitiveElement pe,
 		case PE_PanelDockWindow: {		// Toolbar
 			int x2 = r.x()+r.width()-1;
 			int y2 = r.y()+r.height()-1;
+			int lw = opt.isDefault() ? pixelMetric(PM_DefaultFrameWidth)
+				: opt.lineWidth();
 			
-			if (opt.lineWidth())
+			if (lw)
 			{
 				p->setPen(cg.light());
 				p->drawLine(r.x(), r.y(), x2-1,  r.y());
@@ -781,16 +790,13 @@ void HighColorStyle::drawPrimitive( PrimitiveElement pe,
 				p->drawLine(x2, r.y(), x2, y2);
 
 				// ### Qt should specify Style_Horizontal where appropriate
-				renderGradient( p, QRect(r.x()+1, r.y()+1, x2-1, y2-1),
-					cg.button(), (r.width() < r.height()) &&
-								 (pe != PE_PanelMenuBar) );
+				renderGradient( p, QRect(r.x()+1, r.y()+1, r.width()-2, r.height()-2),
+								cg.button(), 
+								(r.width() < r.height()) && (pe != PE_PanelMenuBar) );
 			}
 			else
-			{
-				renderGradient( p, QRect(r.x(), r.y(), x2, y2),
-					cg.button(), (r.width() < r.height()) &&
-								 (pe != PE_PanelMenuBar) );
-			}
+				renderGradient( p, r, cg.button(), 
+								(r.width() < r.height()) && (pe != PE_PanelMenuBar) );
 
 			break;
 		}
@@ -1141,7 +1147,14 @@ void HighColorStyle::drawControl( ControlElement element,
 					state = QIconSet::On;
 
 				QPixmap pixmap = button->iconSet()->pixmap( QIconSet::Small, mode, state );
-				p->drawPixmap( x + 4, y + h / 2 - pixmap.height() / 2, pixmap );
+
+				// Center the iconset if there's no text or pixmap
+				if (button->text().isEmpty() && !button->pixmap())
+					p->drawPixmap( x + (w - pixmap.width())  / 2, 
+								   y + (h - pixmap.height()) / 2, pixmap );
+				else
+					p->drawPixmap( x + 4, y + (h - pixmap.height()) / 2, pixmap );
+
 				int  pw = pixmap.width();
 				x += pw + 4;
 				w -= pw + 4;
@@ -1158,14 +1171,14 @@ void HighColorStyle::drawControl( ControlElement element,
 				if (button->isEnabled()) // Don't draw double-shadow when disabled
 					for(i=0; i<2; i++)
 						drawItem( p, QRect(x+i+1, y+1, w, h), AlignCenter | ShowPrefix, 
-								button->colorGroup(), button->isEnabled(), button->pixmap(),
+								button->colorGroup(), button->isEnabled(), NULL,
 								button->text(), -1,	
 								active ? &button->colorGroup().dark() : &button->colorGroup().mid() );
 
 				// Normal Text
 				for(i=0; i<2; i++)
 					drawItem( p, QRect(x+i, y, w, h), AlignCenter | ShowPrefix, 
-							button->colorGroup(), button->isEnabled(), button->pixmap(),
+							button->colorGroup(), button->isEnabled(), i == 0 ? button->pixmap() : NULL,
 							button->text(), -1,
 							active ? &button->colorGroup().light() : &button->colorGroup().buttonText() );
 			} else
@@ -1182,6 +1195,16 @@ void HighColorStyle::drawControl( ControlElement element,
 		}
 
 
+#if (QT_VERSION-0 >= 0x030100)
+		// MENUBAR BACKGROUND
+		// -------------------------------------------------------------------
+		case CE_MenuBarEmptyArea: // will be CE_MenuBarEmptyArea in Qt3.1b2
+		{
+			renderGradient(p, r, cg.button(), false);
+			break;
+		}
+#endif
+
 		// MENUBAR ITEM (sunken panel on mouse over)
 		// -------------------------------------------------------------------
 		case CE_MenuBarItem:
@@ -1868,6 +1891,38 @@ bool HighColorStyle::eventFilter( QObject *object, QEvent *event )
 			hoverWidget = 0L;
 			button->repaint( false );
 		}
+	} else if ( object->parent() && !qstrcmp( object->name(), kdeToolbarWidget ) )
+	{
+		// Draw a gradient background for custom widgets in the toolbar
+		// that have specified a "kde toolbar widget" name.
+
+		if (event->type() == QEvent::Paint ) {
+			// Find the top-level toolbar of this widget, since it may be nested in other
+			// widgets that are on the toolbar.
+			QWidget *widget = static_cast<QWidget*>(object);
+			QWidget *parent = static_cast<QWidget*>(object->parent());
+			int x_offset = widget->x(), y_offset = widget->y();
+			while (parent && parent->parent() && !qstrcmp( parent->name(), kdeToolbarWidget ) )
+			{
+				x_offset += parent->x();
+				y_offset += parent->y();
+				parent = static_cast<QWidget*>(parent->parent());
+			}
+
+			QRect r  = widget->rect();
+			QRect pr = parent->rect();
+			bool horiz_grad = pr.width() < pr.height();
+
+			// Check if the parent is a QToolbar, and use its orientation, else guess.
+			QToolBar* tb = dynamic_cast<QToolBar*>(parent);
+			if (tb) horiz_grad = tb->orientation() == Qt::Vertical;
+
+			QPainter p( widget );
+			renderGradient(&p, r, parent->colorGroup().button(), horiz_grad,
+					x_offset, y_offset, pr.width(), pr.height());
+
+			return false;	// Now draw the contents
+		}
 	} else if ( object->parent() &&
 			(toolbar = dynamic_cast<QToolBar*>(object->parent())) )
 	{
