@@ -20,7 +20,7 @@
     the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
     Boston, MA 02111-1307, USA.
 
-    $Id: deviceman.cc,v 1.48.2.2 2003/02/27 17:05:18 adrian Exp $
+    $Id: deviceman.cc,v 1.48.2.3 2003/06/29 21:43:02 deller Exp $
 
     Send comments and bug fixes to Antonio Larrosa <larrosa@kde.org>
 
@@ -114,7 +114,7 @@ DeviceManager::DeviceManager(int def)
 
     config->setGroup("Configuration");
     default_dev=config->readNumEntry("midiDevice",0);
-    QString mapurl(config->readEntry("mapFilename",""));
+    QString mapurl(config->readPathEntry("mapFilename"));
     if ((config->readBoolEntry("useMidiMapper", false))&&(!mapurl.isEmpty()))
     {
       mapper_tmp = new MidiMapper( mapurl.mid(mapurl.find(":")+1 ).local8Bit() );
